(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   1090979,      18464]
NotebookOptionsPosition[   1089498,      18415]
NotebookOutlinePosition[   1090031,      18436]
CellTagsIndexPosition[   1089988,      18433]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
MAP-Kinase Oscillations in Solution
Under continuous stimuli - Mass Action Kinetics\
\>", "Subtitle"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"<<", "xlr8r.m"}]], "Input"],

Cell[BoxData["\<\"xlr8r 0.60 (15-Oct-2007) loaded 15-October-2007 \
13:47:48.408735 using Mathematica 6.0 for Mac OS X x86 (32-bit) (June 19, \
2007)\"\>"], "Print",
 CellChangeTimes->{3.4014700684111233`*^9}]
}, Open  ]],

Cell[TextData[{
 "xCellerator Implementation\nCreated: 12-Aug-2005 BES\nRevised: 15 Oct 2007 \
BES - verify under ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 6.0\n"
}], "Text",
 CellChangeTimes->{{3.401470088831353*^9, 3.401470096830017*^9}}],

Cell[TextData[{
 StyleBox["This notebook has two models:\nModel (1) is purely mass action. It \
assumes that Kpp inhibits the activity of the KKK-S complex (S is the input \
signal)\n\nModel (2) is mass action except for one rate constant (",
  FontSize->16],
 Cell[BoxData[
  OverscriptBox[
   RowBox[{"KKK", "\[RightArrowLeftArrow]", "KKKp"}], "S"]],
  FontSize->16],
 StyleBox[") which use the standard competitive inhibition hill function: it \
assumes that S has two binding sites, one for KKK and the other for Kpp, but \
is only active if Kpp is not bound.\n\nIt is broadly based on Kholodenko's \
model but uses only Mass Action Kinetics and does not use any Michaelis \
Approximations",
  FontSize->16],
 "\n"
}], "Text"],

Cell["Model 1", "Subtitle"],

Cell["Rate Constants & Initial Conditions", "Section"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"model1RateConstants", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a0", "\[Rule]", " ", "1"}], ",", 
     RowBox[{"d0", "\[Rule]", " ", "1"}], ",", 
     RowBox[{"a1", "\[Rule]", "1"}], " ", ",", " ", 
     RowBox[{"d1", "\[Rule]", "7.5"}], ",", "  ", 
     RowBox[{"k1", "\[Rule]", "2.5"}], "  ", ",", " ", 
     RowBox[{"a3", "\[Rule]", " ", "1"}], ",", " ", 
     RowBox[{"d3", "\[Rule]", " ", "10"}], " ", ",", " ", 
     RowBox[{"k3", "\[Rule]", "0.025"}], " ", ",", " ", "\[IndentingNewLine]",
      
     RowBox[{"a4", "\[Rule]", " ", "1"}], ",", " ", 
     RowBox[{"d4", "\[Rule]", "1"}], ",", " ", 
     RowBox[{"k4", "\[Rule]", "1"}], ",", " ", 
     RowBox[{"a5", "\[Rule]", " ", "1"}], ",", " ", 
     RowBox[{"d5", "\[Rule]", " ", "1"}], ",", " ", 
     RowBox[{"k5", "\[Rule]", " ", "1"}], ",", 
     RowBox[{"a6", "\[Rule]", " ", "1"}], ",", " ", 
     RowBox[{"d6", "\[Rule]", "  ", "1"}], ",", " ", 
     RowBox[{"k6", "\[Rule]", " ", "1"}], ",", " ", 
     RowBox[{"a7", "\[Rule]", " ", "1"}], ",", " ", 
     RowBox[{"d7", "\[Rule]", " ", "1"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"model1InitialConditions", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"KKK", "\[Rule]", " ", "100"}], ",", 
     RowBox[{"KKKp", "\[Rule]", " ", "0"}], ",", " ", 
     RowBox[{"KK", "\[Rule]", " ", "300"}], ",", " ", 
     RowBox[{"KKp", "\[Rule]", " ", "0"}], ",", " ", 
     RowBox[{"KKpp", "\[Rule]", " ", "0"}], ",", " ", 
     RowBox[{"MAPK", "\[Rule]", " ", "300"}], ",", " ", 
     RowBox[{"Kp", "\[Rule]", " ", "0"}], ",", " ", 
     RowBox[{"Kpp", "\[Rule]", " ", "0"}], ",", 
     RowBox[{"S", "\[Rule]", " ", "1"}], ",", " ", 
     RowBox[{"Kph", "\[Rule]", " ", "1"}], ",", " ", 
     RowBox[{"KKph", "\[Rule]", " ", "1"}], ",", " ", 
     RowBox[{"KKKph", "\[Rule]", " ", "10"}]}], "}"}]}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   StyleBox[
    RowBox[{
    "need", " ", "to", " ", "make", " ", "sure", " ", "compounds", " ", "are",
      " ", "defined", " ", "consistently"}],
    FontColor->RGBColor[1, 0, 0]], " ", "*)"}], " ", "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"model1", "=", 
    RowBox[{"{", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      StyleBox[
       RowBox[{"Maintain", " ", "a", " ", "sustained", " ", "signal", " ", 
        RowBox[{"(", "S", ")"}]}],
       FontColor->RGBColor[1, 0, 0]], " ", "*)"}], " ", "\[IndentingNewLine]",
      "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[EmptySet]", "\[RightArrowLeftArrow]", "S"}], ",", " ", 
        "a0", ",", "d0"}], "}"}], ",", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       StyleBox[
        RowBox[{"phosphorylation", " ", "reactions"}],
        FontColor->RGBColor[1, 0, 0]], " ", "*)"}], " ", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        OverscriptBox[
         RowBox[{"KKK", "\[RightArrowLeftArrow]", "KKKp"}], "S"], ",", 
        RowBox[{"{", 
         RowBox[{"a1", ",", "d1", ",", "k1"}], "}"}]}], "}"}], ",", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        OverscriptBox[
         RowBox[{"KK", "\[RightArrowLeftArrow]", "KKp"}], "KKKp"], ",", 
        RowBox[{"{", 
         RowBox[{"a3", ",", "d3", ",", "k3"}], "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        OverscriptBox[
         RowBox[{"KKp", "\[RightArrowLeftArrow]", "KKpp"}], "KKKp"], ",", 
        RowBox[{"{", 
         RowBox[{"a3", ",", "d3", ",", "k3"}], "}"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        OverscriptBox[
         RowBox[{"MAPK", "\[RightArrowLeftArrow]", "Kp"}], "KKpp"], ",", 
        RowBox[{"{", 
         RowBox[{"a3", ",", "d3", ",", "k3"}], "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        OverscriptBox[
         RowBox[{"Kp", "\[RightArrowLeftArrow]", "Kpp"}], "KKpp"], ",", 
        RowBox[{"{", 
         RowBox[{"a3", ",", "d3", ",", "k3"}], "}"}]}], "}"}], ",", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       StyleBox[
        RowBox[{
        "add", " ", "in", " ", "some", " ", "competitive", " ", "inhibition", 
         " ", "for", " ", 
         RowBox[{"Bind", "[", 
          RowBox[{"KKK", ",", "S"}], "]"}], " ", "produced", " ", "by", " ", 
         "Kpp"}],
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[" ",
        FontColor->RGBColor[1, 0, 0]], "*)"}], " ", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Bind", "[", 
           RowBox[{"KKK", ",", "S"}], "]"}], "+", "Kpp"}], 
         "\[RightArrowLeftArrow]", "KKK$S$Kpp"}], ",", " ", "a7", ",", " ", 
        "d7"}], "}"}], ",", "  ", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       StyleBox[
        RowBox[{"dephosphorylation", " ", "reactions"}],
        FontColor->RGBColor[1, 0, 0]], " ", "*)"}], " ", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        OverscriptBox[
         RowBox[{"KKKp", "\[RightArrowLeftArrow]", "KKK"}], "KKKph"], ",", 
        " ", 
        RowBox[{"{", 
         RowBox[{"a4", ",", "d4", ",", "k4"}], "}"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        OverscriptBox[
         RowBox[{"KKp", "\[RightArrowLeftArrow]", "KK"}], "KKph"], ",", " ", 
        RowBox[{"{", 
         RowBox[{"a5", ",", "d5", ",", "k5"}], "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        OverscriptBox[
         RowBox[{"KKpp", "\[RightArrowLeftArrow]", "KKp"}], "KKph"], ",", " ",
         
        RowBox[{"{", 
         RowBox[{"a5", ",", "d5", ",", "k5"}], "}"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        OverscriptBox[
         RowBox[{"Kpp", "\[RightArrowLeftArrow]", "Kp"}], "Kph"], ",", 
        RowBox[{"{", 
         RowBox[{"a6", ",", "d6", ",", "k6"}], "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        OverscriptBox[
         RowBox[{"Kp", "\[RightArrowLeftArrow]", "MAPK"}], "Kph"], ",", " ", 
        RowBox[{"{", 
         RowBox[{"a6", ",", "d6", ",", "k6"}], "}"}]}], "}"}]}], 
     "\[IndentingNewLine]", "\[IndentingNewLine]", "}"}]}], ";"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sim", "=", 
   RowBox[{"run", "[", 
    RowBox[{"model1", ",", "\[IndentingNewLine]", 
     RowBox[{"initialConditions", "\[Rule]", "model1InitialConditions"}], ",",
      "\[IndentingNewLine]", 
     RowBox[{"rates", "\[Rule]", " ", "model1RateConstants"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"timeSpan", "\[Rule]", "2500"}], ",", 
     RowBox[{"MaxSteps", "\[Rule]", "25000"}], ",", 
     RowBox[{"gridPlotVariables", "\[Rule]", " ", "All"}], ",", " ", 
     RowBox[{"plotColumns", "\[Rule]", " ", "6"}], ",", " ", 
     RowBox[{"ImageSize", "\[Rule]", " ", "900"}], ",", " ", 
     RowBox[{"plot", "\[Rule]", " ", "True"}], ",", " ", 
     RowBox[{"plotVariables", "\[Rule]", " ", "None"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Warning: \"\>",
    StripOnInput->False,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]], "\[InvisibleSpace]", 
   StyleBox["\<\"Initial conditions are missing (and assumed to be zero) for \
the following variables: \"\>",
    StripOnInput->False,
    FontWeight->"Bold",
    FontColor->GrayLevel[0]], "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"{", 
     RowBox[{"KKK$S$Kpp", ",", 
      RowBox[{"Bind", "[", 
       RowBox[{"KK", ",", "KKKp"}], "]"}], ",", 
      RowBox[{"Bind", "[", 
       RowBox[{"KKK", ",", "S"}], "]"}], ",", 
      RowBox[{"Bind", "[", 
       RowBox[{"KKKp", ",", "KKKph"}], "]"}], ",", 
      RowBox[{"Bind", "[", 
       RowBox[{"KKKp", ",", "KKp"}], "]"}], ",", 
      RowBox[{"Bind", "[", 
       RowBox[{"KKp", ",", "KKph"}], "]"}], ",", 
      RowBox[{"Bind", "[", 
       RowBox[{"KKph", ",", "KKpp"}], "]"}], ",", 
      RowBox[{"Bind", "[", 
       RowBox[{"KKpp", ",", "Kp"}], "]"}], ",", 
      RowBox[{"Bind", "[", 
       RowBox[{"KKpp", ",", "MAPK"}], "]"}], ",", 
      RowBox[{"Bind", "[", 
       RowBox[{"Kp", ",", "Kph"}], "]"}], ",", 
      RowBox[{"Bind", "[", 
       RowBox[{"Kph", ",", "Kpp"}], "]"}]}], "}"}],
    StripOnInput->False,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
   Style["Warning: ", FontColor -> RGBColor[1, 0, 0], FontWeight -> "Bold"], 
   Style["Initial conditions are missing (and assumed to be zero) for the \
following variables: ", FontColor -> GrayLevel[0], FontWeight -> "Bold"], 
   Style[{$CellContext`KKK$S$Kpp, 
     xlr8r`Bind[$CellContext`KK, $CellContext`KKKp], 
     xlr8r`Bind[$CellContext`KKK, $CellContext`S], 
     xlr8r`Bind[$CellContext`KKKp, $CellContext`KKKph], 
     xlr8r`Bind[$CellContext`KKKp, $CellContext`KKp], 
     xlr8r`Bind[$CellContext`KKp, $CellContext`KKph], 
     xlr8r`Bind[$CellContext`KKph, $CellContext`KKpp], 
     xlr8r`Bind[$CellContext`KKpp, $CellContext`Kp], 
     xlr8r`Bind[$CellContext`KKpp, $CellContext`MAPK], 
     xlr8r`Bind[$CellContext`Kp, $CellContext`Kph], 
     xlr8r`Bind[$CellContext`Kph, $CellContext`Kpp]}, FontColor -> 
    RGBColor[0, 0, 1], FontWeight -> "Bold"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.40147006862444*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[1, 23], 0.043478260869565216`]], LineBox[CompressedData["
1:eJwV2Hc81V8YB3CKppCQUYqWZKVSRvVJpFTSJKF7rx132CNlZu9xLzKuRIoi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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 150.},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox["KK", TraditionalForm],
       PlotRange->{{0, 2500}, {132.6599690076124, 299.9999999980185}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {488.57142857142856`, -300.36451853244887`}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[2, 23], 0.08695652173913043]], LineBox[CompressedData["
1:eJwVl3c8le8bxymVSlIZTeGcg2Svs1QfUalkNIgIiaJB9qrsY4bCsc6hUGaZ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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 10.},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox["KKK", TraditionalForm],
       PlotRange->{{0, 2500}, {9.553875310462972, 45.59185367519107}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {1465.7142857142856`, -300.36451853244887`}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[3, 23], 0.13043478260869565`]], LineBox[CompressedData["
1:eJwVl3k8lF8bxq0zY5IIpZSQpWwJFVrObY2SJWulrIns+1p2YyeMdcauKGRJ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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox["KKKp", TraditionalForm],
       PlotRange->{{0, 2500}, {0., 3.328436768754554}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {2442.857142857143, -300.36451853244887`}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[4, 23], 0.17391304347826086`]], LineBox[CompressedData["
1:eJwV13lYjF8bB3ApIjXzTJu2GUmkjahoQd8ISYr2iEoJ0Z4kRfu07zOt02oJ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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 4.},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox["KKKph", TraditionalForm],
       PlotRange->{{0, 2500}, {3.753448932601218, 9.999999999933934}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {3420., -300.36451853244887`}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[5, 23], 0.21739130434782608`]], LineBox[CompressedData["
1:eJwt13c8le//B3AkDVllhxAySygi7pfIHufYQllJVGQlIfPY27GPXSn5UGho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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox["KKK$S$Kpp", TraditionalForm],
       PlotRange->{{0, 2500}, {0., 70.94896322173425}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {4397.142857142857, -300.36451853244887`}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[6, 23], 0.2608695652173913]], LineBox[CompressedData["
1:eJwVmXc8le8fxhNpGHFwbNkrZO+4nHNESpFIhYhk7ySUvfc6RuGgJFEikRJS
KqWlb0NEKHuU0a7f8/vL6/167vv+rOtzj0PiqP++Y2vXrFljz7xmzf//Vm8z
HHnTscm4jHusbjXuheEzTnsUpEwae1ruXyznzzA+sKem80jKd+OoX5tVuTbV
G1dZ5Ab8dF+L2TU3zPnsOo2F/Z6vMU3ZgENuWk98BPuMc3M4c7IucyIvx+GV
27PXxgmHqrnm3ElQe8S780/UiLGJz317Uhgf7mnRVs/RPxv/OT3O0EkRQGva
nW+z1+aMW7OYpxxKhJHlnD+SPP3VOKRCUi32shgaGw/UcUV9My56x7ht80Ec
woJ72pNzfxuHHm1w/uwuiULVPIUJTibsn+lgObUghe/LDpMxbCxQD3lWwxYm
g22vy1xF9dZjPmF+UTVFHr0RrXGR7Jx4wvk3v5tbEbeMmGbFXnKhtpBDz65k
KzhWoitbakg4dkkpJuKyCkYt45jWeJLh5968YcxdHfw5sWc/T4nic8pSkXKK
LgZnnjM96ZeB7Z5f06GWegh1zeR2OyeLeyTm7Z3c+sgyoFb/cZZD5VnSx30l
BlAbvXPi2wd5ONarKYRdNkKE5uLlM01b4TXZ4vDRnYLUwb0CHoGqqOy9tY71
EQX2k636dzpU8a6u44riVirIYVlSWznUYB74YE3IAhUS8n33jlxQg+zP1+dZ
w0xBrfw2Vf9YHaNsq7NbU8zxkPu+QsZXTRw50LyQs2SOzp0eYql6WhisDPn6
zXEnMLNg2xClhdd6S9+61S3Q5Ex5HrdRG73HF9c6DO7Chzt5TPk8OmjsnhZI
37YXm+wtR8qY9bBtc63w1+K96Ezw0PQ10oNdveZmpbVWYLt4fyk9TA/935e4
c32s4Nx0Ye2jaT30ZQXxO5lYQ3ekk9n7gT662v0lV6f3gZz8hfH1qCGiXZ9J
KYjbYOuHVotbeYYw2rhNxsHWBmrmW6S+dhvi1v55ubsdNqgKehjRILkdzTM+
ypn5+8EpHW9a/G47Lgl66coa2SEA5P/2qxjDo+OR3sFgO4RFXyPV2RlD9piC
QXqNHcJp3OFJZ4xR1TC5/SvpAG79Q/mzJ8YoNTtOvTNxAOfzjLeNqQE5J9z2
2OUcxKHoWRmZO0A4/Vzf2u6DsDk9G1XeB7i1vNp9dfkgenT782YGAe0ftF0b
7A/hSJZ0ys+fwECkjHmb2GFsKQzu/6tpAsn4zyZidQ5I2P3l+SrDBGwXxLp6
hxxgWhsQeqveBMv37XBysyMEpqzGDrSZoGf9A6PnQY747SV3QrDfBN5pFw1i
9ZzwOvLvmkdrKbie66H1uecITM89spY6TEFpE+N67vcjKPXYdSj9GAVUr9ni
LXzOyCxuOPTSnwKlNGnBJzucMRL56sRqHAV/n+Tzy9Q6QzLC2OZiLQVVVid4
3wS4QIq/OmbmCwUCLtz761NccIV9x/kdPylID6zPi6t0AfWaPuLWUhGa+4mk
+soFy8PvFipIVJi/suVO0TkKb38ll0g1KmYPaHMa/D2KI/6xvkOeVGgO5Ofn
k13xtTK2yTKAitMOS0LzKq4wOuDmcz6UCk6XBrmKI64YrA/kZY2jQtVL0WR9
lyuueMXrMEqoCJtNfuD8zhUGc3e5LBhUdPlNWLZ9cUVgfRvH4AUq9gWfP+Qr
6QamvT3Umw1UhESKhfTHuUF6Xa+x030qbv+N/Kl0zg0rkvnv9vRSsS7mfXTi
dTfYxlxXUXhGBT2hKEPvkxs2zeY9O/uWitZM0sXyHcdg/F5A98w0FX8YrAPe
G91hdbVoxHkTDTukjjnfl3DH2MijKGZOGjIvdH8W03fHPhvLe7ncNIjXRi+9
8HJHjzV19qQADZSmn+y6T9zhaaHo6yJDQ6rWwbyccXds3iyz4CtPQ39Li+DM
b3eIfmn39thKg9vtENky5eOwzev+IadGQ+L9eWOWrOO4sWb67X8GNDw1s+xx
vHgcHVdzKu2MaODvvby7peM4vMUDa3pAQ81Tj4Nei8cRu1ed5YQpDYtWD4a7
N3jgxreX1U1mNOj1y7iLSnjg/kf/LaM7aeh9Mxr03NoDzSKP5TfvoYF0yOSH
gpcHpmREWTitaDg8WB4VF+sBs7GdFn+saZgdcUjXbvKAtALtUr0tDZzTry+c
4/XE736usoMOhP0d52NZt3nCyv2czBonIv6qwCMBOz3B+2/NpYIjNIQ6sAvS
znhC0HjaOvMoDVw3363UF3liZntG3xdXGmr5Lr7kb/JEqkP4F9oxGj48NUmf
mfDE7JjuQNtxGsK2bva0XeuF0V9SX4c8CH+TB007RLxw2iDc/osnDXXjlyQV
dLzgFv6f1ooXUS+Tk/9yrb3Ak+/cOOVNw0gpbfC3txdu2c6sPPWhIfwn9033
RC8UuY/JXfClob6pLkj/lhc0Ffq/SvsT87nC957/zwtO5JtvnxI84mOmxLno
hWLX0R1eAcT8R7wbwzZ543pj99FvBPPKjn76KO2NiOZs69BAGq7EXr27y9gb
N39M60wQbD4cWd580BvKYjv0LYJoGDWwiNwS4g1rtfjIcoIji/gPpmR6w6bC
THKCYPLKuNZSjTeSRLv2SATT0GDdSHLs9gb7n5vSewi2uBK10DPkDWe5ph5f
gsc3WT5R/e6NkaoKu2iCzxwXulRC8sHFg7tWEwgWuDeRwKLsg/qUkZ4zBDeK
Nx/1M/PBvlKnKS+Cd5+ONX7r4oN7z6lnLAj+/G6vCCXSB8835VwQJThaW/TH
ZboP3nzSiRon/BPKm/6P75oPzg6nKP7f/+sLLY1Rj33gvd+xx5LgPbsTsqY+
+SB/ISJwkYh/smafj80aX/i+JVkkERy7Tnxnu5AvPDWf+ZIIFj46JyOn5YvV
dft+5hD5vH6nbW3OXl8kPKpiZyV4j3Dy8E9PXyzPmnX5EfWYPGl72y3eF3I8
NzSf+BHrvZIsflrmi9bAF7FiBIuoLZ7QvekLab2lnmNEfW9ktO+r7CfsffEQ
qSTqP73Dnj10gx/0S5qP/ST0El8lMzUs6QfD/UMZZILF1izd37ndDxK1v7fJ
E/radzMjSjTID5/YRHcoEXqc5TvskJTuh4sdp2bE3Il+DZLX+1Lth4FlQd/1
hH7btnZ/vffeDzJmEa5thN73J2c/U1n1g83LnawJLjTMjzvWFXH5w6Eo+6Op
Mw2SZd+P+Zj64815l+JaRxpSuFTe8Vz1R3fiE6e19jS01k6EtD3wx23pdQJn
7Yj4aRVcLiP+EJuqeL+V6Mcqw03SbzYEICbmSIfWPhqYAk8fltYPgMhHr/zZ
XTTceefae+dcAC4v37P6up2G19UQIF0KQLDbEwOSIQ1zwaLux5oD0MFzce1W
fSJ/nG+Y2J8GgGFnZ2mmTUMExULv4L8AaHFnT2xVoUH3smrNkksgnqYK1deJ
0GAVxrG6wy8QEWbr0pyEaDhuOk0tCQ9Euylrz0ZiP6QPVw0jLxAPqpw8dvPQ
sMLDz595LxCXdn0bjt1I6DHyT4K8XBBYW5sKWpapUNrT6+o4GwQdW4GXO3qo
8En+MNj6Iwh9j/qMP92lou7uV1ve9cG4cKliLqKDCmUdYfPHEsHobq9eyGml
QkXcR0nvQDCiJKo6jtRSofaVY4X3bjD01zF6wtOpCFKS9At4Fkyc7/F7ipOp
aHTXnng8GIydPBJRV+OpUH/v9C72WzBu2i1U340kzrN7V9sXlUIw7C9Fj/Wh
QptunfikMAQhjzzZHCyI8/H5sX9yF0Jw4u1nr3lTKm5sCg+LawxB+p+a6JMm
VOhEVXrp94XgqbNWiq8uFboeS3tq1p5Agg6zwIQMFfr6Bfzxvidgd6dh+t9f
Cow/vK0xoIZiiiW02OQSBV7We+7bW4XisvAx04oqCvLvdX884RiKYpu+Gyul
FEzWXhFqOBmKPRdsqyNzKcg9GZ8uXRcKA4uBqTURFIxzqQZw8J3E4YD3J/7b
SUEyNUln+PNJyOjfY7L9YILGG79tfi+dhETo63D1NyYYVAgKEGQKQ3DAzA7m
5yZQ43K8ZCMcBp8tiY/OdJlgYFBd+OHeMHw05jIeqjKBcuiHvw2tYcgzWyOj
626ClzVaPbGpp1DHesY/7SPwQF+Ccod+CsYvirf6vwNuP2G/86PyFO5VfCw1
fwFUL441B9w6hc9VMyODncT9Szf3gtPsKXy5a1ydXg5IPJyP198TDtae7E8C
h4GAiYvUr9wRuBk1se8b3RibZYW6XIojMVvL0r6gsh1hc+9Sdk1HoXBKw5Z8
XwfObMHZ9atR2Hfhe0zeNR2c5018nMQUDV7rEQ7hMh2kq295OcURjQOWLMs7
T+rA0c96uF42Gg84zSu3Kurg76fmH1r2BLsY80rkagP/nVHZcSsalkO5zO3e
WrjfxFXkHhMD8XFnOyMLDagMc/iGJcXgpM3qf+H6GijaxEZJzYjBwXWdt+8r
asDLZd1sfXEMio05LyayaYBz80/jlWsxUA7WFr7epw57r7GJuNEYaDz+I9G8
Xx3T4jd0Kqix6HvMdvSrjxo4Mw+/eb8uDkHmk9FH47eBPWC5K5A9Dhyfk7+v
eGzDxn0Zdet54nD3pNd+huU2sJA7YjTE42BEmr6ly78NP0slldL04/CpWdMt
kHj3fK6fitb3j8NkSE/p4zfKuNN3UrH4bRx2Dl3eFGOkBF+O/NN2l+PR4cGR
1qKrAAn3bFKpZiIq7m2cOMEmDQHOaMoOg0Skb+AW3rMqBa4b/kELJomI7N1w
Uf2jFP6u2/vSZG8izl3qV5dokcLABY7cz56JeFH6RK3QVQr5n1K5VcuJ9bS4
wdQhCdZjCVzdG5PAtm8+rylaAn/YT8CHKwnJw9sSbXwlsHzdLYCPPwkXy28u
MB+SwCgL7flx6STc+D7cRteQQMf5tdnsxkm4Vbl/W/KEOMLGozbbhSRB08js
ZNs+ccy4hnNOfUjCx2fPjtf7icG+Rogr+FMSZF1047UsxXBvto37z0wSWov1
Xn7aKoZzJ37xcv9IgtP5V186iPfg7qRIYT2eZDiF3atxPi6KK7Vn5FPMkjEt
myCZ4CWCgC+xFIWGZHwivV5szxHCoJYUrelGMmaCyvY0nRCCeXi36fb2ZBgm
r2N6c1AI4swsO617k7GaPbB0SVIIL3gT9p4aT0b6odMvY24IQl03yeGRQAr+
rIkb5Z0QwMqZtFDPmBRi/xsbOuXDj56Xny/GJqWgVlWdd+YAP4pkKe/OZqSg
4SG7WhKVH/pPvxs8LU6BvqAZFcL8iBZ1Z9JoTMF+Ed47N56QwX4b6b9HU3Bi
1WrzLR0yPmw+1843lQKFmhzVDzJkXHX9Nq+ykIKwgLxzSrxk7GO7Yu3yKwUq
4+VOu77woeiQMH8PTyp4Y7zuZdfzQfrHSkUWLRXm83ItBip8WN1t3V9jkYry
+w+5eLfw4QGjjuWuVSqsbju28XPxwcvc9fiyQypaJ62XGV950VD4XOngiVRo
l3242XaTF4bal1skq1Px9vCL2g1WvOBMZZ0yqEvFz6c/C/KpvBgechGybUxF
+LlvRbt0eBGbIHA66Q5hTy6nX38LLx6+SqDMvk5F+nx+rugXHuwPdu5rXp+G
9tTj3QvneNB2+gCvDWcaDE2ZNA/m8kA8ec/hRd40UCVerywn8WDmnOGUomQa
Ts/O7esO5kFsj8A6hmEaGpS2drRZ8mDy+ebd26lpuPSvaN0NGg/2vGfNG9iZ
BpJMudeYAQ+EFpfF+Q4Q7HM4/JUiD64JvjBMDUzD+fgC8mY2HpClH8bJhaXh
jNedmyXMPIhU6ei9dyYNTfGq++x/k2BOrbf/l5ZGnA8HrT3nSbhieb78XG4a
imMXrt6eIIHX/uxnveI0fD/7c8nkI4m4r6aEhFSnoVvmttjoKxJ2nIy+xV2f
hidi+Pf7KQl1MSfXXm1KQ1x/zM2dj0g4ST+WPdWZhsg/841hd0jg7DSpc3qf
BsmHxzOVLpMQ0qu79OtjGgoEjnO/riZh4NU2/eLJNBhF8LhfqyShekr0Yf9K
GkInTib9KSGBfZl3c+DvNAzbbLPzKyQh6C+bHSdzOvZPn/nFlU/Cdp6fY+Zc
6bB2WXw5k0FCpegXxc/kdPCVum6STiNhg/xkYJxoOm6GTktlJpPgpz7cKi6d
juKAcCnFRBJeGb7+166YjvRUPo7vcSTom/XtOKyWjl3Xr336FkMCw/pexned
dJBzJJoUoklgdbj1qsAoHeVnjSMyzpDg494orGGajqyGRarUaRJeBlw6+nxX
OgoKeHhnIkjQjWBc8t2XjsZHMUvj4SSUJRQubjpIsPeWaS6CmbMzdWqOpOP7
2uF/fqdI8ChJOGPqng5L1Qfb/4WR8PR85P1RH8Kfuy/ruwjWvBrMHh2cjrUN
LIduEFxy08tGNDwdItJBu4cIXnPPpaQtOh22R49kaxPruT+1/3ggKR3u71jU
7xL85O1e+ZUMIn/5FdujCfvqYzv8c/PT0bA2vyOA8LdobvuNbWeJfDYX3s+L
JOHvN80/TyrSUbmV4jRFxOe2VonmVZOOMS2losAoEh6xS6Wtv5oO5mieWCUi
X/my/zFpNqfD4xPz9W+xJDgjKcz5VjoqtiUoLsSTsPWQ3kJ6VzpxX45cIiWR
sBo8c+zmg3RctR8UcU0hoSujdPBTXzq22VY0DxP1S7+414b0Kh1nre/2JWeS
IPm+Cd4j6VBQFr7tTNR/bvlYS+Fnwp/YTU1ZhD5aOQVU7s2m4/JnAZ8ZQj97
KZHCoj/SMR9g56tA6EvIQSV35790vDI6NMBG6O/ziZENoesyYMp8cb9wLQmR
l2irT7kz8DRv/m5XIwlm3as+v/gz0D7zb9i+hQTSUM2YnFgGFtt/O4reJqGG
i+NFtGIGzN5PvVHpISFYscOsXjUDjyJSmCIfk2BEC7zzTjsDrE5tk6vPSfjv
5H+X1anE/PdJ+0MHCX3lJEke2ZmBo76ZbBGjhJ4uE923NwMcNwc/1U+SsHa4
NHH8cAbOf2kPKlshQWWHuws9JAPvH5gzXeHmwY8jAm/vhmcgVmx+SlaQB/dO
9e5ZiM5A1jbFD0/FeXCoXsXQPCMD4/9WPepUeZDE+43880IGssvlr1Ts48E+
lUsZsnUZ0Bf2z6Ef5oGY+WEWm8YMPOysyb7lxoPrER1fLt/JgIh2YQj9JA9G
RpOeOL7JgH1mKVN+OQ8u/9ajpg5l4NO0+RRHLQ9CybM3b4xlIPGRp/TN6zzg
sLC6uHkxA2kGIsbne3mgf00gtmtDJsa/6d158Z0HeVGXdGT0M+FLEudqdOLF
173fuv9DJmYOhsdE+vJin7ipVaJZJsLC79jER/KCu2vEY2J/JqIaR6Qtz/Ii
a61AySX/TGhcy97w+D0v0hISfytfyAT7R2+9Fg8+TNu+Sv5wORO7+D24TkXw
wUJWki+rMRNJjI6xyEw+bHzQrrzYkYmcqIkHu5r5kLRhxalxIBPH9jpd2MxK
Rlyaa5c2VxY0VkbjI66TMXr4muUEOQvPnXcaJDwmg6L0712haBbCDVt9Xo+S
wdRX8vW7YhY8c/JuW5H4EcX5UuqWaRYuoLX8agg/InKQaByRhd+L9Yd8zQQw
4JJJWozJQtluoVcirgLQVx8sYyRnQcZgjl0oSgA/Xp5sYaJnwa0m0+1fiwBO
8l6d7G7Igndd0tEYZUEEF4ruMv+cBdn9QT+65Ij7AIvIpXezxPz2c48+mwlB
JFBovfdSFgKUnko4egjB9ULaxx1rspGtc48ftUJgj0ou9eTIho3781fTasJw
Uo/luyqXjW7Jw6tq1iJ46BFz75tiNoQkJTsqQkWgXh4dDJVs+K1LeOp5TgTr
2aNevNDMRuTXK/4sUyJo+BSRsWySjS8bOeL9E0WxtvjEOn2HbAhojRmHvxSD
z7OQ67FHsuEtEJbG+COG1+tCXB8fzQZvi/5tGYUtuBwU1OXgmY1b6hLH98Rs
wf7d/qejQrNx4Hv1CrewOKr/eazcy87GKqm6TeidOCzcHT7tvZ8NV2bL9ToR
kjgurafk/DAbWb7PhDQKJBE/yhcc8DgbOyIq9R2vSuKO07M1OS+yMSL/ltVw
XBJqBygiL4eIfNRxFcpaSUHAXN5m/2o26HGHlbpVpTGhsNxpL5cDOV3V/gw+
WbBMPl/vqZiDO+OfvAO0ZCFeXb/nlHIOCjZZD8fayuKQ5PHBYo0cdH8Pt9Kh
y+Kp0MC3AWNi/pHHbB8E5XCDrVPF0T4HI+pHakUU5RE/l3bOJSUHZxp+di76
KmImUXu+KT0Hp+NGt0/SFQn9fzRmzc7B9ThpM75ORYjbaI/V0nPgl9ljuJln
K263jigsV+Wg7enml5G3tmIlTqsl8U4OPm38prCJrAx3oeEXl5cIe0d3s04t
bMNOM/X1q465KGtpZ9vJpYGbGfqeAdJ5sG35ec7HTA+cf0puhcvlQaFiYO72
ET0c9fnFkaCYB9MamghrmB427brdWKyaB+WyocGYGj0c3mD0+65hHsSVj8WQ
N+rjT6xJFp9tHg6TrVwDH+rDJMy8uS0hD7tp+VtGthuCPlGz/n5yHswgd/Hm
fkNM22089CwtDyZv6rtjvQ2Rq9X7dywnD78EM6tHiwwx9nWXOUdZHnjXVha/
+GqIBN+974/cyIP/DeFBtarteHTUjmndRB7WeqhnU5eN4FEf72Q9nYctEoIN
FpuMwfq98VbpXB7qeZY8tMSNQcnYHKq9nIcEa6XS67uMcbvl4fRxpnykRolw
2VQYo4Hd4FWvcD78lbZm+EoBew54qvFvycevg1EeUcrAXEVhpqtkPg6H9uvE
6ACKOsvmv+XzcdZqynL/LqDKpb5dWTsfdC3XRq0ggH5jy8Vsq3xoSPN+fXEb
0GTawzJkk4/ifgGbt/eB/l2RLgoH8kHqHbLuewpwfXwrfNcxH+alfZ9iR4BU
ttzsJS9i/Xbma0LMJjjtzBJul5CPE1StqUWaCdw2Te0WacvHJvalC8ttJmge
XDZRbc9HwvEyB1Pifc16dY0OrTMfIXWdaxIfmKDGRkDCpycfyhJM3G/6TTB7
zmzl1st88J1Wd22dMcGJbdWlh2fyseeaCeOUAAU9TI25/vP5aDe9MvFIlAKB
V+1JcV/y0XeA3XSTFAVtYf8FXv6WD7Z7owcOK1Pwt4tlxy/mAmyf1k8yNqEg
cb/rfIlIAXIE5R3I7hS8kfUfu7KlABZ+G9S9vSiQ/xH+9q5kAWKiNhQ2+FHQ
W5p7d1q+ALlz67Q5TlKweaKLrq9VAANW/0nOJAqcb/al7dEtQHzqDbupVAoa
095FHzUogF3Uy5rrmRTsV/3ilWpSADGPLjkxOgVFp8SNBywLcOVRzeD28xRM
7VLSnLcqwD8DlVbGRQr0xXQV1u4vQF/hx7fLtRQM3t3Lo3ioAJ4e6qKB1ygQ
Z4+aOOVegJQLu+VutVMQ+CF1MMOzAK03ucoudVJwt4H+osKnAI7GKvdTuilw
s71y61FQAUbaqA5bHlFwqWwoSzCqAKFZRXoV/RTQdrdk+ccS8TQPpNm8pmDk
R3bW/YQCpIWOFay8pYBsS8sKTC9AzQ0f4Y0fKIhju5z5qLgAVJ72X/4TFIjd
jM/cUloAI7VsgcopIv/uTpknGAXQXjofd2+GgsUu7kyJiwX4c6Iie2CBAsew
sIxT1wuQJXutxPIbBd9l9mU8aynAaQF1I5YfFOT3b82QuVWAN0McDy//JPKv
Mpz+oqsAT+yuDvT9oeDYYGu63P0CWOYapJj/o2BNam766YcF+P29xfP6Gip0
PpmmKzwrIPrUjc2ZmYqXuVvSo14WQNRt5Es5CxV++JH233/Ed+ro/hfrqDh/
ti4tZrAAgeZSAxs2UGG8MzHtzTChly/rJDZvpGJg9Uia8lgBZo9eVl6/iQru
fTxp76YKsPeN08gTNirq/s2mbpsrQP1j7doSdirM63tSExYLIP3RPuYQBxVj
hxip75cKQDlvd5Kdk4ozG8JT1b4VQIWjrLSBYMEbNqlJP4l87ItdZ7aZiuuu
yqlDfwrgdbyg8xnBVtzrUzWY6Kju/vPBgouKmTsjKSksdOz2exTYSnCiT1vK
8Ho6+mY+pQhwUyEplJ+ixUbH5+xnOt4Etz/wTUnjpOP+iXdpDQTbnzBL+chN
R+NxZfokwUuSEik6fHQMON535yFRkfn8Z3KGAB1y5BgONYIVz7xKHhOm42LL
XLEJwfe3XknW20IH38dEYVOCnd8lJWdJ0kEqi6owIPh3okvyJxk63n8e15ch
uFDTINlAgY6a+NRVJoLVR3mTc5TouG3NM/aCsN+XNZ80sY2Or4VjnAUEe2x/
mLRdg4inWSt5F8EsMxVJedp0FJevdVwh4i0vikia0qNDT5XtbC7B+jtsk4y3
08Hh8nGvFMGvl1SSCkDEG9STfJHIX2DFhqQZKh0l14f3bSGYfe9oookZHb8m
l9pSifxf/H0rsdCCDunr9X1TRL0otQWJc5aEP3EuhYYEn1q3M7F4Px1G3ySi
24l672H6NT98gI4lnVfVC4QepP/UHZA9TNTnsaMUmeDny1wKTS50HDkeYQ5C
T9WLd3N+uNER26SyjraeisjZkJ/GHnTQHkbAkJUKufG3j5/40cF2u+rgJkKf
v4dTNXmC6Pijf3XnyFpCv+8NSw+eoCNxgjZUy0Top5/h9zmCDr9NL7nFCP3/
d9eDe00KHSnMN7NPE/1Te0cofEc6HRqqQjE/iP6Kbnsymp5FR2+2oo3XKgVK
jarXBemEP4PnbiguEf1c8d1Oo4qO56oFUnKzFNiX1nacqqajwzb4icU0BSrF
DvKdl+jYYsiR4DpJwUB254/dDXRwrtPSCRmnQC06+Zx7Ox0Hhx5y8QxSwBqp
v66+k1jP7+Kl4XfE/nVy1nepm8jf+NaAijcUJPtbGUf30mGTOZ/FQuw/w04C
o8Vv6Ahve2i3k9ifMrbXyPV9oSNzbwDv0yYKjuodyuZZocN2oxHmGyjQ1WL/
cfA7oY9h5RrmKxSMKwX0fv5LR3tZiTxnDQUGIrq+a9gL0dK06X7FWWJ//fmg
UUO2EOQVyYquaAqCzhxoMlEohFvqea2g0xT8ZJpo2qtUiCuGWy0FwynYtJG1
2Vu9EEaHmn9YBBP54qe1VBkVYusRlS8GxygI0Oi8xXOgEHxDNUetzYj968be
2xKHCrHhnmuZB5WCGP3h29scC7HE1i0TakxBrsnf9l2uhbjGmb0+RIeCpr2G
nXH+hegMc7r8U5aCVe/We0tJhRjW7v+7jYWCMwtm95nSCjExdkWs9p8J1ge/
ub85sxDTQwK7hX6ZQCB8tWdrfiHkHpO7Br+YQC9Z85Erg1jPx6xx6oMJIs83
9PW3FqJDbWFGvMUEzEM1r5umCrG5L7B7+YgJXhuwjjLPFWK8d9NC/UHi/C1x
nbNZLMTgyyuSh21MsMdejGV5tRCJ4/IXc3aYoKg/T02TpQieFVxH/JVMoNR7
Jv26WBFkeXydF1cAu5b9lGabIsymiM2rRwPy5EbLdQeK8GUtm2doGPArZPNB
20NFCHpR8+hKAMBQ7/VfcS4CcwAt+K8zMFNvXKrlV4Scd2/XCJsA0ecVvzcn
F8G87rHVlb/GuJSz5sqN9iLkWX+g9EwaQSXMwPppZxFeiYhE/31jhOtOocuf
uovw/vLlLrkHRrizdVafr7cIdkUJ/ywvGKH//psHwa+LYHBdcvu8sxH+/Ljy
UXWB4LJZier/tsP6qCPfZfFiCFNHnCxvGOKHeltkeVwxZIu7zXc762PqaFJM
pWkJ3ne8vEV5qoWvQR5Fs+YlUPKoijS9pYXfsTuvau8ugSuT2C6bGi1wVbEN
9e4rwUMpjovZsVrQHcvSXTpSArn4KyZ0HS0kuxYtUMNL0Coz3DlVpQlZt0uO
n66UQHGEstE/UQNuxx7ryQucRaa65/ThUDWI/0mZ1BM+iz2JPhpvjqthKN+8
cJfYWXAUq4ofOagGu3v3l/2kz4Lkx3icb6gGc6nOq82qZ5G43bOWzqwG5Y/X
Zag7z+K/BFXduTxVrDqUcTuFn8VG4dAX2hHbkLI/cCpv8Cx+3d6UtuKqhOwH
fyonhs9i4JdXZ6aFEuj6qQ4GY2dR+F5mYLuaEs6LVz0bnTqLJ+rJIkN/t6Jj
9lWz2rezMPzQXiB8lrjvx+vGPuM+B6vg/o0n3yjCpfmfEJvZOcwa1ek3OClA
j5y5O/baOaw931XDXCGLr1zfS0uvn0PaumKN6AxZ1LEdXWhtOYcTLV91NoXL
QoxJO3eh/Rz4st/n77Ah3juzQ28ces/h8GIFnzOrLJ53KbvqjJ2Dje0HGo+/
DNx9+07N8pbCg4kyEmYhDXEPncfrBUrB3ittUqErjXdHK0SkhEtxSCFO8Y2s
NHbbn+g4KFGKb7mbr3kzS0OdKrrugXIp+vUTDuq2S+GPgG92xY5SVO7sCD6u
IYX8e+wX7cJKMdRwZNVNURLJHHtdjkaUEjoc3FAhJIlIuxxhvzOlmH139ejM
Jkm4TfJlJ8SXQl92g/jlGQlosm85dT27FFZfTDTf1kug30ZtF+lSKbrmE0qX
NSVAGrNd6HtXCkvbmhNFe8TBqlR06d1gKVQqkza2Qhw/QwZcPw2Xwu6QZ+WE
ujhGWY+8/f2pFI9zyCIn+cVxTdGja+vXUryaf+N77e4WWAWF56VsKkOMte7O
Y4tiyGIq1zE1KEOq7frbhsdE8VTm6u9cozIcanxAv75LFOwWHV0jJmX4LHf3
l626KJJzh3dFmpfhlmP/e741ooiWEndusi2D4dWgv+mlIggwrUiWCCjD96JP
9IARYVzxvGbpH1wGK7PWNZmPhDGb0UVqDy1D492S0teNwvB4/fGc/eky1Bxl
PJtKEIbLcclrWallkLVOzxRSEca+lKp3f86XwUupRKc1UQjZ9U1lu2rKYHno
h0BekBCevuh2Lb5cBvOCmYgSJyFYCI3PaTaWYfuA0eZtOkKgXpZe69NRhm85
mbsDpwWh2XdBceBdGbaM2eh6HBRE0JfmBbmhMkwOtC6TzAXRwNdz/cQIYa83
VXlGWxBKTp+NuCfKEKySv1OaTxDSC7I25stl8GYkZ7f1C4CPuybiBmc5rD7r
3o45KADW9oK3j7nLsTgUmP5vlwBWPeK0PvKW4+uqaOkFIwG87XRaYBMux/zI
9XIvaQGcDeBzdZErhzrLfdZ3X/iRLsLcGapYDuLq3FL8iR+RDxdF0pXL0U1W
+xz7jh9O4k9e39Aoh2SdytDTLn5IPI+1YEc5Dv8m/7TM5wcpMuCiBLUcXu4s
XjYp/Fgr78Sis6McXNfGc2LO8GM8Su+Oy+5yfNI4KWPvyY+L2xbVWuzL4ZR9
Q3QB/FDOchQ8GkisX3PEsfcbGWIGu0JPhpTjbFhEutMCGZwTuv3pJ8sRWMI1
JjxBxqIRb0bL6XIsX7WXIr0ho2m+dw1HajkOOWy5M9dKxvmSVkfJjHJ87Gdd
fXyNjPwd1W062UT8JePZ/bVkhJbFhByll6Oxp2jzkVIy9PboTrZUloPV+RHJ
I54MxZ8ypn0XyjGu72eae4YMoWqeytGacjA3Gol+DiPj95/5wxxXyzF5IW14
kx8Zc5cGWyUbyyFw8+Dgew8yPtj28uk2l4N8uanytSsZHfUXnh29VQ4P7bhr
Ow+R0XAwTynsTjn0dtZx3LUlg7EuJiWjqxx7BNQOuVmTEevoQG19UI6QALU5
2Z1kBG+0YPT1lhPv1x5zM1My3Jp1/oz2laPaJPpOjgkZphw8LRyvysFbdUjm
gj4Z0flPxY69Ib5/HDLcqkNGm3Bq4u2BcvjoXfg1qkHGSqXpPM+HclSJbQ98
okqGqiKTnffHcrjuEKifUCbD+9rt9rvj5VCRqbijuZWMat0wGaHJcuydW2pu
kifjY4dGRuAMUe+2f1VusmSImC0sP5wvx0kW32IzaTIOPK11EP9aDvFDi9UO
kmTk2rrfO7lSjs5e4w9V4mT0DUooPfteDkZplLXoFjI2uA3lyf4ux2/hNtIj
UTKoM0W/Tv8rR+6pAq2LImQY69Ve82JioO3Y0uMWYTIGfycdIzMzEKnkM/lT
iIzwzmOCd1kYcLeuLg8gWCCe2ufLysA5zQBWQYKbzSRiBDcw4H1HW21Z8P//
X/uneX8jAwMlPFprie+LTwcnA9gYqCnMkaMSnJnbdk6EgwGPOwyxFoK32hVZ
PeRkYGiwRtWJsP9QMJQlhIuYH14Qokv45z5k07qFxIAzNYNpB+E/S4Waz2Me
Bnb9dVhIFCOjwm2z+Ek+Bj4FONn9IuI1kp/rl+Rn4I2i1d4qCSKemd6kpwIM
mAdGLp2RIuPU1RqDcCEGzv6X55ApQwY5OHFBRoSBNcMPzr+QI8P6p8mB01sY
iJe4s31ZiYz59i1sChIM0J6V3u/fRkZ6zJ87ryQZ2JG8q2RCnYyeDTdllWQZ
KAj5WVqnR+jnCX3gjRwDz61kNzhtJ4MpOyQzToGBm5pKWjRCT4b8qqsDSgz8
FNawvUrob2CAozZRhQHOFcUkzT1knCybcVRXZcBH3eDX/D4yGmUu3k/RYKBX
5rwKiyMZ8ppiBbr6DITLPotvCibsf/tlPm7AgACzV+LnU2S43nr3O2s7A/4q
zWN7o8kooxS4TYCBUE4fs54MMnit2TXpZgww7dP6ZXqZWJ93esJkJwMuE7uE
VJvI2Pv2wdk5CyKf8fR+61tkpB6JYzbdwwBjfPiu4RMy1vj9fLm0n4GG9ptH
mxfJuGVPu1Vox8BFw/AEjZ9E/1MzqwzsGbBTCiiZZObHjIBkSNxhIl8H6/Z+
5+fH6+6dfDxHiXzaZ29oovAj50renxuuRPzvX7+cs+TH7uKhT4eOMRARpszm
cpAfXX6BNyo9GBg5XZfxJYAfdYLFB9T9Gag7IhnZWcmP4yxjxq8DGLiaVW99
7yo/JBeU5MODGJBvG9Be286Pwnud37tOMMCyWrtZ+S0/Yv0ni60jGcgUFpcy
5RbAgfs6gwEpDOw5fHNHY6YASA0x93jTGHB7aLYzqFwAT0oe17WmM1BUn8Af
0CAASsCR02uyGRBpXxGUJc4LJeEksWw6AzwRKguxwoJYG/ja+WoVYc9Zq9yg
VRDth8V32lxg4EDZ/I9vTwQRtsNL7Vs1Aw8fcweufhTEnPBfJuNaIj/iewfb
2IXwtkem6mkDA/2bx195HhPCFZETn+baGbC9bWFXJSUMyuP64hMdDJQu/De0
rC+M16c+W/7pZODCFL9w/D5h/H194Ab7PQb+St++7RArjD05+klbe4l+jR7+
78+4MBbWrVHwfM3ApjNtv/RuiCD+uu7Q4hsGfmQ/E0x8IQIB18CcsHcMmNYd
keCdEwE6R38kDTKwMFO95pu0KLLD7/dWjxL5UzVJHy4UhepCqs/4PAOOTNyn
w1LFcK+0W9xnkdBDwOEK5lox2O/+/WrpCwPrN/Cw/PdIDNGXfLczrzAwKNtQ
tGvTFjx3teKU/EWMvy2bnpW5BQFv+RqOrK/Am901Zgf2EfedLsbSwJYKID59
NSNeAtOOqI+TqMDLG/XsTSUSkP457K4kVYGbl+QorNckQFffMnBatgLqX4iL
0AcJhFeVdoorV+CdsqN4r74kaAklGe76FfB2zw948lsSr83z5b7urwB7sPkh
wQvS2PxJ42OJXQUyx2/ao0sa5jH9JVR7YnzUU+biIWm03SRxFhyuQLTIXPkw
WQblijnLOkf/P97sTHeaDDzYM7tO+1cgrWeX8MIZWfx8lnR4Y2oFzgT//TWZ
Kg92VfLHgrQKONQsyK+/LI8t2efdJTMqUH7OvdrqsTxoVl2BBtkVWHTfdeAY
u8L/f69J8qVXgJtVJi8vWwGSL3yvv6isgEnjqYxFhiJ2vrThKLlVgTrvlatD
I0ooerWlQ3GuAk8co5Rbp1Tx8LDQqavzFZjQL/2q8VcV30d5NTQXK9C5fDb3
DkkNB75svLh9qQLWxRMd/wzUQOZczrT6UQH5N6lmyllqyDd76BS6rhIC0lOi
m3XVkdUW8LdLtBIp/+gc1bkaSGR0bT+4pxL9XheFE45o4zCf1J+/eytxiS3S
QixMG6qp8bfPW1eirNRF4Wa2Nt4Fmxks7q/Efxtlrn3t0oaSWZ9u0uFKWOjG
LHtL66B/7q1Gs0clHgaVbdg2pQNxg0UF7rhK7A6y3XrVXw9t/4mRH7VUomDM
936gkyE8OP0r9t2shIy7UbVPsCHIZh1Kg22VGP9g4XAg2RBBrUeoC+2Ef8YK
Dr+uGWLrWUYA371K/Gg5YXOSZTvOOUs+dnleCbfxrhsc1dtxZkYm+udkJU70
D+uaDBhBSTqULX66EvQ6WVLfrBEGHHroHLOV2PqIz5TyzwjaT93rxRcq0cWR
wzYpZYyFhosDO1YqEfncMFbExxjOoQpaeUxVOD530IL1uzGoTMrTW4WqcO3Y
n4jgMwBdbjz8tXAVxo1N1z9PBKYtz7LFiFahwMy7RyQLyC7ZqPxavAozqwEX
EsuBQY3P/tFyVXgvruRS0gGEupevvNKsQmqMvFDLb+BRul1ilDYxPlfoIxeL
CUSaOPgVdasgp9kseYjNBN3/InSjDKqgVr682iZoAq5i+wgFShXO6E9KNmuZ
oPYxN9OZvVWw+J4/mOhlgj9fHubIW1fBlpU77b8AE1gJREv276uCXfp9D56T
JvjmNk+Vt6uCXw5fvUOcCWh/exNfOlQhab+WpcxZE3xQjWeX86rCo5Lc3qwH
JlA7YFD6wpvgSfkLL56YIP70V+VI3yo0WJ/vWfvSBFt7nfe+CKjCOdr1RfVB
E4S5bs+NOFmFnrWMoMcLJuCmr/I/j6+Crv3LulEeCkZ+RbwZJFhyo6wuMy8F
DS5MhVMEC+5t75Ai2EqZncycUIXWhRvdbgRn35Pg1Sb4sca7ss8Ecy7t5jpH
cK3nRMUUHwXsVlUbPBKrQKkseD/LT8Fgs/zDEIL7tE4vsAtQUCd8JSmG4GTH
2n9KBO+eaGU9S7Ac7T9eX4LTzjxleUrwiIw/aY7gTfU/1mgmVcHpatehWUEK
BkhRnSBYV2aDBrsQBbVhLNGWBCvxFKxXItiCtvmfO8EBxbEXvAlOeS/9p5jg
KdEr16cJtjepvV1N8EYpRf9NwhTIX9wW2USwp/ScjCLBD4P0fz0heMXRPNmT
4KK3HW3vCFZsGdFIIdjDyDT8M8FX93S+ryFY93yv3hLBG7Qmoh4SvGGT1Y9/
BN8KtxWfJPh/K2/qIg==
          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox["KKp", TraditionalForm],
       PlotRange->{{0, 2500}, {0., 40.90252569846353}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {5374.285714285714, -300.36451853244887`}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}]}, {InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[7, 23], 0.30434782608695654`]], LineBox[CompressedData["
1:eJwV13c8Vf8fB3BK00gqKZKEhEpIRnq/o5CEKFEolKxsIcre1+baXPtee++9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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0.05},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox["KKph", TraditionalForm],
       PlotRange->{{0, 2500}, {0.04453978785704605, 0.425549500869883}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {488.57142857142856`, -901.0935555973466}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[8, 23], 0.34782608695652173`]], LineBox[CompressedData["
1:eJwVl3k41N8Xx5Gt7AwjIoUW2b5IodwjsmdPG5XIFlFJyDL2nRkURpihhCJk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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox["KKpp", TraditionalForm],
       PlotRange->{{0, 2500}, {0., 5.984856637407061}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {1465.7142857142856`, -901.0935555973466}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[9, 23], 0.391304347826087]], LineBox[CompressedData["
1:eJwUmXc8lf8bxpHQICSJEiqZGcemzmWvc3AQFQ0zISOyx7F3wrH3KqWUVVpC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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox["Kp", TraditionalForm],
       PlotRange->{{0, 2500}, {0., 72.5334105316046}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {2442.857142857143, -901.0935555973466}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[10, 23], 0.43478260869565216`]], LineBox[CompressedData["
1:eJwVl3k8VH8Xx2lB9hRJJSHZCZWozgmVrBVFKZKSlJB9y5JlLLMxdjOWsUvE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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0.02},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox["Kph", TraditionalForm],
       PlotRange->{{0, 2500}, {0.014145692853082351`, 0.1738510839648884}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {3420., -901.0935555973466}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[11, 23], 0.4782608695652174]], LineBox[CompressedData["
1:eJwt13c41e//B3AHIVsiKwnZimzi/TRC1kFIkoySisysVPYm6xhxyCgSpVSK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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox["Kpp", TraditionalForm],
       PlotRange->{{0, 2500}, {0., 73.2637822083229}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {4397.142857142857, -901.0935555973466}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[12, 23], 0.5217391304347826]], LineBox[CompressedData["
1:eJwV13k4lF8bB3BUoiRKJZWkKLQIUZS+ooxt7EuWhLLOTEySrbLvZZmxzthG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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 50.},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox["MAPK", TraditionalForm],
       PlotRange->{{0, 2500}, {49.46061667213701, 300.}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {5374.285714285714, -901.0935555973466}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}]}, {InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[13, 23], 0.5652173913043478]], LineBox[CompressedData["
1:eJwV13k8lF8XAHA7JaSyREmRIiQka/dIthJClixZCokiS7JlX5JlxjZjKTPq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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0.2},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox["S", TraditionalForm],
       PlotRange->{{0, 2500}, {0.1631134308234306, 1.2715127894779232`}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {488.57142857142856`, -1501.8225926622445`}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[14, 23], 0.6086956521739131]], LineBox[CompressedData["
1:eJwV13c81d8fB3AKXxUy0qCQkozLtVfpZd5PtoYGJUTRQPbMunZZ177WvRWF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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox[
         RowBox[{"Bind", "(", 
           RowBox[{"KK", ",", "KKKp"}], ")"}], TraditionalForm],
       PlotRange->{{0, 2500}, {0., 65.29686590574453}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {1465.7142857142856`, -1501.8225926622445`}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[15, 23], 0.6521739130434783]], LineBox[CompressedData["
1:eJwV2Hk8lF8XAPCZZywt9iiRCEVIChWqeyyhKJIkpciSyr4lSdYZ+z72sbYo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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox[
         RowBox[{"Bind", "(", 
           RowBox[{"KKK", ",", "S"}], ")"}], TraditionalForm],
       PlotRange->{{0, 2500}, {0., 4.348270762102344}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {2442.857142857143, -1501.8225926622445`}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[16, 23], 0.6956521739130435]], LineBox[CompressedData["
1:eJwV13k8VN8bB3AaYyeEmRKhREURZat8LJVKlhZptZUs2dckO2MnjH3sClEi
KllSpJTSpkhJhZQsofCNfuf317zerzv33nOf83nOvUfGxvXAmSVsbGyrKWxs
//+9vGnbp7fNvDpXGMoqfQovtz8XtAAz+pvO97T3/0WWt+scMS69Zxk9q+OU
JPifufGATtHeZLd5uyU4/l9xjkDcuI6ESxfbzmhutK5Nz+3M/aOTfEnwUuJV
QfRxWD48VvdPJ+LYZaGfdiLgLthRotNLwcLFr/nq0XSMhN9zVtPjw+1EysiJ
LAlMW/dI+8YIwqtAViX0qhSeOMy0LjQLIaMnv+HgR2lEXVUPX1wqAh+bKqsh
O1m8KddiM9myDId+NHOcH18Nq2+3romriGKz1/NSPj85pJePrThKFYPQwkej
XDZ5vDaVH352UwxjEWMTytEK4ArW2/xATxxPBRdTHwivx2331Ro/qsVRni6g
aZ61AYydA2FbeGiIkpb88E1WCc2rnpgw99Bwpkwx5MLVjXjx/pzHS18aZJbn
inCtUEYkZ8LKM+k0JH0oOW36URnKZ1k7ra7S8K+gsi6zUAXaZrqJDnU0uNjV
cn+x24xdSqP0u/U0fFjfeExxgyr4n/MYbyA2Gm+t8B5XBdcGg0x18v+7NU8X
m2rUYMs9Orq0iob1fq9Nuf22QCmwdbaglIbMbX2FZtu2wnKPWkRRPg3c7F+n
s9jUwdiReC87gwbfth+7vraqw9FE+/yPJBqGoqcylKI18Gn0/YHX0TQcNv7v
u89+TWxxWM0XFEZDqwhl+z1hLRg7nvnMFkiD6lveRJ5uLYTotmhYnaehMFtk
4ECWNrxmFLwzvGkQtlqhmnNqG3rEqLtYHjQEr5GNGJTdDg0Do90n3WgY+7bu
7cbh7UhOzpRrdaHhZKXKOr+rO8AjcWh3gzMNT901L7S46sBQnH+pMrFkdr4d
dQVwie1ZGy/xoYvFS9cHAC32M1qaxHGWpbeNPwK7q+bly4lbdSusPaGLtqDl
p43J9f9bXcWbUaiLRB7FX3RXGjZz3qxp4NBDSmL91CKx47dbJwbs9LBlSCfq
DxlfYcddKudjPXyLfZT3nzsNPRXN19Zv0IeLae5DqicNhu7tbF7j+phzk9gs
SZ537Xx3MaffToSufv5RjtTjM9/v0Q3Rhmg69/hIbjANlkdqxy9NGULAa9fn
3BAa+gq9fv05uQeR937SC0Jp6Nac+vNg815UnrtvXxFOQ8fZiSUn+vah/pbO
5aEoGqoffKfHbTKBKe+jNf9doqGl0VX29/cDMDH/lWx1mdTX9vnqddIHURhw
MqXxCg07eDbJnTh8EKYt3+mSZSQvh8bk7zcfxHUHvdwvJH+1P84pJaQegu77
craEGzSULXfUWLvDHMy97VcPNtJwyfu0sfmlo4i5KscK6qbBPy2nc8mDo3BY
vi2V6x0Np2+9Nro+fRRPxV6oXuqhYeucwT5ui2MoL1U9WdZHQ2+AnGG91HH8
sl07NvqZBtnwIV2pihNojeSvbhyn4Way/Zahh5ZY0y6b6chLx+iRrYLaizYo
/H18kl2fDrXe1NRUcVtcNTwq2WFAx8UTUyvGNtridnlKa/IuOgStq+QLLG2h
VsvmJLeXDmXH9bpcLbYwf51+0sSMDq8AKa9XYachyrQpuG5Jx0I+Z68Tjx12
VUmk2AfQsWv1Gas2GTtk67FrqwTSkVDyYEhKyw5BMSv3zwXRIV0ePPXC0Q6z
nG9DGWF06NXM82s8tcO/o+9Hs2LoiGwb0+FIPItlo109yRlkPN+7S3JEHVAu
kaBxpoaO0l3FoZybHCCiNmCwppacX+Ru6bbHASt45IM/1dHhc4J/uUGgA9a8
nJU3rafj4zPduB/DDji0Z7qMp4WOypoKD627jrh3W2H2eScZr5C/SfEbR2yX
fs0yf07Hp3O7FQUnHPHwkOiXd110iK79PDiwxgmq9LX9z1/REZBBOxqd4ITC
hOGU8B46jC6G6ryzPoelguMfx7/QMdRjslIv4Bwupd3cunqQjuCtknNX086h
6EzPKdMhOm6O36oOenIOtau5S9K/0SFh81NOfoszLn84X9A9So431S+5ZOKM
zJBGsTc/6TCWiOqfd3BGgnOx5dMxOkJfy2Y+y3VGJ9vW6eIJOr7vsuD34XbB
n6xfzPkpOsKL5Eb6ZV3w+1TyxoZpOqTYptr2bHfB9I6HGd4zdBy4Ex8k6eEC
v77gk89/k3yIHT/BiHNB0eJVb9c/pP4eCpqTl11QU5nVyzlLR/2GB79a37tA
V52fKjFHx6GopOcbf7vAcuMFRjrx2NeTFRlCrqg5m9DFO09HlO6G6CUbXGHa
ldzkRSybO3vm3E5X5O94uOkNccN8m163pStUtlssUfyPDvMjKavg74rRj66i
54knaqz+lqW64t17OYMG4mihjT3LrrtCelOi6wzx7fJhr/p2VywZXlIk85eO
bwYFQtafXBGn3vXFgJjWf6yCa478X8tC3JK4aBvvmrfcbni7d1bKjbieZ9h9
vZgb9MQFPvsSv+x+0HxRxg2j53/p+xB/L8oXeKHkhkoJnnVOxOzuF4+v0XLD
kGm1tzkxfcexMt9dbuDaf0BQg1iZT/1PxwE3tJ848HYpseG7ZTulLN1QfmhN
7QcyXquSiWR3JzfcrteJKyD28+j81OrrBrMGWd3jxIk65Rvp4W7YW3j4Ni/x
ZX5GgFOSG/jbnbuvk3o19dh2NOW4weIPb/Be4u7LoIuUuSFs95vMXlL/n56S
dmdq3bBgFcNtRcyhO19zu8UNi34zVb1k/lYKvmXnf+aGLP9J373Eau9rTCx7
3ZAh46h3ncy3UWkSq3rIDbL5ljPcxBf09moe/eeGfoF1ZVkkL8lL5RkVfO7Q
kDnj9ZLkqbyP8uYfzR0KEb8bFkneen0a3S4ru+Om1PRxtV90/NLPaprb5o6m
h+kXt0/SwSPsy79/jzsCXf9Wa5G8alxVLp2ydkf1QN2EEMmzqZ/A710u7hiQ
39o2QvJ/dud3/Sx/dyRSn+6s+0FHWn9RP1LckRHNP7huhI5rFcFKqXnkfv8W
u7qG6Xh4/uSF4avu8NfNoTiR/ppZRqMltLqjTVuux4/0I//A1OmBLndcmWbt
HR2gY821rmq1D+4ojRvPO/CJ5Nkwxvj9jDtS3q1g/umjozpgIUJB3gPJlLOC
+W/o6NjT++qCqgdw7St7Ken/AfFbMs91PHDlRObKwhd0CN1wa/S28EDN8wfO
58h64jr4Zfp+tAf64+JFj7SSfqq+pyee5oGLwY+6f5L1JzeIleRQ6IHFddYi
Ps10PFt+RFHorgd27DtWdIysV4rGHbYnRz3QS5X8536djnNRH/tuz3nghUip
2KEKOiru/zosyuWJ28tsbdeU0aGkLmH4RMYTnKtCDRML6dgofU5R84gnjKvF
umJT6XA5FlySetoTJctaVD8k0XE9NVVqwt2TzNuR1SvjSX55GoWuxHnixQeO
YzYRdKj8EpgRve+JdZ4eSoLedHgoyrq4PffEhzccM4/dSH3stg4/6fPEMw25
Jo9zdGx+f6on9I8n+rI/r4i1Jflqvd44oegFg+j7jDemdGxNM4t8mu4F9Y/F
se3yZH3uOvNPvsQLk4sCA/tl6ajj9fcLq/bC8sL9GfdW0qEeVOio1emFuFdX
JJyESV7sp4xLl3jDe5Wi0us5GrS0mLRwZ298EslK//2QvD+9ypL6/b2xTaGk
RO8eDfXXGnm0o7zx/MK69Rfu0KC9eui/yUJvKLkdvnWDvJ+38at/snznjcLx
rp9bEmnQ+fiuVFvfB3xnWM9LDpDvFTPjNgtTH3Cwppu+7KUhtfXBgPdJHxif
eVi5VJ+Gb+XXVlT5+uDh+rJ3Kqo0JPuGx62p8IHK+JOqAhEavgopuwmI+UI7
wF7F4Jk4ovQZ6v1Dvgi8+9r1lKY4quv+Hvw75QtJ/fvuiZvE0bfOw205ux8q
uDeqVMuJQ0XoZNlBCT/E3dBmdAqLo7dvs8QjEz/kSLZyW42IQcnn42LVbT/o
Hh/1W54mhpelWx6GxpzH3itjNfRhUbRryeg1pZ3Hvhteb9P7RNHwlL9prvA8
DKibfZe+FMXliS+1bnfPo0X4+KNvDaLw10guOTV6HgobnBZ2J4tC5tFYuJax
P6SPli/2aovCbfiK/i/hC/D/z63PJnYZlq5d0WKdGQC17gGTxdUiUJTbbl9y
OQABNaYdXTQR7F1jtXSkJgBG7MsHi/lEECl7+aTbswAoBwYmHpgSxl+pzfOB
lIs4KaOY235fGN9pe1VznC9ivZnHzFYbYbTy+Jd06wbCuESUxl8sBL+fPdH7
vgeh6YrgT1NPQVjxeSZV/g7ChkYrpWWWgigWjXzCYA9G4KNf677uFUTc5lUv
RwSCwRS69rpaVhAnXcz6K9cGI+dw727OVwJYHKyd22IRjJjQo3vztgoAbwI3
7robjO9Bln6HefmhdvqJim9LMO5lPvOWm+WDwhRtS2l7MDwuiXhxDfFBSPiG
Nu/rYIi7R7ax3+fDgNEXw2ejwfhwqnHohT8fQlt325pLhYCm6XZ0YpwXbTVC
GXYhIXA71nyO+Y0HG/sFnP0YIeDeJrNavIcHGbx8ejHxIbAQdZsve8wDR2vq
aGVmCA6cX76J7yoPBJfO68zcIOdXnGfedOGBheOX4bDPIVinr+xbNseN79J1
6gX6oUgy3++2TYobB41q+Gv2hGIVe0OAojA3GnyrBlpNQrG9tmujMgc3Ep6V
x347HoqKj6YhHt+5oBqQ17/JKxTHnkk0f77FhYC3UYym4lBctdzR5mrOBcGE
42/fU8Og8KVxpUwhJ/jdplvc+cOwR7T1SmYaJ3gOxFdwLQvDfMnPWoVYTnCI
N4eoSoeh+1qxWowXJ+ZZsoqxWmFwlbMpOWrIiaHKkWAt1zBccT7zU3qaiq+J
oU5d3mH48FOl5e8IFQPuEuZ2AWEwP6xkP9ZPRd+W/RuSo8Pwt19oUeQpFS8b
q96MFIUh4PqKQcsSKpo6fddnvgtD8zt5+sJxKhquC4lt6g/DJaM5TuWDVNy5
VPavdTAMWmIC0757qbh5+P3riV9heDR/IWmXJhXlH3YEGQqEY0PBLv0PNCrS
flJf/9ENh5n32MiXdxxIfZ7bFG8YDsPRZWxWLzhw6YZ62WqTcPj2sxQnHnMg
ztsh0OREOGzqeuKN7nIgdOGpwhWfcOR+1ns1lcsBZ4HUi+ZXwxH2aD5o3IED
XYvD6RduhCPT02e98GkObJ7Qrs6/FY5r9V8i9E9xYPbll6HvD8LhU7xJuvcA
B8IzVE2D+sIReexTRuc2DmStfiVbKhCBiEntsw+WcWBBVH5757IIfFq7seS7
IAesOC8c+bU8AvJ9Dr0yvByQG5GN27Y2Aj8/CC42s3Gg6prHTNeOCLyf7fl1
Z4yCdk2RR3OuERB54zSX1UnB+g12n6V8IiB0bF9Yw2MK4lbW/9UPiECbdJv5
zzYKDvyzVkmIisCBnR+rApoo+Nh6I0u2IALRxwyEzaoo0K2j1u6+EoFJrSft
PyooKL5y9Pm5ygjwjXv4MMsocIhh57h1JwKum7akihVRMG1i5rzvZQSuqx29
355GwRHdEobbuwhcZDut0JNCQf3muQLmxwh4lC3TnEuiIEisoLv/ewQuc3hv
ORNLAe/7CR0vSiQm6y0yfwRT4PzU4FgmTySmLp446B5IQVdjhlfT0kisXqXh
Sg2gIC0fZdwrI3GiI6TMwpcCGbskEZZaJDqmz6mVu1BAFwzW26VNrnenhd33
HAVCda4e47qREMnosT3kSMEi1eSlrkkk9o1zNsCOgpnKHUt+HI5EENdylslp
CkYPb9yceiIScs07R1xsKOgtEUgecojE/l8fsj6eouDF/oWWRLdIJH7C6MaT
FDyaGZ3U8I0Er1tlcOJxCm7tfGoWGx6JtVG5+0IsKLj2826IWmwk1ghtcBU5
QsFl5tUbHy5Fovq1//WawxSkDsYIK+dFon1TpNXagxTExvvr9pRE4sf3yKY/
ZhSEbnF0D62IJOvLGtEeUwrOfzhasKEmEunarhYdJhS4Rex58fpOJDZNnA99
YkzBWSVN9sB7kShrORzdt5+CU28UVOTbI/HwtPjpBSMK9stxXzr/OhLBtZ0e
LvsoMOj8c0/2PXmeP6PMpr0UbPMenngyEAn/cTYnKWJVybfS3t8i8cQibyR+
D8lX20NTqfFIXEm34hEglnGuC26ficTYRcn72Yak/mKXq9z+RqLl+jc+LeKl
jcxPyykM+Ed1fxzeTQHnmQihBzwMuNn+t7mEeIHfG+eEGFjIdmLzIJ6+edpN
jMZAWLC+jjHxjxOH8pskGZhW+jasSfyZw6Dr7BoGZqsHf6kR91SosglvYKDB
/5GFDnHXodXK9SoMOE+sFDlK/OiviJWtBoN8l7jSQombi5ck8eswUHvazLqe
uM7oV3PtTgYqZ9K/sZPxXpseGD9lxMAOZVy2IC7JebGK+yAD7w7tTmkizjFo
MblxlEH2GWRHT54/ZbQq6JgVA19Pnu2/RRyTmn+dcpYB3l8pyvtI/UK2JfVX
ODPQuzya+ZPY72vQUnMvBj7rFXPlkfq7xrnq/PNnQPmVXrAlmR87NUvX0hAG
jsrfn934//nrM84zi2LAJyHMUYDM7+HwHc/nExhAiczzeWIjxY3/ipgMdJ4y
kv5D8mDwWnLT/hwGtlyrObKE5GfzmoWEvDIG7nw0sNpJ8rXu6WiTYRUDCeWX
11w8RIG0V9/YZB2ZD5G8ugckj4Ktd40NWhm4Uraw/iLJ7w9bf8GRjwwMuK2p
yif5tyhdIeQ5yIDLt/gdu6woaB2tF174QepJ3/51zprUx/s/UeE5BjJ26VvF
niHjYwRIaC6LQgbtXpS5MwW3n6yUfLA8CpqP2HXOuVJIXzRK7ZeOAl1B4Uui
O8lDxoKMtVIUlDccH2DzIfNRHqgQvTsKvxyrN0QHUbBiXGr9MuMo9AmWtQuE
UhCp2ryBdSgKfz4mr88PJ/Vq+LfxhnUUrqhYbB6LJvl7Fryl5wK5ntyDto1M
0i+ToXrrqqKQk2Qztf0ahbyfVhvU1EWhaO3KFzk3KDD0f7Bze2MU8juMFHlq
SX0oHHvMOqKw8ZD6Ht4G0v+iESbnv0bhh8OJ/MoOUl8NxonH9Gj4vvT85PWd
gtwA+VMHV0UjudY9qIysz7wt7ZYf5KKhplBx6McvCr7s4bad3ByND5e/J6b9
R/r/eLTD8v3RuLwt9EmMAAdmAmN9HEKiUXfv4NEhVQ48fDl0JZQRjfe9rPVM
DQ5krNXryY6PRinHnKbJdg5oPZvVfpYZjaV57pTBXRwIlrRjV62Oxqa3C6/S
jnGAvwFxfz9H442c0ejScA6smZspSDSIgbAkX45WPwd+G5m9Kt0bg+4+W809
gxxoz6/guG8agwuGW+NsfnDA0dD27PSJGEyd4NCp/UPeP+ldike9Y/Aky9+0
V4iKbVuv3pK9HANvgfsNUjupOORp1VnLFYuqgeajTrVU1F88InpQMBZab3tP
2jVSIR1lfHxCNBa8FX1Kzm1U/MjZNrJeNhZ7RCREct9QEfqQTs3fFotjhiV8
cb+puLH8xbYY91jQzv5JuKTFCcF7uhWn3sdCwdt5kPqEE4/5V8dyXY9Dj2NJ
xHk+bqSufcOuVhuHL/EPGh3EuGEFhp/V3TicOmUkZbOKG789f5y50x4HRR4/
VSdVbsi+r4HTpziccbUq/XCcGwFlBr+fCcfDSOiAt/Y1bmzcZWed5hWPSuo1
qXQLHqQElanLaSUg7NJPreIWXnimS+4zHEpEn4lZ+Hq6IPbanRg0aUuC3Ra9
ezlPhRD+MzbHOvoSzBdfOJ70FcGe3Zu5fp9Mxs3rU0t1yfe5jX39xFLrZJwo
q3+eryuKgGi93nWnk5F19q/e4m5RVD05UHnSMRmuSktlqg+JgmbqebDNJxkB
/51t++ssikGLm3mpicnQ2/m+XSxfFCGOWzVUW5Khz7bpkugSMWTFNsnsb03G
jXV1b+ncYrhZsYvvbHsytrrzFCwXFMO3MfOPWZ3JsL0umCK0Qgwmnr7hS3qT
ce/ws1cvVcQgGXC768WvZFhF9d7IsxLDnXgtB7c1KSi3PfBO+K4YBBey7vrL
pyB1NK7R554YbM79JxCxPgVMnSGet21i4N3XUJ2pnIIZXd7q6C4xHOfe8ff+
thSwn83SrBsUw0KobqLY4RRUd5usWrNUHLp+hrX1ESm422LVKX5KHGnDpVxt
USmgrt3q+tZGHN/NeY49j01B6crzTslnxZG8pWPxy6UU2HCoW/xxE8eXX/sM
BXLJ+SVnjQLCxBHhbPLesi4F028On3S+Io7HNubs1GFy/n3hksffxWFfGX7K
7HsK1jfHvZQZFwfnbPVd1k/y//j7lR5T4tCLX+qzdToFo3N2tov/iaPh1qPv
Z9lTkbyzK7mRn4Yqfu3XHRKpEBcRnOxRpMH4iIMKbVUqHoxNGjQo0/CzID3B
VjYVkpMbNdLVaFivPm34VyEVM83+bOrbaCiyrmxU2poKb6vg7VL7aEirW3Ul
yTQV5s23FeLP0qDGbszx4SC5fmij/rwjDa/2BVivO5IKZ+9kGSsXGoQG3knc
P5mKSfmnquLeNMTwJSdNOaZCXz1BQjGUhotWHP7mEalYl1wUuySbhtO8I0Yr
61NxXlL2lV87DbV907rKjalw4jEc7H1MA+d1NnWDe6mI/89MSv0pDaUH6TLn
HqbiVnSR0McuGkZzds/cfZkKKXF93aEeGrw3XWYd/5EKZae51oHvNDxkr052
HUvF0nI5m+FRGuivGxlhk+T8YMldw2Nkf+/3xv3qn1SYzcoOvvlFw2ILx67/
KEyIFxtHu8zTEHnIdixrJROycyNi8dx0vF3r+uXaKiaOanAJqfPSoTDn/+6+
LBMVYxM73/PR0cFKvv9dgQnvYeHjIkvpWDrckqa1hYmNDTI9WmJ0WN3pjDXW
YMJWUMK6TpyO6tieYBttJs79nOVVpNNxSHnSMUaXiQuTlJtUCToyzkvr9O4n
x3nq37hL0zGyT1FtzJSJZ76GPxpl6NCS0li35BATXlKv5ymr6ei7b7Js/TEm
5seaxy7K0SHNHzR83o6J/3T7vRTW0+H+MaYv3oGJPQ8eFelvoON+VdqLgnPk
+lv+Y1oo0nH68LW7jz2YaBq8Xuy6kY6y3A+Jy4OYON7IEWa2mQ4Do1uJrqFM
GMyNLNuvSsenuaTEtggmXqy7/A9qdIgfNkh0j2PCl1leJ7yVjhtLpBLbE5mg
HVvhMEZsVPUnQTKFjHfbnP4DdTrC+K4mPM5k4qu9vs5hTTqk7oQnrGKR55uQ
MhDRoqPe7lSCdz4TR65oa7cTT7QIJ8hcYeIq3+RD+jY6Yl1/xPuWM+H3/MiO
WuK1km3xnZVMWE4nO+/ZTsdJP7/48zeZWDUZUWexg45ZuQPxz28xISm058Yr
4tRXG+Ll7jLxuKFNbpcOHZtCqPEXmpgQ+zFDqSLu2Ngf96KFiX7HBG1h0HGm
73acfBsTee4rGhyI2WKS4y4+YkL65qjXHeIc9XNxr56Q+p7beJhNlw71wZ1x
654z0Xr63b4dxC+TV8UFvWSCM6hutyexC+Zi37xhosjstHoeMc/Yy9gNPUws
TzzDc5+4OLsiNqSPiYuy81ffE+vsiYx920/y9HqvwChx72/LWKUvTEg57pSY
IvYp1owNG2KCt6f/wQSx8IFlsT0jTGy/9nL6K3HFv9GYTT+ZuGxVkP2c2LDy
YUzEBDlfr6KkivjLsfyY91NkPqqPsUURB3L7x6j8YWJ0+XTGYeLldQdjGPNM
5CDtxHLim7ZKMR8WmDD+0q3+ijy/qTBXjCp7GmydguhhxD+aPkVHc6Shr0jk
hwJx5Ln66H6uNIhWK+S0kvrKrkiN3sKXhsf1gXRz4sZ25+hYwTT4lFwz+kDm
x8J7d/SAcBrqpvXljhFPycpEq4ulgf1OQ8JTMr8JXfNR8fQ0bB6N9VYjbttw
LUpzVRokVrPOfdUm/dbDiEqUTcOlg5cOKxL/jbSOGpRLQ0y/hrMDydPmz6JR
lxTTkEO53nNfg47OxDHG8KY0vNxP5eon+bTf/oixXTUNjn+FRCdIfvMyLjBG
NNMg/MU1cILkXWvXYYbO9jTsDzC+2U/6oXtqI4OJNLDYBS88IP3Cb/I5Und3
GmZvpJ+zV6bjPHVPZOahNAzudGyQI/1nzP7fWP+RNPDHFcg0raNjzULFkbXH
yfHizh97FejomhZaV2Odhv9emNnpkn6W//ruyVOXNGgGOizmSZHn6Y9RW+ZB
jotrpvasJPl6v4111JvUSzeFjYusH4Gv8l2GLpD7S56mbafR8ea+vTBbdBo4
P26xESXrU3nTCv9dcWkYa2t99p2fjuD6p5/jEtMQyVKKvUnWN8Vq5ZvL09Jg
+OlgjQwn6deCWXPVojRckFPnsf5Lg0pwVI5dYxqCuTfV2A2R9TpAi1p5Lw0O
jwP/On6hoc931HnqQRpc9WavWn+iIcrVVCe4Iw2ytZ58a3tp6D9F/5z5llzv
kUEATycN8dtL5Tsn02BXOZOkUkWDjeaxpGUzaSh7g0nzCho0tvDPHZ1Nwzmx
S0IupTR8VXTrGFpMA9uVaGf3fBq0V2o4s/Gn455SyIcniTSMzLdXq65Nh//p
zZUdTjR4BB6p0V2Xjt5Hy8KOk/fZPPtwjYliOhYMCyv6bWjg5eGsddqcDikH
zt8tR2lQpBncKtqRDidZkf1ju2hwU713d9mRdHjMePkMSdEwW2fSIHMsHSWe
qkkVy2kI0epv2HQyHTnr9gvYidKQrLvYuM82HQeqpXVreGioMdl2L8w1HUvz
fwjeIu/z3063W6cY6ajUembu0CaOwPHdbeyx6bg9eGq9fbM4uDzfti1NSMeE
DuvhsTvioPv/frghNR0rvS4FSlSKQzNK7bFtfjrWVBpw8KeKI6C4qvPV7XTU
tSTvqrEUB+VDaXfNSDqe2Xv/8x8TQ7c252fKz3TYdCbwOg6JoTTL9ufBiXSE
X895Y/RRDMYWUhzTv9PR7+knONYphoxXKSpqHBmYXub9oaBCDIodgXE3pTLQ
x6EYMnRWDOa3DunVHszAKWbhXFW3KMousV2rayT2rM9wyVmGuc31AXlhmXhs
bxEnqCyM22c7o65EZuKpN5dz4Vph+OV8Sr0enYmAIae3GpLCmKVyVTYnZkL1
PneGM68w/rw7+KE/OxOxay0GZ78Kkf3Iz+3SNzPRrn5a5UqWECY7pP/lf81E
GuNOWD+3EEZsGCGFO7MwGyy72/WbAH552GeMGmYh8FFzcmC3AP6G7rm+1SgL
dW01szmtAhAq4vvQcSALl9xPR3IVCEDjS6LGlGUWuJ+m16YdE0CUbca4vn8W
bogPsG528WPt6bKTg9eyINP7PYL5mA/KXjFem6qzILZp8sHtO3zQCneKPV+b
hc8LS9jHyvhgXKx0R6AhCz5XL9YnxPDB5+sN0a2Ps7D6AmO+3IgPbafrn0R+
ycLH/vKh4695cfrME00FejZOsD4u/zPJA+mF6G+aEtm4cOfm2+ODPPiQapi+
Tyob9kcQ8+IdD8xb26Zd1mTD+NyJz+PNPDBcfe96rXI2Zozah2YTeKA0cFNO
f082Ro3Sr+go8+D3iVzhU/7ZeLL/vlhVEDeqp0/cc72YjdCvLjaa3txk/y/h
GhKcjXnT0YFXjtz4djfjaXFkNr42DXltM+fG+xUpjB/J2XC+tfrueyVu3HvH
WPC7mg2nw8bdpp+4EH3IfSSlLxtN5Rz/Fsy4kNS+UDjcnw32ft3KGUMupGnF
nND+ko2DSQ387OBCsXTR888j2TArdXxwYCMXmkdf16r8yUZuWb/uAB8XZsI1
Qp8L56Bisel6UQcn/v5p1V4tloMdpvYDL+9zYomT2YwPPQd9u/t2it3lhJCZ
o73Uqhx8iLsW9uoqJzZI5hg7K+bg5sLiO7UETljX/lvBtzsHYmn0wVBzTtgr
xL0+tTcHc84pbAMmnHDJpidU7ydvtw3P6832cCIgRIX92KEcrI5t++q4jRPp
+22HS61zQJVRXfBfzYnOwYc1uwJyIPq1lMUzQ8Vri4POWUE58G3exxs/TkXv
k/61Y6E5pN8jfWW/U/HtxmwmMzoHfrRHG8L6qaAErg/+mkbG4/Hr84onVGiK
JxiF3sjB1T8uT7NKqPglNMti3czB5P7ze8MKqKjgsxm/fSsHFywOTvizqJBi
35o83pgDg8HDKelMKjhGP7w90ZEDy6Md5hGRVDQN7V7n15mDP2zWqkOhVPgO
3PBP6cpBNzfn7OEgKr53R0h2dOfAykJ0hY0fFV0tSrbqX3KgN/t2cIMTFTEN
6TcPDOVgd1SFPMWeCv1b7JwuIznYuVVz2chpKuoq3pQWj+cgRPfGo0+nqMhO
vzgm/DcHGcFb3wUeJPvv5GEdpX85OJO+K7nDlArBeLNLhktY6HjidmeNMRXB
oXJqQdws7Lm4Q4VjDxV2zp3nR0VZuJHkNeuiQ/bn9upPuOgsXLkYa6S0nYoe
m4KVqyVYUNkg/mpOiwojC+/mozIsNA7eOta4lQrOg/1C3mtY4IlP3n9TjYrm
/XtskuRZaBE4ZX5nMxWb9SWp7Uos5J+Ojv+5kYrR7Qzzz8osrJf/VLlSiYoS
jckrC6osSGxf9+joBiroG9v2qmmxsKNv8dmCPBULdOekgl0s6BUftxuVIc+/
7O1Awx4Wrm9/nxYjTYWboK7qOyMWwuPYY7euouIzRaxb8CALGXLTRbdWUpGz
GCi/3pyFKYfsu3ESVBye++a38ygL1I6SANcVVDwaa5AIsGTBc2HNwEk6FaEj
a53TbVhonmrxdaBRof01qan6DAuWaUtzQ8WpmP44v/SZPQvJbxr2l4lRca3n
tPWIEwu1qozgD6JU2L9+Vs3hysIWW0XlVcQyzzU4pD1YqFriaO6yjOTzceFh
bW8WaLEcPztEqEht5b9i7sdCoVrfTzXiKAETa5sLLEyb+PZfE6YiwPyShEsg
C45fLMu3ELvlvXpzPoQF9m9vDR8LUXH6m1hSRDgLy8+o1ToQW6hY7L3EYKFu
9ZsRcWIj/ywOVgypN8+Kga6lVOBBX1NpPAs9IfbMdGI1/lXnbyaxoHtKg92J
WOGwteq9FFK/sxyr9hGvzC36+SSNBa/7hiPqxELDg1feZrKgnZl0TIWYQ1nB
5ksOCwNmbs7/Pz7r57hyPI+FmriAlXuJR1squucLWRhLPmjjQPyJdzyJ8zIL
H88UaDKJXx1U2SdSxiJ9IcLqJH6Y40mVqmCBeesoQ4SMv36wtnnddRb436tP
2RJf2zh7fks1C5mZ7u9biAt9tdR0a8nzNj3RUiT1SbsXMGZ0mwXJmRX8RcQx
PM2lFndZiPyruXctqW/gAXbb000sJG1eMlFL7JGtL+nWwsJossWsGZkfu68R
by+0snDeSunUPPExpUeXGO0stP9xW3mdzKdesxFnXicL3VzyCdtJHrZyJ94r
7yL5CSpWp5G8rDd74V/3igXRzHS5BWKRL4fHO3tYyD4ge/fnctIvihllPX0s
fE6fspgl+Zv36rUd7GchSjNPfinJ62dOy3d/B1mwuS9rYC1FRbdJQTL3CKn/
5ZNROSTfHRlfjERHyXhuKH7/QvJ/Y719y4ZfLLA2M6bSVlNR7Fl+QX2GhRPG
eZeWyFGR0TC6RX+W1HPTCS3/taT/jd3Ljy2Seg+xZ8avo8LUwz8lmjcXYaJd
3AbKVBjcbdjPFMiFdsrl80tJ/2pw/OMqEMqFrDt/15AqWR/SwgJui+fCN9BI
4o46FRN34s4My+ai6VRQxQ+yfiSy56nv1M4FbZlPR/gBKp7JXf+bvCMXBQem
e/UPU8G/t7nlk24uuLi/MYUsSN6T+/cFGOZispVn5uVJMr7V0lY1h8n1Lgzf
mncged9ZECXjlov2p8bnXoST+Xe4sd/VMxcD4d0h9lEkX/EtIo0+uaBPcH3j
jyP91z2QY3ExF04cjxMvplBhfVb2RmJMLi4UzFxbKKTiQHRRz0JxLqJUJFS9
WqlIqqzJ3Veai0MVgeUfHpHxvnhgm3mV3H/nHtqhTir2rvj6U606F2wlj++c
7Sbr8dU1S84158JYhz9w3Qjpn86S9b09ucg77vJcWJgTYsKlF+oE8/ByM+el
vY6c4GxkvnsinIeIMW6bT66c+G0ftmVANA9nW248D/bmxLt7p8b5JPLw9d9H
x4FgTmS7idlay+chcFKOKpPBCZmu0L38yMPF+xYvUx9xQinx5HIb9zycdLxt
KafCBSntfT6+Xnn4tOtzGEWDC4LDGq/ifPOwhPND+I8dXJjYIRp/6yK53yQf
pceICzVjHWwCMXlY/kx06zoHLmgaa3y7VZiH1stmkRlFXNgpsOyWwOs8xNRx
HgtZxY3g1GdSZ97m4d2Hre5aCtyol4iJbOjNQ9F+O6FFZW4or2c3dxrIg9kn
7eZiPW6s3D0+/WgsD/nb7rS72HHD/96Z5fc58nF79WTR6HVumM3rHrm4Kh/b
+uUUdu3lAZvL/MupQ/lYvzg4R8nixV0Lg7vp5vkw6bT6013MCx/9hCJti3wo
D1Q437jOix90Wa+w4/kQbhVND2jjRfeDPWLLbPIxPHEnx3GSFxXLM49sds1H
8Ed7++y9fDjSpt7nFp2P1GssvX/s/Li20nvwZ2M+Zhnd9XtCBXCjJX+qd1UB
5p+2n3DcIYT554zjPDEFuD/npHRtVBgZr1c1r/9ZgDWF72fdApYhMr9l+1Hj
QvBG8bUbjIniuNjqhUWTQvyQ8juhOi0K5ZjwhmKzQrCdfL1fal4UPZ67tScO
FcL38jeJESr5nt/dqcE4XohJh549ZpJiePXznWqtfSGMrCe5bPeJQVp7Yp1w
WCH4VN5y7ywWw8x1s5G68ELoHvELuFomho41NaUnIgshLarNK3BdDJ6CPvKl
0YX4ZH5xf8sdMTwc+G+NTlIhlq1VdPj5TAzOUVzSzqxCvP8b1b1vVgz1b6TE
H98qxObhWzlfd4nDXtC14MCdQmQW5Fgb7ROH+O5mxb76QlyoNP1zzUQcHrct
9ccbyflb+gJPW4hjQ3a+m1hrIXi+izkkOYgjx0r2iXVXId68+L13OIbsp37I
Bc9/K4TVvs+Rno/FobjGhy/8eyGU79QEK3aKo/fEwzSB0UIk7lTq6O8Sx9Zn
dpXS4+T6fkV6W96JY7zqSu+umUKI8QzFZw+Jw8pn3ZYU9iJkrEz6e3AJDfrs
St83rCiCZMKrTee20JAm/9W/W6IIxk5NXhUaNHzfn80XIlkEo7F9Xwa1aUjK
4lHqli7CXHH0dgM9sj9WHXINli9CukTZ92vGNPjY5c28VivCVJiezTY7Gh7H
mUcGbS2CIGXHsaUONKysEaCt1yjC5ltzQe/JfvbBvwsaQdpFmE/qOWzpToNQ
psWFdXpFMH9wVEUsgIbyJ8LsgSZF8NLQrtJMomFh8tElBbMijJR9TchLpsGU
Hiz76kARdiwfyVxMpeHP6TF9BXNyvGb35tJMGgwWOyJfniiC1PrdJmWFNHxU
DueXdyyCSKnJtHUN2f8f0Wa9cCrCGhH/v0draQi/+EspwLkIr2f4xPfdomFD
h5XJC7ci5Phmu9Pv0uBnuz35gm8RqIh2srxPg3Dab1pXeBH53un6lvWchk//
XXjbRxx9I672MnGVNXv6CLGjZHFwNbGpEr84JaIIhUuGhDuIk1plRLcSZ56p
lZ4jFpwyEsohLq86P27eRQO/aRG3fWQRjl4wNRN+Qepdq/DIi/imivvISuIK
iWuMEOLfdqNBCsRGw7c5s4lfrvx1RYc4NvAZxzNi+XzNr87EvJVzbGqMIiy1
rxLoIO4VCboHYmVtr9g3xOV+HMH7iVVHL3ENEO81WPrPjjjwXu/8H+Lo92sW
MokvShV0yr2kwUK3vOEyMbVz8w4VYoUrmwJqiCt5pSq3ET/y0PrvKfFfPvbI
g8QZ75rre4gn786OnyK237HTf4i45NUeC0dijeIOzSli7Jlu8ibm5jWd+0f8
TWR2dQjx/wB2NC1Y
          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox[
         RowBox[{"Bind", "(", 
           RowBox[{"KKKp", ",", "KKKph"}], ")"}], TraditionalForm],
       PlotRange->{{0, 2500}, {0., 6.2465510673988}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {3420., -1501.8225926622445`}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[17, 23], 0.7391304347826086]], LineBox[CompressedData["
1:eJwVmHc81f8Xx62MsrKLbC4XpcjO+8hMiqLSsGeysmf23uvartGQkMhIEUX1
JRSVvbfMbJHf5/fXfTwf933e79d5nXPen8+9fOZO163ISEhIGshJSP7/+fSM
0ljv+6PotVimW3uwu0IXvSGkRc2hycpoz6rHzOjW1eImk6gd9Fdb4nXi3CVU
pJ3svGdNBn+qMhRL6e0Qp+M3EvUoaugOf9DsXhyEkpPokxJe0MO9o0eLvS6k
oLA7TxmXrJlAXxGXUqlUiFTsWw2ZvFhBQShXRMHoJTrwn8qXjeKA3e4FpWbm
N6gugXz+XhYn/CKW6NQuf0BuBfxng19wQ6LD6xRhtXaU0Z//Tn+EFy49+5l4
crAbeZhXmM5Y8wNXp80pJrF+ZPD7PYX3igC8YR7sPqE+hs65dRUf8xKC3y7u
1B+dphDjwYhOHgkO+AV0DO1J59Fy2PKqZJQItJPD8LOxJfSV/l/qx+N4+GvK
cH/Uaw2VpNPJ38wSAwNqfo4p2g1k9Vw8yPfFadDWYLd2xO8ivhN5TFQnJcFm
E5U9L/qLEoefWOqNSMLJnz/Tpqj+IUfraupJ63PwsaowjkKdFIbxDXfExaRA
maV1i9SADHRWWkrdV6SgzUB7R8CQHPBeP/Sovc6DdViR74jqEZiJWs+QiJKD
Z/sdL1w+U8ONq38XPK7Iw7soHjWLHBpoYSK/0HRcAaJDTQb+OhyFwmym8etZ
irC16fSbjoYWjMrOinq9UIbwgkSXAmEGsJurvTdufRG6tZXqDyOYYOLY1qJY
lBb8OSZ6euYTO5jcql5JWtcCKpXIXJmTHDBU6PZn2+gSqBvTtTyz54Bf8uvb
H89pwz8kBwf0J6DNZpXs3tBl2G5Qihm7dBIqPy5wxJ7RBVwCxbtr2VxwhqGE
80+mLjDbpCfoTHDBzTJpBnEyPXCSytbOFDkFPTvrx5Pt9YDnaKfO2apT0JHg
wm6scg0qhWw+E5q4obnBiX9r4TqEGZgJ7xjzQqBFl4Aorz6Uu3RoP/LnBWWa
M0L3buiDTlvB+3fZvPDWYBn34b0+yJ887LXq5YXq3/YS8akGEPX2ROmjy3zw
/ISdnLDyTeg7/fDAEccPSe6WV28m3YZv3wTjf1QKgA8hp4Ps422w6B4elvsi
AJa1P3RebtyGaVoPa+dhAZDZVbtMbXgHonw03tyhEoQBPyGteu678GXAWQN3
WxD4Q2dUuEvvwRvV4tk/G4Jw7Al3c9vwPUgY/2+3lkoINlpvgieDEVQVm7Pd
PCkEn6g+K39zMQIbm2v13EgIHsQ8UwyWN4YfahfjFsKF4HWy7fmZTyYw22lH
U8EgDLlV+a+Td0xANj2+EM8rDKp2i5k8rKbQ7k16JERSGMRjBE981TAFNco0
6U49Yfj3NZVdqMQU9iW6XH8mCEORnjtLr7MZbCQKKo1Q4WDxlgy94j9z4K78
LWM+jgPpgdTUVDYLeNPL/PC/JRz431s/uXzaAqjVJg3Y9nBAb1aBKzCxgKnJ
1gozJhGQtMOrUDVbAAUdSdUHFRFw8+N26wmxhJaNr/tt2SLw7p/fnniOJXDN
lc3lPBWBI0GDgeGvLUGFIPLo5isRIIRlxMlPW0JQ2APqoE8iUBfP9IyoYQVK
WxWcNSsicJBPOfCAxhqcvj61enVBFDQErExb+azBPKX7KZWmKMQ/+TjDrWAN
1onHqjX0RIG3JHD9u5015JmLmweYi8LFqj1aua/WED3RPDcYJgrhrcuIIsEG
zCiyhtS/iEKn5pVPRs9soFZc64vYN1Fgb3uhU/veBiQuRdbs9YpCcaftbbtV
G4h8wxuhPysKbb0TLt+u2UJbu8e5VQo80C/8epLDch9K86XvfFXEQ7HG42DK
M/fB8+njz18u4uFi0UMT50v3wTcrRuX5JTx43KM9ofboPtxr1/3DegsPI50q
sb9n78Nr/DZXtjMevMQY7t8gswOKZO+u1x54YIocUn/PZQc9z1uzXvnhQUPF
8zD5mh20bSsv6Efioayq1EXhrR28qm+VkM3Dvmf00X380w5ONIw4WxXhYcxe
U5x+1Q4ONFqj3YvxwCI8MT0u+AB+veCMVajEQ3nwyw+X0QP4yO7EulKDB61R
P2L17QdQcj7hTehbPPhlsN+Oin8AnHEU0ddb8MC2OXV+vfgBHOnk1Iv+goeK
a5VMRh8fAImWoGXhVzxMHb3yVXLnAeSukxNdfuBBxz8Y9ZnZQ7flm0txE3iY
6dfluuhnDz+Xw5ybp/EQKHNq9wXBHtpp13l+zOHh9UptZUC7PTTsrgmlLuPh
qk5Ywvy0PdgeySVVWcPDXPF1e30SB0i/ddS5fR0PnOZLQrjzDsAcbUXltYPF
N9aTJek6gGi0e0XmHhbPGTm6d98BLu11/U7fx+I9b7yzDHWA2MeyXi7/8BD8
gz+zM88BVApqmUVJxIDr7Kq73BsHKLhT7PuWVAxq4hquF/Y4gOe6gYMouRjo
LUSfoV12gF/BXk9cKMRgQcOQ1oPaEd7UyI8RjohBaJHQ/Ci/IxR/f92fRikG
3CTrrZcuOELgaN4VJyoxqLvXVFh1yxG82+W3+anF4PqbuIBTLo7w1qwxqQLj
Rda79yJiHUFWm7+PnUYMwl1E5NeeOsIxXq4wQ4x5uzZZ7zY7YnOvr++Ccb3Y
xz8tg44wqnLpwBJjg8jErtNbjlBE63xBEuPlKaPSDEYnMMk409mD7R+pIhZF
JuYE0ozb93Ux5s/bsbJXd4IfbbLthZi+d3utF3+ZOIFbindpB6b/5q0UHvBx
gszPtl+6sPxWq0z3n6c6gWjKx/5iLP8oxtP9zC+dILk6NdsQ86euZNat/rMT
BDFV6+xi/s2pFTCajTnBPcpTCe6Yv+yjd0qpdp0g1vOyWAfmf5HSUcFeamdg
v0S3cIjVp55m9iGe1RkGLzxMpfuLh+5fH9/78znDSsbU+iZWX9KH/ncFFZxB
/Cbf7o0NPHAo33nuqeEMFzRDpTqw/pA8Jrvddt0ZbtyR0uFewYPpk9Xkhw+c
waz1psaVeWy+XDrGWjydYTedsgk/g4cEVHKaI9QZRNXCtMax/mzst2hrzHGG
LKTzrm8QD7+eAgfTc2f4rGCpdqIPD0uup6ytqp3h7Ogwyzmsv7noe0lpOzE9
ClNdv9vxID1YpWsy4AwB/6ruxX7G+r84Mbdyxhk+XvbwoPiIB9+L2vK3D50h
7upqrs8bPCQz4CJKjz2E837XDLxe46FkiPznIftDUA7YmdN5iYcBjwbnp5IP
4bqwDrXPYzzIvZAsXjd7CFXqQj2jsXjQ86Lb0nB8CDcZJ0UTw/Fgo76gmuXz
EJYJcIYtEA+E0aJRSHkIZyxcPxS64GGTmZ09vuUhZMxR1tTfwAPt+Lrl+Dds
PZFGiPUqHgTLv1VKDz+E9IX5u2oaeDDQir46uPkQ9KiDWnll8FDpdxAmgnOB
T0867nQx46Ht0kCPr5QLaMn97uo4iodxtlq+LuQCHQfpvvmkeGB85dzgbugC
Q0G3dD4si4LT9OTGhygX6L/yY33rkyiIX22zMFp0AfyNrAV+J1GwjxwZqtt1
gd6RGzJW2P1d+uHPDRYqV/DKVMO73RAFCVlOrXY+V2i5EmOyoyAKp3ntxeVv
ucK1BtGxHHJROPuHbpPlgytsfL8+4x4jAi7i/I7OXa6grCdNm+wrApXWMrPt
Q67QbkBp7P9ABM4NGvcHb7vCrIR12AdtEZBuedmwKu4GkUmBLvRUIiBDuBb+
Nd0NzOU3+f544MDjm9Uh7okbKAmrBApa4qDmqI9XSKUbZEp2KItdw4FsQKGd
Qocb/HDrCa7F40DOdv1qMZk7lMt+vdY7KAwKCmnsoQ7uINtCoZIrIwxopK9Y
UdUDTt4gNT38Lgh21662Gup5AFWL8BOBt4KQ2vJx3N3IA1JdGItPPxaEuZLy
kxWeHqBQx2L5110Qkj1DYwVLPeC8xR39IA5BmGKUdKZj9YSvFroVnbcFIFI1
QnZ0xhO6aN0SKLr5oLv4/KfgaG/o8mC5HuB9CutrvouNBG8IWpB7bKdzCt59
pW3cLfQG1Z4X/Q48p+Dp6mS181tv+OGrtdvYygU+cslPjBe9AVeRUJzPzAV8
X5ZDFa76AN39Cz4Hr0+C8+wz1T/HfWEvqZLMlIkDrLxT3ktw+8KdEHv/qHl2
uHMsQPE+3hd0Mn+kDTexg9qZm1JjF31B7KyWHJUzO3B4Ugh0uvoCSWtTmd03
NmiiNCMr+ekLTeeSst5lsgKD8Mlms0w/6IrUbLmpxwziQhdsnzz1g3t1PX1u
eGbQFjRlmK/yg/LrcXSdFMwQzv/UyLnTDwycOrTO1TPBPve5vUfk/mDQERnZ
gmOCBXZtqRwHf/iKK8vnpD8O1OwOA6M+/nAhSz5x/TcjCLElBglE+sNlLTYl
qjZGMGX51VVS6A8dvTV54+GM0Mtobv+m1x929Z7smZIzQguNz5NfKo8gWU2I
Y5meHiaoc3VO6j6C/vKEF+TddHBI1bRudO8RvC3mfh2XRgcKlJQXpz0eQczG
zNLBKTp4RZY8sv7iEQQrZi+qS9NC3t/n7MfZAiBhbLGU3+MoeC31R11eCICC
GvxDWh0qMD3mmli2FQCtyiUvjvJSwWOW8PYI0kBI7I6VMN+ghNhzPN3zdIFw
tG5EkTOPEowcr42WCQfCI+XjP4o3j8C/6erd84aB8E+ToeS/1xTwx43swNo4
ELhIC6mF4ilghlyXJMMyEKj+cpzptqGATr45yj3nQPjhXTPOw0UBRKOTLI1R
gXDNKO24byQ5wM9HpzXeBsLKAq10sxMZSFu2n/VsDoS62owXB1fIQGSd/Xzx
50Aw5bzyJ0ScDBiPv1I8+iMQyIOCZx4skMK4zqRW52IgZIrpKGXfJ4XgFk2L
m9xBIPDRl4vSnQRaqxgzrIOCIGN5/8NR7wN0epTOwSsiCDpPRs+SaR6gjKPH
LkbHBYGjTO4pO9YDZGd2ZLEsMwh2RI6cCK7aR/QMe2jzVRDUPLkw1rjxFxna
Tc6GTAQBbdq/U0XRe6g5bexd2lwQTP965cRrsofwzcNJz5aDwOPQOf2f1B7a
Z+9TbN8LApORsf3+kV1U0Po1gYk5GDYFDJU35XbRAm+NbIFqMOyoqJ0g/7eN
9HWqaKsuBcPLH09ZRfu20TvPivEW3WCotaEvL6zcRvGdJTFzd4OBnjwtLs52
G0n5EUfPuAWDkh2VpnjfFvLrjYxofBwMR+P7OidbNxF9/N3ewSMhYPMln+/s
r3VE67zR/JA2BCbuv9BerFlHNNfjSqmYQ8A4a/HkSvo6omB7HyTFGwKF3Wcj
v9xZR3u5/OIxCiFw2fjW8OvJP2imbD5QwSkEIjTZUttJ/6CphOAH39xDQOzg
i8jTmTU0/pDzprVfCMiGKxLeta+hofNXxJKjQqCdqlEji7CGuhsqfs4XhUBm
gmY45Zk11Njhic/sCwH8xEQ6i90qeveSkfXMaAgYmslGmVxfRW+Snh+2TIeA
V17znSGFVfT6xuCP1T8hQIjQMr5Pu4pKhpUDtOhCIXU2iy7EYgURlo782FYJ
hftffWvnaZaRA12q/80XoWAQ4eTNm/obffs3m+77KhQO9AxOvn74G51bVazM
rw2FtmbuolDd32ine3Jm4WMoOOqbkw4c+41CM6T0AoZCYT9upVg9YgFlCfTw
F9OFQWGW9u3HkfPoszzTl12nMIi9SwgjqZxFeDHrCW6PMGgXJUiKE2ZRLFf9
vqpfGByQa54J85lF1w/NzsZHYvxzuqBBdRaNtLzK4i8IA7KlwxPKfTNoQ/ea
w+XuMOjM1CA/SzOD+KwTmXKlw+FTtkpOU+QU4qAPvKihGA7UaU8r6J2nEGON
k8uKSjiUE6fWwm9NoX9HdLtVdMPhylu9oQ3hKTTwhC555n448ERcnm/8PIlS
p6OPSxLDQS6zwvkn4ySitApj/EgTAfj1yWLC+3F0QOsO9owRkKu1S1//Yhxt
vLZ0ZmWPgAYVJVHSjHE0QaH2zUYwAo78lNncdR5H7x+TJdKiCMAttt5MFhxH
XlMBDDfdIsBg4P1T1eQx9NvCh35+JAJYrkaMrdGNIsPik4yu0xFgduRUmM7K
CGpZrD9+8DsCWtweCs98G0E57n9Zju9GQM9fjcWfqSNIJ8KPU545EiJTPeIe
84yg8pJHIlGakaDaJdo3B8Po5Ao3nvlqJAjmVJnhhIdRuNR7sVyDSPCtn3Iq
OjaMjN8dnn5lFglTn4x69HuHEENn4Pl+30i4ZDO+mvJwCDmvBV8UrYgESRGJ
utBXg1i/CqhV1URC26vbtqlZg0jL56P6hYZI+HyP+f1YyCDiJae4dK0tElhz
2C6cuTWIvrOE6XpPRQK7DHVWIckgOicXce8/jijgvav3bch4AOX54Yz1eaJg
zzIhsuryADra/NlkWCgKtgyCIz7JDaDJS9QWa+eiIGBzUK+AeQCl3o26f+JK
FIyI/t0R/dqPNh/FeNwPioKoJ6OskVr96FP3zLPgiCjQkzT4jVfoRxnCF/uz
46JA5WoBkIn3I4XOHcXOzChwPt/mf5WxHwWesiaVqoyC8Ua1XqPBPnT9YfM5
nbooiG1mhyedfUiglcvSqjEKyqMUDfk+9KFP9j2f0tuioIc9rbr2eR+ifQex
+xNRUGEjzGHs24dGGHIaWOej4DD2v9+XnfvQS4vt5dMrUSD/4u4bRyts/2Pl
18z+YvkQJJz19fpQxh1O9k/M0cB6PPdxlkgfsiv30Bo9EQ3St68Rz/L0IUWy
bu8dnmiYmGTcP2DF9n8eOYQXjwa9rFNcshR9SHB3syBBLRpEwvg/ik/2oi2d
az3F2tFw1vU40XmwF33OL6X4oBcN3lk+Ngs9vchOy8Jm41409HDZ0we29iKl
nMYMOoto+HiRhj2nsRfRrZ5oE74fDc7eoibLtb2oIv2b+G33aKi8M0cp86IX
Bf8WM3bxjYZcqbU0sSe9SB9FJMQERYPCv4jmW0Ts/JkLfxrioqHCBa9nkNqL
vihkCvSmREOgkuOsYEIvyozfMFjNjIalONJg8WjsfJkXtfxPsfNY6iXHA3sR
fTTlvGJpNMx0b/jG+/Wi0WGzkzcqo+FLkoySqxem52zDZce6aChK/ZyQ4Ibp
CePwj2iMhrjj+mmTzr3IoN+1PL8lGnozCu2dHHqRkETX6Ju2aIjx4JKRssP0
/Ai7uPgrGko+DgpaWPaiLJFx1yPD0XD83Lv4LrNe9MBP6Qn3ZDS8M1hzcTPB
9H1L/yU7j/kFf7euGWH6BNeprq1Ew/0MBLZ3e9GY51V5u81ouGCIXGtv96JX
7c/tQv5GA6/20xpkiOnjOZKTQxoD9xM9z5HewvS5mnZUU8VAaFAA/f6NXlTv
f4tFnz4GYshxo3wY80ZevbvKEgM1I16pMQa9KDxZvTCOMwbOtPtYyWP8O0dp
Hs8fg/2OCosSw1jvmZTkF5EYmG6QVDDHuOYV3tPqTAwsRfFUDmPM9Y6vkUwm
BoRPcYvnYfsHf+I4kq8UAw6dV6aLbvaiuW8MOhdUY0D5vinXCqbv6iBlysCl
GKBQpWUMxPJ5PX3Q76kXA9KcEyS3sHxPrm7wst6KgUKBn2fdMD8C937bVBrF
wK5A33Qv5tcMxWS5riWW7+V+02DzXqTDMLC5aBcDmmfoF1ytMH9OfFeKfhgD
r6f+fCm17UVsgl9CcF4xUKxsoC5h34v8Tr9va3kUAwz2YiWbTr1oQq7muHlY
DNS+rVWlxOqtpVpmeBgTA/xGZ41NsH4ov/KYmJMcAzRXFzRJ/XsRi2H2jHxm
DHwzuHd9MQirj32Um9vTGMjm12IkxvYiDc/At8fLYoDUv/S+TXIvKg3yJHtZ
FQP5jdJSPhm9yJNglTjfFAOfHtF4BmL9Td+kUmo8GANeFjt1Jz72Irc2ufW/
4zHwsvdzMGrvRQM/zihkzsUALf5CcSU2X0/nT33p2YwB1Vsi2cHTvegC896k
FmMs6I2eSP5B24cKT63hZ9hioQ9K853Z+xC1yNzDkFOxUNiAszTi70M/lH4d
NuBjYdvn8Bdevg/ZW1dySqnHwkhpsHehXR/qdn5u/u1yLHD98zj93bMPyfnm
P3e4Hgs1XoG2BmF9iDwxXrbYJBaC22g97xT0oaw3dvqnfGKhHX+5w3W4D5G0
mGXVB8ZCkoOP7Y2lPmTdaTh+KyIWZJwWBxIO+tC5SQ2n5NRYmJ6WST3O04/+
oxWIoXoZC71FRfS3rftRqvBPUunqWGixiv6vy7MfmUKEl+nbWJDUY+TJiOpH
W66/rd58jgUakKjmKe9H/INV8GAsFnyen/lw4m8/Wtqwqk2fiQVrPgYPcYYB
VEfPcbplMRbGam+cTRMYQLoX/ThP7cYCr1bUiQdXBpDfc7WtzuNxEP3cMEr+
yQDS/Lhl/5c9DjLpZHXp3g0gpuHiSRx3HETwM1Aq9QygYka674H4OND2dJgt
JRtEPz1/vjinGgdmivO8K1aD6LSGtRnBLQ4YL3ytTlYeQrsmHH0ffOJgITzI
3vbuEGrxbru6EhgH9Cbq4Y+9htCdstNKWnFxcLseu2FeD6EIlm22vSdxYLJl
7JQvOYzGJiK+GvXGwc7l6qNvL4ygF/vyqtHDceBPG1p912wEebAtvqmZjANl
1hfPnMNGEJ223jOGVYz9DdHfzhGk8IojuJk6HtpusBDKbUZRSsBzWSGFeBir
0S2XNxxDf3S3P/6EeChjZnrz1mkMXedV1wvXjIdvpBfHYiLG0PHmMdtZg3jo
Kxu0PVE3hhLIOLKeO8UDT92H2/+4xlFMWPi+xJN4iDHKcsnbGkcLN35EjryI
hxupzXbGzBNIW5ifNaEyHuIj5c96S04gms8NEqvvsfhMidIPDyZQBPWmceVA
POzLMho3zkygkBiLZhnGBGjY1CITXZlEE3dfXZllS4BfXufJKJim0EXxw/70
UwmgRifzR+v8FCLtyPqzg08AVY5XH1n8p1AAfbfAW/UE4PVLLft+fBr5JkE4
8k2AlsD48p96M2jALJ5pNSgBUo3NlL77zCCFc0N5+ZEJsFtM4a/1ZAbtdnvW
khIS4IF2x0T53xnkyfJy7mNFAoyuLiX5l88i1/RTl7VmEqBV6ialssQ80qLg
et6/mACCeTxcRON5xPXwJNWD9QQ42vJCPCZxHlk8iRnXIEmEeltlT5qteUQb
EJl7ny4R9I6xlH78vICMzwWzvsQlwtdvx8VMIhbRF9uglm18IhT+Y350/MMi
OkcMdIXTiaDURPHZ8mARUdEGfP8unQi9X7hoN9yXUMW0b9yGSiJ8VLb4OOK4
jMgy3Y8o3EsEbk9t+2xYRfZdbq+DTRLhw0k/ppsWq+jXETeLdvNEiPCbMHYI
X0UvXFya791PhK3LnzirO1aRgY6Tf4BHInR5cWe+N11DTw9tN1sSE6En79or
z8w/SNv63rRuayIEpw/46d/dRDaC8uKmXxLhhk1BLFnkJgqdYHV1bk8Exf+C
ck9Ub6JG4y6SpO+JYNewkxzMuIXO3rrI1T2cCKecxMv1v24hDi0RfYOtRDh7
wlIyyXAHnac8kmW5mwic2rxyrLE76HrL+JjbfiKwaj5NoG3aQbGQ7ZhGlgTe
UQP7t0R3EYk8ffQv+iQI5GWxcCfdQ7OiG02GuCT4Va1DZfXlL6KY+0Z1H58E
tQfNyg/J9xHv07Kr3hJJsGzR+fGv8j66w28zlCmVBN+apEzia/dR58mB7QGU
BA5yBNl35Qeo5ljTaSPDJMh+wnmsrfoQhS7F5JhFJUHC/fBfrqxk8DtcZrkq
Ngmoh6xwL5XJ4DrvOKJMTALRUPdWZEsGvPoykyWEJJAYVuU3f0cG7+rGRDeK
kqAoQt2mypYcNkPO14Y3JsG+iTb6+J0CrE+Ofn+xngTTWdsbtLNU0FEVJfBv
KwmCLlaIWXFSg/QVaXe9vSTY6kt+yaFHDWSBURybJMkw6jLamFRPDcRpKRNl
+mRwk6qx+5pCA30VkYvfRJIhgHws2ejWMbikeY5qyygZ1ChTDdj5GcDctn6V
wSwZzi1kTnkYMYBf1MUBUctkENVbGuHLZICK9utlRnbJ0EU+ZF1KzQjseq76
rR7JwO/3+GV+MCNMG74mpiYkA2WDcqiB/3EIspORk2pOBki73aseywxv4hTu
OwumwH4Dw6OxA3b4z/wm6ZHZFFh54/dJMYkXbMtCja8tpIBmTIKt7WNeoNyp
fJu7hK1PlomKqOWFi3EMHjIbKcD2uaM9e5gX3tV+WbAhTYWtFB9WJlE+qKBV
/NHGmQrVProaM+/4gFDD8yxRLxWEbaXXB3/ygzTpVYph/VR4JcrF/XKGH3ou
+5mJ3kqFylV1T7ttfmAc7+P8YJQKh7MJJRkcAhB9LDlx3S4VzmScOfr1tgD4
m1L43AxLhTYWly+3ewXA8ui8Dld9KgTwqp4mNghC9dCGimRDKljTCrELtwkC
5UsSWbWmVGiVYHqZ/EsQivU5+Ow/pcIk+7o714ogLOZobr7tToWss281VriF
wP3M09y7v1Ph6IVkPR9vIfhEWpnstJwK2fEparqhQsDxoyEiZC0VRM/7XaRO
EIJ6r58PX2yngiBTxj+hx0Lwr5lC4y95GpgZPzpC3yEE4QYWy1lcaeA8F6Xs
f0IYeoWdJst50mA8TMUnkl8YRHZ9+j7wp8FvdMTWQ0wY2nKTPyyIpEHtrArN
npIwMMw2ExTOp4EE3DyXZywMpm86Yq7KpcHyf5sd76yFoTKmP9BcMQ0qjer8
GhyFwUByzS5aJQ1ypDybLB8JQ4Y3Lxq4kgavRrUatXKEYf6yuPSyHrZeeqLJ
vUgYFLjlRMkM0uCxmK1saIkwDH3QZcbfSYMjYt1n1euEgZc2YNbbOg1IJe05
b3QLw8OR6KG4+5i+uaTImD5h+FBB+F5gnwafZSo/F44Ig+WN8rf/uaTBtdNT
910XhOF53nDCiYA0OHC4uZ9FggM1ndoEp+A0OJkh66NGiYOx3cSE1rA0uFUk
kPLlGA7YbqglPIxNg5KOEDFTNhy8IuNO+JyQBiQmEy6unDjQqdiOP5WSBuFi
P+dNeXEQcuxF/H+ZaeC4pbPznygOuN+ExvPkpkHbx1FD9dM4qLc2jnfPTwO9
XxK+WedwsNp8PJ7vWRo8qaNI/66Agxin33GeJVi9HgTcrlLGYe/NrXEdZVi8
TJaT40UcGHl5xXm/TgMKaU0R50s42BG6HtdVmwZMwcUpNTo4SO0RixN6mwbl
YsZTP3Vx0HZ6NPZ7cxocfYz/nHcDB1ZDdbG41jSQsj7Nr2WIA5Lo5Fj/L2lw
nUxz4787OJCdVo8V7UqD24NhiTdNcNCdzBMb0I35/fmCoJkZDhxhN+bnzzSQ
6Zb9oGqBA5rl7hix/jTgdMjU/WeJg8fZpTFBQ2kw3xP7KtEaB+hSeEzvaBpE
l0R27NngYGDLJEZiMg0e6nFEKd3Hgcdj+ZiQmTToVSNru2GHg+PXmWP659Pg
T7Oeh8YDHJQeLkafWUoDaQ1BN3p7HGiVfYoOW02DC+THSsownryTHz24ngZa
P//7J+CAg0fUPtFnt9PARM359kOMT9ToR0fsYf1pylGQhvFrC4no4YM0SGwx
aUjEWO84VbQUKQGuaJOnm2P8u3EsKoqCAHc+n2A7hnG4fX3UKBXGyZcForHz
+E+mRp0/RgDXX03PRjF9DZ8domLoCWDKxhZ3DGNDd82o8eME2K2520CH5bPO
zxcly0qAWAoegRlbHMR/24uM4yBAwr7881TMD/yjH5GTnARgXbRRPIH51SpW
HinPQ4B52fBWV8xP0/6IyAR+AtiFqEo/NsfBfrhZ5LQQASRuv3UrMcVBurRi
pKIoAa7+rXQLN8bBuQmWyCRxArw/6c8vdw8HHQnLEbNnCEDTLOnw/jYObC98
ibggRQDrRwZqXLdwQMzwjZiXJwBLreidm9dwoKBxIwJdIMDDuUhfqas4+LV+
OiINCODYwrIyrY0DWt2JcBVNAvZ+QpvVpoqDZ/tvw9O1CRCjdbt+H+HgYkla
+NIVLF/T3H/kSjjwPnIpPNOAAP8sdDqSpHBwlfTv8ugtAjBw0aZKnMGB4EHp
LeG7mH8XPBeJeBx822AUrTIjAL/2cwVqPhzgpvravzoSoKSdZmUGm8f90Whp
ZhcC9NSR98pg89o9qJR72x2rj2DNBSNsnh/15DvO+BJgW3AsTmJDGH5+sD1O
EkUA1Z3/6ob6haGk8aSPRiwBPtRIUY5j90dg/deJ2AQC0H47ffi2XRjEKyVf
nyAQ4L+mFJ6td8IQUrBzU6qIAN0S7xL9coXhbGBkjnUDAWYEfT6M3xQGSj+F
I2VNBFgz2LU2vILdV56LDusfMcY/+/NUVRginfRQYBsBwpu3lL6eEYZRY46J
zF4CiKYLXlakFIa4C8W4jjUCcONyJTteCIG5/J1E5k0CpDwNz+8hCoHcedrd
2zsEeDKaHvY6RQimxJ3bZv4RoPDa62BKXyFQ5JJzIKFNhyahH+ZrmkIwv/e5
Uko4HcY9to9wDAqCy6NbVSqi6WC3UHG9t0MQ9khnq3TF02HC5YORd5MgHKWh
rH5wLh3wBf8KrJ8Igji7Wm2RcjqUd8vULToIgrNU01vmW+mwILswNLYrAFsP
6lrWI9LhUK9Yw+qQH8iHi39VzadDw9XslKM9vPA8iaS8piED4lht44pr2OG0
l+K1zqYMSBrfaL6cwg6vjT02pj9mQKXtrVvUzuzQKLaowNqWAYZ7vJe7RNmh
p7X3s+uvDOBtehNKzGODg93yccmVDNARIE/LiWOFa+ZGrC94MyE2ZzVJLYQZ
fmll1H0QyASP5k3PRgtmuHem5+6AcCacGzaLuKvGDNb7WoU0EpnQEz03d3iE
GXwJ0mds5TOh1GqiaSuaCZ60HbskdD0TWrVd2Juyj8PuuXo/YkgmMLOtT52q
YoA6m47IZ+GZUHeF5anzIwbwyhlLfRmVCRlfG7zptBlg5whV2fuETKA5PB0q
NEEP2336w6PZmaBW3VbexUoPm4+WLvC+xvRs7f84GkMLa228h/lTmZB9aSmy
opQGKg6ljj2fzYQuD+Vm6SAacJbWZH+1kAki3z9+IblJA6u5DmeaVzPhSOm5
TCcSGlhxrjcZ38f0x/ooFBlSwxKbQRMfaxYcClhun2ejgnnziKBC9Sy4a+n7
3rGFAv642GYsamXBd7FXOnF5FLAffOmljE4WqE1KJ257UQBj0bHhtutZEM+f
/L7sNAXITSbIrZtkgWpSNCLkkkOkRcaKqk8WaDeya5FGkUGyqzdlvH8WMP/J
NSuzIYOckDun+gKzwHrDaStPgwwqirgu20dkQfs69YreETLoncx/mpqaBUn3
SiKmwkhB2PK50XR5FsR65Rfap5CApFu025nKLKh+2u+v7EECCqEPYryrs6DO
K/6U7m0SuPpY4g3dO0z/jsY2npcEPKZescj8lwVxq7ScwWaHqNWyvj18Mgse
hoTco6s/QJZW7fIiHNkw5PBWaqNhD/EeRM3Jc2ZDnssTDULqHhpO1Uq/zJ0N
Zywv0sQ/2EM3W1o3HAWzgZVOfM335B7SEmh6WS2ZDRI9Qm+V/XaRxPhrIdVL
2aBaK7fYcXUHLXi5/jDQyYbclTq8H34HPWU8F2Ktmw3LLBPV7pQ7iBdejkXd
yIYD9QeSWu+3ERPxefY3s2woKsy7e1t6G23dyztu7JMNeK9Z98diW6hy416T
k382PMv6xNh4bAs5xXI6BQVmw6skthsnFjfR3NuMr4/DsyHASSYmuWwTDZ5M
ifidjOnV1JoIkNpETX0RB14vsuEy84XUNu0NFGXwcD5lKBtsrNgK3Iv+oMTP
B4Wzo9j3JrbniiP/IIJC9D3FyWy4ENfjz+L4Bz3mLeqamM8G9V2xzXT5P+j9
4o/qs9vZMDLO9UyhZw1thsoFdx3PAdo7WRbujGtof7tFUYA1B7IJXLGku6uI
7MG1TQ+OHGBQEB9tHF9FjNfsbLl5coB7NomxvWoViZ3KueogngNT53+ocN1Z
RWbVhyePaebAd1MROQ/jFWQrEvvDWDsHnrYf8KidX0GO2RzxlVdyQLX+3qIV
7QryCzpLescgB0jUutcK3i6j9CsWs8VmOXDZUMBx+tQy6pj+VKXhlwMPrmgN
rqwuInm2eJ3gVzlA0RlDUPi6gP4w7uTmvs4Bb3/ji0rlC6j0mPlKXW0OeG3l
KbslLiBuUpnklYYc4HT9ZxV2YwFRLA733mvLgUj2tljeiXn0rVnCQnYyB8zj
mVNGKeaRtUOH9yJLLiymoPt/HGYRr61sOxVHLmhuf4s6vDGL+s0LuAQ4c6Eg
Pz1FVnkW6Ri6v7/Nlwvp79fVcQyz6JzqqSOfJXJBy+RK0UHlDDrgcEgs0MgF
RhPl9CtkMyi1hfbZTa9c6P8p4TjbMIUi6XTNzH1zYfvst3iFF1PI72YSp+Oj
XNhK2D1XkTGFLOdYE8NCc8FwjMKazG0KSdPyeL9OzIVWwYbryuJTqEf/7GWm
57nANnnIv1k4iT7luB7hLs2Fk8xBd02SJ1H9dPV70Ze5UMuw+Xs+aBIVeipI
q1TnwrvijjwTs0nkkq16yrk5F/S6Ss+18U0ipskbKx39uUBSMk4XVjyBKMUz
nvcP5cIJUgW2ucwJtOc2YDE9mgthwoVD92Mm0ASlSd/+dC7sdIvr/uc4gV7h
bZvF/uTCZ5/+5E2ZCaTn4pMSdTQPBq44Sq9/HUcJpERZdcU88HU+E8/KMI46
hV7uJyvnwaNp0vNq5OOIVvt985hKHiyd0f2Ruj2GIpNHL/tp5cFJYc9v2WNj
KFCA17TqRh5QyOploddjyFm9IJLPOQ8cFDqFes3GUPn9V1ecXPPATe83E5/h
GFqMa2Zq8MiDpPQ6v9irY8j213iOoX8e1AQoV31WHENmNvyvEqLz4HnL+p0u
9jF0Paqo/+BxHvz1jMxTKx1FiWVVeZeL8yBgMpCRMncUdX7/aJH5Ig8KJCtM
j8aPIu2TU0vSlXnw9ENrxaDzKFJ9IUhm/z4P2hKM5gvkR1Fwl/TnNx/yYO/D
EQ5f8VHUtK4WS/UJy2fyvF06zyhSUrJiK/qaB94Rnc8zKUeRdMcT/EB/HgSK
DZz71DuCXNaqV3DDefB73P5Y/dcRVMH66bX7WB4sziuErTWPIHHjGeXjs3lQ
5VH2XKxsBNkFb5GbLOTBz6BR/9NFI6j4KeV/pUt58Ph7iKZ75ggSXBHW19rI
Az+2XY6u8BFkzizLQdjOg0a0pjfhP4LyZTWHJ/fy4D2yH5d3H0FcgTY2AaRE
AFI53xrLEcR6vNi3hp4IKhRDDXMaI4iyIa2v/TgR9P/8dUuBEbRlG3J+nIUI
ds1kET4KI6ivyXjlGCcRihWYz/07PYL+s9fR4eMmQvLHNcps0RFUz6HwXIaP
COQxS2VugiMo25nVwgxHhBzD66sjJ0dQLBd5kweeCEUj5F1ObCPI78sqV6wE
ETz/+0WuzDSCHNxGvAsksf0Dyiou0Y8gY96vv2qkiGDKfrCTfHQE6X59I/VV
hghLFniyk1QjCLyeJY7LE2HyccXaCPkIkhRMW9pSIgK6zbA0TjKC+L4Fa9MC
EeKbyDkF/g0jJj/nZ3yqRMhr1H9c+HcYkYkYU8hqEGECNl6Z7g6j9Z7LZjqX
iPBwZdDeaHsYTQXIN5rpEMEql/UwY3MY/RTDcXrqEuH02kIq88Yw+tTL4hV7
nQirEkt3Ov4Mo5oQsp8FN4iwhsr9P60No2dnVs/WGhKB80Yd/nB1GGUMDsd/
vYvtFzmX5IlxZET773FjIiiSuEyewdhb6o3WthkRMhijdUUwtht9+oTWigij
ialUZhjfjUkl47clwtQ3LTSAsY5ssInsAyLgLhXiU7HzlCad3uk4EoHlX+5B
PKZHIsHohPlDIqTFWi21rQ8jbsXLHp5uRCg/XnJWC8uHflauJ9aTCGITTmRU
WL6HycKShT5EkLj1Lp0K82NVmSWu1p8IfOt5eG3Mr/EF0oWvgUQ4oxG91Xkw
jLoJKxoTIUSocFOXJWB+f7g4XLQdTgSanCWRfKweVcttJHTRRDB3/ECzRDmC
HmfVGfHHYfXX6ufwx+qZqvG0XjaRCI2uLml6WL098oLczAlEIMkeH/6A9YeN
ttN3z0wivNWYPm3OOYIMt+6djsshgqwP/Y467wiSvyo3V1tIBA7BxmND+BGE
3xNS73hChGY3x8l4yRF08ilz4UQxEXsvZdWLkBlB+wfLd+leEmHvyQ9GbdUR
tPR8qI6/kggEIeF9Fu0RNHKjjVWumgitZ1++EL42gt6XPekyf0uETa7hRB5T
bF5vp4h7NRJBmk7clsoWm68jQVFxzVj8o6vqss4jKNjonmrdZyL8KlYycQ4a
Qep0zLV0P4hwKPQi6tqzERSY2slt1Yvly0hWblqJzQtndPi7Aew8E+3nnxuw
/sWT3nwwTgR+9y80xJ/YvGqubHxZxvwuufg3kGYU3eosucf7hwhSuzym99hH
UfIN6xbPTSLs4KvjU4RGEbXlcIrwPuaXH90DdtVR5NNkdeIDRT4UT4kZhwaP
Io5Q1Q4HynwINNLVuZIyiqo1+YJOUOcDrfRVD4/Ho2i1c2jO+Vg+XLHpHvn9
eRRZD+vX8TDlQ+35Zbp6mjF0bU/llj9PPqgPy6m2Go+h5QaeY6J8+WDpfTvu
mt0Yig06aPzBnw93Xs3KMXuMoU/Ub4TFhfMhW6PytFz8GFJil9waEM8Hebqr
55mbx9DAAF1J+Ol8MBD35bvROYY8834bnZPMhyxRzrCuwTFUKfSsNUoqH+ym
zt50wp4fItLcaXIK+ZAS+GDc+uw4+rT9V2tKMR/0XARUvWAcWbzt30+4kA8P
2HYiWnXHUd7FNMtZyIfKZ3nhrE7jiOUarTRBMx+4emUNMyrGEYnjXve6QT4k
avXiCWgCvTVUe5t+Mx+QU8Rz9esTyEM1vkjRMB80TB0CZawm0G8OfreQu/kw
fFZFawR7Xv76eImV2TwfTgd+F78xNIFKT2TeOueE+cv0VeJe9CSyoZhEv5zz
Ye9tynPzgknEvyIu4uOCrVdnD6iqm0TpLU07ze75kPdBpVZmbhIFO81lXvPL
h53lwb8/tKfQrVbZIeeofGAZIDJR8EwjpoqgFpaYfGh3PkP2T2Eafc1qL62L
zQevtNZ9nVvT6KKziT9JYj6oSW3uLiZOI3HOCO5EApb/bszAJeoZRPbwl+nL
onyYXptcFaCeRQ13eS/pP8kH5vLJzv9EZ5GXht3Z7af5gOttk/9+eRYtcf4j
RSX5IJV1hYs6aRb1fRIq6qzAzru7p3Sadw6Vc7lPLzXkQ/q/330C1+fRxfay
TPf3+dDMY2BJ8JxHv7xnrhw05QM9OnPXLnce/ft1q4a2JR883I5VyS/Mo6tJ
ChFibflAEcvsHhu5gFaOkIje/5UPmgGsifV9v1Hoa7nh1d58cNcyzn1CsYg4
LB4mefVj/lcvWR5KLiJomtiNGMLqYzL3gixmESX6tLY9ncgHKn5jnJnaEpJc
ibafWs4HRWHgu9yxjFpyP/Lar2L9d3N8PJ5kBRnq7P9YX8uH+5vmonrSKyjw
ucMF8s182J57fFo3dwV9s9Cj5/+bD58lJq+XKawi5z7WChOqArA38aFR41lD
r5rz1wd4CsBPBEpUuNfRghGUhfAVgJ4yseOx6joS3Bu1FhcogL7YWk+r++uI
cI5nwF+4ACZu28iT1awjn6LcJl6JAth/KmHfoL+B1MKy4qwVCkAbWe0NFmwi
fz4FTQalAgjUmqp16NhENQ39JHUXCkC/7lW07e4mEtnicKNRKYAicgXjnOtb
iM4m/U6pZgHsNimoHT+6jX5ppeL+GBTAKxNTvx9xO4hhWmo862YB/DKeSdBt
2kFaQT1ZqoYFsJN2wwWt76D6N0z0aXcLgE9vJjbwzi4i4pM2ZM0LQOqGmmXO
6T1kSxvf7O9UAF3azlcHl/6iva6IuzTRBeBt5LRr0HGIaCXZxtNiCmDewy2r
9AgJ8CQ+tuaPKwDuW8uCvwVJQE2v+aFiYgEM8fMFcluS/P//tQgHQgHYpQ4x
Wk2TAP93h9ffCwtA1sAk+Mk6KVzq1qfLelsAluUmV22BAu6dm0gWbsDiTQgX
LW0owDHZmaOqsQBO/blAUhRPAcnX4wS+NheAuhClyfwwBQx1f5L/97kAyqgu
nsoNOALOPfLW5j8K4FbjscnaLkrI+MHzHr9UABerAxREi2jgy92T3i+XCyBd
/3FizXca2JlgkZJeLYBPZTtxYSRH4dYazbML6wVwfar64pzxUWCj34jX2y2A
nvdCLxq5j0Gq5hdjjyOFUC1iTZZVQgsJ9c7/mk8Vgk5ZnOH+GgOE5zdfuH21
EO4o6bdzZjDDXVaBg3+6haDxU/Wt0RtmkIwOfff4WiE4v2afrR9ghn5XTcVV
g0JYGGV0bD3FAuKaHXIRdwuh5nK/LeMTFuhZ6pOqti0ENpvwHb46VuBVXBU9
HlIIBkFriuRL7FD/k5vtv9pC0Gqr4x525QJbeqeC628KYf6JvGpxGhewab4X
H6ovhPNrGvIOtVzgUmeiutJQCHqOgkETe1wglp3vzNpSCF+IAZ8eBJ2CHFP+
drNvhXCXN/RCSCw3PPotFLg3Vwjvg3Svxl/mBXFBj2OhC4XggJuWSrjLCwP3
PhHoFgvhftB8TegDXpDptC7jXSmEyE/6GToxvLBS8WxAY7MQTtMzrWq18YKp
h+j5FNIi+PCFU79RnQ9USSUWxE4WQQPNZ2qKs/xAwE35/OIsgh5+twF94IeF
K9nHgk4VQZ2161icLj8kZtFI/OItgsh2lfj3DvwwJDXjFIgrgtfMqIbpOT94
WBM3f0gXQUb/w3I1TgH4L/ZmeIBMEew5jL3lFBUArio6drxcEUyVLJj0ywjA
x0NfuQDFIphR3M6mui4AjJmGvqIXi0C3T9UIHyEAJe3HSR/pFoGGbsRX40UB
OFj7kiRyrQjiez0hckcA9DgC+XuuF8GOkNCNNApB2LZcVhW5WQSMFko1t7kE
Qe1fW3j3vSJoSWjoDdcWhBHJUFqcXRG8dVWl0isQhLO3FHO/PyiCm3Olr/Jf
CEKo/x8JP4ciOMtwN767WhDE2kx1vzsXAZ18sV7/f4LgZXEh2dezCFgNr513
WhWE44Qt9m+hRcA/zCtDlBWCsb++vUMYl/UnWo9iXGFGmj6PccRcSAKPnBDo
SdCykYcVQcXaWhsR48QWPhYZjL8ZTs4S5YWAfl2HMQfj0cqFN3mKQkCrV0Rt
G14EhAm6BgISgqFqkS9uGM8nWR/8xLiUszwiCGMyPkUZVhACndk6ymyMZQsN
k1IwjnnUSdGJcaaCyVKCihAcLdslkY4oAnchW6UIVSEYYApoAoyV3OwpPmFc
4kUReAVji+z5Fgo1IdBWYzi0xtgp5sqZYIyjBgUPMjF+n1f93E9dCAxVSt49
xbjtns/5txiLPDvjV4Wxq2DNm12Mv7go/P2KMX4+6YWHhhBk9L2v78c4wuXs
iWqMbZXVfWYwPsGtGbCOsdzjNvl1jCkru4fPagoB9VG93UOMPTZ6pJ0x/h/n
b+F3
          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox[
         RowBox[{"Bind", "(", 
           RowBox[{"KKKp", ",", "KKp"}], ")"}], TraditionalForm],
       PlotRange->{{0, 2500}, {0., 13.518450359280115`}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {4397.142857142857, -1501.8225926622445`}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[18, 23], 0.782608695652174]], LineBox[CompressedData["
1:eJwV2Xc81d8fB3CVUHYoqa8ksgll57xDpUhWUvZI0iAhpOy9ufa+l1JWJaNh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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0.3},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox[
         RowBox[{"Bind", "(", 
           RowBox[{"KKp", ",", "KKph"}], ")"}], TraditionalForm],
       PlotRange->{{0, 2500}, {0.2611539428857392, 0.932123837030518}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {5374.285714285714, -1501.8225926622445`}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}]}, {InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[19, 23], 0.8260869565217391]], LineBox[CompressedData["
1:eJwVlnk81F8Xx5GULFlLlCxZI0JlyzmWaLGVrSKFEv3ImrLv+z4Gg8HMIHvZ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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox[
         RowBox[{"Bind", "(", 
           RowBox[{"KKph", ",", "KKpp"}], ")"}], TraditionalForm],
       PlotRange->{{0, 2500}, {0., 0.24566590443745082`}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {488.57142857142856`, -2102.551629727142}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[20, 23], 0.8695652173913043]], LineBox[CompressedData["
1:eJwVmnc81f8Xx23JDhGSbBKy530fKlSyQyUZJUmZIXtlC9e+ZFyUksiIZIb4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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox[
         RowBox[{"Bind", "(", 
           RowBox[{"KKpp", ",", "Kp"}], ")"}], TraditionalForm],
       PlotRange->{{0, 2500}, {0., 34.33177896127925}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {1465.7142857142856`, -2102.551629727142}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[21, 23], 0.9130434782608695]], LineBox[CompressedData["
1:eJwVl3c8le8bx9PQsOWYx957ZpePEXKsSKlIKJHKHpVkZnMIh5BzkEgiZJSM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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox[
         RowBox[{"Bind", "(", 
           RowBox[{"KKpp", ",", "MAPK"}], ")"}], TraditionalForm],
       PlotRange->{{0, 2500}, {0., 60.47442471246977}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {2442.857142857143, -2102.551629727142}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[22, 23], 0.9565217391304348]], LineBox[CompressedData["
1:eJwV2Hk8VG8XAHD6SRuypJBKhJKQNcQ5RaUQIVQoa6XsSxJl37Mb28haUaSS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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox[
         RowBox[{"Bind", "(", 
           RowBox[{"Kp", ",", "Kph"}], ")"}], TraditionalForm],
       PlotRange->{{0, 2500}, {0., 0.8802297415144474}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {3420., -2102.551629727142}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[1], LineBox[CompressedData["
1:eJwt13k01P/3B3AqohDJJ2mzlOwJWeNeKlSykwplbc++hOxj3zNjG1mLirKT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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox[
         RowBox[{"Bind", "(", 
           RowBox[{"Kph", ",", "Kpp"}], ")"}], TraditionalForm],
       PlotRange->{{0, 2500}, {0., 0.5320371117753424}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {4397.142857142857, -2102.551629727142}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}], 
     TagBox[
      InsetBox["", {5374.285714285714, -2102.551629727142}, {
       Center, Center}, {900., 556.2305898749053}],
      "InsetString"]}}, {}},
  ContentSelectable->True,
  DisplayFunction->Identity,
  ImageSize->900,
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{3.401470073371037*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell["Model 2", "Subtitle"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model2RateConstants", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a1", "\[Rule]", "1"}], ",", 
     RowBox[{"d1", "\[Rule]", "7.5"}], ",", 
     RowBox[{"k1", "\[Rule]", 
      RowBox[{"2.5", "*", 
       RowBox[{"10", "/", 
        RowBox[{"(", 
         RowBox[{"10", "+", 
          RowBox[{"Kpp", "[", "t", "]"}]}], ")"}]}]}]}], ",", 
     RowBox[{"a3", "\[Rule]", "1"}], ",", 
     RowBox[{"d3", "\[Rule]", "14.975"}], ",", 
     RowBox[{"k3", "\[Rule]", "0.025"}], ",", 
     RowBox[{"a4", "\[Rule]", "1"}], ",", 
     RowBox[{"d4", "\[Rule]", "1"}], ",", 
     RowBox[{"k4", "\[Rule]", "1"}], ",", 
     RowBox[{"a5", "\[Rule]", "1"}], ",", 
     RowBox[{"d5", "\[Rule]", "1"}], ",", 
     RowBox[{"k5", "\[Rule]", "1"}], ",", 
     RowBox[{"a6", "\[Rule]", "1"}], ",", 
     RowBox[{"d6", "\[Rule]", "1"}], ",", 
     RowBox[{"k6", "\[Rule]", "1"}]}], "}"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"model2", "=", 
   RowBox[{"{", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     StyleBox[
      RowBox[{"phosphorylation", " ", "reactions"}],
      FontColor->RGBColor[1, 0, 0]], " ", "*)"}], " ", "\[IndentingNewLine]", 
    
    RowBox[{"(*", " ", 
     StyleBox[
      RowBox[{"Non", "-", 
       RowBox[{
       "competitive", " ", "inhibition", " ", "of", " ", "first", " ", 
        "stage", " ", "of", " ", "cascade", " ", "by", " ", "Kpp", " ", 
        RowBox[{"(", 
         RowBox[{"MAPK", "-", "pp"}], ")"}]}]}],
      FontColor->RGBColor[1, 0, 0]], 
     StyleBox["  ",
      FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[EmptySet]", "\[RightArrowLeftArrow]", "S"}], ",", " ", "1", 
       ",", "1"}], "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       OverscriptBox[
        RowBox[{"KKK", "\[RightArrowLeftArrow]", "KKKp"}], "S"], ",", 
       RowBox[{"{", 
        RowBox[{"a1", ",", "d1", ",", "k1"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       OverscriptBox[
        RowBox[{"KK", "\[RightArrowLeftArrow]", "KKp"}], "KKKp"], ",", 
       RowBox[{"{", 
        RowBox[{"a3", ",", "d3", ",", "k3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       OverscriptBox[
        RowBox[{"KKp", "\[RightArrowLeftArrow]", "KKpp"}], "KKKp"], ",", 
       RowBox[{"{", 
        RowBox[{"a3", ",", "d3", ",", "k3"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       OverscriptBox[
        RowBox[{"MAPK", "\[RightArrowLeftArrow]", "Kp"}], "KKpp"], ",", 
       RowBox[{"{", 
        RowBox[{"a3", ",", "d3", ",", "k3"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       OverscriptBox[
        RowBox[{"Kp", "\[RightArrowLeftArrow]", "Kpp"}], "KKpp"], ",", 
       RowBox[{"{", 
        RowBox[{"a3", ",", "d3", ",", "k3"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      StyleBox[
       RowBox[{"dephosphorylation", " ", "reactions"}],
       FontColor->RGBColor[1, 0, 0]], " ", "*)"}], " ", "\[IndentingNewLine]",
      "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       OverscriptBox[
        RowBox[{"KKKp", "\[RightArrowLeftArrow]", "KKK"}], "KKKph"], ",", " ",
        
       RowBox[{"{", 
        RowBox[{"a4", ",", "d4", ",", "k4"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       OverscriptBox[
        RowBox[{"KKp", "\[RightArrowLeftArrow]", "KK"}], "KKph"], ",", " ", 
       RowBox[{"{", 
        RowBox[{"a5", ",", "d5", ",", "k5"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       OverscriptBox[
        RowBox[{"KKpp", "\[RightArrowLeftArrow]", "KKp"}], "KKph"], ",", " ", 
       
       RowBox[{"{", 
        RowBox[{"a5", ",", "d5", ",", "k5"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       OverscriptBox[
        RowBox[{"Kpp", "\[RightArrowLeftArrow]", "Kp"}], "Kph"], ",", 
       RowBox[{"{", 
        RowBox[{"a6", ",", "d6", ",", "k6"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       OverscriptBox[
        RowBox[{"Kp", "\[RightArrowLeftArrow]", "MAPK"}], "Kph"], ",", " ", 
       RowBox[{"{", 
        RowBox[{"a6", ",", "d6", ",", "k6"}], "}"}]}], "}"}]}], 
    "\[IndentingNewLine]", "\[IndentingNewLine]", "}"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"model2InitialConditions", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"KKK", "\[Rule]", " ", "100"}], ",", 
    RowBox[{"KKKp", "\[Rule]", " ", "0"}], ",", " ", 
    RowBox[{"KK", "\[Rule]", " ", "300"}], ",", " ", 
    RowBox[{"KKp", "\[Rule]", " ", "0"}], ",", " ", 
    RowBox[{"KKpp", "\[Rule]", " ", "0"}], ",", " ", 
    RowBox[{"MAPK", "\[Rule]", " ", "300"}], ",", " ", 
    RowBox[{"Kp", "\[Rule]", " ", "0"}], ",", " ", 
    RowBox[{"Kpp", "\[Rule]", " ", "0"}], ",", 
    RowBox[{"S", "\[Rule]", " ", "1"}], ",", " ", 
    RowBox[{"Kph", "\[Rule]", " ", "1"}], ",", " ", 
    RowBox[{"KKph", "\[Rule]", " ", "1"}], ",", " ", 
    RowBox[{"KKKph", "\[Rule]", " ", "10"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"KKK", "\[Rule]", "100"}], ",", 
   RowBox[{"KKKp", "\[Rule]", "0"}], ",", 
   RowBox[{"KK", "\[Rule]", "300"}], ",", 
   RowBox[{"KKp", "\[Rule]", "0"}], ",", 
   RowBox[{"KKpp", "\[Rule]", "0"}], ",", 
   RowBox[{"MAPK", "\[Rule]", "300"}], ",", 
   RowBox[{"Kp", "\[Rule]", "0"}], ",", 
   RowBox[{"Kpp", "\[Rule]", "0"}], ",", 
   RowBox[{"S", "\[Rule]", "1"}], ",", 
   RowBox[{"Kph", "\[Rule]", "1"}], ",", 
   RowBox[{"KKph", "\[Rule]", "1"}], ",", 
   RowBox[{"KKKph", "\[Rule]", "10"}]}], "}"}]], "Output",
 CellChangeTimes->{3.401470073848596*^9}]
}, Open  ]],

Cell["Predict a Time Course", "Subtitle"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sim", "=", 
   RowBox[{"run", "[", 
    RowBox[{"model2", ",", "\[IndentingNewLine]", 
     RowBox[{"initialConditions", "\[Rule]", "model2InitialConditions"}], ",",
      " ", 
     RowBox[{"rates", "\[Rule]", " ", "model2RateConstants"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"timeSpan", "\[Rule]", "2500"}], ",", 
     RowBox[{"MaxSteps", "\[Rule]", "25000"}], ",", 
     RowBox[{"gridPlotVariables", "\[Rule]", " ", "All"}], ",", " ", 
     RowBox[{"plotColumns", "\[Rule]", " ", "6"}], ",", " ", 
     RowBox[{"ImageSize", "\[Rule]", " ", "900"}], ",", " ", 
     RowBox[{"plot", "\[Rule]", " ", "True"}], ",", " ", 
     RowBox[{"plotVariables", "\[Rule]", " ", "None"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Warning: \"\>",
    StripOnInput->False,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]], "\[InvisibleSpace]", 
   StyleBox["\<\"Initial conditions are missing (and assumed to be zero) for \
the following variables: \"\>",
    StripOnInput->False,
    FontWeight->"Bold",
    FontColor->GrayLevel[0]], "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Bind", "[", 
       RowBox[{"KK", ",", "KKKp"}], "]"}], ",", 
      RowBox[{"Bind", "[", 
       RowBox[{"KKK", ",", "S"}], "]"}], ",", 
      RowBox[{"Bind", "[", 
       RowBox[{"KKKp", ",", "KKKph"}], "]"}], ",", 
      RowBox[{"Bind", "[", 
       RowBox[{"KKKp", ",", "KKp"}], "]"}], ",", 
      RowBox[{"Bind", "[", 
       RowBox[{"KKp", ",", "KKph"}], "]"}], ",", 
      RowBox[{"Bind", "[", 
       RowBox[{"KKph", ",", "KKpp"}], "]"}], ",", 
      RowBox[{"Bind", "[", 
       RowBox[{"KKpp", ",", "Kp"}], "]"}], ",", 
      RowBox[{"Bind", "[", 
       RowBox[{"KKpp", ",", "MAPK"}], "]"}], ",", 
      RowBox[{"Bind", "[", 
       RowBox[{"Kp", ",", "Kph"}], "]"}], ",", 
      RowBox[{"Bind", "[", 
       RowBox[{"Kph", ",", "Kpp"}], "]"}]}], "}"}],
    StripOnInput->False,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
   Style["Warning: ", FontColor -> RGBColor[1, 0, 0], FontWeight -> "Bold"], 
   Style["Initial conditions are missing (and assumed to be zero) for the \
following variables: ", FontColor -> GrayLevel[0], FontWeight -> "Bold"], 
   Style[{
     xlr8r`Bind[$CellContext`KK, $CellContext`KKKp], 
     xlr8r`Bind[$CellContext`KKK, $CellContext`S], 
     xlr8r`Bind[$CellContext`KKKp, $CellContext`KKKph], 
     xlr8r`Bind[$CellContext`KKKp, $CellContext`KKp], 
     xlr8r`Bind[$CellContext`KKp, $CellContext`KKph], 
     xlr8r`Bind[$CellContext`KKph, $CellContext`KKpp], 
     xlr8r`Bind[$CellContext`KKpp, $CellContext`Kp], 
     xlr8r`Bind[$CellContext`KKpp, $CellContext`MAPK], 
     xlr8r`Bind[$CellContext`Kp, $CellContext`Kph], 
     xlr8r`Bind[$CellContext`Kph, $CellContext`Kpp]}, FontColor -> 
    RGBColor[0, 0, 1], FontWeight -> "Bold"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.401470073905937*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[1, 22], 0.045454545454545456`]], LineBox[CompressedData["
1:eJwVmHk4lO8XxlWSikiUbEkqiRQiS3UnhVLZUknJO3Zjxr632dfIDGFGDCWi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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 160.},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox["KK", TraditionalForm],
       PlotRange->{{0, 2500}, {145.12931843336634`, 299.99999999801867`}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {488.57142857142856`, -300.36451853244887`}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[1, 11], 0.09090909090909091]], LineBox[CompressedData["
1:eJwV2Xc81d8fB3AKDbuIaAhli0j4XLysyLyfiAYySqVsyd57b/ea16ik0pBI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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 30.},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox["KKK", TraditionalForm],
       PlotRange->{{0, 2500}, {24.061903833576224`, 99.99491205952879}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {1465.7142857142856`, -300.36451853244887`}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[3, 22], 0.13636363636363635`]], LineBox[CompressedData["
1:eJwUm3c8le8bx5EZjvNUSjRQSkJWEum+SIWUiqLILKXI3nvvPY95DipbEUrZ
xFdmibSsstI5xwwZv+f3l9f79dzPdV/jc133/by8jpCZzfV7TAwMDGLMDAz/
//v0xJmRwfrtyKRs82ZDYdLZHoI+JIVNIQ6fsD/aejVI70p+g3HYCgo0Snwk
a9OFcjXjbdcsmCC14fPSxcTPSOBxL8P5MHawgjOSJ7dGUXwcIS6miADbfoRz
DVtMoaDbT4l/LHYATfpWkoY1DW14/SSfCuODr4z7Hop5/UWvYrZNG6YJgMSb
AKePuf+QI0VY2r/oALglMfVWDG+h1CHyW50fgjA+n07t5mYCZ7PnJhMWwqCx
Rlo4JcgMur/rmd1oh2CxkuIqKcAKMo49+ZyuIhD92NDi1gIbEDd+aGUxHAUr
Yt0WNYsDqEFUulSYKGjVGu/J3c0JnYTNxGZMDC6KKu3SuMkFhSncp2+mHYc2
KVUOpjvcECq4//uUsATweCprz4kT4F6BuJ9HkSRcKWW7ktRBAKG9WTvY+KXg
hbD49JISD8R+f3L36g8pMLIKkvocwgNblJIqUo403N560Ly7kgceW1Syj1vI
gPc20QPHO3jgu1jtbfHjsnC8tq3+VycPaNFaip1ospD00uDTpSYeeFPRuVlX
IQf+ozNBMaU8IObaf5Xd9SQ0XTsxxZfEA6Qz33KunZEHjxfOIamuPMDO+HMx
jeEU/FJx5z9gwAMurb8v/Gw5Bc28GU5SZ3lgImwhVSJMAbR2C939KcwDN678
m3G+fBp8M+PH5zh4oGXHNuUGTBG4+f82v1sggOzg9hiOAUWQaZjdkTJCgJz0
HaPX05RAYlaQ8VEvATATftkMozOgqb5hLdZMAN/DwkG/hJXBi9Gj5OkrAlCn
jg1KTirDh9ZLajnPCXCnRPqYa9FZALddaoOFBOi0O+3RaIOgcfSE9PpTAuxP
J1uw8AM0n3JpacsjgK5XHo+YJ8ANq5dVC7kEiDTOf3XlB4BAT3nGWfx5i0qx
qQOowHJ1rbT1EwL8O/R8e2qOCvTvluG49IwAMqwvK94yq8L57Xu6CgsI8HCq
2nDUQhWGCC+OWxTj8XS8YWH9TxUEj0b43SkjwFBxfanY8XMgdJak71JOAHW7
NgZH2jngq6WNtuHx+Oq8L0i9pgZntt/v+vmGANUne67XVqgBw3rvNVodAY6s
DeSxup6HHCcPnroWAhh9+3L5+Jfz8K/ehMG3jQBJdT+Wtc9cgJOCF/8dw/XD
HDChTmK4CKah3m/x5oMxzuXZ42HqAPxjTLWfCWCsV0mLW1CHzyWNdUpfCfAt
x3H+7x0NuOQ+cvnVdwIMnF742yyjCatFGwqVYwTouE9nMvx2CY4f3/6RNkuA
8uYZvsgT2rBHw3hmk4kHGmtthJdnrsNE/sR1xpM84Gvec+iYoA5QMk4131bg
gbMcJ0QMb+hASfuD2Bpcz290qUeb6nXg1imFA1GqPFD520oiOlEXbuQqYV5X
eaBg70OFI2dvwhHTcYqvNQ/EOd29cjPuFqyaKH8fKOIB9+SMLqbmW5AlIH/l
SRkP3K3u1ypbvAVnmANvuFbwgPyq2iV2/dswdCyfS/wND3zxFFGvOWAAF6Jb
7/2H94dw4ITKgWJD0MozOzYwwwMv4x+cnHhnDFc6MsRY9xBhVk+eoLRpBhoX
mLrbjIlAmBl4krHLEjpcSrj2bxAh/0KeP+sJS7jhn+Y+uEUE1Vw7Y1sNS0iU
TLaPY8LA2ZBrr5q3JfAypb7exo7Bj26VyN+TlhDzoCdjeAcGJRXF9opvHsK5
/JURM1EMLhDdtfM+PQSVD+MFXMcxGLG6KE6gPwS5UtGClxIY7Doy9mv08CO8
L56Mbcpg4Jm651ZY9COYtRa94KaMgZaXP/psagWy2mf6fl/DYGJIe5+qpxUo
zUa5PNLFwFd+/2pRshVwREfdn7yJwUtadbnPeyu4YWEX+9EAAwGzPyJHT1rD
jVnn9673MJi5oM/lzP4YLsxXR35wwSAwV2R6WPgxtL7l7NrmjsEBhoVWDeXH
wKtmVyDpicH111E+++0fw5F3r6xtfTGoOd483/L1MShiJi5ZoRiEESWHdpbZ
gE34qJZjCgavCicda9psYD6/yICDhMGUGoVoOmID736ldSSlYZB7ZvvhQXZb
yCE/WUnIxO1xTNqJ8drCtrd2V1iyMfgw0FzvJWQL4zIM0tZkDBjtvAwOK9rC
20CdloO5GPCdvV3gcsEWULUi68M8DKQ4T/3tuG4L0R81VgqeYGDyhB5v98gW
uiz0OLbnY+Bq3zXS4mILfocPVh4rwCAGFUryBdrC3bZssbOFGNQNmXfUZdjC
s0MKwWrFGAw8Bb4dBbZgKu22eLIEgz8O+y3uVdrCgdqlMwKlGDCrrFW8arSF
GbAVXsR5H2GQkavbFmwZlO43lGEg97VC2/iLLbyeO9rl8xyvX35sZvmELfQy
BPHKvMDgrpP1b5YFWxjwE2ccxNlDVfP0rS1buH464OrjcgzieY6GFHPagUy4
X/NfnAu/bfu0tccOLGML9jpUYNBUMCKsc9gOrley7BjB+Ytzre1TKTsQ+G79
6OxLDObPpdWtnrGDdy/P/IzCmQNz4bqsYQc+e/QUu3EW/KFzm3zDDvKFLx/f
wlmhSCp/wdQOwtmyHAUrMbjqyr184bEdqKbafJTG+f75mXNp7nbA33aXWRZn
7x1tcX+C7aDfr6j5EM7Jw7nDkGAH+my2XdtwLi32lUjMtgORpNs/PuD237nd
8ZgssoM2fc/yWJx/XFD8T/GVHWzVajIr47y0c8+e6BY7cG9/EDOIx8M1unB3
tNcOIrVdeUxwPlzaWy733Q7M9qqpDOD5OONRwhA6bQcDlyS/n8ZZVz38ytcl
OzCaOkwOx/NpxXs/Q5LJHkg5n9Xa8fwHjJ2b8SPYg0zt/uB5vD5pZYIKn/jt
IU/q9EEOnMs9N4JEj9pDJsfF95x4PTs0vnz0kLUHhySv82u4HkZ3Vwv1IHs4
TJHQ6C/CYGU8wUZYyx4cxZriSLh+iC9sa5307YE7efyLBq4vUe/LnP/dtYex
0nMjP59hAJfEbu2zswfJUVajh08xsPk1vtgUZg/DFxsrZHE9B5c3qO5Otofv
o/tZXCgYZPlkxlrm2MMjj/rGXLwfuvfqiRPf2MNZg2MOr9Lx/p+QdTdvs4f7
7d4/s/H+2qggtld9tIdPr3Nf2+D9J36lw/zOrD30r49Ht8Xj+Qj98e3Vqj34
CHVt8MViUNw0f2MXmwNUznn4Xo7CQOKUgPp7IQfwqLoWbBSCwWO7E41HTjjA
o+b5x4qBeD2Lzin6n3GAKeZPcit4/0sKWomf1nMA43qKBB8+Lx7f9n2SeNcB
Xn5B3W7OGJQlJh6g2zlAI7p/9K093p8ctcRnkQ5Acf37e/QhBtLz3Eu7mhwg
qWzYqvAWBvbiwo9texzgXWWF8/YbeD0s5Cfff3OA6l5FaY2rGMh8NRry/+sA
Z+5lfjS9gPdXS1ktXdwRlN+yLK5KYeC42SyvpegIZzfWMzTw+fpS4XPZs4uO
wBKgaeQsgsHJEoYcIzNHkOWRD7TYi4F88rXgzhRHSOw0083E57tz772to08c
ob/g57O+FSJUbXd3DSh3BLOI7cxjc0Q45ZPzULHLEertGb2Sx4mg8GDhSj6T
E5Tfq4rUaiWCaw5b+zaiE7y/myFlXEuEV98EVIz3O8Gj9w8fX64kwulrarK7
FZxgx1RU+ds8IigqJu0JtHaCTO3joxN+RHB3LIgddneCE4IFzQOuRKgpreVQ
CnUCazFV/xwbIigdmvg3l+ME9xdXqF2GRDjDdWrE+LMTvLAPKXA5SQT043O+
0jln+CuevNuhgQceXrvSqn/VGXRdRzpvFfJAYkvzqNMdZ/iQOCrHkMgDU4Wl
/M9dnGH90ZpstAUPxLsERh4udoanv98P1bHzwE+ilC03rwtY6f5r3aZKgNBz
IaeGJ1zglIxr7rMoLviQf/Kdf7gbzFv0nX/dyA5tikKqdclukOBGafLLY4e3
nVx1qzlukNUvlacewg5P6eOVtm/cgAHCxD9psYO7QvwTo1k3ELeQ5mf6zAZC
7dRAxSvuIPPCzf8RjRVsJ5+dm8c8YMJDImqbKAvcc0uolzjgAfci2W5IcrHA
bU4fJUsxnCnmMzZ0ZlA7cVN2RNUD/v2jd55+zQx8LsyHuh08YGmKb+LvJWZo
YDVlKvzkAXXtZZLRztuA5wh/oynJEz5aGwRvjjGCuIjygydPPeGeyJmeb+2M
oHnYhGe6whPeRVDv/yxlhGDhp3dsuz2hT/2Sq60HI6wfkFnz3uYFjB83evx2
M8LMHk3ZDGsvUL9Rkl2kywDse6y/DLt7AauheKSsMgOI7I71OxTqBdqF6vQJ
EQYw2TXQU5jjBcv2ZE8ybQsNEs2sXg96gf6kh9RtpS3UwuH+ZEDFG+Le3B3D
xjfQGHumFr+2NzTdjWyMfL2BttgaFu4YeoPQybhTd2I3kCIrq+ovZ28IJ2X/
2zi7gV4wxf9YKPKGfz9q3p0ir6OsfwV7sN0+wFWxJ0zD/h9y/TMUdmnGB1I3
DA7oXl9FJpwOsSXLPtAzWcS6ILeK8nYFvw9h9IVk8+OyH/asokiZgx+muX1B
sebbJ+0fK+jO42vDJUd8wfhgYbry4xW0+aty9aS+L2zmIsYo0l8078i0YWHk
C8X6WWeZfP+iiW3aDKl3fcHF6F3qC4u/qFtoinXN1hfQb7bdtXJ/UfYd/l11
Yb6Qa15+1/PjMoJP3pIX3vjCuX0WYRcElpHc3ffSLo2+YDil6H2CZRmJLuw5
md/mC9uFDrho0ZYQEXuhtL3fF7q99NcEW5bQqNa4evesL0g+JjCK2S4h/5aL
5jcP+EGlwHXfR32LqLWCmGrh5wcGQWJm56oWkOQwt7VriB84fTZSvfp0AaVu
51QNj/KD/bEhFYHJC+ihKctsCckPLCKWj5i7LCACzxpaeuEHt5YHvaiKC0j/
4fhkwJgf8Beu3WD6bx41Jo28TZryg98c2jb338wjscbvcc+ofkAX7P5AK5lH
63s+K71f84Np5T43y4R5RGntjNmx0x8ULBndVo3n0Yxg1SnKOX+4vPdbhN7W
HNLRquCq0PAHEBUq71+YQ29dno+2aPuDYdTsI7upORTdXRgxZeAP3Jpt9ewf
5pCsZ/bwCUd/WLpUx1nwdA55DoaG1OX5Q9zKO7aAG3PoF1OwYW+hP6xeMBge
uTSHrkgGSI899wfF/XQBA9U5JBjk9ZWl1h/+Ehu3552YQ60y9icuf/KHrhCl
dn/OOUSINhj8yhIA+379cbrcTkdctouNdlwBQFDJO/Oino44rkcVs+0MgNG/
Cqqy1XTEvLveT1YwACaS4lTjntLRWqaweIRiAPyZjGwrC6ajFZ83u4VU8PXb
u04w+NDRkqkuY/XFAODfc1Tf2oWO6CLBA2O6ARBws0wu8wEdTZRM+yra4PvZ
RV+9okVHP2P8H/U6BcBZfuYpn/N0NGoncNPCMwD86+UmOs/S0beTl4/HhwVA
z/F6h1fSdPSh9vmn6dwAEFP9FdjHR0d1XS5ipM8B4Cvt5fppkIbelhF5TwwH
gPB67wu/Lhp6HVew1fIrAN5FCh8yaaahlze+9tPncZZSLiwvo6HC72d91LkD
wXnwp9OzcBrKrx+0/LEzENLWtsX88KOhJxRbXUf+QHjqPLR03o2GyPdyjpGP
BoIV7U173gMaSv7D0v9XJRBy+U4FZ2jQUGJPVl2UeiDAKSLLVVUaintxquCQ
diCwlbAcllGioUgnS29tw0B49uysp58EDYXrMVn+MgsEu1EvXeoRGgo5na7j
YRkIcppjnGGCNOS/0Sn6zDkQJJbEjS/uoiHf4Xs7lb0CYduTLMpDAg15NW5u
fAgIhDbNA8Q37DTkGiT1cTM2EBSFmlvHNqjImjvR62ZRICyf+yesMUNFvZuT
KR4vAoGvitNx3wQVydCVysnVgXDrRSTr7jEqWvkwPjHTHAgia3c8PL5QkUHL
KUZiRyAQXniITA5QUV1lhMDJ3kBguG6R7fqRigJTZa/6fAsEqnBbKlcXFU2G
hTzMGwsE+46sn4QOKtL0+Br431QgJDlZpMq3UVGx1YlsKjUQDtzZmRHQQkU8
RgGvdy4Fwj3mHZ+XGqnIXnvwo8I/fH3le7moeirqh+PUO4xBkKZ+NF2jlorS
Dn0UzucOgusJ3ySlX1PRxq6jyl07g0D4aKa0YTUVmbB66M3vDQJlGud0USUV
Nf3tttsjGASfLMdVBF9Skci0cOSZI0Fgfk7i2OtyKgr94vzUVDwIDEUXIpxf
UNHM+46GYJkgGLwUr6f/nIou1x74WqQQBK+Nl9yNyqjoean9Uu/ZIGChu/4K
LaWineR3PMtqQUC97xY8WEJFznH8YgKXguC+m89lTZyH/B+rwbUgSMBijo8W
U9EZxyaje3pBwJBttCMD5+x7u93C7wRBqX3egjvOTHoPE8rMg+DYv4ONXjjf
Va8r6bcMggByunUezm2nd7Sv2gSB3BLxDxVnseMWYwecgyCJGiZ7B98vcl/N
+jnPIDBdwU7ScKZxE/ZY+gfBuUHLiTzc3+tbptLRoUFQLVWu7I3HU0mvvFQR
HQT3umWlPfB4+cY4LD4nBkGw26nqdDwfHh/v+G6k4fm8I/NuGM/Xj5YXacKU
IBh9f+LmRTyfKlUslRefBQF9atD4A57vvGe3eqxKgmBi8MNXX7werKSS6biK
IHxe/td0Ha+XZTgjc/XrIFDlOEVQf0NFnR43DnyrD4LdXnKvTfD6SloXKDC+
C4Kt9JW6DLz+i9rXrC99CILD/+1v88b1oqfyJMT2cxDs5ZysP4zrqUZmlZL0
IwiYe5i2Uf+jIh9eysDwDB6vYZDBTA8VjbEu0ZnncHvNA9b7cb2qrahziv0N
ggt/PJsccD1v/0pHjtuCwWBCQCr8O94vnWq3SRzBIPDskIbmKN4vtamOdTzB
MF8akCfxi4qSyVDAvi8YtvWvHjX6Q0VCFrE7MuWCIefrjhyLLTx/BF/VC0rB
oLs9b7WQmYaIVTb2NJVg2Ozo+Mq3nYY2WbQ/qGgHQ5Xaydt2vDT05Ql3/IQl
/v5v6qHdkjTUd3mjMcY2GHTE/UqeydFQ+9LsnIJLMDT2LrKb4/Oj+nzntYjA
YFCgOlvo/X/e/ArHpLKDYe3BQxmF+zQUEeWuMvQkGB58fF+31wafHycf2vkX
B0N58VC0iAsN2QZp9PW/DobYmZPwNoSGLouwx7n1B8P0cbvZyUIaYr0XRGzm
CIG3qd4fNVdpaIPLCayIIfAmioHtDyMdLb68a8u7JwR0pWecNNnoaIxZrff+
4RAwTHi7dWEHHdXnMcVyoRBIaT+rp36Mjlx/+vDcdAyBmuHKBjcDOrKJtEFb
7iGgdPNMiogZHVnIGdvk+4VAuP0fmMLPhxuBZ3vWokNgf7nPrXJnOpI5vBGd
XRCC32t9mw0S6Oi3uTth+kcIoCun03j76Eg/n5/o8CsEKOeWvmJDdNQyW4Nt
/A4Bvxh1c5FROspw+rcLWw2BX1lV5Pg5OtIK8RQ4vTMUasM+mITunEOlhd6i
YRdDYZQYq79sMIf4aQfEdl4JhcqDPBfs782hYNn645m6oRBin83OZjOHjN5u
Sb4wDYXxh3weHv5ziKfb9+SQRyj+fRAullA4h2zn/FWPPQ8Fz6OCxin4+f/t
5CG1iqpQKOm9JV66fR6puzefV64Nhdj6xKJh3nkkuI1Z41pHKLD53FdJEJ9H
fbuCtN1+hoLCZsxDMJhHMgohhv/xhUHm9p4XvbXzaMk7wtnSLwxcRPYq/5e6
gN59mHjmHxIG4U4nEj3/f/85ojqUHhUGzwT2il96uYAUu1eUuklhIF+U+Uyx
dwH57rdglC0PAyULwTQLjkXE9RYi18fCINLIKhzzW0SHV5coMWrhcLEgoKk6
eAkta137mK8ZDoqu32v2pi6hNnIxc9PVcJhyGchLL1hCD9XN7y8ahgNfzOjc
VucSep7SK37LKRwmzExmr/AuozPyRdXCT8PhQNKBcbHiZaTrYNJVyRYB0nyf
HFkW/6IaL71dOoQIkPqzOhPNuYIEQ68Y0HdFAI92haraoRX0O+PMtJhwBEgW
abvI6qwg/3d8LOQzEfB2NnuvWOUKerG370y4XQTwhRHVCvxWEaFBpdjoawRg
Twmxtmf/IccOhYV/oxEwPSBzZ9TgH/rSf0KRNBUBreHv+gLd/qGn0/vbPy5F
gMTDN053K/8h5Z1r4+rESJDjrpmMOLGOrCzKBWTPR4J8h5x5rsQG+o/rUARb
WSTUth0s3359CyUe+cQoVxkJ2sm6da8ctpAJhLiavIkE7k73+eSkLbTs8Pve
67ZIWIsh8Pwc2kLCXyvg0UgkNOzLAVMZBvAsUFvuxqLAhHqr9n0jA0hesDBN
doyCayv3i9rnGSHBp+CUiGI0aFSiLKk0ZpjX/tv8CaLBPnlTs7ScGa4Lnr8a
fDEahm+n26q+ZwasceTBpG40fBI7uFK8zgwxTHxpBTbR4LA3l8/fhAUigoLX
JZ5Eg8l9pYM/jrNCQIR5ozwxBtb2C/4262aDMYMXlyd3x0Cl+gONP1NsoCq+
NZSyPwa8Hj6v8tnGDoxdafMrYjFg/01YpkaBHXwIHw69OR8Dur3Fm/a57OAR
B8HIIwb277Nk1nHjAIeU/ZfUJ2KA52sPnUGIE9SZ9xUMzcZAsut/fXGKnLDP
jp/t0UIMsPhw/+DR5QTzJxGjFxhi4VKYxImeYE7g8gnNtOSOBY6PWKfSb04w
kvHnLTsaC1XOxffaS7mg/YFfy1+xWLBZGFzJeccFMtm+DiAZC01nxOv1fnAB
G5dPX59cLJB84nM0ubnh+S+PqEWVWKCU56hKWXIDE8mJRdEwFlJvvXZ8t4cA
Vj2OL/2NY6ErXmKSLE6AARZH8/dmsdAau98JqRCgyN6+0dAyFk49kjzXbEkA
XS0bLx9nfL+szO66agLU+T8Wb3eLhVsJfcoJHQQQfW39legVC65rA58FvxNg
Q8TqdE5ALIBmk7cZIw883Xqw1BIbCxYcXz/ducADRPkHedyJsZC3X+DD0E0e
cLe6r3MzJRZ4+Xk+sdznAe2hey8mM2Mh9+qvOw+DeWCl3Mx6e1EseJ5NLL3a
yANm06b7dEpjYdviUMWpHh7oPGj6Pv1FLPh+JTT9940HKJHGxyRexYLSlU1T
6jIPaFoY/tJujYUnLMrmWTuJcP/waXGT9lgo9zzXN8xHhMAxXgfb97FwrUni
/MZ+ItQZ9TDE9cVC/WznUNdRIkjrqe778B2PzzvXof80Ea7wHjQfG8H3c7ps
wnyWCA8//iuYH4+Fx9IiIryqRMjTrjy1cyYW/G7//vhNgwh86qI6usuxULu7
x0FQnwgnWVnS7q7GggjPTLC9ARGut4yOOK7HwpmR040lRkSIhPTHSUxxUM/T
/+DnXSIwnCaEDxDiYGardtXBlgiTxxYb9I/GAS2D5T5/EBGYp3rZLMXiICCk
IjYkhAiCT0uuuEnEge+TgVpqGBFuC9//RpKNA1GZ8vGSaCJ083/5+wXFAQSm
v9lKIUIVZ4PkHf044Ap8iV0pxPPxJyLDNCwOLhStBY13E+F3sDy1IjIOOsoO
/GfWh/srOIpYY+PAq59WNfYR309HfrwwOQ5cnBcDfn4mwttXI8cWc+PAcEhC
jzZGhKWAk9XBdXEQqZK5S+AvESz4h/uKFuKg+2r0Z4eDGHRVhB3aXI6D1Pxd
I4tCGMhdlnO6uhYHfB5fJxwPY8DkG8a3xBAPpf5+yXbHMMj+JWt8lhAPHN/i
vt6WxeDz89DZXtF4UNZ8NfnpAgYaF2XYlu/Eg3nymeb4RxiYPaih85jGQ/q/
ybZkaww8w1S/HLsbD5UZavrJNhg8f3+95M7DeHh3Ji80xAGDPVcddFqdcXvi
BzclPDCQsvt3ZtgtHvY52ylu98JAMz7gyKpnPLwk+r0f8cbAuz9hVTwgHsRt
UtU8/TH4pf8yOzEmHpzbA7/cD8Ng0+1MWGk8bl84n2NHBAZ86S327UnxcKs3
TqIyEgOt7/3n19PjYYV1W9qvGAwqTJd+m+fHw0apcM10Egad/l6fvIriwXZY
+OrNFAwmclnqU0rj4c9ubp2aVAz4J3jj37+Mh5/e4j330zHweyivINsYD6n3
/nVeJ2OQFlEndLklHq5rpK05UjB4WXyB835bPMzr/P0ZmYPBFPXmj7SueOBy
HuXKzMPzTRxue9kbD7VploOJTzDYJ33/RffHeLDqq3T1e4qBtoNLINOXeKgL
fa6jkI/Bg8Qt633f8feruHczFWDgXxmiJz8SD7s0ghvqcc4Y4FG5Oh4Pvruv
7bYrxKDqb4rYw4l46F//OsRbhEEvn+CuwOl4UDC711WC88zp/I3M2Xjw/hlV
rlCMAbOB1GQ1LR4SXwRrVuG83/NVb998PGw/K3nzSAkG8plQ83spHlLo75JC
cb5a157Lsoq//8v4v284Pxy+GnVwHY+/3ee5cCkGgQxDzqe34oGE3dt+G+cs
IVMTHaYEfL6NJ/nj/Ep1WsOaJQEyOX2xDJw/mNvJhrAnwL0FG6WnOP8OXN1H
4UyA0baUPvL//9/y1I/1DSEBvrCmxEXgfKCNg96PJUDrq3YFC5wVpuKGqLsS
oFrpWqAUztc5+JvZ+RIgN45Legb3z0osp1hYIAFGSl//i8c5+JJY8pkDCdBx
Y4AshjPZqtznplACRO1u+vYcj/91lKKl7eEE0HhZ80gEZ8JG2hv3owlgsrP0
cgSePzOrf9xBYgnwztTkxfD/8/3VwCRGIgH448pvCuO8/dLbcpJUAqi6Bmxc
x+tjVLOPJU82Af4pld+zw+tZfsxLr1Q+AZKydmp7PcPAgP3setOZBHBLkHhi
iOvhuUvWlS6UAGKq1LgTuF6YJzfJg6oJwHD35xYV11Nxa/35WfUEuJD1n4kM
rj+Gk4Kpy5cSYKntQ39lFga6eb4zDNoJkDXn1Hk4E4MNf5UY3hsJsP2Xj2YL
Cc/PPGX0oH4CjHPP6Czien9qyiQnZpAAsU+oE4RkDK5A8+ezpgmAveGuYIrH
IKfs0HGNuwlgEDpr9xXvn+UDgV469xPgaOtIa2YUPi821IQfWCfAxlat8o9Q
DBatnjja2ybA7THR3wbBGKh/Y2nzdEiAuQ8d0BSAAb3m3aM4twTYqyq0eRHv
bxVX9cqaoAQw1k9LlrbHIHkyn601NAGCC731qI9xvd7kuN0TkQCfEtqZ/z9v
4k92bI7HJcARbSu9qLsYjM9fUufOSoDSE2GmV27gejArTttDSQB9g/ucytcw
iOzj+iOUlwAOpB37sMv4/HveFSdfmAA6NoZND9QwCLLW/mpclQBXTQZT+qQx
+PKtTOLh6wSwnq79NSGOgaQW0dfxbQKsDJfdHjmKwYBY3+GwpgQo6N6U9tmP
wdGp64/LuxOgOc1ZwpINg//MbjKyTCZAV+kths+fiPCgJNDo2gwer+9Ifww+
71lXyt9k/kmAQi4JKZE2IqhG8TjLL+L2rtXqTFXj8726feY+YyLwJIeU9eDn
x3Mupf4OgUQYPFirc+Qafj7qWUrvOZgIJ+vV1qouEuEPJSXaXDgRfH81FIvg
56XYqUX1ddFEUHsTU5kpRoRc05JaCflEeHxy1H6dkQjJVQefxV5NhAu7d0Yp
3+ABOcYrzN91EkF6k7aicZYHPl7yND2mlwhVQodZ9x7F7xOjnwWa7iTCB6XX
lowrBAjnjI9deJgIWoMXZbhTCOBlwux+Mwj3b/rWo+cd3HB3+7TWvppE0DP/
yb2TwAWV3xZVpGoTgSVtXmd6nhNYyxhOqTXg8YkIn88Z5IR8HT4hq3eJ8Khc
8lU9mRNmMy4uvfmQCN3LIWuN0pzgdOJppsHvRCjK+9T6XHs7BOuaU9P2JcFX
wS3jKj92GDxiM156MAm2XfwYln+XHURX3T83CScB6x3252kX2aEjM75pRjQJ
2jLaHfy52YFnsjFZ8WQSSNcmcLqS2CDVTRB9uZwEMU+GAqrKWaEg63vMXp8k
CIwXMvpKYwY1reoYG/8k4N5Q7+D4wAwjq7ExrUFJMHLFnkH3JTPsvqEWYxeZ
BL+cfRLOujFDAGdR9H8k3J+plmlvZma44+oa5fYyCeoaavRkhLYBdn1nxNB0
ErzxcpspdmaE4q3Z8BN/kiC8+HGwwR1GUC95Fx5ET4Lz7PRlWTVG8GZ3D5f+
mwTD5eo7zHcwwu+6kbAw5mTYobKgUvecAVqPl4aePpgMz9ofS2/ObCE3Fo1g
km4ylKlcU0w6u4GuMP6jDuslg+Oau+ydPRvo8Eax3hGDZJD6bX7Imb6OeheJ
xypMk2G0xGOMlLuOjv78/L7zcTJkyTRyU7jX0aemBxhDWDKo7pQovU9fQ4V1
/O4XIpOhGhefQPca8q3pHIuMSYZXtsmK/MVrSLxc6uXe5GRomnU0WHuwhgIo
Kzdlc5Nholq1XH5iFUn7hmZY1CbD0ueuG+eoK4jVU5GlpCEZTKyP+/n3rqBv
LrPWC83J0OzM181asYJCba4i3w7cP9F927+7rqBhI74x0mAyODWZllWwraAo
5fyjXXPJ0BuRp/BU+i+aXmsrlz2SAvZp4VhoxRKy99arUDmWAqbsOyU5spfQ
GuNkhbZ4CjyY69GsCV9C2zlYKx/JpMD91d7jRWZLSHyPWnXu2RSIDU9Sqtu1
hGxlG97s1EuBhY8JcSb49+1KlfZbodsp0KXtplljs4j8FIffnriTApFszUNn
jRZRvMpm7SXzFDgcEqHaprSIKrTPNATYpACrfHZb58oCWn70qmUhJAVcylYw
S/cF5E272MoYkQJvxS8Vaz1aQGwOg6080SmgHiTjftNwAfG5L787npgCgu97
M76eXUCnQ+X+MyenwPw3w8g8lgXkmfe86+OrFNB+VGP2lzSPmEWhe/RNCuw6
eXLlQNQ8iirq6abVpcDvof3PH/jOo6xyag9nawpYjG8lm96fRw0N4h/O9aVA
3yX3jjH5ebTte/5AxXQKNG02faR/nUMDSqxj2/6kgJHLM8ZTvXMoP838jw49
BXIDr0hQWubQFf0DzIvLKfDlItVxpGQOpX5MkJZjToX03q7X2/znkHiHd+TL
A6nAbSwr+ExqDm2KfkthFk6FlNDKep6jc6gv5HSurkgq1JQGxqbun0PO5xdf
Lx5PBY7l2hkOzjnU2GA5KXc6FdrZXZ7em6Sjm9W6qpU6qbBHdupu/xM6Et1d
fplFLxUOlwS9OJpFR/8ceW7duJ0KMY6JHKnJdESW6bBZMkkFCadesZ4QOvpd
gjJPPk4F/ZqHpvGP6KiOKzM/yC4VdrO1KP93l45iH61VfHJMhSCRpk4BIzqS
P1bZ4eSRCpNqVSY7r9GRb57YSmVoKrD3a2LqCnR0fVvoNtbIVKB9yjmhL0NH
Ima/CDdjUuH29r4Of3E66jhIFllOwuNxMZg4IkRHu9J5deRzU2GWkvblKScd
FcQxlFbVpsKbbQ/P9HXQkKSr0rXuhlTgbFB+WtFEQy+NnBd/NafC1wsNLxpq
aKju+Kwib0cq1E1YL98qoqGPrYNtDgOpsDFWfD0wmob0i3c8ihhKhVxB359V
ITT0I/4yIfdbKlS4p9Xs8KOhKeNm3Q9jqZB5JDL2vCMNbayWjkrRUoF/1ISc
YEhD/iPTgerzqcD4wpGdS4+G2NsOi5ospYKT8Tv/4ms0tCMx7XHMv1Qwtf4h
dO8iDaW4f8KebaaCtNolJi9VGtpnSqysYySBwLii1VtlGjoqGfzvDxsJmGzp
hi/kaKh4V2MWCycJ3tYE5VhI0ZDMv38q+wkkqHu1f1FVnIbOtNuFau0iQX8a
H9gepqHG0uLjd/eQoGwvnaFRkIYuJE12e/CToLM9XF9hPw1dM7vDWyRIgkta
UUZpu2loQD31VdMhEtjtrRgM3ElDhic+Gnw5QgK9MimvJCINjfIStuaOkWCA
6Hmyk5uGLNbVczgkSKDKTJkS5aSh32MB54WkSOAbGetTxE5Dtv/VTSnIkkBw
yn1Uh5WGPJLlTjw4TQKzR0klvEw0xOBl88HnDAlECydnJRloKNi80CkFkeA1
Zkix3qQiTs1ffGWqJKhgtansW6eiWCnBt+/Ok6Ao+D9eg39UxLvHwPiHOu4f
1+UyjjUqSttIYlq+RAJy3qrN9xUqEvzZ+4RbmwSnh6fOD/yloicdnBoi10ng
dyPkwOIyFYm9uDB75gYJ9n6OnZbH+XmKX4yuPu6/oHRK1hIVnfR+K2NlQALH
Tsk9x3Guufv3U4ARCVI0XW5/W6QidEnGLd2UBAvX/a+X49wibb2v4i4JHiuf
myvGWZMvv77jPgla/UWPdeLcszlmNvaQBFn23n94cHu6v/azrlmTwJhUJu2K
85f3+gWYHQlQ+uQ0M+6PcXmC1jFHEtQH8nJW4fwztZsGLiQIi0LhEXg8lj4c
CfruJFBbv3gnCI+Xek9N3taLBNVDz91zV6nIUctnKMSXBO9q+Yd+4flZlanx
zA7A/dPZa6uF5/PV/a7QZ8G4f+cZ+Xo2qMg1YySxLIwEWpk/fRy3qEihb4Fc
HUmChCfGlDOMNLTCwlZSH0OC9kFz56PbaOiVIv/rtngSbOSOrsix0JCrjURr
TxIJklY4D99jo6G/n3W+D6eTQHrI31yCi4aquO9PT2aR4FOWiU0rgYacVd2X
aBR8vfXQTl+MhpaLyNwM+SSY2lI4cGcPvn6kYi97EQloz/l9ffjx9bxtIsRS
XL/C8fYtuH6XvP8oC74kQUPGS7YqXO8vKxg0RatJMOz3vNBMlIYcp3belKoh
QU+22A9pvD8Wryk+hgYSpLf6rJ3C+2nhcEiWSSde30EpjfHzNFR+K63wQQ8J
frAuPsvTpCH76JIq2w8kOCR5pCRUm4bm/37s9v1MAtMlrPbVLRqa6xDcIv8k
wa906aTXNjT0fEuWs2CSBOqmE02xTrj+5S7ueTFDgpZP+/8L96Aheqb1iUY6
CebprwIm8flCs60xHl0nQWqI6Eu1HBoqfdL1aHqLhN9T/hXLFtDQ4y8jLnNM
aRDuz9Nz/jkNUc+xxTJypIHD7+W6j3U09Ge3boMQbxqY1aLSlO/4fLh0v/MY
XxpYN2vdoPyiIStf98/SAmnQrFEa1/2HhmanyXQVIdzekx2siZt4v779I2gm
gT8PTdKfINLRtFmIX875NJhRC/D2P0VH8/YPUmfV0yA1MAjbq0xH6/4aZfJa
aeCpGKTRqkpHxFzO7x3X0+DY6Mi40RU6UhiPUVgwToP0QaF7qRZ0FGqeSjvn
ngZWnAWfZdLpKN7BjTXaKw1eJ0ZKHM+ho4yA2/s/+6bBQGSpjGIBHT3P3XfJ
KiQNNF+1pGdU09HgOPlpYmIacKmNHnD6REdH7hbc+VWaBklKxndCeOeQlGO4
44nyNOjal+O0iJ9/ioGPItwq00DkASnV7Qh+vuZJvOZ+i/t7kc+o8xR+Pv58
sUv+vzSIQim5yQZzqPVuzfvg8TTggIHp/mdz6O6996dF+dJBru6KUr3OPBLc
CJs6LZAOeiv0g2lG8+h7onrKpQPpwFW3f2+U5Ty62dK6+PhwOuwjvnv1xmce
qR9qKKuUSgepmiMNZ0vmkcToS5FzGumQIBfju8S1gGZcHfp1tdJBdMeMrPHe
BfSUKBNgoZ0OJ3dd6x8TWUCCUDYSdgO397P1tgJaQDuyC9J7TdMh212eUdAB
v/8YZmFG7unA06Qavjm8gMoXDRtsvNLhVUmV4W7qArKJFLDx802HtqtHpTXX
F9DUm9TOvOB0eDpCs2Ldu4i+8ieE/I5Ph4K/V/k/6Syihs8hG65F6RBN17v8
u3sRhenaTSd8S4ckIy4J1m9LKLZtI2dyOB2iAtnGHtCWULJiuKHSOG6fm01i
nmkZ5Qnm9oxNp4PAV/VbbmLLqH62v1L6bzpYrpX/NPZYRkuBCv49WAZ4aG6d
rD38F5lWbvFzXswAT9d7m0opK+iBaGS/kWYGODvn2XwtW0GP0/miyy9ngLCK
gkl++wry9JNmvK2bAR2fWcnv11ZQymXzyXxTnO0KapRNV1HXr3cVFzwz4NwR
djrDqTV0ene0lv+LDHizfd+0B9s6mieuZGa+zICGYm1RscPrqJjTjPaqOgNE
O8M6WVTW0QFG+XhabQbwaax9Pu+xjphnvw8admQAk+nn2dk5/H7fKGF+ajwD
jkaWPlqc3EAW1l1us7sywap4eajk7xYSfHDqPRtfJpz3jxoS4maAITPKvkMC
mTBQ/Zc36AADaOk71d8SyoSykv9iE1UYQObcfpY2iUyoaq6jD4YywAafdSzl
Av5+MYF/ToARElu4nt10zYSdxDM7NXWZIJRb29TMIxOK0rY45B4wgefNOIHH
3pngXicZIOfJBHeneGODAjMheL/ZE9c8JpDjOuj2MjYTaJr8RM5lJvioI31p
R0EmnDaZ2AaZ22DH+A1a11AmxP6S/juxxgwxjNmnzitlwYa/4n2zCTboFilb
jz+bBWeDZDg8GNiBS7O+cUQlC16t1k2k8bNDaPzwJU/1LNgkMH36c4UdfA8J
mlTcyIK8UxTv7mp2sD1PCRWyzYJj47wcI2EccD0sd2gjLwtsqo+kVB7jhNiS
iqxL+VlAbtOPUj3HCd19zeakoiyIife/+taQEzT5f/6RK8+C4ydf0u1iOOFc
0WEmq/osuMooXvZugRPkup6IfRnKgnffY/Owai7gxfI9qgjZcHrkxdaVgwRg
rU36/B7LBnFl92s1MgRYfhBwcnRXNhBs+l3mzhPgc4MRjVMgG4jUJ+/qHhEg
3ZbX3PRoNkhYnnerekmAyH3bGpzFsqEy8Jyr6TsCeLbT90VKZIPM8bqknkEC
GAl2DlTJZkMk5z2BuVUCCPX6a3JBNkTfWVKTVOKBHZ62z4TOZYMvWzj3oCYP
MIkaMZ+6kA0cI9filG7zwE+f03WmWtlg+k6xS86VB56doEtX62dDg9aXXQPP
eSD16/foToNseH34u7VmHQ+Ehrz/PWqUDYfPrjI6v+eBh8NPn3DdywbHQxxT
cz95QCLmzl4zu2x4tEixUd5OhANKl5xdHLMhuzPJ5CMPEQiTCh8jXfD4WkUl
zvMSgX52V1S1Vza4WBva1x4kQgW1g4E7PBvWw5myOWWJkJf26o5wVDZYx+j9
Cz9FhMQLT2tOxWaDfqfLn2klIjhn+TmaJWcDN1ksTkONCKevKExV52SD8Yx0
zzMdIoitiZzvepINJUlO5kp6ROB/ujNnLD8bHug++lJ5mwjrG1QD7rJsCGCh
fTE3JUJ9yZMeszfZMMq2R6jFmgjPbyWIu9Zlg3KNhV+pLRHILH5hUY3ZUPD2
yGSoAxH87xiee9WWDSyi15R2uBHhPPfOau7+bHhB7iUnBhDBN7H7wL1B3N6+
Qy3Xg4lQIxAe/PZLNnzprXrGFkYEKTHGm49GcX8ig6puRRNh30XaYjs1G1ok
w3ZVpxLBveHe3iZmMnRfrSwcLSbCtTUVPa+DZLgUm5pE7ycCtfYg5zEhMnjs
abzsNEiESL+Nun5hMrS/9o1dGyLCO/bXR8SPkAF0zheyDhPhzB6p5S/iZFi3
fx13eJoIonIHkhQUySDPadNvs0EEhsdrHxZ0yXCoO5J3QgSDN/pqb1JukuFB
Z7CtgSgGzueic5X0ybAzPTypRwyD33zCjgEGZBC2dBitOIHBQLMG704zMjTu
Nu6zPI1B8V6SnowNGZ72dpIdtDC4zzyOBmzJMHHwk+1/VzAQpomLutuTQTus
58q+axiktDSsNDqRoVC4v/TVDQz8baZI1zzJ8KRf50S7EQZ6rae+2YaRIbKW
TU/IFoMdz/1adkWQ4dY51e/y9hh0pr0vfhVJBsJ3TdaLjhio2hp7McTi8S+R
I266YiAuEHIgNpkM42ltKhK+GEyy9LHKpZKBd22laYc/Bjl0ftogiQzmPbT7
cwEY7HlXWn8wkwwaYmevkEIwYLIbMCnLJYPWPe7XUdEY1BoIaug8IcO/5fdh
8rEYuF54KP33KRkUWEQ7B+Iw+COwyYgKyfBGlqF2PRGDfFb1mbEiMqg0GS75
JWNgNhf3IbiEDLuENso3UjD4/E4kt/s5GYbe7/tvMA2DhBc2EfblZJh2V3py
MgODKxmvHXa/xP0xo3KHZWLQbHdZzaiaDMtWMwE8ZAy8DVPEmV6T4dSTzwRV
CgYKF0d3Pa0hw+bJKCHLHAxK9zn9+lNLBjmlyr6EPDw/70tITvVkYLJk+Bn0
BK+f28TljQYykP/e22H9FIOHogeZgprIcOKs62GNZxhsDuhVcbWQoad8Y2Rv
PgbxQbEPE1tx/Q37EYZxPiL334F9bWQwQpP2qQW4v3GKIcc7yMApOr40UYjB
GHJQqnhPBh4bjiyPIlxP1CKaYhcZthbNY7cVY7A982duUzcZKOvBsd44Z13a
r6/ZS4YB9SnTWZxl1m5wfegjAwfTjTatEgze5Uc33PpIhm+8lgHZON/Wa3Mc
7SeDqfRl/Z8401gYjlkOkIF7rZ3t/7/3CHyp8J0+SIamr7Y653DmM7eLcx0i
w9XbV9YNcS7GCs8zfMXju323+T7O0DC2GvKNDLm7BS3Nce5/LFDK84MMpTcW
S7RxfrBf1yxlmAxurt+vieO8/j5y98FRMvjJl+9axfePdW/teDpGhtfFAlWV
OB8+tukt+ZMMvYqPl0xxfjUoL1v1iwwN37H4DTw+rWCbSeVJMsRcbNcMxXlE
Lj+9dYoMN1xyfzDi7Dg+on15hgz+fRzcD/H8scfvZf70mwxEXv3EBjy/GXD9
leEfMjS3a8my4CxFC7f6SSWDpHty/im8Hi2ZzYJWdDLss/xarofXS19rvX9h
jgwy2i3Ee3h9Z9fkwjwWyGDszORnjNfft8BaedsSGS4s6TZdwPWxS//pXPgy
GVqfRifw5/1fz8NPdqzgeg3IqviC66vX/CpB+B8ZMo9VfzuA6/HujrCmgnUy
XM4yuZuThcFKQ6Oz9CbeHwHHFTBcv4IHZIeBkQJlPQvNZSQMXnY+SmhnooDc
F6/1H3g/qHvkXbzKTIEamoH/ShIGtp95nxuzUeDByKD7NN5fzCFX7k6yU+Bi
P922IQaD1JMhfDbbKSCfL/nGNwqDhvgVX29uCpxWY9d/G4qBror0SVYeCoRG
HJU5FYzBFM1yOopIgeNGtY/T8H4nXv56LXMnBYqvnDu81xuDvH87WUV4KfA0
deuYnAfeT4VaNcW7KeBr8L5QHp8nJmx1wm/3UsAx8rjSnB0GLxrJC18OUgDt
KCuQv4vBzB0oCRCiAGVaakjeBK//2rCF+CEKTA6unuYzxCBZ5uAXryMUMN5u
leylg4F7bmaDoAS+/vpt5U7AoAIpu/8nSQFpESe7HiW8Pl+/ydpLUUCg7z+u
cnkMjHfte9YsS4GMjy4Vu8QxUAtKi7JQpECMjVyjJi8GXkKKF3nOUOBYU8Uh
NR4MqmqHGF4p4/k7mZMgwIGB6DKfI4cKBdI+NOy+u04E7vspt4svUmCalu+u
P0rE+y7x6LwuBfyTN2b//3sHnl+yo2k3KXD7JqYYmUEEdb+Paef0KaCZaRet
kIifb693EJIMKGA7bnNXFD//ssXiFk+ZUYD6Z8fmPWMiPOCKbvSyweu9vGP5
EUYESr6ExxE7CtxMoEjtYiPCF7UuuR57Cuwmvzomv8oDWl5c+YLOFJCkuqGI
bh6QpoZHN3tSwGO2e5eoMw+s9YQYcIRTQNDu3Lmc1wTgkto9mhSB6+XCRvOz
HAIcjM2zEI6iAEP37Z/uEQRQu9popxRLgYfPXcwiDQkQ3bsWYp1MgbBnksKP
17lBuM/6ZV8OBbxVH3W3ynKDxgcd7rQ3FHjVY3NRNpgTUvsP1ov9oQB2LL1w
4TcbtBvwu5VRKbAUDI26PWywMrZLVo6O18PEXaSmnA305jieKS9QYJ/Qf1iS
GxvsJixGX12lgOuPr9kUNjZIvNhu5MySAzQvzdh6EVaIqbHdbNyfA2aPS0hD
j5mhTuXRqwsHc2Dp97nNo7rMQG2/Z/9eMAfqF442xpxmhiuDtyf6D+UAO8FT
r4SZGbgW1bonj+VA4tHhyxIZ2yBcYm8Wt3wO3DXW8UnrZYJgcqPyrSs5sGke
6mF8jREMeA9tbGrnQMD2idIMBUaQCg98m3ctB04sYLNMgoww5HBRia6bA1Kq
3nsv0RhA/GKXQohBDmjY1XZ3xTDAxz+fZSsf5ECnu4PXnRdbKN9MceH2Q/z5
GUM7YtAW8hxML2ewyoFS8/GUPbe20JFGI2ktmxxg+hWqJsy0hdwTf0qOO+VA
ScWR/iP6m0hQiX4MC8gBJcnOnV07N9BS2bXpqkA8voGCtpez66jjcEW+YXAO
/D6zsY/auo4cCM5H88Ny4FuBRLiu2zp6N/rvMIrNAaffvaemxv8h61A2QevM
HDCaZWAYbVtDNZ8O7P6vOgeKp4JOWOPfcw8INpTrr3NAkK2S8KF4Be2+WC/+
rSYHhrRVbzvErSD7V8bnaLU54OZ5pMnSYAUdTyfb8rbkwNq0VIrA/F+UYSL8
3rQ3B/oSmbhUxP4iTZL9zd99OeBCpryFHX/RSl/TqONHvH5iUavOa8tI95z5
SshADjzaZC0Oer+MuI/kiZR+y4FtL8tahWyXkfdvEd+1Kdz+MWVD5uYlJH7Y
mTNwJgcONbxvVCldQl8M3yVzz+bA38f9jM9JS0i+26JEkJYDJx8ov9hvt4Ro
z599ubCUA2G5fOflhJeQifOxkwmMubB1/mP6tqhFdI5RYuY4fy4M1v86Mue/
gJKP/nQfEMiFZU0fJTP7BTRzOZ3Tb38unN/vOc1gtoBi0zgkBgRz4bIXU06r
ygL6Jjth43s0F2hN20bMti0gZ4vspX65XFhN/v2TEj2P/ou8GewjnwtpIbEz
zb7zaF8F9x4xhVywfS6kRnCYR81bHgo+SrkgfMimjl9/HhFJ+h7HVHPBePdK
4PbD86jwPcborZ0LBmv/4lma59DGXHuc6LVceFoVLBNePYeu8vkKf7yeC62D
OQUyxXPo713qOdGbufCtJ5+PmjSH1DY7gj8Y5oLcHUkG9kdz6IdUINfRh7kQ
KLdlGC8wh6T1lDL7HuH73X53+dSOORToNS/haZ0LQSra19fZ59DxDhPtPlt8
P1alhl/LdORqrhzv4ZILz4gkXal+OsKSl/f0BuL7q2wccE2ko5F/HoPfcK5t
Olp7Fufnpowp0zhfIK6bsuB8VYJr97agXLBry66PT6Cj2BahXfI4+y41dZTE
0xFhQYuYgTPh5gnBX7F0xHU1l/1BcC5UDpq16kfR0bdK0XZHnJN4tysI4lws
UBrih/OnvKsvJiPpSGvyFWs6zi59DdXOOEd4dzN34/zkhMiupAg62l6yyiAX
kgsSr19u/xhGR192+DQAzlmzmpNpOBe6MvtexnnVyqvDDGdNNZ4tC5wdWary
5kPpKOzr4Q0SzpVWVvk7cNZXKXz7FOfi/+3e7Z232j/YayzXr9kM5M/4/+Ti
IiD/RJHV7zNAfsL/Q6LGQP6MG/t33QTyD5pNd/zd9sE+w8616hmQr3iOueQw
kG+x5JTlZyD/cCHH2m4gn4Mr4Od/IP/l2SVvgoF8ACvDNI0=
          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox["KKKp", TraditionalForm],
       PlotRange->{{0, 2500}, {0., 4.426952427531228}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {2442.857142857143, -300.36451853244887`}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[2, 11], 0.18181818181818182`]], LineBox[CompressedData["
1:eJwV23c4le8fB3C7M+x9DpWUQhRRRsnbKCoZUXyThJIke2VljxLHCIdwDhKi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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 3.},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox["KKKph", TraditionalForm],
       PlotRange->{{0, 2500}, {3.111893454968785, 9.999999999933934}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {3420., -300.36451853244887`}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[5, 22], 0.22727272727272727`]], LineBox[CompressedData["
1:eJwUm3lYjN8bxpMKaUPTvpf2Tfve3bxRaFFRkfYUad9XUmlfZ9rXmTYh8RUh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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox["KKp", TraditionalForm],
       PlotRange->{{0, 2500}, {0., 39.83947355944246}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {4397.142857142857, -300.36451853244887`}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[3, 11], 0.2727272727272727]], LineBox[CompressedData["
1:eJwUmXk4VV8XxyWkQghJJUlEREhFtZY0qGSOSmYhUeZZIWWeL2V2qXuveR4y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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0.05},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox["KKph", TraditionalForm],
       PlotRange->{{0, 2500}, {0.04435059641737219, 0.39484262728869046`}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {5374.285714285714, -300.36451853244887`}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}]}, {InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[7, 22], 0.3181818181818182]], LineBox[CompressedData["
1:eJwVmHc81f8Xx+3t4n4uicjKihSRlfexJSFKEn2TkoqQkT2y94hrXuOqiIaM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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox["KKpp", TraditionalForm],
       PlotRange->{{0, 2500}, {0., 5.061531578016629}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {488.57142857142856`, -901.0935555973466}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[4, 11], 0.36363636363636365`]], LineBox[CompressedData["
1:eJwVmHc81f8XxymyV9mVLRIhSij3ZSR73kuJIlJR9k7Zu3Bt17pWKTsjUSKj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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox["Kp", TraditionalForm],
       PlotRange->{{0, 2500}, {0., 87.15627535085983}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {1465.7142857142856`, -901.0935555973466}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[9, 22], 0.4090909090909091]], LineBox[CompressedData["
1:eJwVl3k41N8Xx2lRdqLyVSEVklRIQp1jqVRKSVKkrKkoISTKvs0MM2Md24yd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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox["Kph", TraditionalForm],
       PlotRange->{{0, 2500}, {0., 0.48493203000486174`}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {2442.857142857143, -901.0935555973466}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[5, 11], 0.45454545454545453`]], LineBox[CompressedData["
1:eJwsV3c81e/7RsSn7J1URmVE2St5brI5EUKyd4psEtkr6xz7KM45RghlV8om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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox["Kpp", TraditionalForm],
       PlotRange->{{0, 2500}, {0., 59.71518954642438}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {3420., -901.0935555973466}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[1, 2], 0.5]], LineBox[CompressedData["
1:eJwV2nk8VN8bB3ApS1mKkq2ELFlKkazVJ0u0oFCUO3YqWWbGElnCWKOMfQiD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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 150.},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox["MAPK", TraditionalForm],
       PlotRange->{{0, 2500}, {112.045739496836, 300.}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {4397.142857142857, -901.0935555973466}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[6, 11], 0.5454545454545454]], 
         LineBox[{{0.00005102040816326531, 0.9949125144013841}, {
          0.06376011659108582, 0.9257959312996609}}], LineBox[CompressedData["

1:eJwV23c8VX0YAHCEFMkKWSEJSWSPOk92ZSbpLYWIUjKzlSgje1zbdS8Ns0Qa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          "]], 
         LineBox[{{8.632064006928333, 0.9257959312996609}, {9.200976392299008,
           0.9841064117894391}, {9.967720173289912, 1.057035498510068}, {
          10.091980922067396`, 1.0674190038321507`}}]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0.9400000000000001},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox["S", TraditionalForm],
       PlotRange->{{0, 2500}, {0.9257959312996609, 1.0674190038321507`}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {5374.285714285714, -901.0935555973466}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}]}, {InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[13, 22], 0.5909090909090909]], LineBox[CompressedData["
1:eJwVmnc4lf8bxyVJhawmSSKScxx787aOcxCJpK+REVFE2Xtvcexj7yKU2VCJ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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox[
         RowBox[{"Bind", "(", 
           RowBox[{"KK", ",", "KKKp"}], ")"}], TraditionalForm],
       PlotRange->{{0, 2500}, {0., 60.84898691040515}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {488.57142857142856`, -1501.8225926622445`}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[7, 11], 0.6363636363636364]], LineBox[CompressedData["
1:eJwU2Hk8VN8bB3DbjH3Nvs5MpIQWCqX6UJYWJIpKi4gSIbKTfc8y1rHNoCJU
lkSyFuWrkjaplIiQQoqi8Lu/v7zerzv33HOe8zzPuRf1lPuB0xxsbGxqXGxs
//97bZ3+pzctfDsUi1Y6t/Z673gmZIuMuLEdrmd3DNz79nuHjXlp64m4Pzts
wtY2bDjJhuI9dI8FJw44u5vV7z3JBbnzPWxGcTzITd/INTzDDXqqUGpyuRDm
N8Tsu7mCH1FHrol8dxKD/a5eX/FmQRi4dtiK+Ukg+/OtiMvfhbEYPMzSiZNG
/GMtmvAzEdQnc47b5chhwmb8TIyTKLwLaRvCyxURNGDD/a1RFNlvWY1WHykw
uevuX/BSFD6nKk9+caKhvu1ZlvZNUVhPtHD5T61E32PXZ18OiGKj97NSfj8V
zN6VKq3oEoHI4sd9BWyqqP7Ntv0dRQSTUZPT6+NWw3efxK0T7UJ4IrSU/kBU
DZ7c+TROHUGUZQnqHcpZiwtrUsLyK/kRS1H4MEbTwG/ZP+OHd/Lh9HX1sMBy
TfAMixxI/MsDqkyBGLfserhvGpR7O8CNlA9XHfd/XI8Nd/OU1WfIWC68cYdR
tAHml1X6SRvIOO9Uy/PZaSN4TI01m7NJ+KDWdER9rRaurNp1MF6ZhH1T7RUX
p7SgWPJwr+4zLtyrebLUXKMNas3gckkaF9T8Xu3n8dsEy9ZgczE3LjD0+4ss
9TcjqspphYYNF3jYh3/lsOkgxISfrGfOBd+OCePhdh1Y/76szGHBhS9xP7M1
4nTB9+yMb98hLhw0//vVx0wP373Oc0c5cKFdjHNbq+gW/Gd7WnqbFxe03vAl
8/Zuwbk3BWwZkVwoyhUbPJCzFXeV/x7xyuSC6ElZrbzj+vhjXTbPVcqFUGVa
1AhtG1iiMs+q6rkwObbmjeboNvRmN7SLdXLh2I0Na/zKt+MBp0XV2GsuPPHU
C2xz3wHde/LrxIe4oJDLciLJAl6eiQlJ37hgHXxFWC0IRD7F0h1muZB4orTe
/CPQN63hUfGPmK9Bhb0XDJDw6rdeAgcJf1dW8mUXGYA/rsVGlZuEjeTbNY1c
hqCl5BWX8ZHgMlZnN+hkiCecHGt2CJJQ1HWPRP7PEB63hs8JCpPwtqLlptra
nXhZ3LhrqwgJIskPbCwu7wTz9HvxCcKmno/YvKd2gp3P22yrKAmhVo+vZ1vu
QlKssIkx4bpNzw401eyC5IpsYxrhSamXfwcljHCcb65ikLh/1ULvFbKfEard
d25LI3y8/53Z2ndGkNQ3DzQknNH8cc5C3xh8Zzeu+EPM5wlriOldYIyLzSv1
GwhzRXwxZbCZQOnyO/nLhPVPf/3RdMoETjfpGl6EvUwmc4baTWDZdizFjXDZ
mpmd3KqmUNimcSyI8BD/3Le1caYIKrIdLSB8wqZ2KvWnKTau6tvylnB/kffM
72O74WjfYalKzOfwpNbssc7dMM9VH4sm3Kv38/eDjXvQ41t2dZawVVT1wpr8
PVCRbND3JNbb0+O5mMy9F8u+ShG/CXc5T3PY9e+FanNwmPwKEkxqbpHuG+/D
hx2/2OsJty+d51ldtQ8DtT4PbcRJaM74Lvgrygz+u812syRIqH7wVTpxnQWe
Kscv7JImYZ1wmdwMwwIqG8xjpgkfuqEtrM6xHw41h17nyZDw8s9PUbrrfjwQ
oT7+LUvC0+QLUscNLGFt3il+V4GEtiZ32tzXAwgeNSvxX0nsn8OzlWsoVtib
t9NNl6i/7bzrVOwOWiFm4HbTH8L3rCdV77dY4a6P2ULwKhJqJ1w1ktKtMTV1
/VrOGhKuy7jortp+CGpmlgKy60lIvehofij1MFhnRTWVtpMQkJn3lOPBYcT3
SC4tEHase7Xv1q/DOOSg8O3NDhI2z+/ay2N7BOYcfEoZBiS8C1IxbVA8ikNW
TU/kjUigRX4xUKywQ+nWJz0n95Fwm35m05eHJ1D9qu1Cw1ES8mtYt+l/TuDQ
23bnu3Yk7HT5xlCSOIkxnbqAu8dIUE9QlnlifBJpJ9qXGk+QsPQkXUql7CTk
WiYKnzuQULz/ovgbD3ussPlavdGVhG82m4W2Lp3CGi4Nx+FgErTfpaenSzqA
/1iQFukSCcF2P2UnNR1w+oeDs2ooCUL2laqFJxxg9e2KsEc4Cetd1Ay42xxw
7YLspFgMCd5Bit4vIxxxnBH6qTiFhMaloAX1PEc8F+mI+5BKAinsfWj0bUf8
V2jyRzqNhMyo7Mt6I47Yp5a9KyODhPoksRKm8Wk0kVtiruSQsMgivzvH64Qe
aVn+VVdJMF55+mQH1QnPjm+zCr1GQtLVB18UtzhhLuMX24cSEihloT+fuzih
xOZCa34ZCYY1CwK6T5xg90vGYnslCdEdkzu4kp2hmn1hmaeRhG4Ts4fHSpzx
sqQ4KqWJBKmu8n11Lc5Q45zykGshobT7zGGXaWe8gW7n1vtEfr8ZutBjeQaC
mse6SzuJeHztvZonfhaD3jkfTXuJ3xtfCSevO4s1eyxsdfuI5xd7nvDYfRYm
FaxijXck+NgJyOwKOYthJS0ztY8kfOw2SJwYPYsf79U8Pb6Q4LdW+OxBDhd8
+/B1nj5Gglhsv1GLvAv+cU+UNX4l1m/gu0y3dMH6w1Gmq6ZIuFFTcWHLPRfo
WGtw2P4hrosEWFx57QJ7aU/buwskfHI1UReadoGrT0fgykUSxFcNjQwqn0PN
sVyJFRxkBGVLHY5LOgfOndyHnQTI2BccvqPP3hVfZxKVpVeS8eWthbxhkCsi
lJQ5VFaREbpZYb480xWfYuj8O9aQcXuqrvrSY1coaEvM5K4jQ+7UdxXVTW54
fX4fk2Mbcb25gSPVwg0FWrH24SDDXC52YOGsG+wvGiqI7SIj/BWN0V3gBtVH
w7wOe8n4amwr4MNzHn0RP3pfHyEjslhlfIB2HldNzvp/Ok6GItvPjt3bzsPX
qvng0ikyDty9fEnhwnmMvHe4dPEcGQ1rH8y0vyfuH6+2Oh5MRpyI5tsVt9yR
+4E+HXWVjPqyUe+GR+5wPBpUXlBGxtiuQhH7T+5gczwx332LjGJ9PuU3PB5w
1m2R9Wsgg90z+KjyFg/sW/PPbL6HDOntR677GnugNG2b1/teMtbz6/zuOuCB
+w/lh/v6yTh5dZruec4DNnqduarjZDS/dehqzvMAjguY0Di50XsN0mLXPbD3
zcWr33i5iXNYwel0rQdch08c6BXhhrzQG3aBbg9kPJa4wavEjUDDPXqHlz2g
ny+kvqzPDd3y9aU/7T0hu+bexoJL3NjvJzhnfN4TSbeyb+THcsPZ6OvOnABP
GGrVrepI5UbmQPEA0jxhMxNqnXSFG7MrpKSS2j0RqBbmJfOEGwKDPx0HezzB
7WNSc6aXG8o3e6q1P3giymqD//Anblibxpu/n/XEj03hHx3muFEdtBi1WvUC
GKuif6eu5EHX7ncvA7UuYOaOxIGD63gwKFlHfbbjAjQf2jTu3soDkSqPpou2
FxB9n7H8yIoH7iOff92PuwA+j3ODa2J4oG7e5XDs2wUofGp6vvibB66xH/vr
5y9A4i9zxxEeXlTcnzkozu2FoMSsqAVpXmjoyJk+pnohZNvttbxbeaFJcVXX
s/GCfM4NN49wXmyYEZwVv++FZau6mAlFPlxQp533eOaF0JLAL0+1+FDttHn0
cb8X3KRT9y+a8mHj++Nvw397gWGiomnkzQft9ltN0+reeBCunxvVzYfNmZbR
T7K8AWFeNyqdHz49p5dVr3rj+rGeH6QKftzhC/CLqPbGZXNNx20P+aFzqchl
y1NvXAt79PPqX37onvlpXspxEaveTo+fchHAli0ZUpFuFzGStWHlVRtB7PjY
V7p1pw9alMrvLHgIw8XSvMN2vw+2vop3YqYLI739weDFYz6YiE/VTK0XxljZ
TdlKXx8Y1X9ZeYNNBHTfyETlCh+ENGnnb9krgmGR9R6CEr6okmPWrB4VQezO
GJ2BL76wi4dgn44YXpRuehge7w+36a8rk6gSeLSFatic6Y8j+wdzNHQl0PhE
oHm+yB+qSj87X5pL4Nr051qPe/6wM+LV3RgkgQBd+tXj3/xReM5pePUbCVA7
JyO3mAdAnVm1Pv6yJDxGS3bOiAZi+03t1pw/Ujjtn9aioRiIO2p+oZLC0jjC
f2nrWbVA7H7tvi1ORRq71h3S+mQYiIkHtyYtD0hD2pdrZbdXICg/crc5lkuj
lWzPUfY6EL2xfmc2HJWB8CrZNntGENq0fo8O3JSFusq2M1evBUH3z4ySXocs
9iifFB6vCcIbqR8BAe9lEU27dsyjOwgzttetbnPL4Z/ixoUQzmAckRiT+Xdc
Dl+l9mjluQWDNpZrz+SRRztvwNVegxAcme3IbDJWwBBP/j5ZixCYbPd7duWw
Apa5W38eswvBS9b2L26uCthCJhuO+IRg51y2w9VUBVRx0D/+LA/BN4fy4ZJ3
Cij4e11KVPISqIwO+RknRfh9fxu39+slFFz/8ir7jBJO8nul3Ji7BJNLbTVV
Pkq4Ih79OIY9FKtVP7lXRiohcaPSi3HBUKSLWNw7wVLCsfOWAzdWhaJtiOdo
TK8SlkZq5zfZhsI07LQSSYmCGW+ORafjoSi6p+qzS4WCL5wWbNmOoRhVuGfm
u5aCbuoYecEjFK91DpTX6VDAPCYr3hwXihgM2l6xoACvQzSN74XC+U1erU4w
BdqOjzf4toXiN5dz8O1wClb/lNpU+igUpx2UI1RiKRARrdrK9yoUNVM7Aofp
FAzu+2za/S0UXLEjkW9KKAhvN3E4pBiGLaQDh/OfUdBRI5LtFBaGMpEZay4p
KjQHBN38YsJQZHw/VFCOimw+fsP4y8R1Vs2MgBIVLvakbzcYYRBcN/d2chUV
QsILO2arwsB44cmPzVTYunwejRgKw/4MlUiaFRVtGZ8aM8bCoEXiaMo4RIVa
24fUkskwtEvF/l0+TMU/qb6tjxfCkH5ztO7uSSoKO54ki60Ih/yuyPMP3Kj4
SrmjU7gzHIpfq0v0oqmw2lcjULM7HMN2zFhaHBWNvpWD7RbhmBX1o3ImUpHU
XZYwdjQclf9tu1qeSoVWEHNgnXc46Bz/ZHLzqAh6ExvTfCUcl2VuX/lXScUI
R7RdT1k4Etknek/XUGGuGbFhqDIcnyihpx7VUkGJCn5PagqHLzmn3KuBio6N
F9aZvQ6HdXwD34UHxPqTjr55T4qA1TOnL4KvqBDw+NXmKRCBX6WSImt7qeA9
cLmCe0UE6qR4B3f0UcEl2RKmRYnAuZKfRfv7qVjIp6knbInAZiO/TuFhKv5c
uidJNYgAOeW6+cQIFbP21ux1JhFYKnv6tHmUimmV6N4h6wiUdL35YDZBxZcb
46Fb3CPAtvWTueAMFcPJ4ed6Lkag7VlUyfWfVAx6yh1yCopAymmBXdtnqejf
ZLaWHheBOzX2rvv/UPGiqfL1eHEEXkdsc5VZoqKHubv1Uhlxv5nVG79lKp6G
DZVJVEWAKU7v6mGjodNIPNSgOQL+jISzLpw0ND/1VWP0RYCrNdvRiIeGxlsi
EusGIiC7uezbWV4a7qZeX24ficCfaYMtMXw03D74/tX0TATEKYd2VgjQUK3j
3RI9H4HI6j8CtwVpuCUjWCbPFomDAoz620I0lH3YfslUMBKb4n73sERoKG15
c/bjikiMrZXbmyhKw9VCD2tv2UiE9Hxp8xCjgXW6aA1LNRJSudItyuI0ZH4n
vfptEIkHIb+v6EnRkP6soPmyaSQaGi9WfyecWqVzfaVFJF5C4XuONA2JF8+G
WNhFItTdlm1QhoZ4G46zI6ciUVY/9tlfloYYvVyrwLORGM8I4xOQoyF88cnq
Eh/i/uGuTfLyNIQOnF6xLTgSUceZu3IIB7ctLb6IiMQ76+dlogo0BBRnjZ2J
j4S/1B63cMJ+UetfLqVEwm1dR8o3whed/2tKz4rEStM+mf2KNFzYfapUrSAS
5wSkBW8QdhNMDz5UHgkrg/mdVko09CyNZgVWRSL3a0V/FuGN01urWXWRENjr
2dlLOGMw+UlHUyTWeuTyiVBo+PPi85evDyJxkXTs2k7CR9t12EW6IlE9NlLg
Sbi5NkFuU08kvgee+s0gTC0Z2HSkNxKTlDfVjYQjs7X2X+qPxMCf9a/eEh6N
i3G5MhQJyx92x38Q3hP4PvK/sUgMM7dbc1JpqHBdx5ycjMT+l4n1woSFj0fc
XTFLxEdj5rIk4QsWb17q/o1EVqTMGynCr7B28hh7FGwj8zJXENbZeIkngjsK
8wdGu3kJ56x8SSsVjMJy54nwBeJ5i+Kq256uiMKh5nM1I4RPkgNtZmSiUOd1
yvEx4fu/uz2lKFG4/+9cVjlhlXFaov6qKLTMXjOPJhz7zueavTox/sKGxKOE
vz7uao3eGAXxGNqBtYTNmhTfl+tGYcn8RNEsEc/Kmxdme7ZH4YVJa0gD4RWs
h8Jzu6Lw0Elh3J+wT6qsmtzeKIjZ7vmsRfht+PldsIzCV5Pp82PE/ul73z9+
2iYK2+NZl7MIM09L+scfi4Kg7jcYEOawcUm75RAFo20O8SNEPjzSE+ucd4/C
wUPuIwqE1dY6DSn6REFyOXe+isivRPmGfzuDopCkanwdhA8s229Iio3Ck/r7
A2ZEftZO1+6tSYrCCr2SM0+I/JUe4nXqS4+CqJFtqhHhj+1VObTCKCjGj3eo
EvlucIdUa1IShRmXgy9TiHq4UnL4meuNKDAqXkf8IurlbDw7V93dKEyvmu8p
l6Thl4Wl294XxHwnNdXeraDBxuBqjEdfFEK7VE5KE27YOF+Y8TEK60p+6VsS
9XlJorB34GsU7HwbJqqJeuZ7P73DmzMazhPpSpuJ+nd7susIgzcaRr/XJO0m
+kNPU7Z3s3A0zg2cL7bhJ+qZhes88tHgDHve6kD0F6pTili+djRW6zy6t5VE
rE8o1NB4azTWWGeyBLhoELnjfmHKIBqbxF/ovOGgYYlk8cLAIhoCaPE/TPSz
d1cF6V/OEs+7fm2t2F8qnpsttiV7RIM/fTiycp6KztlvP3R9o6F56mG0KdEv
64yeWCZERsMwkyvkNNFP00fiRdczo0HvuMZrNUVFwuUAg7dXo2FSH+fb/J2K
8E0unuEV0bAdtrm08hsVHlG7n7+6G41fjF6rd2NUmKnwpPq/ioayd3P3wiAV
5NNRIg94YyC+ubaV6yUViwIX4SoSA7HZlQU8z6n4ddvRQ0IqBrF5D8dJz6gY
4trV46wcQ5xjes3fuqhoucKRIrAjBiry1fMu96nwG74kfMg7Bo6vmedXEeed
e6L7juWAGHgKefi03KDCSfuEe2lYDMytA29allNxMHL7s4WkGMgxA/Ptr1Gx
UXkxiXk9BnHlgbOaxPk54RAgNP4xBhPK7XsCifPYtlRWxGskBlc1RDyrI6ho
/9YgujgRg4rS0IahUCryLv4VF52PgaueRKFmIBX7YoLk9FbEYsNJaVUvdypu
loWsjjOJhVcfWauMeD+QnVJUW2Eei/2HFX56EO8P0Vota/OtYxEssD1w/X4q
jjcua1bZx4IkO9rF2E2FcHfopreBsfhx0bBOXJ+I749wwzWVsbC8ZydyTen/
593KXTV3YpGi7bhvjnifMQ14YLStKRaSNf1ftksT5zsn127LrljcK/0qe1eE
2H/xKAv/4Vhsdd17Zz87sX7dGLv/pOOgefitEXmQgtmQBJ+zYXHYmsyTa51D
wcMXX0rCY+KIeLpY/MygIHuV4dvcy3HIkSuIiU+lYEv3n63djDiUH37iXES8
n4UqOLFrVcdBmF1e2deHAoFGJP4bikPdgsmJm/spUJ6fLUzeFU98z/58abik
hLl9li9L98RDiVMkNeqnEh6xKrju749HRjdPbN2YElxMHZx/ER8T9fS4sbEX
SqjM6lE/fDEeBxpdey9dU4L+5vI62rV4BM2+j/HcowRrr5NPa7kT4PxwWWQ5
UhENwTbiVkIJsFh96MpPH0VQYs2PTosn4Lf95lMvzihiIk9/XI2WgMZ2HTnz
fYoIfyhNYukn4IeuYoO+mCKqZJ7rx3sS1wsqRMcZChBqNag4/j4Blw5HJitm
y8O7S/fn38EESLy0itaPkce7V+u2MMYSkGbfIbTTRx7XxhU6X84mINJv5V1e
a3lsW7Hw2VQkES5/rF4ECcnD1alaTssoEdNltMdzIXL4T2BlAvetRAQZc16G
uSzSV71m165NhPjItHvbVlmcRIzfyXuJ+N5hs1lzjSzmvCZO332UCIezDoWP
OWVBe1+Dc58Sib5xM1qqXgZB13fNdYtexodlg3ccCjLQNHayz/S+DImm7O/P
+qSQdum6jsqWJPiGf+L9SpHAjMXvB6+RhJ7hXpcQHgkcoBjtjzZJwsbv93fw
TItDtO3TmVHrJFy7vDC32CyOZA7pnOvuSdjHReEIsRNHQlT0P42rSTAS9Dqx
JXMFIhIc2jaLJMNYkf7yFI8Yho5WmY1KJmOq07qONSUKQ/Xlt1kKydhQF9Y8
0isK9qc5M3/UkmGz8vRizFVRXBJ6sfKeUTJOKa3cYrBTFIGpiN4RmIzf79/y
a4aJwCtLYa/pl2T8m2+kGMsIwZRL/vrbb8TvlyszT30XhLynLPe5n8moeVzA
09omCIerCYPGbClQOb9gaHROEAKXYvPPCqbgYHMZ40abAI5vDJe4pZqCpcvP
064G86PzTFj7bzXCMeIP7hzix0ZmqBc0UxBqW8i9ej0/uAUuPX+unQK5f7T5
jcN8qBwJvPzLIAW6LcyvKy35wMG4SNpil4KXIXf37QAvXJ953w4/kYJv+t7i
phRe9JK8HR6fSoGAzZ7y52y8KL9woc3ubAoWWUx19wc8sN7nHnzJJwUrUsv2
8FrwoDn8vHqnfwp6OP0DzLV4sPqu23uR4BTY9M0Hr5TmwaKKq15RRAo+HRxv
jfjMjWvLZ2bbU1IwI7dObncYN0Q2n7kimJ6C85sTlfRcuBHg6mx1KCsFZmxL
ze1W3LB4e7pqND8FfJR++ZrV3GgQPn1yfWEKdvHkNEmJc0PZ2FHY/0oK3DYa
3ZVj48af6lNufOUpWPvCTJXrHRmnxu3lrW6moOwr94XxR2Q8UbJ/nFtFeOXD
B+53yChMPLFGoz4Fq+dFzp3IIGOPk92IRUcK7FTzRVuPkOGsrKd+sjMFln67
d4SakxE5JOHl8TgFYuIKGp2GZDQff8aW+jwF2q9I/8bVyXgvX2FS+CoFQ7u+
trfSyPjzLjap6k0KvIV3yMvIkLHBxlD+xQdi/hz/jI25yTCXUHIY+pQC2wWe
FMllElxe/r0+8zkFGgKVlid+kxCT2jfNMUrkg9DoG4VpEq5Y1Oqs+JoCQzMZ
Q4txEtoE6SErv6dg+5+QmOkhEj4+Pt+hNZ2CkQ1SAUv9JEibrraynkvBsyee
ywdekLCJTMpxnE+B6Iwanf6UhAPtg5+8/xHx+2rydv1/JLiHN6tGLadgwtNL
Rq2DhETkns/gSMX0Q6OYgDYSri/51l4lpSL+FmWfYjMJDxut/9XypOLJvYvx
ovdI+BywYedD/lScOZrosL+eBDY9ofheoVS8MTq80FtLgsLvrz1fRAkXaAcV
1pCwpfaR1G/xVJRbjypWVJFg43XlOLd0KmaODqn/vEWC94awq1JyqZiX9+D0
uklC6tSxb6qKqeAcrpFefYOEmze2aOlSUxHWvG5ZqIKErnNSAabKqbi+yvWM
cjkJo2t+tdqqpoIcnqR6uowErrEe7rNqqbgWcUWr+zoJlGs3zP01UiHwXuC6
HeFtjvEZcetToZYx2SVI+AjNuZ+hlYpsyUXOgVISfD/tXFm2ORW1QflfnhJO
L6C4NOilYiN/jXof4Sq7xcou/VSMvO2p+0u4W/bd73c7UnHX60XyZmK8ib47
2ycMU8HYpz8UTZgnKy3qr1EqMt++ZpsgrHLQ4wn/7lSU+hietP///+9XmK2Q
35eKe04HM8cIn3i+5oi6RSpM/ffYXiLWF5RMLtQ/kAqJ2tX+ysT67/C3ah6z
TUXQu+0VGUR8Xv6Xd9HtKHG/IOfYCSJ+0zH+jcHHUyEkcf+5NhFfNS6tPQWO
qXgQ/XzqbyUJ+f+unh7wSIVkUOq7qdskNDSEV0x5paLtzwrvZWL/ev1O/Fz2
SYWG5vgziToSRGalwyjBqSAZhTUevEtC5PeEPPu4VLzm7cuVJ/JjInrzZE1i
KhKH2+18W4h8owzuIKekoqZnr11fKxF/q82fyzKJeAqp3qp4QEJj/ac1v4pT
sbea40UekY+zEZvqoptTYX1Xend2Lwl2Cp943ralYhvpbu+BPhLa78QfWduR
Ch8dZ+aKdyTQxwcWnz1ORcBOM93SDyRoWsTvknmbCr7vI7spIyQ4yQ48L/+Z
itPrZ5ydZ0l4WhO3cmkuFUO3fu5JI+pN20z74v6FVPwXoRLxaJ4EjtA46Vk2
Oq5//XJr9xIJzBGtE9uF6BDbL+nfQNQv+dLHyhRROtZ12/pr8pFxXjqO47M4
HR5/P7hXCJChv/fj1Rg5Oq5E2Gs8EiWjrzL2W89qOoTeJ9wPkSdjxx6t7SvV
6RCmGBvuViLj2ucPyRfX0aHiTGpSIvqHt6SWluxmOprjY9t/qJIhEvTB32En
HUa6tvYbtcnYbbKRe+4YHb0WTRluFkS/O9MwLWxPx/GIWL6PB8gIijN8t8aR
jrbXprHHDpFR+fjAjWMudPywUx6OP0aG1H4vqw4fOpKXD5iXupKx3vOv/oA/
HRoP2LVyPIh+SI9YNR9Ex5oUtmf53mSEvEqbV4+gw+5AV/77IDJGbG8z05Pp
yBQbWNyaRMaSv37cTTode0bK/nTQyZDObb/QmUHHq6LpSscsMvZ9eGX0L5cO
95LJuUEWGTX2sxMOpXREvKC5j94mI8xls65WGx3cI5fYLg2SkZPQTDVrp2Ps
K/tUzCgZtyuM+Z0f0fH04uyViu9kjE0e+pjzlA4elWmrvQtkWHj5RnK8o+Oj
tabvBHE+nElfdpP/QCfOTXHLT3LcCK+Nsdn8iQ5mvunYLxo37vzOUnP5QsfB
ismjlzZwQyGovuf5DB22u+9+Vd3Pjc35aJiYpeO2iaPeGltu7G/uLCbN05FG
bvQxP8mNSLa3PnrLdGh7DQ6TPbkxETkvX8ifhgftOQ+2p3Pj7uUtZz2U05Db
EfnQaIgbQos59wJU0+Ct++EM/Rs3Trn+FYxSS8OBo2b8fL+5wbe3sZqxPg28
97vOBQnw4CjP9n/39dNwxPWSdZAeDyp9C8yf7kgDT3Bf5TojHnCNLrHeGKah
j301xCx5UNHRYvTNNA3BzRH8zmeJ8zfcIFniYBp65+mdx/J4cGCmcFDJNg2P
JtU3MK7z4Jo9h7ba0TTca1Ef5a7jgTke9G23T0N/nLZ+2AseMBd30c64pSG2
tNnuBz8vDPxMaxuiiPv3Z13eGMeLzNFS7o7YNFz9FXK/n8GLr4d4jzxLSMPF
BEZnWxkv6Ju6lj6npkGG0vRz21NefJ7ZaypYkAbq5EF9Pgk+RLlZvD9xJw1h
388XmFTy4V3/LQ2Xu2lYmNwR97SdD5r7REK9G9OQnXVZMf0tH3rVnivH3U/D
vEO8+zAnP1THDpyv7k6D5a6UtYyj/Pjv1CF20mgabK+T+6KkBHDmRuRxy69p
iD6REmS+UQDkP9X38r+nYZPkdQ1nMwEYXhb22fwrDSuc7LXjIgXQWNf51Zk9
HYy20Uv0OQFUCmx91SWXjvKBAIuWcUGY25zdIKWUjj7v6+eSeIXwvTAryYGW
DmGeUr8ba4SgpvPL9N/qdFRICt985yKEYvsbTRqb07FJqfrkxLQQMu8olaTs
T0dDSFD8c5IItNnNuT5YpaMkIcxptbQIXu4Nsl9jk46lWYfsK2oiEBnsk7t/
LB33NlN+8+8XQTw/PeWnSzow9XsoKU8EwSe5Ag5FpUOo3oJTSV8Ujnzj++Qb
0sGuYVxeQxdDbf8vg/VN6RDZFmwQWyIG8i02nV2t6ci4K6N9oVEMpVbSVNeH
6VDKdD8X+UUM3/JMZu+9SIfr8KqijK0rcHHdtfyjE+lQXFiy4xxfgWhrh8kc
+QxUFazhLjSTwPWCD8kylzLwyVKUJ4oqjV376pLdwzOw+7enUL2eND7NpyR3
RGWAFtKSMmApDcmDu5I9EzPwNU5tkDdcGhH85Un/MTJwVTboZ+OgNI75+V32
v52B8EwpLo0CGYgeWJHwdjwDvTl+ZhQeOVQsf4tf9z0DP/ipbn8V5GB642F8
1HQG+I9WxDRpySGEJyB+w+8McN5/nzB7XA4TzZ/i4rgy0bH5hY3GbTl0rL0Z
q6eUCVP5ymMxh+XhT9odzbDOxA+Dsf9KkhRgzv53csAmE02x26VKWApQXqyw
WXU0E23RkpviqhXQ80tkTY19JsQSnt+afa0A1eG+x0/OZ+LSWrf883KKeH3/
jChbXCbmNljv7WcpoqxZNsA4MRNX9XYxSFWKCG14MpSYnImvCdwxom2KUK9e
f1smMxOzc/ftnn9SREThn0NaxZkY3ZMz+ENRCRtCY/OcmjLh1fSjrDVDCeSg
LaQbrZnQ50uelL6ihH7fb24/HxC/z2UxrauVEOu+f0doVyZCM6nZPt1KGDgu
PcR4kwkDPaWkGg4KLm8rVX36IxOTp8aXyDoUjC88qtZalYU+yvpAOvE9fSHE
psZgTRby1m++fJP43l5gH62xUM/C0WH9jBYmBXy85NpzG7NQ0pRe13qdAnWp
XXXF27PQefBGDpoo8NBqvbfCJouoL12GwRAFf+5YNFKPZIFPb+Fh9RcKwrYM
NK47loUu/j23ZCYooBssNe11yEIk/+Knzp8U1Fjot0a4Z0Fu01raTS4q5s7V
t/+MycLzzKi3BcpUhEyZdLAnZGF9GMnLczUV3F5vOoSTsvDtTGX8FnUqpAPm
Hq5Nz4KhgYdjpRYVerHa/zmwsrDqeYyQuiEVQVcqn76sz4JM7JsQt2NUcK1G
9+C9LOgnhIbeOEnF5fJn3VPNWegVpzcMO1BRUD35jL8jC1nb73PpuVDR2qr+
YufzLPjks6sG+FDB+aG0t2aciA/1i8KZy1T0biUPcX7PwuYQhy1HU6gozXH4
bjWdhXV7md270qgwt1Xk+jWXhRCL1fS/2VRkv0zboM2VjXIx+tc/xVSod4Uk
3lbMhlPC4J1t9VQsre7P4qJlI9pyi0ZBAxXPY/SKrVWycXsD78BsIxU+Rr/u
/lqbDQOL87SENiraWs+OautlQ3FL6EnzLioO1Vkb1lplI9TmP6rBOypWS1ab
kWyyMTri5iLbT8Vfb+HDB49kQ6P1e9bEBypYG7vcZ09mY+xyR+fFQSombuzI
33Q+GzGjN+LUxqhoFsgvjfLMxt2YFs72cSpSzi3UvPbORmD9hRsHJ6jYvKa2
62JgNj6W8dXYT1IRekXtT21sNrLP7fBT+EXFAc5YTnJiNt7vP2rvP0uFyqkR
oUPJ2XiROt/0dI6KLiWWylxGNji2PP5xYp4K8VwJq83F2UjKD1JYu0TFl/kL
x6OvZaP0jnfw3mUq7tr2nO29ng3mC+UkRzYajksmhPpUZkPm4bmPoRw0XE9l
u3mnKRuamnKLp8g0aPpttexuJebLYRazhZuG28d9fo08yEajn/wQPw8NzWu/
bZHoykakqppiHi8NO8VUP6o/zQa1Lo/3KB8NnX/sw3b1ZEPqz/e3K/hpeNnx
5pFXbzZ+aFXqewnQYFshdi7hbTYeON/okxGk4SPdTKi4Pxuiu7NdGwiPnXhg
/WKImF9zZtK4EA1uxku/x0ey0RqUqOInTMOMul4u+zix/4YWD9lEaFicvzm4
fiobGDiymU2UhvBP45GmM9lo6hkV9CXM80h59clZYrzXM8ujhC/fOPHY9082
rH9cELESo0EsPed88t9sHHQ02llPOCvgtWjJUjZu3TPOk1pBg7y9SG0zOwNy
H6HkSVhVM/rvd24G/r4uqhITp6FCvK2AxM9A6PyWziOEN/79a6AgxIDvM1Gp
fMJ1g5tHtEUZOHU1ofAtYf1Oz9h94gz4fVlwEZGgoe1mxVpHKQYqHhT4GBA2
zhjtDpRlYOP6K49cCT8JpF1IU2BAzUvVnk7Y8tQxiXIKA1OzG42rCfeaZtff
X8nAmZRW/yeE7da9PPpuFQOnhe8sfSI8KCG0/GMNMb9X42+mCDv9My3i1WDA
VF+aZ57wxFCEEXU9AxeEv6f+I+zxX/OYrhYD9pG8fguE527NJ+zfzMALtt+N
M4QDM7XXndFj4GWxpsMIYbZg9xeX9BloHpNxe0E42qHsYtYOBnh/CH24S5h/
z4j0LUNivHnr2lzCKespjQ+NiPnPKP3xJSwhdfTER1MGyHKpJeaEcxYzOOb2
MvDodX2HEmHKcM9VQQsG/vBkWk8Q8bvaxb9b5QADJGmZQ1WE1aqMv+kfJPbj
tuITT8KVWWHJ1rYMfFLyrFcnvCmkcaPrUQZqs5/KD/3///+Ov19HHGdg2a5/
IZXwjr0b/XPtGVB5r2OtT7h9g5t8jSMDUY3OaoNEPjxbGjo15MKAV6aIlSxh
6xEF8oIbA0FKxqU3iXx699j2uqgnMd7trkvbCA9nd0/Bl4G8JN+GPUR+zm9s
CGJGMMCWuzZoJZHP9c5PY0uiGZhjKPInE/nul/cp/VYcA9VZjUdmifr4Q+K+
0ZLMAH+B7/Zqon5+91l9GMhloFGvc9V3ov7uCDqPjxYwcEt2RZcmYR/DgNmp
QgY+9N/ecI6o17lyliBbKbEe9UDzVyQaZkO+b6PcZuAxy7HVmaj32zVse1bX
MZCzzjr2EjsN3mMrDq1vYGDH8VRxOtEfflluOY9WIj/C2PxLiH7yUzmm4OQT
BjiEcp3SFqj40UVZZg0zUBhAsXb/QUXlshb/9VEi3wPPKGtNU+GhbSJV9ZWB
blbUzR9Ef5vOd1vXNs2Aw13PiePfqJjyaDgx+I8BG2edL/NfqPguad1KlcjB
1jRm4fr3VFTsdX6yRjoHNz3Jrsy3VLiGBvRtkMuBbpFmH08fFd/GWdMG1Bwo
vbNIevyK6L+N3ymnNHIwTGfXFemmYvxUTFiRUQ4uPalNTG+hYubCmexvpjlQ
DHa/Gt5Exb/w3bc278vB7y4/uNyjQqSY/0PXgRxsG1g/pVJHhe7nZN2fJ3Iw
1RHUZX6TiliH7KmdATlovDYj5pBLBd3Ln5wUnIOAl2viRonzKS/iiEJfaA64
XlINT2cS8SiW3+sak4OVOnwu+1KpePOZdS09PQd3m2sE/4umYpXj9WMjN3Pg
HaR51NeDivXe8d7rqnOwb5Lv7mU3KrZEnkvwr83BdIYPbz5xnppf0bgr2JgD
C4qy6zVH4jwbrhLf/F8O/gTdYDjYUtHh2PA4+nMOLD0D3MK3U+F4+rHeaulc
7K52LVUhUUFZjBvTk8vFOdm+rBR2Kj6km2btVcxFOWdb5a9FCg61d/w6r5yL
q3KLxqVzFJiubL1Vuz4Xhn8r7BpHKdAYvK2yc3curm3e1krvpGDOrkD0eEAu
Wm4aqz6OpKD6l12re3AuXP1t2C1CKXBPlHMPC81FCmW/9uNACsbuZT+5Ep0L
ZtZEbMUFCt7LpsVM0HORkGO1SuwkBa19MYt+5cT4fLnfT+lREGftOZ7WnwvP
Ta4Hnz1WQsqjxaLRgVxIJrxf+NyihMwt8XZbP+fiT75ryHCNEq5Qip8Njedi
brn5VWmuElq+vard8DsX/67XVeq7KGE2Ujf8mWgeft769T6UUwn2tcuy/CZ5
cImP8PynoogzqxNfHd+TB/PtLoFnpRRxPlc6qdosDxL8PeqtPIoICtvAfsQ6
D4WC20zVJhSQZeYwWmqfhx0XnzVP3VTA05GHNcZBeRjK/OSitVEBepJJ+8Kr
8lBU22yxT1UeMyJ/8vNv56GMElqyJCmPCv5TU/V1eahK8bfLI8tDkX0zfaop
D+oDOi8YI3Lg+vbhjV1XHlTEbjfkFcmhp03DQedzHiR3Ofrel5aDk9tT/2/i
+fj0Pl2hbFYG6e0CJYf88kGl21pKXpRCrKCF/anAfHwX/jV16KQUgg6lyp0P
yUfMKnnl2L1ScByTSImKzIfvRi/uJqoUtAWU/G+nENdLNgj4PJXES6sNe8Wu
5+NkzeUQK5okxD4fnHr6Nh9b+4/yejwQRzI7U8doawH2lXiQ1WdF0a1y6x99
ewGin/sNjvSLQmBPS9sngwKIh/7cVdIuilj6wN4g0wLsLPM7uDNdFKErKSdr
DhYgxfN6+08tUXgYFcZSPQogN1O0uveiCA7EFb9dvFIAZm+DIVVMCCk3agr2
lhbA4++gwbEvguh+/sCBUV6ADIOXpPcNgtgjO/xdu7oA/SY2KHYUxM5yZQ7X
lgJcCnD6mXNPANpPr6q9e1sA8pP1PL1+/Ljwo3ZK9UMBELOpT+wAPyolHt6+
+KkAQfN7zlWu5Yf68S/bRUcLUOpsPS3xiQ/KU6usTH8VYPhx8dEHZnyQEC0N
vCPEhH+VFpf7dl6QmzL6HosyoXxEp7qDwou5MxGbBsWZsC8/dzWRkxd9rcen
+OWYaNW6w/Ts4kGuh4SDvSoTZxPYmPeP8SBRnrPVR42JeLmrpg938iCoc1o+
UYOJA99vqBir8eA45UnvHS0mLh7j62/5ww1qT/geATCRx+Pv3ZzLDbEgjxLq
Tiaiwrg0H0Vxg2P1cS4dYyZmCgLzD3pwY/iSXrP9PiZE34Rt4zbhxuu1qnK+
Fkz8K14pqK7FjYdvxP0SDzBxpVGu+60SN0rWTW+os2VCam/L+RcLZGS//5D0
5CgTiuVRmxTHyYiNeTwxeJwJvx2b63+9IcNl4NpVgdNMcGQZJxjWkaGRfEzm
lCcTY0fG8o8HkaG4da+Przcx3+ONekvnyRAa1X2Z6MtE+m5n21WnyJjeLn65
LpiJ2fEbOgJ7yBj8yv71SSgTJf4r8h5tJ+NF5pTxUAQT26pfdZK1yaiZ7GIT
jGcS58SZz7wUMq7k1B+jXWaCd0unRJckGenG1xp0UpjgFG/MIQuRETWTJmWW
xsThC0EqTSQyfArCvE9lMkFL4twxsUiC8x73574MJsQfZhklzZFgO2eneTmP
CbtcJ/fiKRL0zHXH6oqYUFkJI+nPJKgtqBg9vcrEo4XuK54fSJC9tqJoqJQJ
4yb19PV9JPAfYF/+Xc7E4ws1hZYvSfi3OHlU8BYT7xdYO593k/D9en89rZqJ
UcFf78u7SPh4sEtCt5YJmdT4xg8PSehmr79gVk/EQ7VjrcMDElpuXH126h4T
7SZhZ3RbSag8nKbu18yE6n/TNw83kcAihcVdbmPiPrvMtgcNJKRWnf9S1M5E
/VbYeNaTEH7Mbmf9I2I/ztnsO3mHBC/ePaynXUyITVIDEm+T4Firszj0lAnd
GQ7LmWoSrO1VjvzpIZ5Hl7BNqiLBSHBFneArJq5KLa07VklCaHq34uk3TCzL
WkiZ3iKhQS4+uvEdE7G7Q9873SRhtshocsVHIr/KhW/V3iBhvRr7oXODxPOq
VWbXEz5X1dh0f5iJ06XXDF9XkHBN109FdoyY39c5eybhwRaty54TTOgd69+f
SFjeZOpX5yQTmq6fDBiEbbrL7CgzxP7akHIfEKYfdGr3nSXmZyI3y0OM/7Sf
qv7sDxMhL5dlnAnzOH5IW/WPyNfu7xz9hHdOZP8NXmYS/V+n9zQx3x16ZVUu
7CyQrDlGOIj19P+LOS3JyUJuX2tpFeGA1tMy97lYqLpZ0upBrF86cudTNzIL
fVie3E7Ep9aEGibDw0KEXp2kHBG/6e7+MQ9+FqRdWB7zNSQk0Rvy5AVZiNI0
/jVPxHvtoez9nUIsFOWcFSYR++H0wapeSYyF/+R2FeoS+8VVuMH18QoW4l7I
Cp+8S0KhozDFV4KFHkPr5WRif/snumK6pVkQqG2Y5Sb233LBwCZYiYU596mo
/fdJmGxS4l9DZeHCxNupGiJ/EsMWm1/RWJC/FPpboYOEhzx3V6mvYoEReyaA
1EmCvtT6uXfqLIgUrEmjEPn57p1gWbQmC5cjlkh1z0jwLZg4tnE9C3do9Y1W
z0moVinpiNNiwcJhjp/1ioTV2ooZultYsPT3OxH1nhj/91/T4a0sbKWv5rMg
6sPh3tt/ydtYeFkefFppgIQCwwzHUbCwxKWc9GqIBHFLAe1MExZumkVUpX0l
ge38wouf1ixEvtU4FPGXhHu2u+5lHWLB/5rTiUaiXn12JhVvtWUh70Sy6NIy
CRPSNO+IoywcOxG4IY+LjN4HuyVWnGJhvIqyZErUf+rNtMU7Dixozm0ZfCJC
xj7Gh5Ejp1nYXSAudXQFGW3nPe8UnWFh6CXFNUuajAoZhs1Gd2I/+burMleS
4cz1eUevBwtnGDorvFeRQZtSXx1wgQVX+4CXx9aQkdXe+qftIgu/xlLTbdaR
Ee4+xrAMYmGEM8jz21YybDp0+j3iWGDJHnn42YYMscqwdvEEFm4trrxXcZSM
JzmPK+oTifm1/3ci5gQZhh4ngtlSWOh6wWbq5UyGulyMYkomkX+GbiPr/cgY
JT0na2ezUNIrkEcn+mvRtOzUGwYLDzq+m/OGkSH18GaLUj4LD5VzPHTiyeDw
7D15q5iFze98vYvzyWg6StltdZWFvaW7XtwtIsPP2GXD72sscMmUfxkrIeO7
3BL7jjJiv9a5rk+rJqPvoUpxdyULn/ddTFr1Hxk35S+OfG9i4fyR070tf4n5
Pr7BuNjCQuCZWMM1HNzo9f9ittjKgiNbUOUtHm4s9drcEWhnIXmddaCEJDfM
U7fErO1igT9F5eyBjdwY2uG1teYxC1Zd2r5VetzwmSyf2vKUBdlLVRc2GHCj
YK+C7Z4eIr68rrqZ+7kxRWJbc7aXqJ/v4hbsntyIvK37YfoNC36dz8V9/Lkh
7eCZ6veWWN/jyyPC4dxA69B8TD8La37Itt1O40ZKQEfXtSEWzFWaNF7Uc2P9
VLzr8CQL62ifdr3k40F7/gOK6zQLDXtZ5/skeGC779+rnz9YRN0eVeOn8iD0
uts2zlkWujsUAv/q8KDHYb8Q7S8L27mOu0ie4YGjWNz96/9YWA5aK5jlzYM/
rW0+G5ZYiD25KnR3GA8oiloDYC9EyV7mN6NcHnj0SVSe4C5EIDPfuvw5D7hi
zB1HeQrxMWRmunOAB9mbYqTd+Qqh5mfmIz/Jg1b6n9AQwULUfz6v48zPCxGz
95b5KwqRYLdCm2HKi6o21s93SoXwu7b9yZunvPh6DDciqIXY2ardKDjIC+WF
ASf1lYWQq2iuTvjFi8yNSu+CVxVidYZnk708HwKK81spGoWY7t09E+HOh11R
OZedthQiTyu4llOZH8HULSbC+oXw1HIbnt7KjztNb9nqtxXC+XzaC3Vrfqye
k/bmNShEr8FNWXoUPwSds45UmBQiImOiQ+YbP3pN01VnrAuxvVKjeE+nAIRH
tAZzDhVCCzfDt48IEN+dL3N22hbi5FDPSASHIBruigllHC3EnP78Ts7tgmCq
pf7SOVWIg2XNjJf1gjgjkNQW7F6IY4f+hhY3CWHhWcxR3vhC7P3RVyQZJgKB
9ZKDGQmF8Mq+6rAuTQRKKVecaJcLsbTS1NP5qgh27W/z3JpSCA6BTae0u0SQ
1LMQ45ZZCP/XqnV6EqKgPXe7/byoEJa7P7VUVIpi9wsrwZx7hTiy+w13+YIY
sl8ptah9L4TQ4P7n8vcl0HlU1v/WJDG+9s/9AX0S+DMkrqU9XQjRG6dfvJuU
gM0P3pJtPwvxqqRzuEhOEpJCv5L2zxfi1mkUGlyURLpJ53EfUhGyqKs7zVZL
IbnBY6lNoQh1OZkqzvHSaDY4V2+sVIR7GmaZ+ixpTHaevvCYUoRU8cV88h1p
mL858uXVyiIohuSP+gxKQ+DXru7RNUXYlp/4uUlHBvEaMgWCm4tgc3bvt4xB
GUSz2rYdNi9CYndktv5qORyVWLm4ZFGEJw0fX1Zsk8P6+MjGK5ZF8NL2NOSy
ksNbL5Ot09ZFED3/6pZzsBzUTZ7qxhwtAkfN07H5Hjm8/N6nVXumCFyrqgLk
vORB2Tq9RjSiiOgHrQEbixQwe8ty/E5kEcgNRiLqtxXQpVxTahddBJ/tncI8
DxXgJeSjWhpXBOqH/SrO4wp4OPhXeUdKEeY4m+63airCLZab4pZfBLrq5/GP
NYpoeK0o+V9dEYrVfuWPlyjhjJB74YG7ReDl7D+zvVYJkiYt6v0NRaDp1MkH
3FfChfoTO6eainAg6HfYtX4lrM1leUi0E/GRSU77yk1B3knaY/sewil2q57q
UrCHceHQxPMidLCNytZsp+DP8/uD3i+LYD9uoHh5FwXWOx3+xPQWIfkGT5DC
fgoEV11RudlPxPekTnelEwUhEyqhC2NF6Oc8+rM8lQJ1ZR/+yK9FeCTKod6X
ScE7u4eZgt+KECu7pDGfS8HmbqcblKkiWD/e0yJzjYKpypJ3xrNFyJG769l7
l4KTPms2pbEXQ2PWiGv3AAU72TW+rpUtxpeTvz640KjIVB0O6JUrhs2XOeHc
VVR8NcvlD1MoxkAH+7cWNSpScng1einFCGmx/DS6kYp+rS/uoarFsN6t7FJt
SIWPE3P2lXYxtm0cNd9xkor/Eg9FX9pcDIn7B/a0OVAhXyMopaZbjN3vBQd1
nal4sByoe2lrMUxz5GR5z1MhwrANXGNYDPK90d3rAqkoeyzKHmJRDI4ls2cF
aVQs/uhMXW1ZjIuzpuJhmVTslw6lvTxQjPQo3ueHGVT8dpzcufpQMZ4I/jcy
WUDFrqWu6Bd2xdBb/vyp9DoVWcrhUsHHiyE1PbAbFcT69uiVqp4sRoNrVXL3
TSpSs0r+C3Iohj5Tc+hZDRUf10cKqLoUo4q0PO3URMUGm635z88VY98HavKd
Fioig2c0gtyK4Xo0+MxiGxVru05aPPcoRruM4ILHQyr8HLbRA32LIXnub/d0
NxWimXNSPZHFGN5kn2P3kYpPfwPf9BMuLrSwcyFcac+eNU54q6q9vB/h/RoC
kpxRxWhq/Z6ZRjilnSq+mXDCxM2LXYSFfu4TySOs+Gvgrc4AFQL7i3nORBcj
J8trm+gnYn9qV3d6E46qHXmgSLhC7mZMGOF7fMGm6oT3jdaTcwmz35LbZ0I4
IaSbq5vw0Tuy24IJ892YZ9OOKUais+bDMcLvxC61gnDQ2n+ac4TL/LhCzQjH
6E5ncA5SsWeX8LIT4e8ee48rEo57r7zIIPx+XU+fFWFbg7LGa4Qvi77YaE94
dcm6oBrCB+8vxJ8n3Hlhy98nhBVetW6KI5zd97/t33UTyJ8TFtcxDcjPsHOt
egbka79WurkYyLdYcsryM5DftYhPYyOQz8EV8PM/kF/Zq1i6D8gHACxFVVg=

          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox[
         RowBox[{"Bind", "(", 
           RowBox[{"KKK", ",", "S"}], ")"}], TraditionalForm],
       PlotRange->{{0, 2500}, {0., 9.06463501154421}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {1465.7142857142856`, -1501.8225926622445`}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[15, 22], 0.6818181818181818]], LineBox[CompressedData["
1:eJwV23k4lF8bB3AkZca+m0eSyJIWS4WUL1EqUqkoW+inyL7v+67suzCDSkWI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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox[
         RowBox[{"Bind", "(", 
           RowBox[{"KKKp", ",", "KKKph"}], ")"}], TraditionalForm],
       PlotRange->{{0, 2500}, {0., 6.888106545031205}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {2442.857142857143, -1501.8225926622445`}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[8, 11], 0.7272727272727273]], LineBox[CompressedData["
1:eJwUl3c81d8fx+0R2XvPe0tGRXadd6gom6Iiia+QvTOy9x4Z17pKMlNIUkJo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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox[
         RowBox[{"Bind", "(", 
           RowBox[{"KKKp", ",", "KKp"}], ")"}], TraditionalForm],
       PlotRange->{{0, 2500}, {0., 11.757770441780488`}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {3420., -1501.8225926622445`}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[17, 22], 0.7727272727272727]], LineBox[CompressedData["
1:eJwV2Hc81V8fAHCKKCMyspOMiDIqoZwPKSpFCGVTilSKrMh2kb1de5WESGSP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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0.3},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox[
         RowBox[{"Bind", "(", 
           RowBox[{"KKp", ",", "KKph"}], ")"}], TraditionalForm],
       PlotRange->{{0, 2500}, {0.2777999001933846, 0.9236823656322156}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {4397.142857142857, -1501.8225926622445`}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[9, 11], 0.8181818181818182]], LineBox[CompressedData["
1:eJwVl3c81f8XxymjgciMipRVJFpm56RBIoXiWyojEhUVkpUt+yrjyl1cslJm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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox[
         RowBox[{"Bind", "(", 
           RowBox[{"KKph", ",", "KKpp"}], ")"}], TraditionalForm],
       PlotRange->{{0, 2500}, {0., 0.22675872962904955`}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {5374.285714285714, -1501.8225926622445`}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}]}, {InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[19, 22], 0.8636363636363636]], LineBox[CompressedData["
1:eJwVmHc81f8Xx23KiMxoICMj2732+4S0lBkqMyOErITQJXvEtbfrkmRFVl+V
kVFZ2SIhe0ZWKPnd31/38Xyc9+e8z3i935/PuXx3H+jbUpCRka1SkpH9/7dA
UmVyuOEo6m6dkE15SCbxhckEkiIWUAfRgPK+tKiK8Y3CRouIXXRzMlCXdbtF
Je9qvOu+HQUsFek4vmg5o8rj0kN2MYIO7rU23hsmt1CNxzPhY4uZgOx78YTY
zTjVkNsFzKt2x2E4rf3KWb1a1QtOrSbHvdlhZ0sw/Kb7iOqB/wwBG8EFoXZT
IyVdO6pvYikXTdN5oP+bHKKIY1HzzOWXDio+DZ8M/rpc2hNWSx0hvDMY54Wx
r654qlxVNa+75ZZzdvxwl+aNTe2grprhcgOVz9pZSMOwhPF2WKnJeH4ppPcW
hLWQwvLo525qzAfj2tlkwtDQucWiF4FT+xnyc10q4hxk3wtpfeoRo9bJ9C+x
mUUURHT8l/jp09SKUhgVjdLFQPuf4YX5+/lq4bynvi/wn4cKz7vbxbTlarYv
xQMfF0vALUeTreM6b9T4TmQfp+WWghoTx2MuY01qcd+f2+iOS0F/ULDK5aDP
aoe5pTVpRGkIFZnPv9nYq+ZiV003bScDN3C8kUX8X9W+i76/LS4mCzWblRrF
zJNq2mstJQ/XZOH0iSy23D8zam8rO//VV8rB+oa5w5X1JTVR7wFdOm95KLiY
yZxC80stTWWMqKeCAc89Ks5shW01OvKZrXQyLPwr9m+dOLWv9qh1WWumBQuH
5rWt8m2HanMRm6nnIxRAEXdhepSXEt288WfJ67oiPCu4csa8hwa1HKdUbWRR
gpjPz+j/7h1FssNHY48MKcGMISJTLjiGiBnHf+inK8MUc37WkstxxGLJLZtp
rgLZJpFh44bsCCfAHzLLrwp2o5co4iK40M8FkWGJeVWQ/FnuXsVyEpmVSot4
F6vBNydHK96NM6jTTfFx0wMELh5FjdOc/OhUBsGOmhtAyCRLbPyeADL0zz8m
6gegL0BsTlkWQtEWhW9ujAMU06UH1D4XQS0XSqw84AIsRUW7b6SKoz9ny4+m
Ei/Ah7JXQP9JEjku1Jr+sFMHytLxD3HusojY/paa5rM6iLaX5bo5yaORkoYy
UTENIPMouUAdiUXMsc3GOjEaYLPmfbqjUxFddvtI5rmmAddb46QvY1QQzqDj
ZaqeJlSNzQ3QfFJDtfJf9N9XagL+oqZZRxMgof2hfBrvi7AbNNJ2oUEDmY+N
XhcbvQjZvtLYGMuLKKl+fEdHRQumahm1/py4hKiezl1OI7sEJ06bMaR8vYpU
bJd+vb97CX6ylxc+mtBGHpd+pk+1XAKOr1Idk+Q6aIp+Z0Us4jII5+lJOnTr
IQvj6jX85mWSHhJotoQM0BjRc+O32RUYeMzi1o83REOKm7+bZa5C573QnZ8E
Y2QQ8npfJOsqCNZmS1tq3UI9PW4HsbTXwChS+HIc2R3Ufm+dwnTsGpyhGMgs
rzZHlypfUX/Q0oZcXb6rWyaWqOWfC925Cm3o/L7oXXvXCtUnrTJuhVyHlJ/M
aeHp1uh18xJXtKQO/EcZKvMr3x5JHivi2UjTgU1q/fSRI47IqFTumDiFLixX
HT8l738f9e9ussQ76ULSJiW2Nc4FxWcbsLbm6oIVZU/cOJcr0tWsZNsd0gW2
WxZ+xr9cUVesO6f5BT3gEbWuoX/rjqLl+7jwXnrwwpFYVlbiga5+k+ZuKdaD
BOGanVMvPNFHoV8nRTn0oVQhJUOx1gs1vX/Av7OkD9HLE5p+Vx8jnPWXsyK8
BtAd8b4wIdwPqR2RFDS9aQC5txR6VHv90VvDn8IfGgzAuFpIN+cCDvnuXxfZ
3jKAAcfx7fAdHFIglIqeEzWE0YGRFIWKQFS97HT+WaIhvP+YvXpf4SnyxHdK
NH02BJEf9gwy1MFIBisutfXPEOZil2fVvwajV0HLMrcdbkJm23jxF3woennC
UUFIzQjkTPr5A40ikX3DZ8VbHkaQK8EmHXIrCgnZiihHFxpBkr7N/q51NMor
X1DdOG4M/Oofd7pin6GsS/c06ueN4UjNfml/Hh6ZrrZp/jppAs1/S011LsYj
7gQhLQF9Ewj9N2QtuhyPUsZnL0e+M4G57JAvJpqJCP/Q5oYR/hY0WodNnZNM
Qb7JmV0UzbeAQ/88y+BCCrKpHdB+tXULdu4fP/u7IBVh9jSv0ZnchkD/bL9f
Uulo1E/wct3pOzBq+FNQOCALNWeZfbTTvQO/GAv95syyUUl9khZr0B0we/58
vFs9BwWQ0Vx0mr0D8p3BkmrPCIg/eO7C6RJTsHfYfkwdQUT0z083tX83hZu+
SwELTHloq9UIHh0zA2cbxaW2lDzURvtRrcfdDN671DWUvs5H96NeKAcpmoNa
Pk9zLdMLVBVvLz/XZgG/yE7EgXMJyqokVMXvWkBJF1fST5FSpOG4knaG3RLG
2occkpdKkXiUwIlOLUtoHtOgOO39Cv3rTOQULLKEgLhUT1brCuT+Xcr4zwdL
yC2iZTfvq0Dzq53Jvd8sYVjf0GZL4zXqYaLmCGC0glRp+wMJiUqUp/uQbdjV
CorQl2JW3mrEZcViWBphBVL+37g3iNUo2q004SnRCgoYnXQenatBXvGzx6UG
rGDwiR1zoXItujxwkyUCexdOjYbcpA/+D60YY5iU/92FqhQmq43CeiQ3mpiY
yGENWXvCD6luNSB/003unxLWIBXgtqRG04iYrMqFcy2sYbLCp3CjvhFJOYpe
oG2yBslDjTBhrQ/IeyX8o+WINRzFlHwoL/mAmlzmr9f9soYL+2wXpdibkb5H
/m1nfhsoPMZii1lpRp5+pz37n9rAjFpap21lK3r3z29fPNMGlpNsDgtE2xB1
4DdcaJUNbP74c00svw0lh6TGKM7aAJeJVKNQ9kf05tnxFzlatmAiJhfA+eoz
OiDQjN4/Yge+tTe+/7rRjbTO2lq28tlB9lJKcPFaN3r2vHnutJIdPKWs8rBN
+IJ4i3CbvY52oK/1QJ7OvQepV+4zKHTawfrdw/y5wV4UKX8rAT9jB2hFLptO
tg/119aeWP5rB05Oe8Iz+D5k885TKPv8PZjDyn6aM+xHoa0/EVXsPWBx6/y4
uz6Aui9dbzN7cQ+kO+2FWk0HEWd7sXZtwz2g1Xk5F9U+iAq77W85rt8DBTb9
22IlQ6h9eMq9R88eIvtyeUrCvyKmpaHnmWwOoLbdKLlaNoYKtfKDaCQdIMGN
25j82neknudm4XrFAYp6rZpPL31HXqYMJzQDHMCR8jV/ifQEGu++EL087wAK
OTFdHZuTyFvsmMNNCkeg635EXX/jBzoePnax4aQjpJpERzkX/0BaFx4dxus5
wt0WNnd+xylUWlnirvTWEZ6It2+9OZhGWsy+OvmDjhCaIh3leG8GTTpdEmda
dwTvrXh+zv4ZxCY0NftD4D64t9yOCCyfRX6pnLcint2H1J9vZXHB80jbPwh9
tXKC2eN0YgGpy2huROekup8TWK3sB7cKriAc5tRecbITlOQtaMZWr6CqtdrX
TzqcoMLypU3X2CriubsqKCzvDAs6fL1eguuoqr6OAq/jDMKJm5UEr3V0gyd8
Yt/BGXJWGCIkP6+joAH+tO5sZ9gIaKR55v4LLWmZMHjRuYDnQwvnzqENFJwn
uDjB7wJKO//WM2Q30WmyzdYrqi4QixIdtvCbSP+/mCen3F3A3bH1rL7BFqoT
a95o+eYClw5q/FUXt1EEs8QI66sHwCo0eKLYdg+9KZr3rPv4AHTdy2nZBvfQ
gmYus9XkA7A11ww+prWP8lSOCgzTuUIInsuzQ/wPInfzvyOg5Ar17IWnKhkP
UP2IdXt9piuU6AYeJY8jg6EC4Dr+0hXuXXe7cGSQDFY9TtnZVrtC9fW+e5vc
5HCSaZicodsV9nyIm+4vyeGx+lXFW4euwPDIoUWjlwIUiqUKN63coLiwg0Xl
OjXoejPuaLm4gZ2g0NddAjXcu7ikke7rBgUymmpF29SQPJE3QRIXkN/gTfyZ
SwPbrJycz1rcgN2cSMtOQwev/Q5Czgm7wyarwGXfg6MgfqPd2mzFHX7rV96f
HmQGp/DxsTd77jBb+fmFBxsLlHzYuMlG6wGJN0Ev3YAFzmN5LnfwecCsBAV/
UT8LSPA6iSsae0BgcgGuc/Q4SG8wbrN98IB5MRf5dip2wCTrhXameEIU9R5b
UPMJ8OqxPRR+7gkBv8oKVlm5oeaor/fT155wqMFeNWrDDdgnREelLk+gi6bN
laPjAQX7zRuFFA8hXnqgptXwJCgpJXEGOz+EmKmXT+SozgAa/1qorOEFZpQG
Ah0m/OCod6PVRNcLel9dlfgWyg+JLc0/Hpp5QUkwkztLNT8sFJVxlz/ygjgk
tr7CchbiHwVHC5SQ1qf9UbnYdRZmmKVcGdkfAdoqICdcEYRwjTDsxNwj2NPe
FejQOwd9hfJtQZE+EK5yXVTXWgI+KvGp1yf7wCe23uaYWAl418lQv0f0gXNk
yZ8r3kpAwfp0tetbH1AYXfj0klUSfBXin5uv+MCvcTui+gdJ4Pv0M1jphi9Y
cdWIvI6WAtf5FxobLI+B2gq7TD8oDbY+CQ3nTz+GAubZqp4FabhN/0TZQfQx
6J6X6vD7Kw2akkayk+qPgV9zIDnirAxwPaI62+3xGC6yuC87ucpAI40VRdHg
YzAR2sRzUsvCMSHuJqs0P7D4OH6TjUsOxAVV7Z8X+EHpwzzxOBE5uCpgeWyx
0g96y2M2Z5TkIJS/wMy12w96bA/Uuczk4O9pmf0ASn+wvPy9OTtHDpY4r8pm
OvuDptGphe2T8kDH6Tw64esPcdx+TtNi8iDIERd4Ntwfov1kxQqU5MGSbehL
EdEfrvdZxRUZy8Mw812n/4b9YXnaou1lrDy0HPF9PnQhAKiP6hLv/JaHKbos
bW6dALA/1/k8jBIDh7SNm2amAXAFn4dCj2FAiYZGfdYrAEIKrcr3hTBQQRE/
vlkcAGeq0pjeG2Cgm7w6BPtfAMjduX/J1xwDK2RfxR+3BYDR2yz+Iw4YOHd4
6jHFjwDYd9s0yvDHQPafl5wsHE/gtesrpth8DLzb76w3PPsE9tltXw6VYmBk
b802VeoJvGXJEF+rwQDbrnzVmWtPIOq+DCH+Ewaitpp0JXBPoFws9FbuIgYK
N2d+u8U8gedV69ddfmGgbYM2pzqd5G/C7iX9HgYofl1fVal+Avm9DTa1tFjw
Xh2JuLb0BEKuPfvcy48FS3qPuNKdJ0Cnur1bcw4L+WyhHWHkOMjjpHNyl8BC
tMyZvkVGHBD2S+mdFLGAa7o/yM2GA81ySukiNSx46r75eo0bBzmMH6LqNbBg
5qI3USqEg47LhBGH61jQP8iaGhfHwa/t7nYyfSxoRS/NHpPFQZ3/8VVnIyxI
FD1dcUM4+HxL8FO7ORb4FXvWiBdxkHx652ndXSxwfDq52X8NB7lbJx/h7Ehz
5mz1nrwJDkYFvJhjnbGw4UlxYGeOg8J/H+uHXbEwR6lDlmqDg9v5HVU7HlgY
jc+g/OyIA6biqN1lLyx08y3Q7LviYDKBI67WBwsfyuWOij3CgfkYV9AtPyzU
oEBGU39Svuzvh3oDsJBjxs1WH4GDLcO4zxefYiFxxY5zLRYHwgHbPhdCsBD+
uJKbNxkHzz6ffs0ahgW/o2Sn9TJxwBie7/cuHAuuadp8QUQcRDacmlWOxILN
uTSBykIceJhQ7+KjsGBSOys8U4YD3ZqlpvpoLGhryYixV+MAR2Os+yEGCzAY
IKH1FgcOznUVmc+wIGfTIf2oCQcJxzO3rsdi4dwmp3zhRxyoZIaeGyLxySAb
hZEuHPyunzWTj8MCM0uF8tEBHCwc4Xl+n8RUhAM15VEcxPPIs/iQeFfiqrrT
JA4G94orzEi88j75YtYcDkIpndNPkPiH9vTl7hUczPWIT5SQ/A99k9Q+3MDB
2SvLCZwkbnf005Haw8HEK/OuW6T46vc+6Vsd4sBwaZvgQYr/dTi7UTx1IBhx
vBKwJeVXwHn3VjN9IDj42z2QIOWfXlBmusUSCF1c91O/RGDhmfwfC0GuQOB3
Xqy9TKpfUMsla6PTgSA4Ez2XFooFL4NEuzCBQMgSaVBtDsaC49SkwxvRQJAQ
fjLcEoQFc7fzzotSgRDmndydjcOCAZmvKzc2EGpp9NX0SP28HNvmcU01ELxt
XqqPPcaCymnWR34agfC7xn4XkfQgoFLiP64TCFy2tat4kn64OnZxx4wC4ZHc
mgOOpC+G2xeDwTQQViVrmC+T9Lf1aDySaB8IPpwa5tYkfbZWMqfaBZJ4aSOn
6//6nmB09g4LhLPDrD+zSfpPPUqvHhkTCCEfadav3SDFb0W9UpoWCIthWxmK
F7HAdGwfbVcEgsvDgtB70lh4pPSbjfZNILxq4LPhFsfCpO3WIlc9ab3OX54i
ISxUvvuZoNIeCK4Ulm8teUh6cpyefzoVCC+8hvglKbHQlDT5LmkhEJh+YzW6
/mJAtOk7/sXPQGhs8wu/soOBv5xflTv2A4FOmkPq+wIGcls7Y4+zBoHwmdWR
h50YWOKtweZqBAESVddPisGAgXYlQ+WVINgxZ1IXCyHdX4/Kf7ToBIHLQecV
oh8GnnUXRS3cCYKlsQfOcvcxIOuXMyHpGQSK7j7lP7Uw4DccHlafHwTn1hNq
FnflgenZneFv1E9BK260M+CyPDC4bjW5MTyFtRGvd1nK8nBEP6aElvUpfJiQ
iCBIyAMVR0OgLC9pveu5ZX02edjP4hePUnoK53t9ZD3G5WCudBGn9OAplH3y
ujPrLAf1XY9E074+BbpmkR+vHsuCM2Oiv1FxMHCOcKTVWksDn13c8Sy5ULBx
arZ+bC4KXEw4dS3lUHAUIx6KK4kCc80D97ULJNaLsFpkF4V/1Dp9F3RCIfK4
gFBwlwiMPmeMn3MIhYsrdVevq4pA4mwki1ROKOQfBuuEnzkHNLYhzM1HwuBA
6nzT1V+CcMDwEJyYw6Bv48gmxxdB2KqycWXnDIPzbs8m9koEYYpKs+eeQBg8
Hx6QonYQhIZ8ijgGFAa/OVy8laYEwHvmyTEjT9J6Au343ZGzsGzty7Q4HgbM
VSLxSWN8YFLIzewxGwbH69gmjer5oGWljuVgOQzcpKqvYAh8kPnwDxvLXhgM
zp1V1LXhA+0wPx5F1nBwHL7Vsr3KC2VFAeciLoVDxoyEkwQtL7j+ClIXKQ8H
jyh2p7r8kzAmf1azsiYcPj+8Ln3X9SRc9m2+qPo+HIbHps7oqJwEXkqqK3rt
4SB8lItvb4AHetlCdHxmwmHLv+0j/ggPyCiEmX7migDN5LTY9ScnYDsgyssh
MALC60PVJ3M5oK1v7kVQWASIrWVIXfbhgFQh9ZGMmAi46TgwtqrLAUrdu8rd
aRFwz6j/4gYZB+BO2ZHLvo6AtqLW7e/W7MDwDqL/TkXAJcFjdDLybCCwt50b
qxkJD0/FM5+hPg472nr9hVcj4cyVjOMcMyzwkVBC9UE3Eq7y8QVdamYBx8vW
97ZMI2FRKfHAJIgFylN6xG89jIT3mzK50pQsoIIpruUviITI/pTSuGPMYOhh
2VVNGwVX5rx1MHkMpPeaMZsBUxRQeuAT0x0ZgDf8xp11tij4xHGn2VuGAZYz
VRZF+aPAd3XOltBMD0FtXNQElSgoe+suH7V8FCpO9KpEukXB3c6/3kjvCHAI
fHoq7B0FfKMf+HfOHAE/iYb2loAo0CqksDm5RgeXNUpNDqNIz99t/FP1jA4m
nSI8PQuigKPzZgZlPy0wNV4oMf8WBRVVgQ/9H9CAZ7vC5p8fURD9g3XtmyYN
jA5IKqUtREFjdcWRHG4aKFg89al/Owpw2a/MdD9Sgyrr/vRl5mj44Lu6ck2Q
GpzsXvPIXoyGHa8xOLpJCZ8ZzkbRvoqGhgZuYkMPOSQKDZLLVUcD/SbPTedK
crAk3cSWb6OBuEZnaJFMDjsey7b/fYyGQz6JWUYzcuD/Vgn3J6Mh/Rvzx5BV
MvB7qbnTzRIDSLVXyZqbDC417zj94YyBPc4WvePkZHD8e+G08OkY0Es1Ctr7
cogKmRl7caIxINQjPUHhfIgGHw0Wy2jEgMyQ06pnyT8koWVnlewZA6K6f4bH
0AHas+D6+sE3BjBLz5142Q5Qi0/7jTVcDLA1mY18WviLbpdKqFyOiYHwad23
Ggl/URjbb4795zGQoXqR8cPKHzQ5FdZpNhwDixc1Lk2V76OEJy+xgkrPwMWK
7Nizh7toQ+d38yA8g/Yn478d9HaRPu9F3dBLz+DrScq92PO7iKVp0n7e8Bms
ZRUNV879RrEUXOkvHzyDYwryFudNf6OokNC/558/g5dcDVFu+jvoaZR1E4Y5
FsRKeKnXLbbQ1J2K6/McsaA+v1NZd2ELqYsfjqScioWFhW2b5LNbiLwrfWNX
NBZ6UkunvOc30ROmvrNvL8bCgGbQtdcPNtFjPISix7GwH/4tRRK3gTxSTl27
PBcLDLGCRfPx6+gy1cmXIyuxUB3DV+blsY5OunHT3t+MBYuvLDnDBuvI+nnU
Dy2yOLj1/QmiY1tHDE/CsxwY4+Bd88j04tk1ZC4TxP5KOA4umc57a1KvIoq0
h9RKpnFgGHw3f8liATl98awKsoiDRuBQ7WBeQEPUntYdd+PAZ7G7m79pHhW7
uzeZOpC4f/KkBu88MtR+4P/EKw4KjWRq3n6dRQWH9tstcXHwJX3PiUVhGjFj
7PMZE+MgoNf/FsX0FPJ1umdglBIHXwuO3J+KmUI6I7YV81lx0HYhvbpw+gfa
fX3X+WhxHDgz39VkwU+iq3amszqtcXABPfdROjKG7gkoilt+ioNtbrqbWd7f
UPAUu4drRxzwDpayiCyNonrzL2T43jjIsbwS7TIwgr6dLLmUOxAHjgG+c0HX
R9DuaPizimFSvFn/LXh+/oqkjdVP9n2Pg8mwLoqC9mF0g/2M9dRkHIwfkSaq
6g4jx/4/Lzem46DZWtLSemQI5etUY1mX4mBki/7n351B1MQYH3B2NQ7GLoXw
10cNovEOl1bZdZI97nf0C4FBxHX5nIHhThxsvBkM9bAeQPI01Ok2e3FQibGl
jT0ygPRbfkx6/o2DYIcvWM2qfvQgqF445DAO2D2s7ryw7kfRkOGSRIEHdKlS
4jNnP3r571H1c2o8vLz5vq2mpw+1vTP8W02HB+aU7RyfZ31o2ldao40eDwPT
ZW6cen2ITJEpcogJD0PRp1LjufrQqd9LPXMseOj3YIlcnOlFStUfOX+z4SHm
kcsSZ00vMvbIN6flwgOxPbqNPboXeUoHPufkwYPPlJvDV7tehF8zWxE+jQfn
nBxTfa1eVFaqJKvAhwc3C8UKD9Fe1H6f0/eyAB4C/tPWEWXtRfMiW40mwniS
/h4p3CXrRVQLPbQOoniY2R0YoN7oQbwFpTd8zuNh3SMR+2++B6naRCZFSOGB
ev6Ls+xUD7rNf28sTRYPamePtUVP9qBHkxpnizB4WM0Np/tFsidm8zrWKeKB
NkC8VmuxB1WYHpS3q+BBRTD6kudmD+rmHv09ivDA+RZjbEnei5a/1qgtq+Nh
VvDe11/HexFdSkLIn4t4mPyxpsB8rhcJ3nTtpL+Ch5EViug86EXqrNdZT2rj
4YnuWkqiaS+y6BW5La6DB3tLbuqux73IL5YmV0UfD2epP9pjs3tRDX2jhJkJ
HhbJDnj1VnpR/+fMh8538HBT8dmrUc4+tB7m887fHA/406tZV7X6kCiV7NVs
GzwUtLpSZxf3oUsfjuHL7uHhkivctZnqQza4leF6Rzy8SaL5OcTTj7L+Pred
cMVDns+6bHxyP6qrCypZ88ADkzHuSttwPxryttg89MJDww9GFX+eAcS8zRXI
60+qh8A9vptFAyh4NSrTKgIPFBY0F+lmB9FyKOZnZTQeEviuhE7DEOk+/IFo
4vBwI+k2NjhnCPEaYKaLkvHQ+SOm9JjtMHr3ZlJkKw8P39XELA1YRtBZ/ajH
Wi/wgLnU9sL46QiKXJbvSi3Cg3xx3Z7I7ggyOR3lqlqBB5HWENerpPO5/VS+
NrQeD+r2mDccv8aQ6alJupEmkh5+8fby+35HLTWRt8Va8VBtNxMqQTOO4hcn
Dr504IF99AnRTngCSehEap4YwcOFTFlC2cdJZMc90Vu8iYej2q8qDJ5Mo67K
iLP/dkj6K1lTkR2fRnLX5R7q7uPhD5bRZkltBlHgIri2yeJhnQH3eJ96FuXM
ylqoMcXDYLIWv03xHKJ5Ml4exxIPZyLuq304MY9cuCIoptniYedmZahU5DxS
uTb+PIwnHtr4TlTccVtAX8vDV3rOxUPrlY3/mm8tIXRVVu2seDwEHl3t9xlZ
QgXT32MfSsaDoUqXQcCdZeTJISvLjYmHDnqd7Xi7FcTs993HWiMe/j2Pme9J
+4muXJKh3TGLhx8pzC1/3v9Cd+3r1o9ZxcOVhvprGQwbyC9CfVTEJh6iPk0U
e5luoPIO/VIzx3iQrPJhWDvcQJy6HgatXvFA5aJAd8VoC82aVOUkxsaDXBr1
q2qN3+ifj0pEWXw8vGIYKn/z4jfiymhx/5QUD8tOZhGSjLtI+/vAxb8Z8bCk
esYhdGwXVVptL1sXxgNN3kNHbMw+CnTEKMg2xcO25V3NcMV/KD2qnu96Szwo
prAzGdf8Q1UlWvT3PsZD+svjOV1yh2jhp9F4elc8fPmnTG3BQwY6Ho+CKUbj
4ULMmYYAYXI45femp3cjHnS16D6+cqAETBbULW/Hg1avdcNBNSXo1n/Ko96L
hzADf1p5SioIJhvxUjyMB3nXuCM2BCpYDt47mUufAF7RIRM/ZqnhvxglB1eB
BHjOfIlJLpsOmA7S3/oKJ0AOxkKz6Tcd3HX6wxgimgBqhvf/U9E/AkevvXud
JpUAZ5QXmsiOHoU7dGp/P6gkwNT6w9OdwfRwEHQhlv1mAjwUeXu//QUT6G/k
/jhjkgAHblmabszHoMCKQk70TgL8slHepPc9Bjeg+auaVQJs8k3gmM4xQ86B
Jr+9cwK0Poh6OET6Pr3gfbm6LiQB/qXyCkv0HYfk+ULa1vAEUN1IqOZiYoUl
oyO3v0SR4kt+f/XxVVaIl2//N41PgOK4S/dftLDC9Ma1y4zZCRBynVEtvp4N
Qpx1vlnUJIAStW6+8ScO+HzXiJx6PgHqXu/8fCfJA/alweZ6SwkQc7csjBLH
AzS7r99mrSbAsibFeGMPD6jHHPPCbCXAzd85f9I9TsK72k9L98gTgddcSLSo
/hSUMygPtPMkAjOF7sVgOV5IrjnzIk43Ea6rYw2ZKc6CzdFF7ZN1iaAs674/
tnMOqse2Lki9T4S5eccKXgERoHlFhtVsTITkAk8LWz0RKDTg4nNqS4SXAv8Y
fxaLwErmpe23fYlw/1tsxbSlKDyULMi6s5wIct2flFM/i0GoofXP9JNJEMTY
5vInVgKGhR5Ml51Jgq8zbvEv3krAuT3frx/4kyC0wr1NYV4C2rPiPyydS4Lk
oAVOWjVJODbflKwknwSY6IZClSVJSPXhRaPXk2C7K1H4fLYUvMz+HnviSRKQ
yoJh+SENmtq1sQ+CkmCGVVzvxI40TO7FxbaGJMHVoxKtlPQywHFTM9YtOglG
WM+fDZCTgaf0xc8+pyVBxd6v/oMQGTDz9o7xqSLZOa8dDPLLwq6gfsyX2iTg
ElLxGpKXhcR+sRjBt0lAH/3eu/KyLLRLTET3NiWBE9nvXnIXWcDOXowW+UKK
N7L31HyNLLDos0aNLCYB26vft+MvyEHJ4Uqk5GoSKP0bcMXqy8Hl0rbIkPUk
iJRx8a26KwcBdL6R0r+T4CaluZP8UzlYrp+MiKBKBqYZPgHtD3LQKlYWrngm
GW7iZeIzFOTBciQsPJY/GdooT1Tka8nD31Cr8FnBZOj54nwzyFAeZKbYwvHi
yaDVoe9d90AeclIfhy0qJoPO/Yh7J/LlwYf6SmiaYTLsGw+oPqDCwA3yPz8n
jJMB9f5n4nMMAwIHJcZCd5KBcisPGXNjoGeLWaTSKhnY/XUOYyQxIDzztaPT
JRnIcQo2M8YY+DsRKcfqngz3VjQ3Iqww0PdNJevWw2R45Xw+kOI+BgL6CS5z
j5OBNbjumpM/BgY/2LOQRSRDU2iNMy8BA0X13L5a0ckQ/pN18E4hBnB1nVPR
sckwQnek0KEcA+KvpapOJCdDLcq9+bcBA09zd41k85JBqCHP4u8YBkyyihp8
CpKB5edc6edpDEikmZ5rfJkMpuWbNA5LGBiNa9zTLk8GjtWemlO/MSCNC8+0
e58M2OtaBuZMWKDxU6IubSTFGz8k+5YVC2OPVpw3m5NB5cir9UUuLIQ/0EW4
9mToEm3afcePBfP7FIVtXcmwlv72gpUwFuTuVZEmpmSw1rhjPSyGhQlzrqm0
4WT4zcyHUZTDQtXt9quTo8lg9I5uWUABC5FGfpVC48nw70xv4JQyFjA3JoMr
Z5JBzYDfrl8dCwxX41f35pOB+WTtexotLExd1DSC5WRw0+tgYLiChRjVQuGu
XyR9CHK8ir6BhbuKt+NYt5MBwr8ep9PDgoI8w96t3WS4nREcd9MAC0zS9VaE
P8nwsiRX5uFNLMyIu7bP/UuGJ4SvlPeMsVB3jl/2PEUKaAsnMIvdwkKcwECG
B3UKmL7xtWu6jQU73lCqOroUOPICsYqaYkH5pIIzGUMKuN3/IGBrhgVmrqVB
rWMpgCZai9zNsTDHmqkWczwFLJf4a/QtsPDu2I0X/ewpwNldbUxtiYV4ejJm
7hMp0GGWQ4gksT3ta2/LkylA9oA8f4rEapQ2PwrOpAC58txDRisssB2yX13l
T4GHfLdE6Um8uP/xtaxQClS1fhj8RlrvHmBceUEkBa5ahoiHkXiffL5SRzwF
zv/pekxP4qAQryozyRRQuOAzZE+K5+gRmur7MimgnB2rk0OKNz46qdpHPgUK
/hX/KSPlw8MsWBOmQNr/vwvrKaR88xOqapKUU8BJtk399h0siHNq1uapkfKL
a6TbIdWrKr2/tuJCCuxq0d66b4IF1dPWbxo0U2BnLuNanREW2nI33nRdSgHf
R5G7U4ZYuCEY9N+3qymQOjb9aFYfC0OFLHWL11NA1KV2qkkXCxbiuXW/dVOg
ryTSwJvUX1fZxresxiT/wg0VHqT+79bovOO7nQKSaiKDb0j6CFSaeCdplgJU
w0ecvmqQ8rnw7/016xSIVhG1f6GKBe7WmPpbdqT6HqE7YqyEBeLlUw33HFLA
VpOY+AODhUodlcanD0j+wqoXwySxoNLf0Yh3TwHQfLuZR9Jzi9GdppyHKZD3
xtQhg6T3ATPfD28fk/TwgfLMqTNY2Ln/pmUzLAX6XylFPGDAQsDapVbyKJIe
NIKbHGmxQOsx3HrsWQoQTuOfqlNggct3p00sMQUiOnbVwknnUTFc7rM1IQUc
5ZYWXCcx8IG+5bNbXgrUJR5tMhzFwNVYg/YnBSnQdUnQlmMAA7eT3TsySlLg
P7nb72U/YsAvv7yr/00KKG4t+X4rxgDVOej+8TYFPGXr/V/nYyCm+Ev3Wn0K
0AeyVthnYSD79c8v9K0pcPuzm43HMww0Nor3afSmwKQKnRLtAwxQfi8cqlxM
gR8mH9cMRDEwpEwzRbmaAvdMOw1ceDFQmG69arCeAjpGXYO2HKT70+Q01dYO
6bzw0F5cJcdAan+CtBxVKvQLGNnbDsuDeHtAdNXpVDhX4Lql4CcPRrWG6tUG
qXBiiK3Y7ZUcnON4fZ3aOBVGP2vvv82Vgz+ex27dvJ0KCg+OF64kyAFBpv3B
tmUqLNCnG1N4k94PpShL3iUVEs9ffkaL5ACXL7pbHZ4KglbLg+8/ycJLPFlZ
zftUKFMt4T7olAEJb2W97sZUaHhc9rfxvQxUmXttzTanAlMo16FXmQzUi60o
sbenAvcLRrO6WBnobx3+6DGUClU0L9BzPRk42Cv7IbWWClFTZVIX+qVB764Z
ezFvGjTGc+XIf5GCPZk6v5ynaTAeX9HG5XweFu+GBRIvpgOvGG6wxlQQNtzt
U1cup4MPfQE2VVkQ/gZdeYXRToevHqopcdyCwJxH/71dPx066su9Pn4VAIXp
WIVNi3R42WHSetNIAMKtU9c0fNNBUMZ4UdroLAjZvDSbLUsHwxeDVs8d+UDK
M9JT8nU6pNWEWcxr84FS8P0on+p0oGw5x3JZkg9u5J//j/FdOgxOeejabfGC
10wFG+ZzOhxjy+LnwfFCq01dR+h0OrDErHexKZ8BG9sOxXNcGVDQ+/PK9BQP
8B5ELCjyZIBc4js/1koe+J54OeXa6QxIvS10EfeUB4xaWrdcBDKA79PeEWZB
Hrh8tvFVtVQG5M2ynae/zw3nf1QJalzJAEla6r+BFCdgxzSbxdw3A9Ru3B1/
b8EBr7dMGx/4Z8D4VPZYNpYDHkTzPAjEZUC1/fsn749xwMLb1M780AzIOnIn
pLKRHb5xJ4Qtx2fAbKPrOk6QHRq/hh14F2fAG/d3s3H7rBBh6LaYMJYB6Hci
f0cvC8R9PCDOT2TAtZOUtL5lLJCsFGmqPJ0BsRvmMs5RLJDPm/dlajEDpA6k
A85osUDDykC19O8M6MrdiiutZ4btYIWgLyyZYNfifeDufQz+/m5RPsueCa7d
vDu8SseA4r7ethdXJjTcNEvR+csEzHqO9qfPZMJJc7E08SAmEDuVecNZPBOC
y5TfDiYwglX1ITf9pUzgO9nywbKbHuzPRQ+YX82EXy8/5fSn0INLBtez19cz
gTbOnPDeih78AqXJbxtmwinXjadbO0ch5br1fKFVJugxyHZ/EzoKXbNtlVp+
mSBUtRV5kEEHihzPtIMqMsEI6081MEQNG8y7WVlVmfC68hFZUjk1lNDfXXtT
mwmCG/xMxZHUcJocE7/2PhOmHKM5BhA1UK18HzZtzwRL/PPhI2VU0NN03ho7
TYqnflYuOI0SIt+lVOnPkfZzT2rS86YEjVpyGpfFTHgcGqZy35gSakoGC/PX
MuFR+3/VTzgoISPF/yfL30w4r1r/9nQqBdg5d/mssGVBQnTCl+pCcuC1x3bQ
cmWBwuOd3YMochi5m3vyLE8WGP/L2g9/QA7aJg8bbvFlwbSZv6YtlhxkNE5R
fzxPGrq2bTiF28nggMs5LlcrCwqejR8Sdw5RYgvDCyPvLNBX66rMZj5A4Yw6
VncfZ8E79eZXUXN/kZ8RnsclIAsenBSwH3r3F9kssMeFBGfBoNvTtzjHv0iO
4YxPVVwWxNYTPY+2/0H9BtLXjr/MAhPPW1p/U/fR8emba10jWXD6hdq4p8su
ohFPfTkylgX7I8J7a9d30b7nqPXsRBYIsjJfzT+/i6ZoLL7+nc0Ce78b+ZWr
v1GFqH2T2EYW6E7Gql91/Y103X0TIo5mQxHuprxiwA6KJc/BXlTOhjejLXTN
lVuInaXwcQ1TDozJOD5lnVtANO+Tvnaw5MD5jt23YRkLaMf+qfwPthwYfiL3
J0yXNN83mq/R8+TAhdSaWcx/8yjDld3aSjgHrI/MjReHzCG+nqCrDJADtg+i
n105NoOO+7m+4NPIAb8v6ioJDdOI4pw5FVYrB7w2xlHbg2k080Sx3ko7B1Qu
fzg83jOFXkiuS9ea5ED/oNVKKv4HOh9rduKuWw7QpdRd87g6jk4rX/N65JkD
Ru22CqeqvyOmeYX+6Ec5wHrvbBue7ztaV2OLqfXPgQaP3t/BZGOo8mc7GWNk
DuhO1UyYfxtB+elvzPhjcqDnWNFn3lsjKFGroA4blwOYsxX+DKNfkVd2oOfd
5ByIO6SnYJobRoo3FBZqiTlwN1f1l6jYEBLdF7zY9TwHTpmtC5a3DSLuAlbi
VGEOLLnNu8TaDaK/Bz/vML7KAfH1+tVPlQNo9eXYG/7XOSDLNV6kZzWAxm+2
sytU58DLKz22eNYB1FD6/MvdtzlAQTj63Tm0H5XfShD3rs8B0b+H9Kcv9SMC
dWBETFMOjPtmThUz9CN8hcscsSUHGMvkM7iG+1CQmanGm485cMlhYNmqoA95
HLlK6GrPAYlzdvFBvn3Iphp7MNWVAzwyoxfcDfqQoZXg7d2eHFg8mUguJN2H
LjKy1jIOkPqf8fhqHGsfwiV2n7YdzgHnzZrPjbu9qI4nMvTdaA6MOGjs6073
om3ixZ+s46R8o5a+Cff3IilRcqP7P0h60DkTIPqpF92vePf+wwzJv0O6ncqH
XlSg4C3IvZADJ6YOdlFTL/rRIBvjtpwDgS4Puzlae9HJS2tbn36S6vH8LQux
qxcZdxeZ8m7kgHvlj84Po70o/qZdy6PtHAhQfS1/e6UXdY3xiX/ZzYE7OOvl
KxR9iM7me4LQ3xzQU7kq5XmyD2ksp/7xP8wBcxv86XdKfQgpFlU4khNAwISj
n9qsD439DbPloCRALNmbMMzTPuTbaHviAxUBmqUul8qV9iGuYI0uZxqSPbee
bWG0D1Vf4gs8QUeAS+4/BxVJ9V/vHltwpScAjp6gb+PTj57F12WeZCSAhWR0
OEd1PxIzStX9xESAM4p0fNxb/cjuu8GbM8cJ8OXWusnXxwOIKlfaqYOVAIza
k7OPWgZQrs0x3kfsBHgYq5wjwzyIxpbbw7q5CPD0qD5XX/kg0tu/YOx/hgBz
wyktC+zD6Of7M/QifAQoENHuD/MaRtGBB/UD/AS4mWJ3jWV0GLXR/SckLkQA
0SscNeMvvyIVTqmdUXECJAc/Irg7jaLRUcaiUAkCxERusTnPjKJH2ctmMlIE
CLWlSjWz+IZeC75ojZAlgKulzBk58zF0Tu50koISAbx/+u6Y40hn9vefyzPK
BFBrDKcvZZ5A1m9H/saqEuBGt9Y5ofwJlK2eZDMPBPjz5WyqueMkYtNjkEu+
RICQoV8lH8t+IDKX/b5NQ1J+QXqGb6Nm0FsTzbcpRqT927+lfV+dQV4az/KU
TQiA8eYSnNCbRctc/J5P7xBgsqzRNv3MHBpqvsLOepcAct6mAeV98whflnBQ
Y00A9xHV7kjNBaSd9n32ti0B3riodj1+s4CaXNxqiPYE2KmzUGwoWEQlJ9KM
ZR4Q4Llb4EBW1jK6RzWNhlwJkEE3v/uPdwXxr4mf83UnwP3cIOfKghWU0tK4
2/SQAO2LFu3y/62ioAcLaXp+BHC8ox785M8aMm7FjrlGEKBBZCOfN2ADHS8P
bGGLIsBp9e5TOgMbqDO9o+RNNAGW9pIsFsQ2kbqrhT9ZHAE+Pg6avD+xicR5
wk7HJROgVvf2STGTbTRP3Usjl0oArr/kQgJ124i4zr02nEYA+kHC2ZendhBn
W1nDmSwClI/au9xb3EEUbkOWr/IIcH7ZIEA4cRe9v8N7xeA5AdCWAm6DYg95
azlK/y4gwKtRiQUHjz20yvOPHBURoIpB/YPzrX30tU0wr7ucAFdj7vRilP6i
spMPZ1ffE4C5VYSCSYQM1DtK0x42EED2v8NVakcyGPKZu37QSIA13aSt3mIy
+DdkXMPQQoAOt936ZWlyuIFXChNrJ+k1oOn4tcsUsEZNJuIwRAD5KKWyzmwq
CK5S+L4+TKrHsyNeWatUwGXthvceIZ2/eDX3m6rUAI1Te2FjBKh4VbYaMEEN
cb6t7QVTBPD811rWK0ELUmuRTjM/Sf3COpmL7R+BlqxmXqd1UvwcxTsDxkfB
RPvvwOYvAkjHRi+41RwF3EtnVcptAmhz32wO86KHHmtdJv4/pHq9q/gqQcEI
rl/Zyy1oc+HEbinrwFlmqGgibI6eyYWeQ8mwnFZWWDKD0qd8ueAi9dSU/ggb
COxP2ImfzQXy+dYoqutskCxzZtRfKBcs912PZA2xgW9eViPv+Vxw/ShsZ7zO
Dpoh6TF2SiT7JaV7lqpcMHQ5UXjDMBcSOHmY6rCnYP9L2J0jkbmgYtDBJy0r
AKkDZxpEV3NB2+49nauLJHy6w+3z6mcusJZ58/9KlYTdKTZZufVceHMvZc+g
WRKMfx15obpJ8peruPidXgo4mLae6e7lQgRmNOqJhRQkXvpk7kVNhBJ3xUlj
SmmIrXP913SKCNQcG6sbSqT55ML9N1pniPADfvjlXJeBn59s3Tt4iVCJV+SW
sZSBG8O35wbOEkEkR96MLkQGGLY0u+dFiOAs2SHn1iUDkedPZDNiiPDBnDFh
10QWQglNqrduEEGd//Gn87fk4A772YN/OkQYV1Q7dddBDqQig9/l6xHhTFTi
0Qc+cjDicUl53ZAI3fdSmlnS5ED8UpdC2B0i4GbF3D2H5KB/9atstT0RRr5b
u+KuyEPhXaXN245E2P7+X5+AsTz4DWe8JnMiQk6DbnK2jTwINZlLaz8gQnw/
MZXliTz4Js5ITD8kwnTdEuevCnngVV4XYXlKBDHfT2kPj2Fg+5XeYk0wEYJq
dXnNuTHQLlBZaBpKBPtjil0nBDHgweQlXBhBhKa5uvNHlTDQ9uOPAIojQkuV
pGSnFQYyjMxmZvBEUK4wZb52HwOuHfV5kQlECON9o5fpiQHu6kD+oWQi6Gr/
zq0OxYBzOC2vcxYRPh8RsG4qxID6gf3E8RwiiGo5ivaWY4DDvT37DYEIWQLr
Ta/fkObnOzGnqPKJcMznqcgyaR5nk2TlySgiwrcDGZzkDAYW8zxHoYQI714v
23cuYaCeayhtrpQIS3JbbUq/MHCPIo1LpoIIkvZprVEHGKgbPM3xuZYIM9Ie
Iv9YsWDP9CBX/z8ifF9KvviFCwsclxrEx+qIcO1H5n+PTmHB/Y2Fxtp7Iixg
I17cEMIC769X3d4NRKB/d5LPXxQL3SJktymaiPD3rdtGkAQWxDIIruwtJPvt
/jw2DBZG+9f/ZLcS4eYVo3CCIhbCGS6EnftIshvEdVOqYmHG/0eWcjsRaMPG
YnX///9KjbRIawcR2DmH2ZS0sABrgVU3uogQNdDL9OcyFjIt+TuseoiwGsvl
R3kDC1fT3I2We4kARfsHV3WxsNv74YdnPxHqHE+xOupjoeAoq/O/AVK+7ofN
loZYMNSw3g0bIoKlQxKXpBEWKPwqn7J8JYIpQ97JQWMslFdRHssYIULNP6dR
/VtYMF81SBf4RgSLYIJZ4W0sMArlC5aNEcHTReb14B0svDPfKseOE+FI2cjM
qCkWHFM0VZomSOfFdYnijRkWuHoSP179QYQVjrPczuZYaKOb1R+YIoINo5ri
Pok9L8iPm82Q9FiKe2BhgQV+3xCH+VkiBG8adWaSuOf14JbrPBEUfHItX5M4
YFkQt79AhFJlelUCicUFvOiDl4hw48Kqhx2JR03bkhlXiMDCIctJTeLwJA7+
lFUicEzIKPmR9sN025XyrhFhzXZ7rYMU3wxNrULROknPF0e0t0jxxyPaFtkN
Ei8ct9sm5QfexjrvN4lQESel94WU/1r5i1GtbSLELR8KBJHqk73427ZnhwgZ
DY9+M5pgQZv/8q9bu0R4nzE+4U6q7/7tVL/pPSJk17jvlJPqX5iwQOv8hwhy
MuUGn0j9MepUSNj5SwRtlXGW/0j9o6KOOI37RwTyW81Xn5L6a+klIp9Angd/
En2T8q9ggemVT+NJyjzgJy8e/0PSx7v5z9cKqPKA6s3esfOaWDhxy/Huf7R5
MPv5NPGUGhY+4etW1Y/kQcDjGLXvSljwaj/q03k0Dwx36pQfYbHQp1wcO8GY
B3rah4NKUljAef7hdjiWB8fljKtsxLEgUXqtYIM5D24XGno5nMNC5OmVd9Rs
eRA9912UihcLGuTnl8S480DRJwsbxIiFZOEZ3yGePNBwcLPhpsPC0vUM+sBT
ecDIhq6FU2AhLv3I+SHePPiZu8Qxt4OBMdm5Bzhhkv/bVrqvvmNA8nYWmZhI
HrTbMf7ZH8JAEM4QPyiaB6c/vaA63YMBka4Pr0Ul8gD7jJp9uQkDXnY52wNy
eUC8AS4v8jDwOdoo9AkmD7Y69vSqMjBwspKRU1QhD2i4QuzSEzDQfPhY4Yly
Hsjc7OLaDMIAc5rJYxH1PDiLT8B9t8BAUQcLeYBOHhyl6bL5chwDB78+4c/p
5cH053y/GDoM6HLh+Pv18yCq8szsuX/y8Nvmp8Y5ozxgUXb/sLsgD5r/2kP7
TPOgUwgfRvVeHsalghmEHUnxeF80ZrCQB5bkHc6eYNLzHqxTa9FyMPnn8fAY
iX0STZeCSVxuRZ6ySOKr9H0rJ0ise56BgzIkDyYfak5qRMlBXAsfG4bE9GS3
AlMi5IBpU5s5k8Rcne9KVEPlgEE3j84+NA/+SlwrCXkiB2PV5z55klhXU/HP
CRKX8JSFBZLYAmw1ywLkQHv+DU0Gie1pvVqH/OUgKqCbqpvErq8jgoT95OBo
6R6ZXFgeDCtsLXz0loPR408agcQeIRvf7pC4yJsKd53EPfcxn9ceycFVzWOH
diQex+DjOUkc8U3gII3Eq6eIk3YP5cDkQtG7AhILxY093/eUg3MvJP0qSaz+
z9L2GYk/uSv96STxjcMr/dUecpD6taFuhMSfi14FXiGxvdpF3zkSaz61Ev3u
LgcK+e2KmySmYrfsciUx3VHdvcP/P79S7EhF4v8BmWAKBg==
          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox[
         RowBox[{"Bind", "(", 
           RowBox[{"KKpp", ",", "Kp"}], ")"}], TraditionalForm],
       PlotRange->{{0, 2500}, {0., 23.564347339120623`}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {488.57142857142856`, -2102.551629727142}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[10, 11], 0.9090909090909091]], LineBox[CompressedData["
1:eJwVmnk4VG8bxxHa7G0iM2OXJWtkKV/7zFERiqREkpSQfStL9p2xz8hYQrQp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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox[
         RowBox[{"Bind", "(", 
           RowBox[{"KKpp", ",", "MAPK"}], ")"}], TraditionalForm],
       PlotRange->{{0, 2500}, {0., 53.5736762747242}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {1465.7142857142856`, -2102.551629727142}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[
          NCache[
           Rational[21, 22], 0.9545454545454546]], LineBox[CompressedData["
1:eJwVm3c41e8bxxFKIRkRJaSUKFKE6r5RSKKJMrKSkuyRvXccjnHIOMcoiVKS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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0.3},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox[
         RowBox[{"Bind", "(", 
           RowBox[{"Kp", ",", "Kph"}], ")"}], TraditionalForm],
       PlotRange->{{0, 2500}, {0.2856136560063464, 0.8497566914112812}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {2442.857142857143, -2102.551629727142}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[1], LineBox[CompressedData["
1:eJwt2Hc41e/7AHA0KJEtKklKRElKwrlvikSRkTSESKWMrGSPY89jHvsYlZEy
EklCVlZkHlmRjIhP0jB/7+91/fzjel3HOc9zj+c579vemza6t5gYGBiCNjAw
/O/3kyOKI73vtgLD//98ZDfE2KBJYKJXb7fo1Fe4rJVdZRz0F/THLja6erEp
ZmpE2S5ZMOGunB3U65udFHdatzOoBrGg3CpPWktHlWIUhZ0SkceOHNY9D6sp
fxX9rj7hmLXgwg4TWl5+/AEl5ft1hlzOvHhkbOgNJ0lLadX9K00uaAdKB987
84jdVqksYsPU9cSd2Hi1yrkgOlTJIV3kqE+eEAZXnAzw3/1EiUqnVegNCSND
pLZUZWilktPNApNvFiI4tW0uR1e6U0n/+7uNj+b2YfOeI1TqqW9KMg4fs1md
9+OtN8N+Jet/lDhWh86nMohhtcBb97+GLKQffj/mpYMOovUtY/m3RvykFva1
mPecEmjXU+LMq7+flBvPJm+QeAhvVzJbGiXKkAKFdw9Oikjhv/wuIwsRIN3K
kfR2zTuMs7xa25n5zpH2CqRyMQtK43P2hzpkfz1S5OBj84tD0hhyZpY2ZWdE
Wk/Pf5WQcRSfHB3XuhJ9i2RtUcIyZiGDrWHTza+brEmDEm+vSh46hi+GR67q
2zuSzs/VPnOcO4aVF/7pLSu6k94Ut6xVFsui71HjTWaBviQJ566LLM7H8fEB
lopiWhApQXEgQ0fxBAruGT6sFhRJYmH8+iuRQQ6LTcTHYFMs6WHdd7WvtXKo
vGi+LHUtkfQtaIEqFXQS56zPGaMOjXRJa3na6YI8Zt0W/Br1L5NUy7VBqYrz
FN4WDHxeLZNNOta7NWJLzylUbzhep7gln5SRxPVFN1EBz8u3dNHPFJI4TQSP
Jd9QxCuPAtNCTV6SvERF/MZFlFD7daqU/lAp6cekeO/hCSXkVJUT+1X7hmSU
f1TcOY+E+yVtdJ6xVZFaHsi7VtsAZsvKjmg61JB2J9EsNgkiDpf/8v4nUEfS
d8/aLuGG2OMnfOA+UyMp1Di7TGsIkTddp8b2aDOpVvmZqT0q4wmKcvl0bhtp
eV/BVmqGMlb/Uc++K99Bspwsvf7FQgVD9ygcFfbsJmU0vdm0+YMKfr3VaMwx
3kuiP3v3XOLQadTlXBaMdukncUS8v6wddhrdF8p6e5UHSeoPGhgc5k6jpIk4
LURohOSl15xD1TmDm7+N2Z8r/UIqPf5R923xGbQzSwzQuD9GOrDUk7XZWRUl
3u+YfHdkgnRjoP/CoX5VHBg+eyIap0ixlUO/tRXV8Nb6/OPbdt9JG32/qScw
nMX15iCmdaF5kuKt6f/e3jyLxqP7PPZY/UeyP/sjcbT2LGZ5PI6Gtp+kUdbf
M4eC1JH8n1sFd8siyfhyyRxlQR2f1bx6/DXsD2kgw+HnH6NzWBH6jUv67j9S
j/zCn/cyGmjxbEk932aVpOdXtCSeooELGuybM5LXSe3tD1YjmDWxwZstQ3OB
AZpuzzNdH9DE5IcPi2ItN8DZ4hebatTOo0S6i3Tn241Qu2bNcrDwPIr0FXNY
7d0MlbGzbL/8LmBBWLBM1s4toPDlGcfV+QuYRWbuUCzeCmWS97mrrmqhxt7P
8weNtkHR++kdoUe0MXklNmTD9HY4sj13588EbbwuQWZa+8YBBvmy2yWZLqLO
57GTUmOc0Pl3gTPq/kX8JOw6LrfMDVGpetx16RexhY0xMY2fFy6eKeb523MR
Q/m+UHSBD1oj7PhvKOtg+dL37W8Ld0Do8U87KE46uLph3oNlVQA0Ph8VrM3T
wawHBlsb9HdCw4H/dknw6aKMZmVtu4QQVL+1Efk9rYtLDJ4bBxVFwMvs4z5x
YT2Ud1mQS9mxD0hbjuy/fkkPf2uEBfQt74M3+j/Eat7p4YnlqN336fvBZemC
+OIvPfQ0M/iws+sAnKTlSxyU0Mc3xxUMFnvEoOT7fanwGH2kfo8Z+rwoDg6U
lsPVH/RRpyXykirXIZCRk5T+taaPE1dC8yhykvDC57vM1buX0OFeSEp0ymHI
EbA8eYBkgGOX2Mf1fhyFO+8+yF+xN8DULVdTGjJk4MAtcYXQbAMM5+Mqd7p+
DDILJpV+cl1Gz2ZjjYVhWUg5e/t05cRlVFfNO24vcRKuz9af+W+XIaoNLp9u
YZUHwegDaqK6hmip+Gzt9II8xA+NqwdXGKIinX/r1m4FoDiaaxlQrmDaRae4
mxMALnHJrUzvryCt4r0OOiKYl3adf/HrCnK6PzSZ+odw4t8ZTRbDq1j0ZmNP
9TYV6Hfbr14udA13CjpzC189A+9TjBosLl7D0AefHLl+n4FnlbFq3D7XcNOG
rtqYWFXwYNisen/8GhqmTf8LGFYDEfI3ZaFn1/HOlPKjedo5YH0sVN00eB0b
ikpviF3TgF91BvhwuxGecd1XZiegCfXMDaR2OyNk0dwUE5ZxHu6FPFXwkb+B
u2Mmw7onteFl1J3j3+qNcWVPw+ZLeXqQUkx7GfXXGAff6r0OktKH05YzCXt4
TfB4II12u0gfJENEBVrUTHB6dMb3fO0lWGuJ4d+fa4J7GZ9JMW41BLtB6cvL
NSYo+PS+XV2GIUzMtsR1fDbB4UMBe6NIV6CdfROfB5spPqsWHH7oeRUyLzry
9Nqa4tfmJOFxMSPYYcqpnx9kiqMPPSav9RtB6IP8aN8MU/zCcNNILfIGOEWN
c0l3meKDjuIjhhtMQL3rEmeQ3E2sJwsJVkSYwszlE+wKazdR0/5evRrzLZDt
j4mJ4TPDdyttvlfcb4H79QXBH4fN0Oqay+nIxVvAbloglm5shieS80ZDZixA
2lJCmbnaDHU8KexFi3fAeSawwYRuhvqX9YT73e9CtfXEhfL/zLC0SvyTFYsl
6NpnXbUSMcf3z+N2rYneAwc3IYdOX3M8qF8U3uVmBRVrbkuSyeYom/uTZilg
DZu8P3v5vzTHNU+j6Tdl1hDnRw2THzfHHFXVS+XrNlAWzvU0Te0WXo1Q5j9k
+ABWaZv7722xwCClfoclXQdQ23fLpG6vBf7dL9tY8doBwh+//yZ0ygLtXQrZ
5UUcQTjXa6HD0gLlRm9+dP7rCCrFS9tOtljgdtW2mKbyhxB8/Eo05asFnl8u
tOaUdobO0lKB7ysWeK/UvFbtqTOYVzgcSJW6jScU6Q+oSY/Av+4HbIy4jY/c
My8kJbtC29kL9UZPb6P4cKmbgIgb8DflnS99dxvt1ayLKnPcILvtzhXL+dto
FuT2JOmdOzT1jtq169zBmuNr2ic3eAH7dM/jZJ676PCm0zTZ1wey1bJ8Nh+5
iz+UD7s9H/EBlcwHxrbn7qJ18r0PF8AXnK5vEzjjcRflW72fqjOSYahNOfT7
xF184XCBtZrqB86Htt+9xGSJZ8o9FduY/IErcED13S5L1NLPtoiy9gc15Yfr
UTqW6P3Hf1hfMwDyi5/ZnXpjiafkXxQZCAaBGoeLdla3Jbb47D1ZEBUEI/fP
SrLPW2JXQQl83xYMPAdGx7+I3sO0jkOLgswh4EblvxIUfg/brkmWLHKFwXl3
H+gzvY/7ct/XJNRHwje69i4Vt/uYYLs9n52bAl4ndv/Li7uPT5te8aeaUODl
XGmRZ/N9tElqj+Nbp8DOm7P7xY5bYUpxi2PxuWiYVjPc5sRijcZTPxVe8ccB
OXP/1LCINV49mO382ykOhBgW6s4pWWPlTqk/Tr1xoPs6zHO3nTWaKtH1lJPj
ofzQ+5+1n60x87+ihuPHEyCI4zCd+4UNzuxWEdB7kgxluRMO5Q02+Ghx7uAb
rhSYPJPOYTpig/414ZH6XimQqbhVtJfFFn10pYOEjVOB8YH7NdFTtmhxpH8L
jZcGlXSzpspkW6yVDFQ5v54OPU9wB1eOLcpWszZdhAyYtd9tcavEFi/fTEj8
7ZkBu9h7Gbe12eIBu42lYhsywVVFQ/7Kui1KXPu1X4IzC07mSWcvmD7AheiG
tl+aT+CiM9tvNesHWHTlG+V43BO4rTp9OtHlATJtyTmy68sTiBvOHMboB3jQ
W1H6s/NTWOTm5w+vfYCFl0l9ogXZUOS26ndQzA6tguXN55TyQFKrycxoxg5P
nY46PWtZAPcDhwbK/tlhlNNRf7PUAnhW8/MSD7M9nl7YuE/+UwFIye1Ub95r
j43RCg8YFQrhsPB9SfnL9hieJzW9xlEER3+yLfLU2KOWvMIOy7ZiOBGn498S
74CTz6NfGoaWAgz1ZSucdsJDSacb+f+8A0sdrTrDi05oNc1EbRCqgpja918c
jZzQyDTNWFilCiZznwsWPHTC/tXyJLGgKoh6SA4VfeaENRr1r7x3VMNXDmlb
Nt6HmB37LX6LYg0Eng6QG/72EHe+Hhu2ja6FT9nH632CHyFr2OzLKMsPsP2A
YLVpghuunlIb0DrUAZL7le48fuKGEQHS82+VOkBD1GT7VLEbcm5rvb/3Ygf4
izwxsm1zQ4NA+F3r0AErQjJLHhvc8WbxYsWjtx0wza9xLNnKHfGnI93p/Ceo
3eLyuEfZA32P+9S8Mu6EUZaU84LaHsjV9efGbdtOWGeuWjC67oE3DmhWMnt3
wqnNm1XGnTzQrve3Gn9GJxQyRQ0t5Hng2m5DfuuxTkhdzuHn5PPEE3te3Rq5
2QXOs/QgzWlPLNUvH+DR7wYTVvvI/N+eaJa+gx5p2g1ZPP7NAYxe+FJDpHTZ
uhtCZfZ8mmLzQqdfGz+mBHWDkbXOcP4BL+R4yebCWdkNa+Ml/44bemHS7Zz2
p/t6ALs9Dqu98UJ6e+F90S89IGvefPRhtRfuDiSh0UwPHFzgP57d4IWF5wJ5
ff/0AAdnocLWLi+0tAmKj2XrhS/nx9TbZrwwXDayqetkL/jUnjUzEPJGLZ/h
I8UhvVBXzEG18PbGtq9xWSUifXB4mM3KOcAbv+m1b9Q51AfUrawqwWHeWJtQ
LUM/1geWpptm8hO8scNrbPLFmT5g374Ei4XeqH+8/IbTrT4wtByb8B31RuV9
N2VuZfZBdexIReykN7q3Me1oye0DiepBytMf3ljOr/d0T1EfrPD3KTQveaND
z1RVaFUfpNe1RHBx++Dqt7xhj4E+mBZ+JZd+2gdvCOfavuegg9754m3F53zw
nfQ1sUU+OlQ8LPhSq+2D71+vx3PvpkN4W27I5DUfFGeQKuITp8Mxt7ThIw4+
WC49KHwC6ZD8NPmlsosPft7OutqqSofNnQlBel4+OB0ynK+rSYc+8ZhjD0N9
MLLoeKqIAR3cegMDKrN8MNQmRn7Qkg7jTP7X23N9sOjpOfkBGzpoHfY9Olrg
gz4R5ccaHegg7Of+edNbH3Q4+d/h2x50qJOxO3Kh2wd1+Hd+q46kA3v4td7P
m3zx+QbrTfOFdNhm+6v6wTZftHQ0HuV+RYctumHPmLl98eGkR//ecjps5Hvn
fUzYF6uXT6uuVNNhKUVEMuSUL47Hdh9+1k6Hv55v+PYq++KXqWg2kS46LJrq
M5ae9UUOO9sbPr10mN/v3zOq74vTpRp+TEN0+JY/5XXKxhf9Xa7IM03T4WuE
z712R19soav8a5mhw5cHOw0s3HxxI/udMJ85Ogwcv3AoKsgXE+C4xfNfdOjn
/8Z7MNIXL8nq1Yn+oUPvPw+Gyjji8x2Npfz/0eHT24LuqUxfPLZ9QmvrGh3a
085Veeb6okTQ/D4phn5o9R7N5S30xeA8ZnkFpn5oVOXxUq70xY9qB68LbO6H
erF8y95aX9zT2ew/xdwP77eoXbJq9sVOlmaJx1v6obL1oURCny+OzNkLDG/r
h4oXHLxHhn0x4Ol/3kbs/fCakrNeO+6LS86jqQ3b++GVvcr01Rlf/CVN99zN
2Q8vL33umv/pi6dKho4Zc/VDkZzDO/9/vjhhC02h3P3wQoAtdxcDGf1/O+g+
4emH3EGSpzobGTv/TTql8PVD9rveu0PcZDTyJMu48vfD43RbfQdBMn7LbBFS
3dEPGb5bYOteMsa8btBcJky7lSFOEyNjXHnshxSBfkg9q8Bz4jAZrV9aZksK
9kOSeNdasywZWR5n/n1KmMpqNWWqQMYBq4Sm7Tv7IW52U9cfZTJqXm85bE44
5mNqZZg6GZnYqo8/JkwplMvZp03GqmnR+U+Ew6Pbo19fIuP25krrWcKhjnc9
tK+TMUJWv+YX4eDLTHfHb5JxSrVheZJwgHySnutdYr+1opJNhMk7ZUmctmR8
YudqTiXss9py8KkTGc9Qv5XoEfYavsWt5E7GHTNFR1eI/bpXr61+8iXjud0n
pyiEXTLjJ+8Ek5HtefMsD2FnP+nOtUgyajkPXfQj4ne8/eFtTDwZ3b6zi44R
+bE7dzNbIpWMf+VWnQ8Ttj20HFWVRUYRDSXT20R+rdhi3A3yyHh2Nv5HGJH/
9rWJeNdCMh5d+RJcxNsPMvMKRbRSMrYIHNRoIOr199PYt+n3ZDzA03Ovmqjv
tVo5Ro4mMq45JH9/QtS/siRk5/F2MnI0TTa6cRDxUo9d9Bwgox15T+8/tn6Y
CAqwzBol6l9QuT+d6C8N18/kD5Nk/JchxibP2g/bb/i+5l4kI9e45Ogpln5I
3Ncpks3mh4ufks4FMvbDKo+YUiu3HwrZrjG9WqeDyWbXyz8F/PCnYXFr1yod
9k+JhCoe8MOTpTu7xonzUvDcbrGd5IefVi/qXP6PDty0+u2/z/ihS+5z5e3E
+XOiCErs1PTDj728lWXE+VR0qLlx67IfxjzgTRiZoEODPFfjPxs/bGLsCPYb
pIPEIYtRISc/pKjnhjf30yF0V/nKaTc/LL8llrShjw6666ZHwwP9cGJ33TaN
T3QYqi1MFEn3Q8cvUqwy9XT4pa1jpfnJD6cWN591y6PDZeXHAbZ9frgSKnRq
+ikdymX+pccO+aFKxtAxzSw6ePKm9wxP+6FtF5/Tt2Q6bP08Dw4b/DGMi2nV
N4wOey0iuVJk/TG44BHv3ft02MHupaKm4I+bBzY0FtymA8crG7s5ZX/Mbjl2
d/omHdY2aX9S1vZHEUmjD8euEPfNY7aob3f9UbLFR2EvcV/HjAdzSqf547fZ
q6XOgsT9fcuP4/2WAIw+Fzf49E0frG5zxPscAbg5606pfkkf/HppbsvLH4D7
37dv+v28D0Y3nmm/LRqAUZpO2nwZffAuiylyGwRg+AuTio8BfeD81XO7gUMA
bjgssUVOpw++m7mwTw0FYEd8NrfRQC8YZgty2I8H4CmBwtgvXb1QO1POufo9
AC16DysZtfZCsuMyD+e/AHR5cl/1VGUvnA9w2ynPHYgdTp6cYWm98DzX42DQ
2UAU3ukxnWnSC7b/+aiIFwTih4qlnxsHe2DRI8TprncQXv+Wermouhv07U1a
S5hDcHeOb17So074sG1fCPOLUIw605w9+rodYg50M8qWhGIrW/2NteftYIIB
ziZvQvGieJkdT1Y7/Lb/fut1Qyh2c7c5HglvB5HPxXhvJBRlgw0499xsB7ec
M7/bOMPQ/9zo8y6WdjisZmEa5xCGYumNSlsy2uCf8Y6+GpcwfG/ZzR4S3Aa1
j5q05rzCkKnLedOKXRtczT+sqB4WhhKhXFa5p9sggOcP39LjMBzXzJGR+doK
I6MBLUa9YTjAFVZXuLcVoj1z5PafCsfzTbaRZ0Ob4af2n/fdGI5uBv2jMzbN
oCusetH/bDg2/nKRsdNrBs7qkTsT+uGocI87RlCwGSKYdiTm2ISjLLO30KfH
TRDi578i9TgcLV5K3L346gP4hphVn+CIwDTHq3nOrxpg9FrhhQm+CGwQ5b7X
EtMAKpLr9PjdEThj0f1twq4BGFsTf/6ViECD8PytdocbwJP90743qhG40TW3
tSSjHlwp6A+uEag3wkth8qwD+/jdmurfIjDe1Oai4FoNqG/clUOficArdwO8
vnfWwK4Hgsz3FiKQfapJ1iSnBsweh3xRY4hEJptzM4f1amCbZ2DKXbZInJWc
vaCUUQ03ZHx4X4hF4suvyz1bpKqAKcFx06nrkfiRcpl539BruP/R4aWPcSS+
9h8b77Z+DT2bHMyab0biyM0L0vlrZZBnZ1d9/W4kNgaPfOrZWQb6523cPZ0i
USx31DP5/Ct4sn5nsTYyEhPnUl+/Di8CjhN3sthiIvGUF6PJFE8RuNy/rWcQ
H4nPPe749yQWgjb9VuFESiSKlC/znnxSAH+LblptzYvEa+dyHkq65oOGxfVx
7bpIvG8Z++kCBzHviMpLmjRGot/HSUOa4mMgj/La2zZHYvBKbMnIvSyovPGR
gdIRiY9lrpqSujLg6GWVXZ8GI3H5daPI7NM00OLdYzY6EolLnipUS1IqWHYu
5/wcI/Khspflv6FkyNIukeOejsQm09Y54raFarYoj32zkaj2wJFlC2MCDDVb
1x2bj8TFE5Yjn1rjYYf6QT3935GYarOepRsSC8c3b0o0/xeJea13X9i7xYBu
7ZcRhxVivSyK4SaXaAjFJOtYJgqKtNc8LEykQM7aw5LHmyi4rhKgWPM2Euor
9FdKWChoJpf3w6Q/Ahjk2YN72Cl47u6+29MjobD7z3T7N04Kbh3x+e9JQAic
Kmng/8NDQVlWMRkV1WC4bJ91g3kHBaPev3jPJhAEDke9H/PvpCBTHc+4BlMg
UOaMZsSEKKgvmmkkyRAAz/NPHTu5l4L884/W6Jz+0HSP30VdlILV343d7E/4
wYT4rypDMeJ1OaVpLisybJxsZ74rQcFU4WHax5e+IPwkX+uRFAVtAR5VbfMF
JfPg2CBpCl68MCi3Zu8DV0VuDyQco2DmSpTZ4ylveDhyel/uCQrueZ7R3Hvf
G2JShS3L5Yn1OpW2Vq54QeH11YImRQouclV+DaR6QZtg/x/iqQO/eNd+egBe
8L3vFem7CvH5Sf58zl88gSU+2m9ZlYLLZn1ddy57wv5Lti2s5yiYqGt823zY
A1S4L3DvOk9BVYYXdVLOHmDcIX5VUpvYP3BPJgl7gFvE5nRFXQq+Z1wjJ/a6
Q8KFsYnzlyjIVS8RdzDZHV6xVh02MqTgt91p1Zet3KHzQ7Kj1TUKXoqo5zmv
4Q7zAY8q3G9QsJl7x+VTMu7ApmawIdyUgi1Of2Jvi7qDxMZjGqnmFDSK3yV5
UNgdztZspzy/TRxy5WbqEPG6uddMb6UlBf/7fOjZ0lF38CJ9EPpoRUEpntX4
v2rukLLy+NawLQVV/nu91cTMHcrLfZ7N2VNQUL9m73t/d+hxNl5Yd6Lgq48t
LW8L3GHhhOIpDhcKPh9YH/k14g4cizu8hd2J/uIR8uDl9wCp4sUGaS8KnnJ6
q9ml6wEaDz6xK/tSsDRrdmAm2gPIsyHJpkEUvMNl8ubkfk/47n/iR3EoBQO/
VX2fdfUk7ssvsDmS+PuEE0++93qCsN6Jsdw4CraZPOV20faCgJkR2dUECtr3
9v34RPaCH34h/topFHzKdtHLqcILKspGxH9lUtB1wvjDdRlv2Kcb4qr2lILJ
C++9fW29Ifj78VZqLgXnB6rjKwq8wVAoxFapkOiXkxkSJDkfWPQ9XupfSeQr
+kxLzjVfuL57hIVeTcGON4FnyDm+UPsq+OqhOgp6jhlvUvrnC1FTw6sfmymY
vr6wREolw2Ht4DMCdArqXWmquLbmBxaCwx15C0Q+ix3KdvIHQWtx0L613xTc
xzGekOQTBLIXZB0vLlFwcPGAJuN8EDB5Be1YZIjCoenJ1qD2YEgbP2ZMYo/C
mPCVtW/ZobDZc6ggkjMKJ45crJ3ZFwbWO4KYxnii8GZzdP1PWhgoag49DtgZ
haWButXs6eHQVxA4034wCr/yFDguXY8E0DhG2icZhSaPN54oyYiEJ2ODEY5H
ohD2nt/pNRUJDnzHjgmeiMKTe1U+aLlQgMNt8JHZ6Si8fvbZDdacKDh3Vob5
t1EUzvSps48pxsLNO+Xz202jsPihiVxdeCy4Ban0i5tHYe6xt+pFX2KhoFk3
38iS2I9Nw2RxcBzwX7TXq3OKwuObfm8lT8XDuOHLtJiIKEwJkbWu+ZwIa48U
g55HReGvj4N6/JAEO5Jq7Rpjo/AjrT44MjMJzg92qa4kEfG2Jacu2iRDseni
d7PsKKwQ2stRyJcK3pYnTh6rjkJlspupfxsNEkMq916ojULytTGXjC3p8PKZ
GuvthijsO/zi5VXVdJj8YTCU2BqFnd9vRKdXpoO2/UMyUz+xXuvS3biyDNjt
Vtbe8TMKg2u3WLk2ZcHrsFN3bUWj8W9BZrbRnRxgX0184yIWjTP8XAJ7X+XA
zfvLbH4S0ahpf3+X78Zc2KpZUZQgTVhWfV4kMxeusZBWahSjcbt25KWOiTxY
9VGO4L0UjcPBpVr08Oeg7KxeUu4XjQuX5o6KixdB3EQ2c11gNA5lCe/oulIE
0wZbrn4MicY2ZfXlpuAiiDretDZGiUaF/OqXSbNFMPZTU50tNRqvhD7eVfOq
GPystD8bv4rGtcYynDAogQ83DRg3TUTjuYyrcVdbyuBOPvmGznQ02j3/69C3
9TVs/lv0JmU2GuvLT5Myz70GlbDtTid+RePbif2auxtfQ0Vp4/RtxhjsnA4h
RTeWQ8E2ha6mnTH4jb3Hb7WnAuJe7XkaeTEGCwLmrSOiqsB869T5XeUxaKMT
H9MiVQc5qYMRAp6xmIPh6reOtsGZ86URNj6xqHy6foTJsA1G/kVG1PnFIse6
QGq0RxvwXToT8SA0FoMbzSZDm9vAlzUv/ENCLOZn/PHpNP8IRs7OYY9exuL2
V8ZPJTXagVOXO4Q+FYvFJfXzBnYd8Gx9JvjIbCxWvXr39hG5A9Tz64P95mPx
K0OjRmRcB3iwuAQf/ROLplHrX+LLO+B75UhQ0MY4XK2ZLdzG9AnqDj0PlN8T
h3zBYw2W4Z/g0aZz/gn6cXiD+T+5v0mdoMW4/GP4chzKb9V7s5LXCaKrzy4f
uBaHZwRNuf570wntvzjEi03jsN8itj77cyeIfe1rbrGOQ/e7fw7qCHZBd80d
ToagOHxUYNNqFdMFR70Cky3exiFLN9JEXbths9upTflVcaiZcct+PrAbBh7O
WC28j8NzCgqr2XHdEGhzEbya4lBSZWBsuLAbhm/sGE3ojcPdkjLtNye6IUwp
W6z1vzg8kp+f9UyrB6aWGoqOHYjHr7zhV/vZesHO43Kxsng8Vt+6/ejKjl5Y
Ypwo1paMR647TdvqRXph65bNJfdk4vF743fL23K9IMl/pjSTRLz/mMD6B2Pi
ef9Y1Rvuy/FodG6rFnN+L/x9pV2x92o8iiwoPbvyqhe8Tw1XHDGKx/Oxv1ap
73ohSnntraZZPK6Pi5oPdfRCsbZila9NPGpx8Ob6LvbC73tltQsB8UiKnho6
Jt8HHnNn6xhD4rHE3Xu3nnIfMNv31m0Pj0fmnFoW43N9sMPld/2hmHhkOLlp
QPFKH8gHyn4wo8VjBTtFksO5D9yyClo7y+Kxy4mizFPUBxsPYtuXN/FI7ld1
XS3rg7C8j21zlfHY+JdBu/NdH6QW/fjIWhePVZcOfDjT2gdVVZKfTnfEE993
YQdhog82DGb3FE/F47A4r1w0Px16FDaPbpiNxytXIpWqd9MhO9FsVm8+Hq0d
96b07aODlqHQxl+/41FmVNj1/RE6UDujj8pupKKZmMylYDU6WMr8p0hmpqJ9
Z+qbDefpoETRUu/aSkW655+nFjp0GNXaYuzASUUtF6HjU9foINnkEfpSiIq6
fpqDX2yI+fLgQPxGESqu+F1Ty3agQ0eAfKb+fip2XYl2NHxEzNuqv17/OkRF
Ofdj6k4+dKiuujshK0/FBXmTiOxoYv7c0/CTrEhFlkaSYGU8HSw8RNe6gIr9
Bg/L3ibRYZviMI+jGhUxXQVdM+lgUKqvUqJHRYFjdoX/+3/fQb6iC5suU7Hs
oxT9cgkdlh22X7l0lYrpoqY2OWV0oMk02SyaEO/vXJ1hfUcHe4qYq6o5FfM3
hf7aVUMHtXmyf+xtKkZ8OBe1o44O3/Mh5bg1FfV1lWo+NtGhcltKtt8DKqoY
f7QKaaVD5L2l4m4HKq6dOjR6tJ0OJ8RLmhxdqXhupPUKdNPBK0vib0kgFRvU
KlaMhuiguyFww+ZQKpr+53vrwQgd9t8cZzeIoGLvpakNtqN0aNpD2/87lorG
CvcFj3yjQ7LHqrRaAhW37LN6MTdBB5vBq4pxyVQcWMstTpqiA08Sr96JTCqO
3ZBSfTVDh2//7G74P6FitPWZedEfdHht2H63J4eKs23Wap5zdAgtlXI8kE/F
bRNjBnXzdLjBF+LlVEDky+KP9J//6HDUcTKkvpjIZ6vsV54FOmzsUo3nK6Xi
YvcBL6FfRH/JZGZYlFPx7BsvHp5FOuRQGJ6/ekvF4bzdhYuEDzsr6LRVUVGU
ievSq990eHnD6df4eyo2vwvNv/WHDvKqhfGr9VTUO17YsOEvkc9DM6d4m6io
3JhZEEn4NJfYkGQrFa9MPnHc9o8OjX9Nvc+0U/GjwG7Rh4S1hpNFr3dSMbX4
zod2wp11vQ32PUQ9nP7aCSzRwfAZ170QOhW5qHcP6xAeirrAnjlAxV18xluc
CZs9CiwsH6Yi9253znDCk8bv9T+NUjGw0F8/mrCV2tqfqXEqnnp5bSSA8E9J
+STGKSL+PwM19wg7czuQBGaoKPLv5xYgvPrv+RfpOWL917nvGQn7jEyR1X9S
UTJ851oxsT+WBtGDJotULH1s3HCJcFi+cfPDv0Q/sryQmiDi5YpJtI5YpuKh
z7pwh3C8Szfn0zUqxlrEbKUT+dplylFSyZiAvV2NKfKEM85qGvZsTEBDFXPm
YCK/Yof9l2eZE/BZwvClJiL/z3iqUzexJmDulrr4JaJeMsvLyrvZE/D3Su5n
QcKKjQ8Cz/MkIHPYhqxDP4nz9/zZIXP+BKzuGFfdRdRfLXaizVWQWO9zpugq
0S86N41484QTUFpwU1fELFF/dWpZzb4E9MsyrlEm+u36kc5r/QcSsO0Hs/jX
aeK8rqhnbJFKQI7mD0lLRL9+H/VV3SudgLc1KuusiX62/VA5efJYAh62v5/V
+ZUOrnGyR+7IJ+DJ9eQKmy90YHC3+eSpmIDOHmE8T4fp4G+W6xgPCXjVj/XG
x0HivEkLV9SrJqBy3tENC3Q6PG5iPbdfNwGnrYvOBHbQQaJQbUbxUgKSFg70
qX+kQ0G8d4S+IbH/4Bd9Sy10KDf/0+17IwE/b7tmfKyRDh/XRm+OWiZgT5iA
/N+3dPgnU+6W5puAXOcnx4ae0KHsdmvgU/8EZJK9EN5K3DfOySMxL4IS8OtX
B/EXNDr83cSc/y4iASWcJa01E+nwp09vcDgpAcu9GnumQumw6DGrJPwyAQdO
r19vJu7Hl8UMGgdLCedyHZi/RweHSW4D6fIErHtZ38Fyhw6/dE5ZYxUR/8M+
Nj4TOiyIBqSatCRgQ8bGmnRtOvzXJLxO+5qAjm7Kd0IkifjWj7HmTCSgmJuG
66IYkV/Zs/yF0wnIa7nbXJ+47+dTrI5UzydgfHfHwrwAHeZsy42/rCSgu5Hc
yyeb6TDLp1+1lzcRidnvF+dQH0zdDPDOUE3E3al2kRf9+uCn3R3qjHoi6rIT
be3RBys+516cOJ+IR+ovcwQR32ccmayDTbqJuKeWJhB3rw9OjkWcXDBORE7m
UkFpnT4INKPOnXYh3h8vNmUv2AcHzHOMxp8n4s0E2/tlj3vB/Faz/MEdSfgk
Xu7SZEYPCK8GTcrvTMLIiUSB6cQeGIxRj9cUSsKIlKb58ageMKit+2UtmoSU
qqgNLT49oL6v6kWJdBI+kiuZ0b3ZA1JfXu4/fS4JcePstL5wD/y+nsp5wyUJ
r4zxzVhRuyFI/8FU9EASljIP7a106QJ5vvDzPoXJWLnnmnh/Xwf85PibkvIy
GTdduXfSuY14XmO9OVdWmowMsWafOGs7QIjxRNTc22R03tjtL/eiAzbODPZe
b0pG+h3/JU2/DmivljKTG0tGvx0u2ZHSHWBh1fpohicF63dX6cn5tkNM7ban
Bs4pqPxhuem5RBsEsmmb3nRNwRewMqXG3QZuBpSd1h4pOKYln9y63Armk7yR
fuQU3GYSWvW4pRVkt+159DIyBaNiDg4/smqFTr2jmlw5KSj54bWIQ14LcI1d
mmulp6AJHsxy5WuGzZLUHPpACjY4kJt0V5pgyaHfbHw4BZ0Gry6wjTbB6Gbj
vpXxFNQONgo8nN8EhRJ3qg/9TMGZE7/+sKo0wUU7l+igral4eEQ7vOnWB4hg
TJNTVUjFIaHgM3aUBmjb/2IlipSKu+8FpYvbNsA2jXfVI8qpuBz+UT5XqwEC
o4Y13dRTMVkxVGUDawN47RM2Kb6UivwMOUf+edWDrWp64F7bVPzCIuDKaloH
z+8WXrCxT8XUsyZrnxXqYCasmuutUyreYFmqNeergzs9X5IN3VOxXXyXeWJT
LZjeFimMCE5FnYFxAYcjtaAblElfzUrFr8rSzi1TNRCZX5yqmZ2KkuM/XcPf
1UBbx3uzhLxU/BV049evmBrQEPw6K1uUivtY9ijkkmrgdJ4o0/13qXg95e9A
dFg1yLY+luinp+LU2+ePTXZUAS9ntusr9jR82G3+NLOMmE/exvY1c6bh0dFJ
ZyWd1/D7ju/xLzxpqP3U4NeeqTLoq7oxx7ozDVW6LLSb+cogyZbXzFQsDfMd
pL9KWr6Cve0+GtswDV1PPPsR9LsIuNxsn+49nYZdHqXM6v5FwHTwxkY5tTTU
2tX0tJ63CL56yleank/DuZfhNSBbCE+PzB8tNUxD0S0/82a/PAepCCOBmw/S
cO0q8o7/eQpCCppODx3S0G/v5LuOvU+BfeJkZ+jDNMyuM5cU1HoC8ySesFL3
NDySzLpe8TwLin80MbAFp2Hto8EU6/h0yEosMxIJS8NbDT4q2p9pEKP2pFwu
Mg2/sf5VouyjgVOqt8PNuDRcvJdapE9OAXmtk5OlGWmYVMR/d5crFSSW9qu2
Pk5DO2qGdp1+PAg+4c4YzU7DNx7jD8VOxcHK6o9rbC/SUKbzzbXGgzEwmzNQ
JlKUhtMKMl+UZKJh6FIT78mSNHwnJpRLPxsF7/Iff7z5Jg1z2LxfXYmPhIIr
0ZLOlWl4suI4I3tGBNA2eQeFVafhcRmFmc+S4UAptP6WUZuG9SWtytltoeBj
dP10WUMa3nW8LTDlHwL2WzRorU1pyP37CyvjpWAwL5FbHW1NQ5pVTqvyySBQ
ZeMuZetKQ8GPQiqoEABeMW1Ct3rT0EZSjVfvrD+U7wz2r+hPwwfh6WXWd/xg
MUP1B/dQGv6npVHmmkIGaQlGg3tf0rDKrK/BZNwX7hVWvK35moZ/TZoUNoMv
PDnpvF9wMg3Z07MdDHN84Mu7Y2EPvqdhoO2UkcY+H9h1du5X4480fNVOdujN
84bLbbnXhX+moUdtzYVNKt4Qdcmi9uFiGv4+WTHy9asXtA7slfz4Nw1vOG01
iI72AhbzwegDK2mYtrur5NQFLzj9nbrsvk6s75+yhYvTC0A+t9CSkYbmNi7W
byo8YWAl4BbfBhrqfaXnDd7xBJeqWwI1G2mYZZg+r7bfE3aQT7dababhKxVW
xpZ5Dyg5u9dbgIWGs87FR640eYAu67ps3RYaFjQmnf2vwAPm2wYmbVlpWDof
p/os0wPCo8qTd7HRUGWLFderdA84ZEC92MhOQ74n8fwXcj2gUcBpowMHDU2X
+tiqKzzAYlCvbA8XDR0O66Q/6POAjelH7zdz0zA3J+hE64oHpJtvF37IS8NE
1fh6bXFPIB2c7RThp+G75sFabyMinu9NAW07aNgiOPD7N9UTHr3IVnARpKGV
vjLlwmdP4LP3n9u/i4ZLXQ3xfFxeoLOkfNl9Dw3Vyw9eP2juBT/e7mEV30vD
qu+Pef0pXhDqvVrZJULDe4ZTR9KqvaCe5fUByQM0FKidq0gR9wbzlrj+XjEa
Tjzf2mJg6g2MkQ7hvuI0nHZ7+O9Bkjco8kv/7pekYQdLnXsYnw/097Pl+h+m
4ajqvaIHl33gYep3IxlpGnYPjt3xTPSBov1P64KO0fCnm+XFuQO+cFBWKPbk
KRre7Hl48ZwhGer/LKt/VaBhe+3yh/gcMpi9oa9EKNGwMbh/vH+FDKkqseYT
SEMla1F92Rw/4NHZJht3lsgX8+AUi0AAMFgvfVrQp+EOGWstLaL/3xieeRNv
QMOj0rdcIt4Hg9Pp8EwFQxouyuxNf30sBL7vEHHwvUbDnJe8cZ0CodDz/hwv
900a8gT7ydquhgHlefTqKzMaFqvcjdNwDYfzCYPjV2/R0Fu3nnZgORyqrR+8
yrhDxGMiNeLMEAnPBBIuy9jQsIirVCmViwK3N45Bjy0Nlb9dda+7QgGROcmD
LnY0bL7plLiSToH42qq/1Y5Efln3y2YcjwIfm8kEHTcaKr4vZt5gGQ2X6+QG
bIOI+rjH7hlkiQOuAu9anhAalkRXvfjPNA5aEpuflYXSUNbFae14RRyo2Bq7
M0QS+bdP9rnkEA+SOwOEIuOIfty9n+PAAhWYHvSYvMikofDY7ainksnw9prw
Ob3HNLztODgSl5AMzmqWR/88Ic6LL0PWJ+YUmN25xgi5NPxGbRo6PpkCffX7
M9sKaDi+eZNXd1kaPN/lOD77lobvmxISrrSmg0pzfoLjOxqO+a03i27NgJ5H
3y6sVtFw5f3H5aCzGbDWc/nVtloadhUK8YvWZoAW5VTAoSYaWntflM6ozYS5
TQzid3toGOaR1cg99hjIL08OzvfSkDnk3vNc8Seww+wBxZlOw8DSj7Ujtk8A
q0b/BQwQ9d73V/EQ41OIdKlrejJKQ92z/8mRxLNBei74/tcfNFyN+bjHMT4X
alPeC9+fpyFptZrGPpkLhudXuhb+o+HOiX+v1eXzwCvHSmnDIg3nt6z4pw7m
QbvZRXaRZRpKrKveb5PKB9s+3gJj5nQUPHKWIjLzAgqraQv9e9KRUbSCy3Gu
CKaNMN93bzp+CCwS6t9fDKJLwxaS+9KxJYf6gHq9GOJk9vS7H0jHviduCXua
i8ElM6VKWCodpTS6hLWevYQzfolhFqfScZ358rluj1fEfBIj9lM/HX8kcQYY
mJbD0seAa1uC09E4xtPY370aqF173knMpiP5SsDa2btN4E+rVrqilYE3k6KV
p0M74BrvvtU17Qy0Et/vXZXaAdLB5IosnQwUpdWEBhd0AN3+rMK8fga+0N16
/19nB0iebT0ZcC0DD7Im8JAEP0HnbN+xkjsZ+IoHnVWyPoGwwrw4p28GUgXJ
6qfzO2Hxhc7UK3IGOm8T0LzwthOaRIuzr/tnoEv0XItaayfYszuJZQdlILfW
u2bm2U6o/7IsCpEZWC2tx/LuUBdYBTILW6VkoEClec3U4y4o7xbi+1CagT2v
Xzu5h3bDHXabdN3XGRjlq8FyJaEb+M6+kxwoz0AF9hS/fU+6wa7M+PTc2wzc
nxLJ6PeuGw4l0Wx5azPQtbrspPN/3ZBsItJs2p6BckpW4ly6PeDxfb/X0mQG
qmpFCBVv6gVJUSdW8nQGMvHfndPm6IX+6/VxbDMZqOv8cY0u2Asn2izyhecy
0KtBqKjkSC/MFTztV1vMwM1uOjeDDXvBxEn8eDRjJvZ9+Xsr/UkvnGaUmj4k
mIkBTo9NLsn2QZzYV5eenZk48Wkw8JRSH0xfSGL13p2JS5rsRSxqfRCZuEWq
RzgTU6ZPbzC53AcDx77ZeIllouTwmtwSMY84WaQtdslm4rZlP7PPpX3wIdTA
3/NEJrptGszXftcHu4rZ+CVOZmLFZ7bxZ/V98H7d9aSnQiZqj8AekW5inkkw
dBVXyUS7iT8Lf+b7ILeZk9FDOxMVubipeqLEvP9fI+WgTiYeOL6v97IEHS7u
8BLp1M3E8f63J1SlifnP/MfpgwaZaMkbavVZgQ5n1pr8P13PxIccl81/6xDz
vagPv/uNTOQFF+0zl+kwrSGfLWaSievUf2Gu1+lAiX/6wc0sE003R+x7YkGH
IWnyNjHLTNz8+yBl5hEdjl5WSOm4l4nKkf8t+nnQgez+U8rNioiHVXWexZcO
h5pMtDtsM9GC2aq5OYSYV82UolwfZmK6nYKUWjIdmoN+iRx4lIm+VeFaUsT8
KlSQV9zukoncdYGX1oj5tnZFoHu/B5HPNuKZO48OnHG/+dvJmUg+t6eR7zUd
RpZdewcI35qklhwhXGDKGD9FWEqaP1Wd8EWpbXwb/DJxg6iIiQvhyNq9PCcI
GyQ5ZA8SZl84z5FMOLlJSCOznA7bLmay3PHPxM7rez5JVNBhoORgowPhHv2r
wqcJP9v5PMCb8I+i5LvXCJ+fKNucRLg8XW42hHCIR9vGNsJvshvLZghvzf/H
IBuQibpvLU3ziXm+n8uzCgkbF4ia1BHOdd7odYHwtQsTVwYJa5zZvm5BuHDQ
n8RWSYegz6KrCYT/vD/acp+woXJuxRPC4XbHMsmEDz494lZMGN1IjsmEG+1O
LbcQDvlnu7WFMLXvXTmdsE0CtXWM8B2Sqss3whtmP4QsEz6Z1SS/QNh66yZV
7nd0YNl68d864S5mjX8ShP8P9A1Xig==
          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       ImageSize->900,
       PlotLabel->FormBox[
         RowBox[{"Bind", "(", 
           RowBox[{"Kph", ",", "Kpp"}], ")"}], TraditionalForm],
       PlotRange->{{0, 2500}, {0., 0.4079563043349674}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]}], {3420., -2102.551629727142}, 
      ImageScaled[{0.5, 0.5}], {900, 556.2305898749053}], 
     TagBox[
      InsetBox["", {4397.142857142857, -2102.551629727142}, {
       Center, Center}, {900., 556.2305898749053}],
      "InsetString"], 
     TagBox[
      InsetBox["", {5374.285714285714, -2102.551629727142}, {
       Center, Center}, {900., 556.2305898749053}],
      "InsetString"]}}, {}},
  ContentSelectable->True,
  DisplayFunction->Identity,
  ImageSize->900,
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{3.401470078789246*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\
eJzsvQeYHcWV+DvWzCggMjY2xjZerxNeB4wxTiQDxgHH3fU62wvOGSdyECBy
lhAgEAIkhBAKKKOAEso5p1GYoNGdGU3QSGBj77739b9+1XVOV93b3feOwN79
v4e/T2Zud3WFUyefU6e+dNEff/bjX1/0x5//8KK3f/b3F13ys5//8A9vv+C3
vzePql9XVVU9sKrqdb99e1WN+Tuqqgr+LyoUCsn/3cL/9ezpifY/1dGKFSui
PXv22F+93bOVK1dGO3bssL9q3LP6+vpo1apV9ldtyrfVKc9qMp/VRBs3boy2
b98uY9VmDlOjn7tPpKn04Pcqn7tee+dMyv/89JTR5dtt27ZFa9asCRZeOnT4
bXWF7XxAbt68mXF03LTlyTPXR/byYqDt2rUrWrp0abR37940+KbN6DOvAgqU
W3WN60GeNTQ0yDSrsudZ6z+TMSpqX67/tLWc9hp5JJ9bvnFWzDdOcGODW5/4
xCeiM888M3r3u99Nl+7b3tHy5cujk046KfrYxz4Wvetd74q+8Y1v0H8v+/rY
aObMmdHb3/52+/prX/sa+2L39Mc//nH0jne8AwYXHXbYYdHxxx9vZ8q7lOHi
7o7SV5/85CejPn36RK9//eujo48+Onrf+94XLViwILrqqqvsLGpqaqJ3vvOd
/oyqerk1MyVmTJte5n9R//79q/pGH//4x4OR6ZrR//mf/zl66KGH4k090o7A
gpg4MzAf2//edNNNtucTTzzR/j7uuONK4ZEOymo3Mbr+l3/5Fxnxo+6TFBAq
2l9wwQXRe9/73ui0006z3c6dO9d1d0xxdxa0oPKHPvSh6Nhjj2XtFvTnn3++
bkvRN1WyapnDe97znuiII46w373lLW+x48uS6LN3797RBz/4QZlLJUCTIenu
DW94g7/MXu5zRmB7amtro9e97nV2dLrwtwxgsqOnn366hfvdd99dnQPAXjnv
zq0EtQ/PRO2RI0fa5sBXFqsoXLLLxRBmJ8HoN77xjYrZjzzyiH0HwfTr188i
T7DGGv0cOjIgipG6xu7H6NGjZZ69GNlsqocSAVmU9NA36CFz/HwYp+H8qa+x
lv9B1pLG5M1m2h4BEyP+53/+p+4EAmPnzp32XXNzc/SZz3wmevLJJ2Xkc845
h5/2NWudMGGCA0n/6LbbbrM443Vr/04bTrai+N0ZZ5xhd5XfqE4nnHCClVcI
ev5ubGyUKbk+TtI53XzzzdHhhx8ePfXUU/b74cOHa//0deSRR0bf/e53o3Xr
1tm+nGzUcVAJwTD64B3yk82g/xEjRliwsOZx48YVzSEdpL0cSKV/vvfGPi0H
pML0nai2/+69916GKNet7Aay4nOf+5zfbdYnVcJ9i6fykY98JJo8eXKwi0xJ
dtdNSTYzD5AATYaG7o455hj7LkSiBCHYzLe97W3Rd77znZLNrKuriwYOHGin
gELz5je/GW2wqjySpr8TKXDIuH+4nRrLA1o+7udu0lElXf76179W9Jd3rBZo
soGlq036eOGFFyzPuP322+33sHIYBO+YhrD30o2vrI/8eeRDPY08Ts159xo3
+kdzIysnzgzlxJe//GXFhBkzZiCxjIjjXT/7/Pvf/77uTHV1dbR161b7+1e/
+hWYrFtx4YUX2uV6/di/0/rv5fovfocgla1ASTJY6dq+y/KJWbNm5c4JZQu9
s6mpKRibvj784Q/rnKQvbxz7N9gPBf3yl7/MW7PMQbcie429g/69sT/iXmcM
0ce95jGKuHztehOg+wuhJ7TpH/zgB8FkQ0AeW/JN8egASeRBysJkSkJOefCT
dzIMe8PQIe68NRjm29/+dtS3b9+SPSzGq7POOsuSRd4+5eHtBT3G8b52Lief
fLIFjz+XYFfOKAthLDTQPG/aecv793//d8sxUGP9d0wDEEsfefPI6qMn83Dt
8qjg1Jx3r3GZvzuXSWP4yJvx48fbZvgPjE3l/FF9ow0bNtjn2F6f//zn1c/A
c2OmCM3fc8890X/8x3/oaB/96EeVS7ku7d9pQwkbKn4HRGRXfFHO0J/+9Ket
GV5mSphqF198cTA0XaFeypToSrSJUGr2jz71qU9Zl8XYsWOlex2K/r/+9a/L
FHRTspfYO1iGN7awfn8I/jmoilmwadMmixq8euCBB0B91WEyetbZYmoKMGWz
wtXWlnxjpqKQ4BvRdH1oMid0I6BZbk4+NOWdLFnGdnPLRArIonhH0cdwhDIH
SAZyFvUxQIraAE/DJVb775xtUCH6H16C/sxMrCgf/d2qywM8Rl9cXWyajxcs
lm4YLmOxQR8AHW/GkiVLtA9RcmXK5eaR1kfl8+iXCp5iEhG58Boz+h9mRmkS
Aq/T9OnTbTOsBqMn6KZgEOIRxiOFRYKXinYYiyeeeKJA4MEHH4y++c1vBjgg
K3Bd2r/ThpJNKX6HzSqbcsstt0Q/+9nP7N9MCZ0Af1qZKQG097///Xbh0j1d
/fSnP9UpAdRRo0b5w+im8I5nbAw+SIaUKSBymYabgm5K9hJ7B8vwxhYJ4Vag
rx1URUIADLg0rhYciFOmTFFCzuhZAYNrRoApmxWutrbkGzMVhQTfsGqRELJK
+nzTm95kOXclcxJo3nDDDfadLFnGdnNT71UxNJF0xTvKnPAKMAf6uvbaa4U3
ZUA0ZYnV/juVEBWh/+El6M/MYO/MzEd/B5FKAQ4VAWB/FXQJuyLA4Bbrvjku
c7W///3vo69+9av6jmlglMiUy80jrY/seWTicR6FnJrz7jVe9A/kRWkCAmiy
BJotXryYmIpGzgnVMJ2lS5e6cEVvK8GBuGgMl19+eXTZZZfJSoDEUUcd5Xdn
/04bJv7miJJ3rFo2hFkze/5mOuDHmDFj3HSOy5qO9aiB0tI3/Zx99tk6H3Zr
4cKF/hiq9Mg7xOqwYcO0f8b/xS9+wa6qwz97Xb2DuXtjfiQfkpIk8MMf/jB6
+OGHrQ/RNK126JbRqf2bHmGiF110UQCMcIHHlHxTPAtCUSIMZIFMBx/+P/3T
P9kIYrn5ALxLLrnEvpMxAD7v3LwyEYB2xRv47LPPRl/4whfsJpBxUu2+zUKA
rLUx7nmHit997XQ+8IEPWPD4+O3AUCmE8X2A4v47VkjX7F6ywpMyV4juDmNA
QeYdU4A8ZPXl5pDWR/ocykAlnQpOzXn3GoP5ezKYNDY/b948uzSiLNi3jzzy
iNuFWittfvOb39h/f/jDH5iKCsurr746Ovfcc61OR4YJwo+hjEpgl0843evT
vksZS4SlvEJAobYi8mUncJAgz3/3u99ZLka70ikdqVOiLVkABDUxFPGn+f0j
eL/4xS9aS+krX/mKTEGGwS3HFED3O++800IBX4R0D5JBFkwvnEI6NOWdvww3
dJXkC6VAUzcaBmva6k7MmjVLdyGlTwUZf2Piv/Wtbw12KeWb6iII/uQnP7HU
74cJZGnYrIAHnuumUwkEiXrJqECGDA9/tbKJMgz2DloPaF+8iWgw6P4yhcGD
B1fnALJXzrvzXgGqT5s2zWrUpDgxTR/VKwDygAEDbF4W3ndBdXnHnov6Gaww
+fx73/ueBQJYTjM8w37XvANQGaPnfZ45ej5805D/1NfYzP8CNuPnDr3ZiVii
C7/97W+RFS5zttaGtlkG/1hWY2OjZsbef//91h5csmSJjrV79+7o6aefttgv
fVWn9C+sTJ7hVjZIRUjd9dUn2rJlS3TllVfa2CAh99I51No5oDuy+/zX9Kcy
T/pGNaafG2+8kXxa0R6k+0svvTS64oorouuuuw43m3xNz8RekODeyNmLqdEe
3UCnp8BJMPz5559XuN5xxx2eWlPSjYB2/fr1FkQEkEKwl3xS40GHpjgu4QBr
164NoANkIW1vFqIsZ0DH0oU/GmCR2fibCjL//Oc/L9qUGG4wIYPE5pkZ2Dwz
SpQoJtrOB1pNyrPze4igAtw5c+ZYYfajH/2IvcuAeTEAp06dWoSece/shYFO
zkqO0D6GDh1qoQFTwrFOO3kHVLzh3YoPK/utG7+ngPSR97SUZ69R/yunfp/D
5hzz+arrkXRR2bqk5WnFLXvRULa2dfXmqGXj9qJvTom/eYuDIx13jmqw/zrG
NUTtExqifc83RYX6vVVvdR0V9uyNCs028TZ5Fv+2v/xJdj5pk3CrhjpIeRO3
/9onzo86xsweFAw/yv7rGD8+ap80KWpbsiQqNDXFc37QE0LfpPnZ+pel8W/z
11n6zH7zOX+JNcEUFDy19vGLP6uLOsyK3StlmEWfVJfvyV9j0lNf+679ucbo
4J922L9btjVHf/7m9qhzeH30dxiwv75rW7zH/n3g8p1sZvK327iyyw2R7tPe
0K3rdkXdN8x9RVB79Zb8f0VPn/PQoeiTqGvwuMp7PtR3la7tkJf8dx88xMdz
KiDuX/0q2rdgwd+ZuP2d7DaC6K/G3N1n1O1/yID7Zs2KDhoRZdFo2LCMAfN6
tgzzC7ZBzDCtCBG3WsvOvZZztWxv1tNy/i4c4QZs3dhsn++/c1fUsqlZNgxe
033jrqht6Z6qfimfH+Y+LzTsjTpH1EcHrtvp85/uW3cZgdDoNU3hSXa+tvH8
qHVlfIjv8Myphs+OrPBZ2rcX6OAqb9dsjrpvfypzupWOVumzc0q2q3Xt2uiA
UXYKRkdM264jU9DogNFJWjZvNlu4MTpg1JnWNWvStioGQSzPO594Imo3Km9h
zx4D9ltB9/4pn5TK4vC9zJqd7xhjhXDV692zrofro798bVvUPq1R2+2b22Tg
u8trVwOyRS9/dmu0/45dYJFosC1bm6MDVxlh17S36stFRNExfq0Zbs1D3oJ8
omjZtjM6MOCxQXkTHjYs6njmGfvrTa4bYHHwT3/SbtqnTYu6hgx5s3u9/777
orZly+yr1pUrzeSuQsexIPp6MfX19ldxjfUWVx3nnrVPaYz+38PWQ3HarrB3
b3Tgip2WSqVdi6HI/37HJgBZ1cc923/vbgtEfn3Jp522ZXXR/rusi7nqwRK8
Luxpjg5eFsPrvhywtGzdaqZ7DdNxYDEYaazS7ltijVb6Y+0tRhv2wXfg6qsN
s9mp4Ot66KGo3WjRxfApGlogAFq0rYgPvB4j09nGtHdErav2uKxSs3NP1kft
z8Yc5ViBiuFZXcPq7S+BFFDqenC3/SUnqEuP6noctcns1OWz+G/V9ZntqzU7
lF/9FdDC7w5cZrTmhnh/7tW3unt33x21xeKs6o0yz/nzLah88HY89ZRip7Sz
2BlHc7Qdanb3bbclpPrvxXgoI2MXdIxtCKDb+Vi9PhPotr1goDZ4d9Bu3/yE
aKVdYVeMryDKmQ4+eK1wPkuKiLHpVG5lHo4V/AWk++9eGLUtr3NxCvOsYU/U
umIH/xKjZWdT1FIXb//5OZ3Lhvzbv/2b9XlOnz5dtxDPHU7Eiy++WA1mHyUF
vN0DHjMUsSPZzAzU3Td7dtQ1dGiwXTDXzjgFLJEuGzYY+Xhd0K7F8OzugQOD
doVmg4rGYi3s3BlsqzAGv/xBmoyQZ21L9hiuFW/m0T5DunonnFbleWG32cwr
482UdjCk7gE7IUmVhN237YIU7a8z3TMcAuQFua8KuYfi/M3uGL3aWJLrlH20
bG0wi55tlI150V/PGGGwcwXKxwmyIjOfzidWGAY9M/rb6Y9HL5//FKR6Xs6Q
ggL/+q//ajNYpk2bplMk1olfWTJYduzY4U1RtRejCqASpFNzYdcuwzEut4au
bGfH00+bVU30wFFt5WtrfLC16njZmoULo64HHgjaGe0vao+TOOJt/7d42491
c047RC4onbb9qGQHDPc0tr9ua+dIQ/PjY5qXbUXwtjrOe5TOL6F5adcxqiFq
n9yYuf3iWcnIexeXkC+t983dYpjf0oQatjcaXWC0YX5rlBrgCp3Dlttfgiz7
73jBTG+BZdr089IPJhpmv+TcSmZQreHbZNK11i1Pzh3/OBF8yimn5PKG/cbi
a1u81v660j1Lq9nAb3fiOVWnVdFw552G1lYESAJPQTz4SNIxerQRf88G7fYZ
/tf52GNBO+wXo7xkIlPa4dRaRXFh89037LSGAb9Ef4USD15qDIotzVWiM4JW
Rs8LUKjrkXozs1D13ze7yT4vh0J5KfTVjom0bK4XF0bVG2RuBh9gIB1j1ygk
kBgHLptldJOETDtHroxeunhSyHVRwa593nC4nc5VkjmPfg6IcJaJMbXb1Cw8
l8kcpePOYVOifc/HCHy5+zLvEDjsnTxsaN1gssBEakL4FQcWLFiQhqSJ1B9n
9OQxAbLsv/12DIQAWdoWLYr2DxoUtOM7QTQFJRwPwWQEhY9UAn7vVFsq8fRR
iBjUmNUUoBWaB9otvwStQJ+uh3aH6FfvhJURYNKudb3Z9pt3lUWr3LzbUjsC
ddBwJFldx6hVsVTyVodIap+0PkDC1jXG/LjmedQXbdc+faPh90vsr3PyZ9PP
DbDWWIJExGFmBrnSOL3qi6NmGqvihQDD0o6RCoZB/OwT2prpXiZ5n7FwXGQ0
hRdg++y/664ASdBmWlxFGkUSA3hBEmmHuYWW5IOuG0R0yrVFpn8NOVTaOZla
Ja4+CthGa336KNL5eMKNFEXW7LH6i98Oxbbr/hi9hDdjbhQaY359Rg4q5SXs
BaZX1+DFRppus7/UsttSb5QwgyG7mlSCty3dbmhzQYBJ++98Ido3Z3MANpRi
9CSw65z8yQjXleCKwSJvX2W/2icYfvnM8wHypB1J88sqFUu5EszJIHzsZasy
NTcnPLu5OTZsvFJQFjecyqTAMLjXuqKI/EaMMIg/JROH0jLp8+bXttxozHeH
DActGB+FjyVWrWqKsUQ8SzC19hmNQbv9RoVqXR3D6lPuGaEsgvQGozRMlp0L
VMqVOp5eHXVMWCtuls7hy60/JG7spnfVbMRdgHNtS7YbM35+0G7/oEWG727z
uFL6VASRIMfzzjuPJJ1UMArOt89YYjjj9ACl0s6wCHGWoE91oISgPzuJJau2
ZpPhaj7CoRp1xCMo0nSbVbTEWqAizb45c6Kuhx/OQJqSZNveJZwQl6p1TXm7
j7Om+/rwGSIJ0eQ/4zu+97HEisPnmwIskUDrwIEDdYElaQYBo9k3bws6sP0l
jhFrVF0VM4tE+C43gnVTgBzo0oIIghztUzZoKPDTKTOQ2c83Gip1axTEAXfZ
t2CVEeETA1RIy1bPRIUiFFM3EA7MadMCpGh74QXDz+8PvvU3W9pZjnPppZYL
qedr82ZD6QMyOUlaRl7e/A5ca/Z5R7jPOMIJ0vr40DXU7P28pqAdGjc+d78d
Qd2Op+NvL8zgDIiV7uvnyqayeR1j1gQMDj2k8/EVAZLgYjkwYE7QrnX1TiMu
Y2n0jRxKb12xMdp/z5hge9OyVHu6vdakMUqDv20w+s740ESybUb5EJeK8oYt
WwwYrg85Ii7yWDrG2/u1cHvTsnUSEhNHiWXna/YEm4WPUTZQNot4dMczDeHm
G9GAYuK3a1tgFJAHYnEjeeglPsci/+IsqwHwS101eC7h+NsbExa1yaJCsM8w
h/YZG0M0hTk4SXFO1gyqQq+nzKWkCmcw05YtOwz3fTzAjLQcNlF3JX3VFVFI
uK4AH++ZsHwVfk8+qVxAtxo/dF1dwN/ali61/nu/3f7Bg60bphgl0pzUynWG
J4aL6gJXG0qvC7n8PjZ2aH2IKJ7RE0gNR+mfdLPjYChjk4/olRYr60nNoFB0
SmPSBhizb8YmtUYEvFandJigzsIdjYZyYvGhNHCf0RkWxyr/2TlzSnPAivct
zZOVt4bCTqMvX/Oo/XWFe+Yn6Ah3kQQ6sozSHKOyhoN/+INZU0OAIl0eOsi3
CBOEit+uffJkdexKO3z1HXExjVJUCpDYZ+Mya5RLUR1E6bTmivO/KaIhUraF
iEZ4FmeM+a8iELSKX4HEJ1buig8JAuV7Z2XbUCtBEx8drJawZHsASuuzX7Qt
aNf+7DrrYfHbobW2T1gXoE1PnbZpPqvSmVv/1B8fsPZE4rRVZ6fnZ1PtZ+BA
q1CWbKlTJlWgYsUaVPfbWZ3D97O5rRcO5ddszRV4RoSIq0MQg6SjzmGhbWt9
9ZfvDNr5z47SNe1Sz90n3TMKlOBBQqeULLkyrtJU7R7FcNSqYDiraGLRGjxU
f3FsqIQoZCwQ9A0fNXzF9azKpuV7cAWqvvPJrq46EJyGfbTsiOF7Tw5r6Bw5
Ui1K7cuwigMu9KbhRcJ2zoEv+OFFiJMAsBGSoqD4+NHfzZ3EXUSiV6m1Stw0
RdUgS/UR6/dyTo3AFTs1dMX6RofsjtU9nPNDXbZDdtvn/BJDBJ6Kb9OIpcrd
s0mAcrsVGP4gcAHhDuoXnrM56npkWdAOodV907ygnfX5DpgboEoZH22aGykN
u5NozZNR67otZRHFaqiPPhogCu6s/bHbRBEFbfSAMywEUax7bPfuoF2Jhhqn
ZCqnRy9y53J0HzLKwaUtTwO3jS4o5KGMVWtXhgEgQuoS61OCHtOgwSNp1zG6
QcPxZ7hpoUxzjif1kHR4/j4tT1HaEQzCIR+wNYMQos0oUni6rk4L3vPMmmCZ
VsPZFWP3mW6quT7YdP9RInEEzvvvG2s0zHUJygQSp9VsjATpBVHIi5CIjari
HlJoAgSmzA03BO0sl1mypEeIklFGKg1RVB8cYLNRgmdoG871pRy9y3NeqJC9
d7cNPvs7gurb+agf+umnZx4ZO+t8bim4/X2URbdu2K027OF+u93xLNSZd6PB
n7Uhx7Qa7dLtAV5kzEaMlSIXUZpg16juw5OMhIvZneiuhxIo1D0gD8Q5LwSd
rBnkhJaiCbkmThgJOpF7gp7rtyPXROI8laJTRs2ZhP+rdnhXElpWobV6j+U4
/BIkIg2FFBUfiaxG44SWygTTF33y6xNuMpirxMKYlHeoKu8EYB7/x+cuGoo6
X4xC2+E0HnXtovguqyvBQhFP0o7vJEJ0Vs6chOWkOZpKaaBz5HNR+/RYsF7m
vjyEmCI1JVGzxNZE4zaCJBlPaIS0WBLBfGzCSS8YlmRnPWktJL+dj2Gq7hb7
YCvAuoxCFnlMzPesqgmGVj28PsA/y5ycpi3tMLXIZvXbwRAxw/j1SQdaBO81
11wj50vSjjIlmpvu3+MrzEQ2BthD+p6YV+oaBnsmrw/a2ezHImzcNztRoM5O
mcFhDkfS/Fx51NAxbo4Zb26AZz2ILMrWUZoY7fa5556zn1Ga2LDWtJGF/LuM
yJKQoXq6DO+zinhTU6oeJhjn2/KCcSTHdt94Y48wLuNMfUIeqhl5/EstXtJl
XOqzLMDnX9KOVJvilDtr0rv40udztsf30QsqIBptIuOe5sQfNWuT5tBodOK2
xDGknuf1u1TnFjQq5w70r0xxinYKw2qftsjMdEaASJVGGWW1Rvuy5RoWLFiQ
6t6R3eAEUkdcuTmBvFmBaGEqidasscGlAMVsIu4VNv+6n/8MtGtoCFCnv1sr
h8LxV7hSKeKuSDuVm6YpKCanMCGrSS0N/b04G4UJKbLhVxoT5nemuQAquv0o
2Dgbl753UchtMNec/1BlH6hz6/ygnfoP9+4NPVaXxXm2Ig976j9EK6MtR7mR
aOPHj8/lYm0EoR581ptbjQ0CtT8738Yp2xavlfzStmXrDWNebIyKOs05dX4D
++s9bgp54UwOVcIA9TKkap9XoLuLL1o9Zp5TUbHO0JiNixtFT7F47VrFWN+j
JbFyi51fibFTNoHzsHI0OOMkY7LrarTAqO7ZHUzIhjx37c1kVMJpcWNJjnrC
kXdbRsevjzvuik5CXV2MEcDFwXnvnoxKHd0acKhrjNNuCr7PfZmGPBQByYW/
dKblj4H4HLrU/lJTAf64OiYzSXHuqcfyMWPjUZGZ9tSSp/BLKW8kxXT/HaPt
r/4OOIWmPdGLvxlkiHiERdO/fO3aaN+MJSe6jrEqDlw9zGL1y+f8Ido3f6Ve
HwdGc0aTX+917dNCrrJ4dAQnz1MBrHa2QfMDLtCr1p/nIdc0YaMTiK6oTh8z
NiFbv51N3nDBGx9x0wIwqpRtT5QyjXVtbraJivwSi8iG3jc0B+1o0+L4oebA
e94ywUvIGXFUcFYp0QpD0pX5z4XB+0aqLNjKEQJ1dY2JQ+Pm+fYwZrL31VaR
kwi95jQNX66YrP5h81sUwQ+6yR9C6isH5UkR4jlJZyeccEI+oW3dEXVf/3i4
NDPs/rueBi+DqM3B3wwGfZNYx7Zk/PhZn6jzsWmGIB+yffCudeM2i/odE+bp
UYCOp2dHL33vFsii6mQ377Q4s+C01LLSo/Z2c5KQXRIi9NNa8cGRdJ9sRKKD
qo/U6JaSlKsKB+4cw/RTMTngq5I8S062JtYtaor2OwVQY7V4Yhc1OQi5bxv2
xulphhGqI2lyklJwhqMUfBVsO3DJqruetr/qzjKWrVjAKg+8fACFhGGuMM5y
KN4+zSipI1aGKH7/YgPFrQHqlnHkQmuUO0ZscGj/u9/9rpdsq9Gfhqb4EI43
qbYXVpvJjwqQ2IYUrxuO307bvfzZy8yiJodMb1OdWdAjhpYbAgI4cOUj6Aqe
a6zZSPZ1hkHtSnIODSLDpFt21le9z60iOwRea80NpN2jxpxx9XlSFUZ1XA0a
ZFN3fTRGE+h2LmjlExMnqj4cZHGjXTQ2JvNdvTo8TuTQWNzW/qWNefo3iqcw
Wk08ebbRzKEhQPJO70CBJp6s3BOfBPTa2VDFkJhAPulag9i4DtG5qd3BHPJK
gScRIUFzi76zNgUzJ1zV8dTqAM3bJ67TZwE5uGS6xDe1wzqPAnLY4w6V7d5T
9SGH5mVczqg6oDpWNJUBly9fnkutFtkbQxcH51ZAer8dDuoDAx6zHFSDAfWN
0Z+/cxMZPAllDh5nNuWFkm9tLkdTkgfAdweufdRyI7XZh0400jS2u//FPSuN
09dYO9srdpKH4/55B8HdjgkT7HO/ndWqXQp7Hi34WrWP43nxOBGU4BP2p3ev
nmcwJQAsZd32LITzQyUxAMO6nwgPLdpsZpckpEElL7ldzLhFhuoxfJK6sfnJ
7YFqgjdS4rdqRNyzULM69AyQ+U2GaAmBPB0SSKF+T5yX5GFC2/I6e0iHX4L4
uT716mjIkCFWt4obF08a9GvZHIvs5LDiakNxo5Mv4ClGmegYPSuAquHJsS59
04iEguHNkENzcgiXgxooGv638MmXvn9L8C32oJUJDU1x2lagXOx7/nl1bQom
2qwD5ypVTNy1S44bJ5hNCqtLJJH+rOt13bqEK8enoXMdV0T65Z5F77qvPO3e
P8Iji+++KUlgVWa82DDoQWHs0ibcTw/P5Kq2UpBY8mF2SuT8TIu1/vyqt+ns
zp5zdu4Ilb2NzTECNjZ7TpLEGlQkvztxsGpCwo3zjKwKDV0bPBwXJy6c4mg/
Oy26xlab+tKXvmStAmNZ5+tWY6K2FRsCNO4aMsFmTPtoLChmVA0H5Rpj/G+x
aow9yL13r87WYHvHU7OCz612g+axqU4/L+zmgOXD8efNzfr5uDmWaPh1XsrM
VTkg/c4dVFVT2uyb1Zk9/449ErJtW9COEKagcGKaD7O1LypBa1mWd2mRJ9AT
t1+jdboGgGhyWNi8NzhXL0l3evzOOwOpUfqrkxTejzs0QGrh6L/rrrsss0U6
l400hfU48Ild/XyAcJbT3hPLTbFM/Rz+JHifILq028/5ksVhUpZ1XbhCGh92
z9JSt3Fg/fGPf7S1xUpnijSXyKWyw/pGq/oajUNnxQGSrkcmeXCvsUcj0STs
EeotO3QBnGwGLw1a6+czkNxjg8/RurtvfAKuS/0r9UAZfUOEQB6u6pGSpqbE
BT53riZqacSFOMGi0LdpTxa4fA2N/+Gec5nHlbJgirhtiUsk+Der5LFgGwlw
KTmCwDYR8NZdAWIqUhuy0/QRftfvDdpZpHZ5HR93kCUdBp87FdEM8mZGq4qm
qG4NL184iSAneV6KlYZFC6tVcb2kCMt7wWWViXNM0/mKT3XPKs1EBtbbHM9J
FDKt9TFqhp6O0/StWUstfofU1WQxrHXNZkVEzm12PjrFIqjRgpOlrFOPnX7O
iXmjpbSu3KifS3q8yxBJjtKtj/a7MjPn63yTwMxtet5FuSVHgV3qocYBx4yx
qrDfzmLqiBFBO3tw7557eoC9tXrVBqqu3PqQhheqTq1N8lUFdTm9KRkfkg5p
c1hdUF854pZme8jKb2cDt7PL5KUHlVb8LA71+HkhLvX4efF4xWAE/vgQg/ct
2KoxDo1az00yFT/s5lFp7EIojfYk9fkQSNMUsME41+ljrUWjBTEEkvjnUj2B
Uet6wAbj287hU3mvwXmj30rSgH5uEBzHnf95mzuzA+Kb98mRm+kGcrEP6IPu
WblMFoEEv7knvLk5vQqVxruHD4/a4yBxYLLZQ4O7dnlHN+frUZ/ksN3txu4I
g5x6GLVi3K+xde/xh8+ePZsQTmKLJJq7K37iIbstS+N8GYLEBFDalu0Jttr3
ZUg7W5wlLmHoslrimCL2J07MJ554oqdBEeV9nE+etiHAIg0QNyd+RBsgfnR5
SD2cHHB+wCQhLcm1U7wgl2HqhoAqKg2UyDwxufHhKh4FHHwf5wkfD495FHY1
xJpIc1KGoPuWJ7Uog4S67PHWMbPjTIZxc3y7zirY23YGzsvum0calWCN0gIK
EMpNx1ibCKHJetcNt0oKv97v1tzj/Jtaq4Dh6CGQyWUalMxJWJuqHwYXJHii
/o4FCzSKKESBS9tWb/La2WcEbQyiaDqwd2rbEsWXYqIoE8+GLki0ksykwYMH
57on7Sn9Il7vk0RyiCexHvUsp3eCStrtm5Ek7nzM4QJ8Req4EGwjc8poA5XF
alRQzdikB/tVQYD9D44RUj0xeP1ciFvxaPceJSY1HK5MYj9qSt8w16aH8esU
N/kexGrkGSnhVzh+lmsmL1ojRSmTZXo6j1ZYWLBKXeNCMVAL8UMki5Egejba
mK1SG0+xEM/6LU+GBOcyPRjOSBx17K7aZNV5fn3Abc8hZBJxr+36OLhodVnO
5Weo1ZrU4qV5qJOOWjtOzihZxNEf+0ttSvSpxx8P2uHcIX+tmHzSAu7+0RVs
Rsm94laRhNBVgt2V1EBLAolJ1F1PQk5OLF211h7YbY+d+e3oS46zxxRzhD1U
jHOTtGbgi37yJ1f1rifRIi1YSJq+q1ug/qAnV6qOpf4gmzsc530oSkFk98dE
pkbLnS+YedcFmNuyrUFt5g+7NxnRItng1atX27MuipmB75+aynB6f5CuByao
uau+N0Ma+5zCJYiJIII0rA0waKyumYxM5zfX/bxzNJH54HMrh4xMsqbBXU9r
qRZKeDw7PyCPSvOjZAWkp7nAtQrbNILQUnLGPD7Me4ai1LJzZxLcf+ABW0fI
J4j9d9xhT1P6BOFnr/gEkRbI12MqnKR01RJ0V6hN5gwBOcBvC9K5I7LqCyY1
fWtzgOq+Thajej9NMAFWhvPbWJDUVq8sViQjcsTWJi35HJ3I/drQMrcq0+oi
zXDkSk3hlHaYzEIgCXum1OOyAMkzfPqykdwxtNRtRtqGa82QJrPhl4QH4+N4
9yO4ChNL0ehOQhaCr5AFbB6/izFvdfXXP2596D5e2TDRwBFW11BqGTHdenhs
zPTqYfr5jU/oKRtB9+yUqhoLCOQefjWpWFPt60hW+Xfn+pLMyoVq+GqmFYfI
izKt7BktpyNpptXKldZrX4zTmef6AkZOiU8Jy2vZCU/zF+y2Rz+dK1I3qz45
zad1drxqAh9zrTkBSRzcYXZFNY7SC8XhJ0ex99ED16PNYTEwUUXt0aRyhHzb
PXCeTf3zsdtPRk5iK0n+imB3hvtfgMhJXiksUa0g1klfmxzoU61n+Xp1yySh
F8OD58aIIWoh9rL1wttsjIeC0jNWNAx4LOzj7jFawUv6wCjYN2d5TFvFfRha
sbHRgljK+UUv0IM4MDVx4sRUjVo9PmTSu+qCgrzWM+SYviCvX6pJ097Nd2JE
aLIrBxtdOR4fyYXZywb17dvXrLt///7G5kONFtziX9ohxQyebyngoXDL/Mxp
wfaDcdHCgK1hNEjmdFLKrNi/GRv0ODOT28crqNWkYdoHl1jF3ycEslTE56P6
F9W8HKvWPa9L/PrSrnXjbk2nVry9bo4Sm9yUlHce5Fvf+pY9yc0/rlw59dRT
c/Uxv2alAvmpWZrFr/XWlq1XZi04jbrjuHJs4W7flUSNpy60Ok7QByaBq/Gg
tEVhxIXWeykFVMM+XKxJ6CIviwvvEleZ6VrsbqkPiBKHrnJuktFQH2N0fb36
LGzQgWeNjV6E5Db1FanPmiCte2ap4YsxNUhqADlyRC8FjYYPH17RScxAMtho
/i0hx8fnL8duBbf9HJok27/Rhmn9djb0+pyfwFhtT1tgNkEDYoBUegxKz78T
6B+9OkAt+D+oH6D4uiTtW0nGyAjh/6qf7d0rxUsS04HjUq6Co1xSk3ZoBQkn
hhP/hg0blmLFE0YtTnrB4CRsyq+jHDuE+e+bvUwZmPUCuQxvPKFGMU/cFYMS
h6t833X/eAnXxkieHBiOkX/JuuR781vsB0H4vAwwNFbyhYECR52M0MgVCL7H
R53URhgIWWiBbKMrtDn3mhrkxoqWg8nSzoYU/EIWjgQEewl/koPXZCyHaocv
PThbmsTnXACrKfFektUr502TAqhJ2oyep/TKqEg7MniFMD7hnpFO4q5Y1m/T
z2SpNUpqgYtPqfVtODrWZ4DKYsnWJ6jsp+f61fvEkk28+us1F/ILKRBS/xfm
oLMmg7RDVwXlaNcaK9Jx4Djq+dvBSd1Rw2n3ubwCTXskfnv5wzZ+e7RDaPpw
ntSYIK542CYL8LeLnQWWhKtx7txY6Rle+M5RTgcNGgRPTMNhYePgoNSS10CH
0dqlULripjENOsaODdp1mA0WfNUEFTLB7r23BIeFZgjKXHzxxfZXxQdaE4dA
UgEqOaee1PjX8t9enReBvc0/3xRiuD1n4dIdP5sCJPV21zs3o4dL1h158/yg
PxsFW1JUkNPLyU2qu67RFBfNTSGTwBWBE3Zc6eEv8sYl5pPmYE389yrMcBO6
Z8e472C/+EswLI0dqgVHcOG7vCz5nGaYpv7nNpHGdOtuO9DPua/KpYSpOknq
mEs6+KzOVxwatgjIJD+jAVNtU8xqm5u9mooJqiUZJ03x9Qh1dUnAXgqIiJ5d
hJJA2V0ZfyinXTV4hi4wpTFATr/E2Bu9Z1IXPkDiq0MktnkGf9zh2fPVksNr
f0mYnlubMdh9hEgP1mpoiWP4LutKex63VsvVHR9/YR4psq/coQnoWkSdtBnn
o1dkJ0UGu7Wx2SFxz4+XGfFgJTPuFbaFclJ5KjeeQHG2S7++5Bf8xAX+0o/v
tOaoea+FG81PQWX5HN5tUdn/fMO26MWf3m29NPtvf6qXN7qgsn4+fKom4qax
FVXgKQjgwqiq+ZGD6IpGKwI3NqparUQ9d65m3GrEk6IDTs+wiB6XKnTj9daL
sgWpg5vSq/17snUpaYhuU2cfqw8Q2C9Ooghcn9xSoeDyjttKOXlcME7Ztv/I
SDD6yKnuNYHrk046yeIPeb+ELA7hoJp6ionJTtkQoosXa1X09ornJOSXZCpI
OxuCcq6aav/bu2NIChn09PAal3uK+5k1ooyW8vaWul3q69CTPxzCQIswWoLW
VzMY/t/v+B6HKxOmw0ki52sJyrC7wKz/7d8++BPKFCffkiF5zaPp3xq79XM6
U81TBonjIiuJF5RncOtt21Rvsyd85s4NSNzWOnCZYuoFMBJCYkM+sou9eNFF
F9kCCxzncJcF597YWxr4bV2XpH7rpSS3JSWF9eqdATvltJv9ZyOqkxrl7gzP
RrT/UKm7HqkX9MYbJTYt8/rMZz4DnlQWQ9WUJi9eqtuxy/kQ9zR7MqVZ7UBV
jCjqsyaUPSSPS3kNVWg9+/MjbvKHcN4NSfpoXDHAehhOPPFEL0TUW2BKmmJy
8DdWOIZMECQhAhR23DvOrG1U5ci6RwyjTurHzxQdWz/xdW3+WX3+tlEfcZ8c
SqEYDVMSvXForObHlCmam64r8VJpEmm7UoslJL7qTXElMyn+H6B7jZ0XLlt3
TWveUeNUtt5HL8Ginp1957FvxeWRmmdj/7nq3PIay9BdMBFTQlyUO76ouZ9l
Z9///vcV1SsNdiZH8JJov6qXlNQdHt5P4h1vi7eVw/HXzz3BdWZVnfhIUfyP
hWNpGg39NNdFmdNwpEGTTEL6LjEuoy7m+HN6GzX1GXXL8Y/8rn2zlurlZjg6
4syZGG5EMyfOD17H2kz82ijuHWPnSLZPDzJfBC0IOXPdOW7j7du3p01dK0cZ
2SOZu6rm4dMzhmPr2rWeHNyteWJq0xjtXE5wHu8/c8Zl+t2JR7p12dq+c2KC
tgUaB+92d6nXxkp0fA4iLth8/c4qARehGheMjPf2chvDj6m6r96yDRXDjB6K
vTWy5fkhyb6CYobZUjlRCeHW+TBhIQSKy7gT7fGOPbYCn568pmYanuiCOyRi
K8IOXvxR97rMGTWOH+FE/PrXv243cPTo0Z5I6BP/ZfAjfsj5R0kaFwjhjSbP
xA7gfAqG2+prLL7YZHO3YT2MUBd863HeSHxxtSQK4VI3K/IEblBghsPBW7cm
hio80/HH5P6Ykfaqp4SVx+5om2ZiuJVe7oaOfMcd6ahWlebTq7XKrYsTWitt
3/wmRTqiIgd/Yy/ztFLdKL3u2H+NXg0IC+y+fddpDtk4+kN6GXSJZD/Eonx9
3Qz2Pb9Z/L32kFf3zfMV7ZH33M9FKETjh7v3yOTRcS1TJM0uLjhfJQiXezas
lrO+1l/KK2oIfehDH8rhdrXxUZkbbbDLeg86H51SJaUTbCKSvDM2UtfQifrO
nvaNDzVap4Wx6jRIU2k2hkCUOYOIHKfvhY1pni1wd9n67fz5Hy0C4plnpFBb
zGDWrYvxcuNGJ2P62Ir1B3/7WzlYo5VG25Yv17sbY1DfDh6WYXWwrJcu2h7f
4RrfN62YhTr51zO2RC/+oo7iM/KY7KK/fXBz9PK5W9FIxWX0jne8w3oEKC0l
PuKyETjZaFDoL195xmYQvfTDyWRc6zSo5/jSjyebaU5CgsqekfT98rmjDCye
i00jo22e7t7lBdZgIui22KDf+9730AtK9Nqa6M/fvNGGeqko3LpuiwxqXUy/
H2JTpF/85b32zIBcVs5xQVxR8LTW1ZsFf9LSG/o5+MiJb95hNjxuzIogzeFo
Qe+GhuilH/3IVgDEeH/5/PORZSqUjPH81zPOsH7Rv516KqLTUWd8t6fEBSwu
fD6bF6l/YPGe6OULtmIcazsqiNq0/obkenlKFMlBQTE3kR+SKvqHP/yBvS9/
VKpoHno4xKDFi7+ZzrYn82jea6NM7VM36DzIqbGnA41+JtEw3+kvuir0iwYy
ZswY/wKkNJWPnIK/nnkJO6nDEF99+fOXoxIlzwzLefmCS2345yNumWkxfzk0
+NnPftZencF2jxw5Mk0vFscPRmqX4c8oN23Llr1FN2exLSLaumpVvKE/LSbu
m9w8KEgkwTPSRrinLD8m8rD+da3rIy1OK2vBQcJ6ctZiJ/hIPEH79zrXb1o4
TOJEoAnhJNNn/NFIr4P1rpEffhB7CBc1OIciWvJh8n/xpbbqx+Tsd0ODX6Og
NvrOd75jxaf8I0VDuBp5qKcaKpN3WMdeNVAkLCmqyVZmfiIIiJYiQasL/v6z
en/KsF9NGbbfq77gI1JG/lrmyLVWRfYXbIhX7QN/2KNz2tfkAK82ZT4WReIq
eHqKknlBLfw6zvXHHRgI+qFDh1pkpOaM+NAQfEQiwWIUF790HTcp4XdLwJXf
HoR2sRd39e3fbz4fSBnzyyljHvYqrvOolDG/kjMmygT9omjRx7p167QPf8yj
c9rX5MAsDe4WJ+Kyda4UXLX1cGx01weI1CB6M8+lzoq/kFT1+fPDVIlJkyZZ
7ud/i3LEFaQoUMfmtKOWJ0oMvz75D5jLB1LG9fEQZ9Ve70iqP27/V7Deo1PG
/UyF65VxUa7YR78/f9xjUtr1ToFVGux9nJDxUCgRf+afUXpe97rXGSijAKMM
SWEGzs/Yd/G1yK/nT3sPLTnK119/ve2gtrY2esZYA4RFiFPxDDFLB7hWPve5
z9lnfAufRUzz+5prrhGh8u1vf9s251esgL3JSms3P0sPvMcy5MjZpz71KZvP
REFgmYI4gLmchquzb4kvhLew4W/4KBfVoPybdfVywGIbMcQBNYlcrIDuDThV
AaGqJ8MYtuzY/dFlp8fvnL5l5V5IX/W013bmkHZG7CFio7Jao97G3R1hXZA8
4mQJyRWy8J/+1Cql9kiZfIZh8IMf/KBKbgOnHcZRAoV+laxSp+nv8nterV32
10lJbj5APeU3oHXWvj3oA3h5jgABnvxtAJK9y68YwbNp582vtGv7Hj9F3759
bR9UN+EZiMRvUhsNCNOg/94eQN+Qh3t3vGIL/5wT6u9LZidUBCWEAdECarvg
q2YJDC1eDFKf+R6EJEcR6Aku/OhHP8qho8oQIGd8iR9lUHltyuZYMRUXMtWI
C07Uy+KbbSzJAWjITguCmD5IeR3hSgqIjUHWxMC4GIz9h4FpSFiYCw5WIuJQ
LXuEbUeoxXym3aIxEB2N2UrcLdzCz3kBPQ0wZFRcmX7poA984APRrbfeKjQF
LEBmbnlBFyHqBFYI7wDpATdeUErGoQPifuc7M0s5/o2qBxsD8VavXt0vf27x
V33LdS6owIqlSPbbXtuESjdBosz4yVDtEzDURieffLI91EjvqPc33nijggjH
BEzDmYf2iLAhlT75a6lJ2az3vqLNqrYevVDIHWb5hsSCMDqBCx4xlFpWhAJs
iPoQNqtCrHwlKN+/XOf2Ey5JOeuss9TZDZT5xryvSgPzyRWAWUCKzYaQ8uHx
j6UJ6RZGzaqYMSiHFckwXFAnnBomLuED/uGhMJCpSd+Cvq/WwH3yKDJ1C0rl
RLW/HbqVbLWLpeuW9JhNVUdHHHGEVB/WrhGOfOZ3jVV+k7v+M21bWD7FMmbN
mpXGqthp6EnztmK7Lhy5tw0IEOgRVgVyrF27Vj6Bj7BDnECQiSH5QfNVq1ZV
pVGONzHpxuu5Kq9rKo25kJGTFq9tRaVb0ddxKRgrdePo5oknnrBt+Bv199m4
sKjlLkaMVNkwqBkaMUImn8ApR2x4ixFi8ndNNOJD37U00VEbiA7UW3LzpD1J
OOiCh7hlPUXSVwX/e/td+5IjT3D4gD65QkDLsx4Lj78LeUg38HGCRT7+Uy6C
lExJt3cCRD5x8sMbJQ3/X5WRHXXK+jzCTOVUWYYGM1m2bJnVE7h7CHFH0CZb
bTrMwvbGOBHN3xL7NwILPDffyDRIWS3eDjKl7nVJ+uLuZSqUsgFgmE6//OUv
9R3Ujc1LsIstN6qN9gUkxrjcaIEW5fOdTmoRGy+Ax9pAXExmMwXnnU4fXobw
uqhK60PaoUu4wteBJfEalOPg9dE22A5q485BATrlFHtiyf4tF1HxHf4ousYM
JzYEmzFTlpFh/jAmPsPW+MIXvsDr6pyF1Kbs0Xtf0R6VlwLIrK9//evanr6L
pUClm1QpLh4aPvf2+1Bef+aZZ+bxeh+UJ1cAymwj4R+K7tIeNuvcPAoFsZ/E
nVTE4EEoYfCVALqSIRxlySceUaXylVJO3tsCncMQ5HribaL7K664QlA+S+3k
EhWBN0fZDbqKgcIiEdFySy+TZaK+UUZWX2iUxcCgaJoYQMm5ixpLlcwOm9Gg
Rvy4v+3WXTNkh8LSBjldmQmFl7GVFOFRSFBWFi1aFOxD8dA+wuf14TtOXTKe
Y+D/PwduzLf7WuzjvAQrJf+VA0PU1KL/uXPnCvPj6IRcc4JibxR6B5Q+lmdz
mIiVcRqeRBJ4uOlGyzwWraJ3yra891C3pb9l13iecF4wQ2bBSC6xwfIqfpv3
QcZgMcuudG8qxb5Dw+D+fh/Ksg8//HCpgWMDovioORlekwLKk/NBKZ9kqeX/
IAwX/IGXoii70LJFaQSs4bmBQwd0l2mRg/Stb33r6Fel+z551JQK4HLuff6R
64WAJP9LyADE5cgG8liFXh8bs0DbQaXByDGSxsbGHn30UZ0iuIDyxD/MZdpy
Pg7IC22IBZ/gdK2aJIgajgWsX78+0Asxy9lwdmyvHt072k4fmmGMN77xjXZe
0Au3c0NX7Dx23tFHH23L6RAOgjYJ8hsD5eic4cVhWqYLAbwknye8+zVgh5A6
ygGUQgDU4WPK3IAHZyYMCCovXrxYmDlVzFgZRIxGYnpQduS8L/aXxIdZyYC4
eIX9l7aS2pTNSnPj93Cz4OjU6KA5m4YcQtaYFepmsQwCk0gASpLC6Zw3v8eb
VSFqvgrYLZwN3s7qKOvE6lilAVgaPGO2fngePO1vVHr0ADif4e81/0OIL4CY
NWuWXTyHV9gjxobhEmGdOXOmz+Lh04gXrAAEnDEuyoP6mHIjKJBySKwqjdtU
wuaxZ0BaH5mJeCA4abdy5Uqf8/AYMkUlIbyMbZNIq95WeDJV6A23J6aTAb7A
Hh1suSubJJ/4TifMJJytq1evjl8frw5UsANzmrCMiG9GYpIcy4MCr732Wvtf
eU/qPCEMTkfhM6R7ZmQUkDiJ68is0ct9LuCmqauIWnXSayAOYHS0IyDUWZga
+ZtoKEgEeDQq4apVq+QwFtm+pMm5GKyvnjuObv8BcRyOeN+F9jIWUJ2ySWlB
wx5uEkyd+pJ4VSdOnGg3CTcohxZEWnJpOaBCFeaAi8/MS3fokNHwFWKx4Ifz
n1svGKuhidEV05D8fRlM3IOfMnEwFPhdf/31PhN/1RE8f/1wV4akK0xDoub3
3XdfgmO1lneTGUOAhow0jq1XAtqcrkUi5dBPVRp8SxNE+1hAIdEYGk0BgxfJ
Z54rUtGHg70mrTrAOWyOn4EByOlEQTrGzo9IMCYIMQ2Wg4yBrJg/G4JhjbFF
RS+OqbAOIsOnn346upljfn3L9SU5rzSTW1je9n/dMqstVrh0P9UzJZvMjWvr
HKFsINbp01htDmGPsWoAIh+NgbWSE4mHlvbwyErm0isFlu99hbDkCIa4FbJh
WXab31hZM6kdKvwnnnvpqk6uYFV+yYOV7orzY3qEIRVP10vPcEnoZT99fcqq
Skm9t81Fp0ie/KMbsyJxOCEb73LFWuX4AhYSIxk7Q8+0wogkrYZ/lGrpZY9L
HWkZFc4ERBNDkCwJ0BC0/OY5wIG5yW8jQ4TAmZHMLqUrgRFC0p3CdUTzv39x
cVCUvDGiCX56Mc0mxsV07fldjh3J55xHFNE1d+7cYIWoAUZW9XJCs4KZ2CEc
8N536HBzWQq2Gm95uNWmwa3qjZXtuJy7JKQLBZDC1ScFC8qsRrgSShdctK6u
TrlSz7AgfTUyTeQ8XBeecVxlKzwuZTX+ga83etPEt+lvBAyVLcbeu7LCdkNy
2nHoDOXJKNV6kAe0YtqGoVed7Z7BAlGu9np1yv0xTnTP0Et4hvJq13RJvKb0
04//X34qEPHr6AiJVVS1rujb6pRnNZnParRKvBurNnOYGv3cfeKfqZQ689Kr
fO567Z0zKf/ztJqO8q1/tXfaLNMAVF0h0Gq8FeKtduNkD1PrP5OucruuGM7h
5x9PgZJABD60xt3Clz10+G11yrO0dsUb6cbK3shkhUXokbVC2JrpUVdTbkYf
y4GETyg9hUS5dj1G6UxCKUWjTPiWA8anc4gi7ds0Qqls4QmmV0aAIWW4v1Pb
F7OVCniF/yw+Ae2qbqUXeJLwXG51xGPTqiPayeMJlgAgnuLjjz9edPy04eLu
jtJX+EgxaigthTubrAi0FZzMzALDC5PCm5H6gJgSM6ZNL3zfyc0G/sh0zeju
ZgPxSzACC2LizAAPLv8l5Y+eMWb4jac3pVpkXq2sorsUpIxEdoHJ9DvpqysA
PdlMrABFk/iMvEv5ppdbuMycGeKt41OOKxFzkXesCLBiz7rpCNzoGYVPTkwV
w41RMf4Ae87G45ASnKELZkLF/fIbnw7IvH35WPq+1LpPWDh+f0IofGosBTU7
U7qz8MXKML97kY5gmrEKKf/Fv6KRfJzjMQEIYEgkngWSjiqLggpQgr3ZFO9c
HuzonqAcOxqMXhG98CW94dV1g2cgdcbj09MfV8RkDgnaKZ9UCu1cCo+hDWxI
OMG3I9CukL9UQicpe90zcJ9Tln2UfCIGLzBlK1gaW05US7hHBUClOXgIVIR7
yLKQB3LrcMA9arQJYsIe2QUH+9kJYJALVVO4PZ3Cky4gWXswNe4C2OKWZt7w
H7YN110aA0ljEnnvisRoWt06wfBDqMIquTnYr4DN69b+nTacsNPidzgkpQKV
XGaCroJOIjEANyXXx0k6J+iCwA/x/YKLG0j/9AWmktvkXYwSjIN6xobRB+9Q
RNgs+sevDlhYM0GFcA7pIJUQUsalLKfmgFR2o66uTpEatQ0aMSpaJbvB/uPA
9N7Zv7O/Kd0NCMNdS6zvmBJeSHbXm1KVsB36Jw+O8fmecX1IMrZcNMU7B63i
KRDZg71IahPUhVJZHiHywJK+Uafnb5ToOJJjVnDhmuR0W97+H2O7hbpxnPm4
lzFcgJPunenLMCwJ/Mj6mJBsbTihyuDIf2Fk8EI89m4CwVaWIyzmIMTu5hB/
fkRP1qdDn5a/FeIMLcOlsnejf+ZuZH9TUzybks3I5w7JZgBIQtWk91fIoXpE
VykI8Uo242z3bQYXyv1WwM3UOPEAG/HZUDa4j07tk2wsYUWyXOYFw6bPEu54
lDaDBNhxOfYKCQBFYRHoV2TmpnFE6YMzSOwO4f+C8wZRCMpJZnvwCBLwkLEC
3pD+zvezVuLw8J/1ymmX5TOgXoTvpCn5tpcLRIjBHzdLOij2/FCXj3Spnnjx
jg1VlLQqp3E6bmXVswX9LrzwQrtvXj/277T+JSpT/A4FWXQSd8uUa/suuWUq
d05ox1CsnGOT/ukLDU/mJH1549i/QXMUTLLSctYsc1Dcyl5j5m1ZciVmxhDx
DhxvA6rj4vuOMmcj7zDUEDL+u4xvRKErnjhKpdB+yqLs31lTAngML2dv/Xf0
habOlPKQAOuEb6RsbogE/StCghAx0zfn9PzN6eOmRpcYuvI6e5/72q5oK+CT
qbohZDYpqKerw0UjFeCzNttNqSptBzOgp/+Vsf05VEpCPhaEc+iXBcWUNVb7
7/RKhzK74G92/i70z9yF7G+OKhm+km0IOUC4DRzPJuWjJ1yoUkLKRoVD34Zz
HWr6hB22Pyp1rkhs4OzzoWw4n5o6P5QK+sjjbXk8kLxsFGZQ3n/H3/grpJZV
Ma/0+6AN8JaT4FmMz+15eaaf/u5Mh+25nq1jUj1bzqtlXSjoV2C4vMt2L/e1
Lhja4uFAOohPi2nZrOe4SDlNQndm7NMSp5T4tMR7yOd0jfdGvK+B6/gIu2hG
5FPxaclFwnSNi4nu6JZsm8QNle+0TXsXJwipQpNWdrvWAaSiixiO8i9isP/w
EokccF3av9OGkjBI8TtWK7qN77NhaEQje1xmSmCNu8hQu6crjByZkrvI0B9G
mSNlxnAGUFPPv22Ev+mf2x3cFBTg2UvMvERRVJuMC01qHLvCn7AlvgbSkiLK
n1ia7lOdub8hvGMzsKW9bou+Ob5kE4tXAnqKmJB3zAk9GWhmzEmmROoKWF0M
TLpCf2ToSnAC4vFN+4pxol/ZFTL06fl7JR4XkpgkG5y6QUabrwAF+pb4rgT9
Al9TbS5Wwt7FfeYDkimREcUKwylVBkj5r4ztz6FoL7OIiynQJegQTqFfFkBT
lljtv1Olp8yGpHCqCjakf+aGZH9zVMlUsnYkm0+U7ggCtie8qkLqykaKQ9+R
sypgSMXe9JSp25voAbtPltlgPy51vuLA8dfMvGhLn/mMMhYTsHmIgYqm/tah
J8m8ihlq0sfh9h0KDPoZ8PfXQOUFts9Dy/JYmf5O9KFD9jAeZnMApEaIQDOl
fVp4AC0MCaCaV1x/6uH4rjSrq6Avql/vSNsxS4a6OBvGYDi46E16hnLIQudv
5+DyvYocVMTAQp/AlYZXktHomuPAQJU5k4RecQAi/V2RUpR2MYUoRRVdGHSU
f2GQoragl+vS/p02lHCJ4ncos6IU+fffMiWcSQRey0wJZuSu0tXu6YrkfpmS
u0rXH0YZJu94hmKEPi23YDEFKIBpuCkowLOXmHmNryhFGRdtCduH9iUgSrNr
r71WaTvjUwUMMxalSN65b3QDijexeCWwbREd8k7mxDs3p7wpkdNfDEy6Imue
ocvhBJsmDt8e40S/sitk6NPz90o2A8yEkkk9wnSaMmVKBSjQ13YL6gggBf3c
cNJFHlYSJBcR7AOZKRFkwl4Np1QZIOW/MrY/hwCQ/TOJiymAZpIkkUyhXxZA
U5ZY7b9TpajMhqRwqgo2pH/mhmR/c1TJVLJ2JJtPlO4IGk1PeFXKjqRRVzZS
HPqOnFWWIR2X27eASJQinyx7Anb6xGlGHz7Y+Y3Wj4+ieF5ZjBJi4DyWvKMd
lqTMq5ihJozzcH1HKj/wJ99N1gCPQJfw0LI8Vqa/+7Tbtsp9nodZEEjEQvxV
Ke1FEfHdcBxEgI6zvMG4zXCPGSgVu7Y4BIomavC/yu+avBLpArqA+6R53ii0
gCplZh5//oZUx1tPAiBpUYAiPSjtUisJnPXgHjuhSPgjQU2vO/t32jDiGit+
BwMRHUhYMn9LCYkxY8a46RyXNR29Zl36ph8us5f5ePesyxjKIeQd5gfnZaR/
xv/FL34Bc9Lk0+x19Q7m7o354XxISuY2tTxAFY7FGJO73IL5m3eQL/jvv8v4
JnMD4LwiGeQd0+EQOkAw03EbcFTmfIqBRz/UAeFdOQRgk0BbJAhVpLIRoAw+
pu/P6fn7IxvAnRdYP3hY9baHvB3va3uEFwrwBJPcSDKpbOSLLTi4iOynrI3Z
gNAYWTqbt1UEOlmnDOsPXyn9MDzhAFzTOny/LBCmrKzaf6fqTe4WhAyoPMX1
z4R/HvcpnkLWBpRSfzr0e8J5KiWe1M0/dOhLydwMFpPXrcyYGQJln/1kQ/nI
1D6xIujDhwJT4g4CDvnplE7KBJSgOlyPd7TDG+MuSivhjlmck+Ugp2X6RDxR
HCtDvPR3ojAemuPyMKvASmxKYiwp7QXCvvMMLQZdsNghJ05tHFr4RS688EKJ
svk9sxLiVJJ1SNfgiTg3gBZKULq/LM7Jxt8mm03fVLPFl8isUZ8zAwm1Oa64
8Ebw+ACoajJp12jKOYXsm1iPTbuJ1Q5NYQKIjmid16d9lzKW6OvyCr0d8wjz
TLQZYA8wOKGP6UO70ikdqVOiLWhAQh0uMnRBv38ENdmV7LsRrjIFGQZVkClA
UHfeeaeFAsEc6R5FDcqRK9/8+2nToCnv/GW4ofXC1+x7bWstccMGZSe4fqq6
gl0An0Dn4ncp3wgEZfqYAaISiVSQd1hVoCJqjZtOtbcBOBH5DCOSq5iKoYdC
zayuueaaLBzA388eITcAMlZGZTiQDsi8zTk9Z3OEDJAjKGGyAcbKUTJI6dNC
i1PkuGJJ4IAJuD5L8DnAwd7BK/YPxcFLXZXVwYUoZwZ0whkdWREUMZrYICDk
ZlDdAyIiMgCFCApoWfh0OOa9+2gF8M9jQ4cC/0w2VDH8s1lAAn/kNFoV8K+A
C/WEhlK2/1Dhf04Okynf5+EWzmgliFmqQvuMJofd+12S8SmHx4TZyEohPXHu
h7zvKG3DpXEwJDBVEN1nA2wCz0pZQtIH/JJxqI0lPJ98c5k+HEuwvSc8P+2d
aDiH5oWMNRxX4kP9syntBR99TxgaDsss9q6Jh5qpoBhOmTJFNJzinskBkrgY
XROLEkcYehr8Pd35dVg0aNAgO3tRsOiblbB76JFoTxoV6Fc2UJF0Xe2/Ew1H
7q/37/mWgiGVXmwu+wHguFkLYpa+qlP6F5ktz4gtc63KU089VSVMBH0OPCO/
D021dA61dg4wafCS/5r+1EEifWNl0w8Fjerr68W0l+6pRUZlOhLdjT4oX9Mz
DjJ0eG/k7MXUaI9uoNNS4CSsGt2XHRXY4nOoqQCuOMDkXdo+FMMVzOPsnX/H
DO9AdIPM5ll84Ze7DcK26OXBFk85So4DTvCOMSnME4LhSB2bcdkTRI1UuMvZ
0+zlhND+eDq0BbI4jAWqlL5KvIthN4JB1IBhj+FYriu3ypIh5BN5DNKRMjRw
4EB1GDF7GK2gjZuCZAiWgU0v+jV9gZMymZoKUR2QIgZKRs1YR8nj0/MBm8cK
egbYdFZQDqqZxBhjO9YIaQIVcoGaskheZi8rhaooDmkUX6YnIIhuhjFsqCGb
9fQOeuCmDkfzAm9WwgoNn8sh+SOU9rjmrhg9PbpModHD9BmBCowWB037rUzZ
qDEyvNtCb/i0lYXP5PxQzxx3h1kNwtWKVEdaSvs0nx2MFxO92ENFsAiUQs8z
1Oq28i0l3aJIoSlwIoh+iSeKmwh9kL3NcyExD9wEBecBQ6lCrcD7avqudlMu
57dP88+7UE1RYae3O3hmGxN9Uo0JZ0iYNm9961sNp/PfZSq4ic5M3Ilz49Re
E6pH6UThBU5iRagKHxsQzBLbA52Y0KcE2qRbCaPSRWDDH2F75xWRRRCEVDCJ
htE1Tjp0PWLvqLSJSp1vPae9KwH1tQ6TSfcWIhzeQ0YrA8ImoHfQK3yXraYg
YEBd850QEDoQIARtQsEZM1i5KcTxBB1eWA9HAxgq4Qk1VpEF4/G3mj6kOzyB
DCXiKkv7SXt2bCoo7Q3j9md8isVQYimAB6U8ezDl2ZCUZw94z+rm77O/7Hix
phwr0baUqTVbvsFf5+qzc/QvG3C2V2A960+0xna8uylW4G3xhBhU3hzklaon
/jt70Xvq4/+9Pb0a437ae3frw93/i1b3f09Pn/E+WTBn3/+KOf1P4VPPejrf
e/zCMx2veNz+xZ9E6xe2RUsnt9u/l05pj7atbf27QbuvfdfcXIg2r2jTEZdN
bY+2r2v9e4A5ZLHned1sn10ODQ950EN9V+kMXpXHhzrV83247myxv35h/z8W
NFZOHpkC/EqfHVFhu7O9Z44vv+pjpD07T1d51CvoudJ25xaNdmTJpkBJk+/Z
Hz3xh4P2v3NHdkYLnu6w/338dwejYb94MWpqKKTRQzzg4fqsqb4QzR/dEY28
9GA04dbuaPajndG8UZ3R3Cc7o7E3dkfDf/NitHt7S82rAqlK4V3pt1YD+jce
vcVDR9eovslT0OyjB3VyvuI1e3in/XWMI5qNS9qiYb98MVoxoz3a01SQxLIp
9+2PxgzojurrWly14hoLvGeu745mPNzFc2m6cFxHNPi7f462r2+tkorFMMDx
t8Sfn6/zGOoT6izDna4+kMMSXxXxlfu4R6zqf2CWb/O22QJwcApH8LXvebNi
rdrXvqfd32V/STFmNnzgp1+Otq5udUUzqqMXxnTYXU0Qw2zhnkL00A9fiibd
vV/brTL9j7+5m+11RkR1NPKyg9HQH79of33QPUsrMMJvVyfGXQoUz2+7m/ND
ukqAN8ooAkPiCR3mNc5jLpU+OzzlmSMoqZbvF0OpzYV+XP28t02aoEQloTSv
1GdNSIP2L9mIvXsLFpjrX2jTIuF7GgvRU1cdiHZtbdGNmP9URzR10H77S9qZ
TYlWxfJd+1u3oC16+toD9tcH3NTzCnlS0YwcD1wGxtYXexMnDzFH3AEGBskK
hqbRjJlHYUp71c9i+PV3TfzD365+ng6bWqcyBurW3S1FPOwe95bLTVyKhrch
dzrgExcikZZgvVcy0ufiE++MASi8duXMfdGzt+8PEAwqANh+uwajADx15QH+
q+3WzN0XTR28PwA+fNFsZAD8tGNgAgWwC38MSTgG+H6MAuTjH9WEuGzIh1AK
sdTEG7HZgM4gTmFry0/jvRDUl2x2folXNq+WWSaqZ+6Fa/e8kSD8usMNQmUl
Nl+usXYHz5JBBHYg8+rYZlIYb1vTagWIvxdLJrYrl5J2ENGTl7E/SbstK1vt
fiQcKb26gV9pqLhEEoW22B8DmSqpOSA1SrSdRxa9S0RJwej8hfv2nyBMcJvZ
IMwbONueggQMC8sNzowwInlpm8Ob3I3LqJfhY3pARO7ZbY+U2cLqhJyqrfcZ
b55Zr5Z9ohf0AX6JbrJrW0wbPlOFARnmFbSD9pA6/JJ7eKY/0BWtdT4gaYcS
tmhCR7Bvael3/RwwuDBD8rbwjuHPFUZmZ5xQiWxrwaBLwfDcwsI2d3uCWaDh
uS3/8eeo8Fin1Uha/vMldutNAp2lbVHLF/9iNq4zavmy+e/09qr3l9+pvLPS
dnK3uoYcVwW6wrxcGdWkYT4PvNu9xePpjpN7WyqgRbub+UhXsFUzhnYp2clK
2NLRBgaGrLQdpjOqtr9Vdpu3tQRblZZHcJjDfm4NpJIY22SEQxpLu0qmWkZ3
yCtYllYUzRfzigaLDTYONGjQTNUFnvWJCg8a8Ny7P6HfZ9stOhR2e22MNGgx
JkJhTexBKDQY1Pm1+T22o+pfyuNE3lExu5m3uYaU4YHMcTHT0JXy88l84EOV
ceUZU2KuLHgip+t8sNFuxB8PBjs8bXCXCjTBhGXT2q3F5GMMKmExZsG8xw7s
DtrtNAJKGMiH3CzT4k2CMRx2Bmt8jLEwutJ93APVJrdYcGZ1m2RbBE4FA5PC
czE8RVUsbDJUcM0BeHqVRBgKwOixGE5vkGfGSrKM3kfDnYX423Wt7paaXPQp
k4rPLm7YaRHTIVK1rcuEWkoguLdyhbscPIjwkKjGYAZ3euuCBakkeVtj6KKf
N+5WQae7PuoKK4aDZ1tWtUYT79gfYILlO8/vC9oZy9MaEsbo0HbwLME2wZi0
HCcRKQSNkIcGWwIK2DYjHusK10eP1bL8+pgZtQCq0nwIiiDwjwEx0rw+hmth
TIeiGaY8b1e2JugDJ9rYGvbCwpxeG99U5mBRoymJLs9NgkaZmY92X491rWat
2xc9NK8remBuVzRj7b6owczyze7dxl0t0dhlHdGTizttu0Z9Z0i8sSVatDlm
GXJrCVf/uKIMwaYMGBLaT6LCI/3Io/RVeE/Xr7VEwBJE+FPxy+8Y6YWyLlhU
t6E1GndTyIsstl16MHhGmzoHYHk24bZucRYrps4c1mV5Hr9OEYz2IoTSDhZO
zBe2VMq8eqaOZup9snDv6GWMHdUB28KQnhazLXHQFNCP17UGYqCAMuBsIm1n
dOnCbd2BWLFScmYMgvjeP121xFHJlfJjpUAH7qu5MPFmrdsRz0Au4kabHzit
O7r1ue5otsGueRv2RffN3h9dMvYgWBirZH0skv1o1EvRyEWd0aRV7dHg5/dH
v3nmxWjzrpaqN7nuQdTLnj0YTVvdrvdVyUFYsh998ixGxjzLpUis3ukWCa/2
sj2SHTftt69rVQ4gzAoGCCoVPJH7zA3d0Y5NLUG73dtboicvPxC0w4W3ckbI
QMcYfiHo+2FhoGU0KeEj/rUuiQwQVM3TwDOUXLFm087VpLFFRcD1ZgHXxmxR
3EsWSW/udgO6Z7dZDd7+0nbI1gntIaKCvAaoRusXRE3sxjihg1wJ/64IWQn/
0jwVgbO32aDrnTPBvYO6hqmr2w3eHYi27G5xamO1ZaJffvgv0dq6VgW6wcvo
q4/8JVq5vVXbrTfkcM79L0fPrWmvOsM9k4NmIWmbP5evaYvWmh3f3VDQ20H3
7EnE8s/dsxJrrsQljC9jo7E/he3hEF/q8DtQBxeGNtymZW3WT+y3I9KFHee3
Q1lAOUhYZo+0N8GmtGsgAu/R1HjKIufT7BFB3AxNXIZKS5dOQ1xFNHysjiLF
bVcwZlPBQUIRd0WbIqQiLory+tawHYqmc6e8J0Zcca2R8clpAVE5jN1XuVtH
EHeyYZr3zN4frIFnNxreu6c5UW6317dEV048gFqp7RYb5nvt5AO803YQwg1T
u0H+qk+4ySDG8ILCI7yjTZLqBhg/8o2/RRdd9VJ0k7Flbn90f3TlvQeiS249
GN0+rDt6dFxntHBF25tdbzsMO6cZzqiHx3RFM18wukdT4QT3GsHxwFNd0dX3
HYjuG7E/mjCzI9pVX/i8m1+6cSxqcKbHsyr29RXzbmJQxKR8vMd3uPjZ9qDd
kkntlpb8djhp8X1k0ZHQR4+V1MzrIJLlCEdPM7uEMDJsDLFY/KzBhJko2uLM
crqWkgFm9byYNOR2Tqu0Lgi919YWuupA2G4VanJMLo4MRN4ha0njN2pWleS6
VeAcMxzY/hJWR9Ts6kkHok1Gc5BRhxi1d8KKUF169IXOaNzyjoBIaUNbv92M
tUYbmRM/+6TbLijRS+b0Wdbp3/pbNGvhPl0BaLzaKKwzDHB+NfDF6IYHuuHp
ovd893Kj80zsjNZtauUzi+nfufTPYHqVtBn8ZFf021sORpuN4rDA7Ae0dPZ/
/jVav7m1SsghywcgSs0dDlHKeaNh9Muntys0iVw07Aydf1hxzz8WCoRZwzpV
h5Z2KD4oQH4703c0x9nMQhiVas6yS14xDpW9VlpMCaVFmmXZz71LM5vEpErL
8UwTFUojtye6i7Bj65W8InY1SaitYBhF4Y4wyGDpyDEPbYcy7qzpd8c0ItvB
zdOunmHlbkm1fQx2P76wM6BHDLyrDLWY/6r4MpQTXTrBqufazoiQaMCUbqvb
SDtEBHrRGqMDna+jyRdo4I88E69MtKFVRiiKZi47N/Tprui6wQcgCm1HrPnS
Ow9G23a0aLsFy/ZFl91lRtvYWvU59yzdmSFO74oc/m5PF43viBaO7VBmVF/X
opE32VOjUGnUTvCZgIbYk9LOeT3sL1FOoRdR8AXv89TwjCqQyabKBcC+oSqu
gowDGmkZtAnUlEMjHu8LQ2uFjS2xklNI4pVWKiwrwnqUI0eFis1IEKftF2Ez
xO0KUVXkUHV7tXp7yPHBy/XO7JRRRxg7crzj7iK3nl7aEY1Z1hG0wyTF1vTb
zTUm6l2z4md+5tD7v/Zf8N+EJsweD7g/xkjB3PEzOqKnp3YEfHjY2M5o7HPx
M3H+mG80Ciftps9rjwaN8MfN8Y0E0dKyYRNB6w2L2jTOKZuGG1dia34MbsSf
DtqsAGFVJNPs2NgStEPHgSx8tM5W0tPreCXLGZrHZA1LsIakAbaiG0zSOaoV
LWenoC9Md0Vr2A6mvSie+btitDzSDSjFRAQFg0IyYVGPap27IOPyrW3RTdND
UkHnRiXBs+anCqBzbzRqirSDoQ6YcgAfiiIj6sjz6/eVIOO7v/Rf0dLVbYrI
IM/9o7oCJLv78f3WpvSRbOPWFquU++3GGeQcMy1EWuYHWzbtNRN20qRJFr04
ByMeETed5yaHzpOc6BAhiOlDuhQnUQkkGKVmeHOMfwStBNe2r0/ixwJFcHmD
20VpN/qaRGURnMzWj0sKsvjh0S1O/a80kCVSoeSSHIsiyhEJiD4RGhE2tuBg
KAuxevK6kNehV7T87iAO5aQdZODkkkNlMS0BP35YGIQ7RZ57LjuZrAw4anGn
URw6gokNMgwTxunv2IJNbdG9s8PsC7zKo5aE2Rck819h7M8mw1nOdIDEtY1z
DlH+xBNPJGxLINbIR/cciOobEkMW7os+YN4pk8DiXLQyRgdpB0ddvKot2QtQ
xHDoZ6bHEzvPvUESoy3gJODsjLHKPXCIYZkZwzK9Pnu7JtorCNCnlzkvhiAt
MTMJqAvprzXmwXMPhmld9lvn5JV2jbsSx8uH3czz9Ny0g/mvKPAmcjojO0qQ
K/vu4JC9q9YBwTp9WWkCx/Xq1pAm8Ac+HsYrC8a8KgwMBVhhTyIuApqo0cvf
qDdgtKcKfNortoVeMvg0SjP+Enn2gsF/8b8Irg9b0InjL5gYsoBv8clIO5yJ
j8yPN/9TDr6wFDHUOE5MUM/wXB+G7/zCf8PeFTeGGPY/f2lMlmK9rlyf6BlC
JRNnt0cjnu0M2kFNl98dUpP/7XmuB/RnAkDsH4WNOAYWZABJUDordOcUa+X+
KNQbFreFXH1QolXI4vDEkObrt8MbI9ld0m6zkfOSGXaqwNfoyI5gdS4+2xak
lcOohDs4p8YBLH/um8bFYx1C2FH2zY/pi16eeSGoBagqLKRJOd1agGetTGNt
FBoT5FRKqvcoBMv80dBi96XQO0OpQREG5k4JI87/UR8mL9evl69iLjMKkGjP
MpZh9tbpiJUpSA8R1DWEoZG7zXcLNoZehPvnGKx2z4Q4OPNPIiLeUCaKSvmn
P/3JJ463fOa/MTcVfM/Nb7cOSB/pJz/fHj05KfTnGpMzunbwgaCdr6wLw6LN
1rp4+he4Z2iG4FqyufFcJo+P8eYu94wgCjAOA4lV1cLZA4ZBGEikhSD+HLNv
K2aEkuF5wxVXzgw9cGvm7bOxeb8dXhq8Nb4EOYTEC47L4o7ksQH9ocdD0yjD
r6eTUk41TZAE5qbTEpVMsFpuKnqG3TC1iJxI5JscenwLRuAWrozJqYhMUIfl
GDhHOuNzvvHMc6+WjWeOpeCPhLb0jDNPZUbDX+i0YaWCJ+5WGvP3tufC1SBl
cGj67XDZoGnVG5Z+hpsWm0kdYzaA0v+cXhWpUu1zmzrDRa4ZFJIB3pw5i0O/
740Pdkcbt8QyWvxCmCIiX6Td8PGd0YwF8ULkeBiijeO1HAcOrFVR3RobCxL/
0oMR2CWy5/+Rg4te6j3B1j2NBSEoXDO4aPglVpZz/wSE4tu2QlBbjToiOcb9
YpRfOK5DbnY+BA8/+MPU8cvyN3hiVKtSD3+as0gwJ4108q49Cnbapg2sag2R
HnkxNMwAswb09UVEdM/+mOD8Zw8nga5/jglGDGtqJJCVJXMKLiUMb4NLDGvp
lwSCldvDzA2ULvHeCNrj9cHT47cTpQtzUtqRcXCfU9jEEMErxkFvRxq+7H/D
2f+PtYUFi3D8CP8/NuWZIP5jHuJLO4gDIvHbEf3CUZQQSLVemz1x4kRPThzn
MGLVirbodiMcrjHm4I0GxZcubNOcHuznp42QuPmqA9GdN3RHC+ftq/p6pSgH
EG/utva2Tw/4ifAB+XSDMJGELmlHG9r6dFNvpCp2ud+OvO81LowkgqinSTQG
MlZwCUZh406ZMsVns8VKW5p7Ko+Qcq/KCGWQkhRugxFF6haJ4hNCTm5dqmuK
SI/MkIYw5c66WZ371ZGUdDF37lx798wll1xSeUBAcHhnY6yW+XNqwBB4NrbP
5dntM7rVBpJnd8zcrxJM0wWNrT9xZbzGs9wzEhEpVGDIKdCl0acaGhM1hwjw
7EVhvH3n7hZj4secWh22pg0hA5+eiKkRQPPpyRdgn3HPcN9QvyIm9kKQI9cn
2ralJfrqOX+VE1fRSgP180/9WzR9UruG4pBGNxjZMdAoanXbW6LlS9qiL5/5
VzQ8VxK12j5b58zWj1eCp4mkmj7EpmQITLBlOEnhw4TI8uQ4p1lhArUj0fbu
Dc9w7WkKdaNJd+23ffoUVy4XiMw9jD7SwHwlxu7iG9z89xglaZvRPTcbm6Kp
ruWtgkubWqIdC/ZFDRtatVJgmicuj/zyCrb38pG5YFhM4bIDNgFciQlH8OIQ
cW3a3LDwyEkB/XpAmJJlCc55394RE93hbrnMiVRMfB51dXU9CF0IxcjAGDYP
zgtzxvAiLN4c6ob1zmvGDks7gtfF+iJCco0LiAsFkvqG1qEUGPCAaZ6yJji2
dHVbdM/jIY6RrUEqht/O0K91wRElEN4HzW3fEXN/qUKB1kkdFPgAADKUEPCC
yeNCux697w6jasya1q521E7TJ8+WvCDHPIxpNLIzuu/Wbg9fYkcGz6ZM6NB2
5hv7relXc1nK4jZwiM3tAA4E8ST4rXxqcxLolnY7tyRRFaFJG0Fx2YDSDqlY
7+AlNJkXQZG8F/6dfPLJ0YgRIzzd4A1udfUGcRddejBac39XtHrQ/mjy6X+L
6ubtk9QblOh1RmwvNvSy8o790fTzX4Z+z3ZjZDsUSxLMpUxOdgXiUEQqxeGv
XhASgzWzdoWnPK0348qYqrUdsfbBIdEUcA093eFTq2ideHN8sqwonCOE99jC
xACTsZ41Ik7c2r77TzRRTZxL8YTsaIjTryDkc9yzIUOG6IU3eTAjek7uh496
+PJGTQ4NF8I2QoJCUivWtkV3Dg9PnJJdtcBp7+e6fSQIQhIOHhW84KRXJbxW
RoVgn3JEIDNG7N0xID5ILIElROotZG/XJ+127YyfbdnUou0QYHy7ZmWry7HJ
QXRPXnJOfdGEDv+052KnY/lnnsXaE5rbtDyuPuDTpsuYtL9Eh2hqSL4VGy87
khSfX0Jf37Rpk/bBVDc6xBRDeqcZZ8oZf+WclPItZOWiPx2Mdq9oddpGnDu9
wvCyZYA11gmj5nqzbKPxb53WLsUkSlMA4iR9qRwqrLak4maA6YXp7eojVEUW
Y+a6MAvCng9eEjpnrcLrnLNKkWsSr7yjSHGcgOzIeSrFoX8YXlw+KuVgKacR
ZM+vm3KAJPFgaBIE0Fl9wiPxZWoRIeOWJIGFuKy0I9b6kJPIn1VhIKPFQaeD
UdOeBMMeGt0VzV2yr5S0loXOuEnPQ6ohgElqlHQBkZaZKVrBCdtGgw9Yd9u3
tajv8lGjPkrCl/hQHnuwK5o5NUyinj6xPRrmaghIuzlGrskzSa4vxeeE9Diq
PmtYpwAGL6NLrFSSIs5FsrtPUu6zoB1J83JqUdX3Da22modPemliSc6WSZ4E
7vtFixYVW8vVqKXREiNIdi1vU1ZEOZ1VLldAdIX1j3fadioO0L4M411q5LSh
warv5jBoK6ycCqqkAU8pOqlu7cBRRaSGSjo7jKnaAJazpP8pJCFUUIK6JE3i
rSC+Jq6mtEqlgarMQYrrp4YnsYlpYfc1eLTg05a0u9fTTqU/YlczXTz4synw
kf4Iz650XgXBY3IR6naGwdAJM9ujp6aEOqHvfNSY0Ko2mzCZUE/Pkr7GF1UG
gAYefyimAY0HOBFm6E1xafcurMD4mbRDhOGN2WRsHaGpuwdakWZ/faocolaF
R+tkjXgbJcFMCAbZtWm5J6usF/I4/UvkHNn9013JjY8IoZaJhYlJSjsQiOKx
RQdlNowK6ReSERGn6SMGHEuMkVy/JsmNQsQtMaA0IkyHXmv4xhbncpd2dXOS
BO1zc9CpYMzZghPZ6v6fnJCWkhHW3bWh86kAbynK2yuMTHIwHLllVg9xUyLr
we+Wo0uknvmYi1r4QlE7DnXeMDXMZSE986kloSqHBhAHzhJ1kbM9a9asKZlL
MXgen9AZPTurPVgi3km8lD71kiF09+NhWqrv1lf/3+44CSOhtgoSz2RgSGHV
8lC9QjTNnRnKDDTLMSPD2AEi7ckimbHWkMrdTrsQ7y25GSUom0gscoKMtaVp
QlcnaUKBJHo+lES+m1La+UagtCP2Js9EYvW4Vku1TZowfCHZXc9HZaT+loSE
hPPg4Nw4KkwvXHXvfiUrwZHdhhMtdyBTBd0sZLUzpd7tnlWa5FRyMj9w1xeI
eY4Jky0LFKqaUXRIwDsro8kgEtZu8totSIw+R5xiI+JMoxjxxRdfrNDNDFPL
9uP6F10yjwInp1C0r19qWNU8u8VF5cSOJq+J/JhTTz3VJq3X1dVVJaQhcCRl
48HRXQGdzluSPJMZ1zfE3hZMR61l0xinbfj7An0L7X7agSMtHS84PrR5Y0t0
23Vx57JdKwxvFfeKIOA9N3erc1O2C1WUAMTOHUkOOdahqKJnCvPZulXceGHY
Gy5n/ZWNoU+TDEB+idylQhwVY/zBfVkog2PHyembPt63cprnEOJ1QgicB8AF
mU6eG540knB0eKbEKp5XxZDVwKZR6hbjsPUy7DHy6p2/Udotu6E72ulsrXf2
nKfIWfeMXC277oxKCamOCBW8CN17Qv+gTdZaFep2NlFrWrhftrjCDaHko1yL
jXs0lui54IwYQ0RhzFIqPxsntLmrMYlpiNW2Yhs0HOpa0LR4aP083cvct9KO
8OJY53kVWscfPGLECAsrrLYhQ4bkwpDDPMQtfKpH5xWJLe18SSx2KymOg0eG
jiUC7MQQfapPS1Z00xlbdIhtqjFJxhelUhE4FJkt4NiyKeYTfrvRZpunTwrd
LjcZE2q7y1o5w02HwyvwalDx17/+tdyg4EHHmnzb1yVV7Eh8ES+qcAH/+JFg
FUc16ouisZieT18XHj+zwtyZqcIFepqowrlqMqOUBTiQrns0lBLNTQVrSe7Z
2ZKwVLO+3Y5KZD0wjc0uQ0jmuemZjmjT2NBrxHfLXRbLuw6dg6UFWTIKXiSU
pFIdSsXCbfIo/7IkYqkUjSXr6nop5SPBHwwrElrL2J27fHtI+dwQBkXLtdan
nHJKT2pmSRqZ5sevaY+GLQhH32P9Pwet/0faUWvrmskHgliab/NKO2xjOXQi
PAD+KrdXcfHWT37yk1weAG9BepPWLDzgrseSnH1ph+0rsdEj4z0Z91yHZlDO
bbdHCH3Kx0bgZguinany/n5jZgptCx1Dw2NGhEg8ZUJHNG5UyBcwae+5OWTh
6ATyTJKNCGH4uwQirl27Nkg0sET3sPX/KGh98X1cyjPf5JZDAiIxqQEiYU9p
hwm9xRGdEH1a2FMAyjtSVZToq33H2zbDflYPDoUfpLrJKbuCNGwuFrCR/9rO
WMPR8ptDdrbO2BxbnZAUsn4luXOaC19cQKQICZWk70pIUA/b2Hho0alfz4pW
kiapYVx4ysoq/e5ZEUkjI4mEC8km9yVUkLQgMERIL9saKnzkjS7dElqXmOKP
LQytRiI3o5eGrBbCJpkhIeQ45wNYcekO3jQw4plnnik9T0U4hmgpv8QcEaom
u0HaTZmT+H5F5N7nHUwQSvfDNBIxlyIJhGXg59dcc42nekpv+KTISvBPzJCh
cIsr/SboO+TOhPClHYJ+fZEzZKLZ2mcdSgtBE6jyD0aRGzx16lSJAfqCnMgM
5ylV8HlCWzDfCvcbwtx0P2wqNO0nFEk733oXmk4Lm8oGcHUHPlGfaqzQHhae
ucBw3rEgZPUYzituD+0g2qwqUoEtxV8VU7yeka0vRIvJP9wtBnblqXySH55Z
cyVARZu86owjpWOORg0OA12WhutCaNpiF64y3DH+t+5UUUDHNTBxez8lqoKh
42rXVwX5D3KSTYiPw/sc3/TRgtNGckxT2uGtlspCshA0dTlxIe2obyUnk4SY
mSXhTO4DJ5qBy9zTh9J4ImeDOMnpk/UGo4Tf9FCY/wjp3/tEmH9oDYa7YqGu
laP2xOeZiY2e46aVV9uhSEnXKi5GqxrxSFhp4gHDvpctDitX1O+OeUGzlwpD
Dvr40aG/e9BtiTHvZwjjr+B0DNnBHE4ozotAgxa/skCe2KtU+hTCpYor5Y9j
NI6f+bFXaUc+k8Re1SfdmMRe5ZrjtNirFig08+bOIiXwIFrWtM0Z4Z4VJy7q
PTsTnIL86+aFUQZYxLaZYWYav9c86PvNKk8sFLKutCKNEjh2S1F0InZ3h4qH
zWx3pRi0HUTvinsqge90JQoSApeh5A5CQ9xVQt15pQqD441ETyXSKjS9ZEty
OlDmZAtrPB+qeY0u+5DTUdIOuuf0LBa4RHmYiLvENKhnWwwz0huIxfpUxKkP
0ZelHQcMkdl7vGKFVGK6eWhYZo4I1irnrTzPPSspRxHI5VHDO7WMsmAD8dhR
j4baADfMPPZgSNsbzUh3XF9UoXdnIufPdJhEFi93cYFFCBeusEyzrqlaNv6W
bt0pinyKNSy0aAvkuZxUoUVbtMMdFdJ48YjkcKK08wvzCc1m5xL1tteboqJS
E5V/6IQrV64sJd/NE9qtmcwvLdn9QFdUNzd0JhtStiY3fjU9cGeY5tpHQsPP
l/JCvpUmJoounV43R/OWtiQZhUqEGMRzwkiCPdHl4h1aekpynjzCsNq404FO
CokV+UYKsJFtylvyz/YKz4YqiUI1efWhfAqs9Z5xLn3FtqR65X2eTSztOBcs
yVKSzUAiCkYgh0+pW2ZmlqK8+KeuBIT4v+ctCYsZU/Va6M/XrYWepR2/ec4v
0QPKltRQIjf7tnVzeDKNrCXSLRCpPmnPmh4eIUKV3lB0ZvuFuQlpn+kmwzWT
KPQFp9dhqC9fvjxBfYlTc3ilqT40aH0alX3DiJYCPLIf1l8+KcwHgWbnFiEc
J+jlTgm5nreyM5O97TF3RAX+joEDB1pF20DXF2QiKEXtwAm2a0Vogmx7rj1a
Nzz0PWwxU1//WEj14k332zVuTZ69pyzbyUxhrLTsj5I4HmuXZqeke2uSNKwk
Tsb1XWFlNptANaioLifswTG0IhJHuUHEXHXVVZXU4Jy1LsQDfFr4sBdubtMg
O5rzki1hbYiH53fZeBe/3hBj4thlHdLLFPMGQxnOcJ77DmcEaWZcbD1t2rQ8
cJE8vG1HSFXoyoSUd+5uUaoiGRmXlk9VFLaQTEXpj2pZcmBGHHCZ5UXcnCRn
UfrdZATWXTeGIv7Bu/dHSxcVHXYw3HeLS9yVbycY4pr4TGgjEKWWiLZQOqF6
PF8YzxAKsRk5bpNyxwBnlzevaBMWHRezKCQkbBM8hBFQMWDtglCAU8ZODkDL
2qn3LmXrRDAfwpnPNAd+4FXcbVB92YAw8a7BwHjZjaG3cMUtCQfQymA3J/Gv
o+KeN47uONljR3k5jkLE+TWONDfxgaSCXVCiGVf2Xo8kG5JnSrqTEpX7OP+Z
i5440hWf1wUXXGDBSIFHwD137lwFc2aQWsbieMDvxh3EbI4T1CxByowpzUGt
UlRBIWsM6punhxW2qGeEkb2joaXqizkUyrEaSWQUGHOs5paii8ooZTfsmVBV
FUrG6pV2W7a3aLWvs92S04qtBIoTurKQqTyz+vLwkHTJy7p9QKgxrFuTJIUo
6Rr9WYT5WW4SIA6JIkRPDKoncBehi7K7fHqo3GKQYtAqcwTa85OqHdLOPzon
NIkAl5K/tSljCE0ewgHSPCe72+dV94Z56WsfTjzOemrfUG3DpjCNljTlFbeF
Hg+i21IVR9pZQ5oUuS0tqel/KjAnJlSiVIdf/vbQHWCPaq8vKmSNuTQzrG1h
T56641FFVOdytew/2IABak+OZosA9Snok/f91Va6k2rUBH8kiVLwBtcVR3B2
NyUJpZLCRbEQxa/1++xxno07W6u+xLNA//QNVKEvUiIlz1/g7ivN6kBel5wR
EK6M5JUUy7McgPLrwshMnhjaFc1/PlTBdxgNjOgumrBgBUQrBCqzQxNeV3S4
ERkqRCvpbKWpdaVCkexgo+BqTubaJDlYSJEzNEKeQmJ+MEja+eQpW05gaZMr
ZSek2NOTqHm+8UD27DE7gUeYZGJlXMO69NIUTWI36uHWIutixwtt9rnfju+E
wj9bMppVNN1bpSV6LTLnC8MS+tJ2NyQ2p9JcfSIRHc3JORtsKhiUQKCi091C
YSRE/nbsQcK2VXJKidLFLsRq1VLKqu1q1ALB1EZw2qrVZInabtrVIsU42CBX
qSY1TVJgT3EPkXB+orIEYYWKrjeSbOPWsPwddaTETyztOMiKbupTW7nCMqOK
arPAM7A2yaiSfn1Hr7Tz9U09nTSmI5o0NjydNPu5hD4/5sCXW8Ap4063Usrk
xqCnrzsglOkXHBGVhBwMuVhItpvcDLk6RkuqP5wkXwoK2uIn7luhzLwTq2W9
17LrJExKppY8s56ioaGz0Kb+Xxc7juVZc2Mc08HLpDVxb0kytd4nzw61WlyW
/Nzp0iJ9GkVVmhGa+LasiTPxBeAx3R4MWGEBrdwVdHT3Uor8pLQTZjJTwEt3
4YUXVh6pjSdnA7Lc8rBye+uJrluSpkiS5Oiqq/+jJQtIoPzThIM2tosDypC0
K6xTa6urgJ8oOgSezDanmuayG35xniR9ucXGZfgldggp0tPmhQW6SJ/cvD08
9AA9Sy1b0WQzC+AIsyaiKikR0pGfYiHb7wg9WMBqY0hJ6qUeRTSK5kJntHzC
PUtL5imbFic44d/4JdDk+Jy7slsJEzexuJbkW7nA12/n13aWdmi+Uq/uNLeb
ecdbs13Z8U4vvSa8nE4CO007WgIJiz7q086aIck5A2m30ljJu4qql+CHkuyO
k92cDqE6Xsb1lWWr4wXWtK22siVknP65BaV3ft8S2nz21LuT+0rvxLodgy2i
d3AIPIG4yAKdMmVKZRV5Y4ngnL5aOXrFtta3OABxrggu8K6b/yvaVt8iZXwo
jfe+2/7L1pO+wPUEX8SrLilUv/71r4lEJYxFNg6yFReRkLdf1E7ImxN4FE/3
26EgSxhX2sEarnI1Uc9ykylbJUXdzxM6Sg4Sbd+WJF5ovGJlqw24+gOTSbmx
qMwKRwwJ8NTvTg7ipZF5BTlwwhZFBeN4wwp32Zm04+YZIW4hZD9ZQxDKJ25p
hx4+vgjx/CqtQvB5txOUdYQLBftHGtSTfHupHwkpLtkamt0+ITkiIe3kQGC9
3tR2SPZ3xsVCQumZtf0yJJcN8Domr3fK7Xbp0Z6fx/6uD7fXZl2NDQ+C+FeW
BDRfE/3whz+0J3BhRgbyFcd5nX5KHtaMte16UQ2HaWU1/4e8N4/3oyjz/Y85
52QhJIGouOCGjjqKoozjyoyo6MiIXkdHryPK6IxcGYfrOKMga0jYw76ETQhL
gEAS9i2E1QAJS0IIZIPsK2ffEhYd7+/161vv6vpUV/e3ur/fcxI27x8n+XZ3
dXXVU8/+PPWUqHzdpuze11z/iCVyO+GqPCPH6pBDDqkCyiNmiVUY2+dqGxVd
mVc+43ZL6oTi8AS1w0WsnGqF/zCQpd7LTdtAJaErCod8kEO58PH8ELi3oFC6
Em1cnmK1IxVDZQH9FhIjiy50ntsqyq+rgAkh0MblntJESIZ81uV8+A13Szp8
ZSfRsS0n6PbqyJVB0pWyrPWNcCuU6L0q5lvpDk/h/Mivt+XgTHblosLhzDYi
PD0fG1pr1gJdAIpWO+t9npSvDWu31RsOwfb7Pd2QGzX3BZ7wCCZRziCqFXpy
D1xinoxx6F+Yt6GsKHdo5dudl23E9+SOA91F4AsiHnIn6iWPD0U962+6T7fP
EfohXePc+/onu1eI+JBRhVOeNZw7d25TraRWkWYo0qcCLu70Ox8UI0O5vqtQ
EY39huwOxqWsdsR0MbBDyq1byUXrvmF9Klk3bcpYAZ6rqwsl5MPcaOERkaIz
JuW3fJGedYdLeaqi1wby4toKklrna20JjiClkgUeLhxvckJiW69ZkadIylCr
ypMoN1Th1e7307PdVJ9292KnSZR6y1nf4NBQrS9CGpJj34OvFAQZHp8HH8Gi
W/b6E9t9/fpagf5EPv1SKZTLb+pxpzRXp1CGJ0M1XA3REySAczzYE1pwqsVu
6eyNmPVPFTfamIHbZm+4qN2782TIgYUKUBErJ31EKkbpxn3TAu/WUncU7Kmu
Lzzb8FnyqvF6lBXdCV1T1MENqYzqFaI8rcLDZgXYhxC2w83FHqOwnaHq5Den
b7NFo5WLVF2fSGtEJuO03+WTcshaxLHMrnq/G2N5tt0o3IIoEat22NAK0FaR
Yl3lRuDjQC85o7TS4QH2KggHEbmSM/YPd3ORSOlHB4RlRNpvD7Xn6jNC/jr+
Ir2LPELtJLY5IsSR9TrDus3XBXj8xAF0s9S9kAP3k2f3J6sfyefMk081a/f/
Y0lNHl980Mqf8oVxVrYnc77xcrLk6t4mbYQqz74eHp5OZf/cbj5NyJVUFPGU
S8tgn6Anv5OyjIvd3OdsvcQ0MJT+PWprcGg9bEa0y3Z21CkjgyVwfq/sxIxi
gELgviA9Fcw+OMV9mrUiyVg524jJY489tooqqYjBLj+MxeHBPUKnmzdnZj4y
86ml+cy8dRvarOW6cnV2ch87A6Xx/k0wh1hlokvOzZ/YcMk5/dQRzdEbfqe7
binsujWq64xpeW6AKL30/DzXoPLaxS5E93kH1UL6Td2UtQLYhCAkLuooGyFD
eL70292KQGUuKdH+IRoN9b3DjVMHB+v4a0leVuPTbmhDONkSfy6zwJxF9nOo
XTgbCrOtmtvly+qwWZC8KHRf81trSZ7xwrPyebO4qCjctubRzuwwjLVttnrU
xmezakBwA9xgRn1u2ssNqzyDeqfwMC37vG7lxV2Eihf5vMbUX3XMVg99Kx2P
8hsE0xIAd3R7UgyKThUEJZ8FH0iRBrhG3HugR4MTKWD//pI/2PNzTnPdUJQO
lJo2bZqNyc2aNSuyqQuaUZVeX8LEmAlUKX1gfpfXr5GU2nmrryJVdXqOrxey
osNWQswkY1r5BSkdq/yydk2mR4l2kGeTj0tzkt8c3MOxtCk4poFxsv1+2dKO
LI96Y1qndOkzHb4/5K3SFSUja1NoKrQQL5PMmpKXtGZ5FtG++5KsSsY7HHho
42Sc5KT39kOlruC2zaK464I+JweHtKkV3MVlfPjhh+d59NLUuAoWtiXZsLTd
xmtWGOX3+c1tbw3gSBLS8pt7fFOcRKQvopduWNYucyy1SPOGNdEkvNNr5ndW
nm0vT3fsZC/xwkarKY4TIhIDvNhJI7xA03v9KlhTEupc1+ZPWPHk92xWsKpA
fpw5Qs1OujTYgdbUeIThdAcZWAnzg3UI5QtT8DU1jIXAYZgc+aepcjaDJJlW
ia00ZOVfeVOvb8fhaoRn2XGnJeKsB/l+RYH46bBuwgIxKaK02npOUBahWIy/
54OULyhn9q35IBvOoKkGBaBOtQsloNpRTfh7X/0DaRO+HS7f443MwcV7QAQm
cq1Tr8KJM+vbQi5tWNMmGsKVi9uGR9cdbQ8L9/TFweFX/dc2u0eOOI0x/jx9
DW53aXpgDoY1wqGwQ2ndIuteyTJNjZk077BtyC2HZKNseu7dX/+DfQaNUcOG
zbLOprOh1be5tohBZBvFMQjjUPWQQ6AphIELCJtSZ6HHbNXCme0aarzyoZdf
Rni2//Cl9Kwh1MsV7Y56Wmyt0fb/8XKaC3Fp3ztFOKyy04nelSccQs/sn7Gc
bfFiV4gsXdAGfPb7X/wHe3V+BC9S1X2klVQ/PeZFhSktAnC2LNvWDA28zTVD
OfzBb16yWQo0gXROumTAvmoUxjBBiaDnRdf1+VItNWVOzNowko1OjJMEdO9d
3dZdeapheiTDPrO4w4sDdD7il1kx0J3sd9Avf/vvL9gST9Sv12kO7H5BXi1b
0rGb+xzEdOx/brOE9oiREDoIHU/Mkf/7BQjLFVUbVVngxIXi3JHwzQrFaSFz
GZetVv07+x9fsjYb9HX7uf1NuztcYLCch/sf7/o/uDwV4eLsiP983/+xWqSZ
r6gs5qLYyT3D501+MuYn4zUmaKCUGInt0hBsah0bVRBXVCrcuLzdp8eQmsB9
9D5SFHCHGnnla/xuyWr8zvvNtmSxkdBr5nV+p4IHU7Wh/R3/H+msbtLN1jvZ
/ssXbMWHz+cxnXgGoRtUYE5N+PGPf9y4j/p8/2u8e4W0UmwZ7J5/PfZF6+E3
8FS6DxVt2RrNPkpKcMLg/XHhqadRaTeyemoqdQRqzAirS4G3+BPQs+D+/3Xw
i9b/IPMePMf2wSUIxwZ3v/OlP1hdK2wD/pKgc5xR38Hjb/3NH0FaX4M75oso
iRzF5Lx8sTjqzzec6uT9/kAhadVZdycgBtyo2e710j2hZHngfbitFaPgK8cr
8fkbb7wxkJHDrZWBhvTYpK0WrUgONdj5noCR6JP+XhAV+o7v69A8IhECB5lQ
7A444ADG0pDz1PY1JQKvc929eCWHUyKLEvPrxzYWHueGXBXSPPPMM20ZypQ1
b7EJAHIyFbpL+Hd4CI20HDRhw0wEV/utCl3GBIfgUbYLXu1ikFG70K2alZEX
PKo0XdVumjx5sk3KKrPsQ2Co1P7Pf/7z5Fvf+paNoRrDpCpgYV/fy/Ubbgc+
KzIrfT88N12zjykWzAGtHAhCOtxO3VLZwTOG2R922GH2jM0Sj659bU+3piW7
H6tGG553bfv6qntwzTXX2JovXI13rxjD2BrP+sM2kieN6ZDjxdU7K9prW8WP
fvSj3DNOpBFikCGh8uWpPzYd21fcPLVDLPR6m4mc4UBU4g6KmUe5KTNdVo8r
HYmDQYIzHOqDrRo576fMFkmehVOOtdeUCVTCkDjsFowA5loH1KNNmzY5AWCn
/FeRlXhLBNrvd1DB8sYbIIjC/55//vkYUL8f6frdka7HR97Vfg80HngbV8rG
iy2qZsjsEJ9cfaCivaDLMomOpTrEnAsFBf1tkak1MrxG8bc1ApL9IyAZX70q
Mai8o/qVGGAUZWOmeJpJ+5J3BjkHEw3xBrwH1biStxitnHJYxI12j7ST0OJg
Tio+hveIPeFcCdB272BIoiaZ2iHFvN8BGacgAgpmBcWEcjKkin+M9PueSL9v
jrwrk9gsoLJEPFJUUSUcE22aGoEfqGivpcHF4dQhrzKG431XA99slKvEYPT1
yDzHNwDncJ7vqGg/LjJPqcsHHXSQlb1NNl3kTW96k+kDZy+ZAapKwp4Q+yzV
/97CT5u6Qz4cahVbLemE1AJeQPBzDe45J4JNeR8xYoS9DxDBX37vvffe4nUH
HnigJ5FhDtsoW+jG53UpYITCvM8++1gXFHoVz1tbW32O1Q033GBrwUJOXEMa
CFl0iHHjxtk5sq1ZTm08yfTBO9RRh2Q0XGPJy56FT3DL8CSn1rzj1Rii14KB
KO1hMAwPTd0sjyAYWFoOS9xG6GargbiEyiivEbGHfOUD7h4HXKLUhe+GPOTv
G+Rn74l8Y6RDXIiBDDT64H/DTqP86ksV30LD4CDJUDDG+B+KOqtBBa2/iLQT
wUAAUr3+qsE5Vn23Hs+OwVaeGEpMIL3C/sL5SlbE1iqc7zsj7XaJzPedrgeU
Yox60ApMnjVrlsVmtFuhHXtaXc1Tb0BRARy9LSPmnSy2KyCKFGZMuLbBTWxN
xmOwuiUANV4brmQAHXLIITkzEJAaIlPqFSYb1ZbbXNwKq9+YG8PcZJgcH2VC
GLpwcvKvw22BkJ+8ovyhTnzxi1+UJg+ecuQwlLxo0aJRr9K4RliEIoqIuQAC
Yk7AiA078UAHWgpbF6zJ7Wb0FHYQCwMJOCtJjB82RQdYW/vvv7+9x7voQ1jI
DvnKGf2uO4KLNpVz6fE7hEubPlLIjIl2wTVkhXXM+rNaQIhnPi2uwKU/9oaQ
w+/cIeDDBmDItCEJwSn6FnsYumFxsRUc6QgAPZ2umDGVqjm/mEjuueee69Ww
ELRpEc2RdrOhPgvl4lPR0fVmSK8GRGHS8j+lU9yjLjQQAjsAova6RG3wGEng
jveNgHHgfn2Mb5hbQnz69KHzV4GntLWbbrpJ7A/2KZe+9JnXN2Ht8WoRViWY
Q6fna6Hdxhhjup1gZ6sn0K9ESoyKGcPOO++creBbbVNULRwKNEEV4VUwHQk5
ceJEP2RUD9ogoLGbdP9f//VfLS8HVERmBKZaat6poSXYQeIjJNYRQ/n824by
efucWBop1nwGjyz3QCZBNjt9Kk+MsjYDZdILa9zZxfrEjSmUrTmFEuLiQFG1
BySsXNgHVjsRqTKNEt0Lv6oRGTHNDac2OqoheY0etHbbRbwGSWIP0UVn30uj
1CtOocwNDJOTPThGo2+KqZSvzMDgB6eccooGAUmRExCuDnTiIqhNOZf8UC2D
4bZ6EBXCHKXbgIJZWOm5HJqA7gsjQZ9kbuymMK817XjL4BVU60vfllSD2qAc
EpbuvPNO66+BGlgWM/OYUv/x7YL969QqY+7hyergG5MJ0ysL6yOdECH9/e9/
37/KPGBgs2fP9nAI4fdBNyJirrQnFoN+yA4WQ5OvEOikncKilMTd3MDkh20/
/AZjPUKYzMCwBMeEXhfD02cYmrZU8cf28DPOOMNFgM1yve3/NeJoHHqvgd8i
Rn7vc+/B28nNiZCgfw992iUeunvjrDyX0scf3nWJEnJryPv55je/aYGEhsb7
jG/atGlNoRI+FCLcMcw8pLGRO+rro+t93b6CfgGAJdoBAu/4IhqWiEK/Hx99
/PHHbW9Ea8EfguGDI6K8msaSGY7t29N3UU2jxCV7mrKlb7VjAWXQlFA5Dz30
UP8MLEUdJRFjzJgxQMD3BYo6ddcDU9CS87+goNGNFLRxr8LnWaSZM2fqFRIH
CSdlr6SHeLCubUU1bHt06jqqWLOdjEth9F1jD/Ja2PWOU6uFWTtaHy59W9Ni
TdAyFy9e7KdKYBl2OXXqVD/VUB/++HavwOvTqhme40iwCXJVf/WrX7VGVkc7
7wheKgYiICAoi5ZOCMCiNqY/5Nj48eO3h81UwU39uq1mOYoomfn2wU2DcPZW
DkYxowueC3ypvjLqtRnY8HBg9s+pXxqj075yi4KXgcwnrpR///8McQx2kV8N
k785NPmjJPg+dy/QyPy7jgxz4KzVynaq1MrYMuL4qt8+a/QRnEihUjYEUtxB
DD2ktZGv0JeHh1+2rzldrFQVKxCTcowgJkIfDAjnLe8cddRR4su1NDTa0hBu
PAwhvgyvRbmUhxAa5to893BCYSnSERuu8pZNqhTtscce3gTw5avMv+AqQ6Rv
o+Mp2RocBV6q7YT3HHwxOlUuAosWL3wiB/OHP/zhLq/kV1Mjiq/Kn4+FB/ZT
a11AwEGtDJ2IN2zw+vJOVpciK1STdSqY/Y3ZxDqYdzQCtiwV1a8doS7vOsT3
mive0/ggCCDJcbIhxuMxJnindqGS+/HtAuvrzQxJWQp8mBwssIjiauvWrVOa
F4dAwSpJQ4LzmOH56YVgkcYE+wYk/E8KJXFQQ7WvFETUL1nbMTYdmVnz0IES
SlLKgoUyKTSOxr4GIxgejsD+NaAXwUpcuMTpRX/2iD24NdyR9nVzaF9HeUvo
hcJZHCGkCi9Urb7DthXpO7Bvtz9Sn8Yzx67zcAWGQEjbw2EbpJTBfWJ4+Ak7
G7SaoNJzTKsJSUGlF0J/LX/s0oQUsmNBWywZkC/O57w4HGG1GpaH5lSZYR8I
e2LMknjBjhQlKQktiA0G6AfObevzRgJDJyfSUPNUnYyMxBAlKZ3OqQ5oRegg
8gTizCTxiaIEfBOPCWRAxPuee+4JtRwwBWMIqU5Q3BD/Ltv19V3rfd0DGA2J
5cdlShuQmqqfBnH9mgelWvLqzhA00dTZxIi1zOx1MdxKy4SjAFio3DDeMQYe
xv22UwkdP/hXqr4Skgb3jb3kqQ9FHyNg3rx5Ue3x40OF4+tMo2+1PAWuTPET
9jwYCvfbKGAkkCa4DXLhEAq2NoYAkWbDBnOAASOGVcGHggIPrwRA1LfL388x
gdjshgAQGSJVRsa4V/+TYWgN5i3ShHkElekQ4PCMtrasttKfJ+IOZp12sB0a
I4pQU4GOIoRRV1PBKaZ1RUQi+/lNTQLcMGZhBWx2HhfDZYMjiu1jlGN3eP+j
w/69jkKumE6GIY0R9oSDLIbvZUoKih7KSKiksExINdotXLgwVFLIGSPxh/Ky
JGXhl8tS31ot6KkGwHDx/ITKCfVD8TOFwjT0QaF+occuWrQofTzWewpVRp2k
GglWNARGyXO4LUyZrUTLli3TAqObkLiHk5EsOKoV7/qKfllaAGAHfAT64R/A
hP/BdC2z+ZoNN6RvBGrJdqmSJD9CHyAeCpFRfm16yeWXX+5VSZAI85w/tH7a
okSho+xIVXLXIb5X9T2pp+hVON/ZOUaqIMoi3JpsyYkTJ4oGQt0vlnU0SOi+
nhT1kI2xkth+5H2SLiFvN1MgI4E9fmJVQmOuhkXAFAtn4fhFCBjZ9ypBCG+p
Y3aVMx0qhJodHtUxIsa9dp8OtRqMb6QueAObD4oBwZIFqNAr82eO4YNcv1fI
Co6xmVh2UIGG/CLgswHC0KiBuhQsxCrSnknjZoJJ8yq50sOCNsRi0Cx4Hb1u
t912y2k9gyWi7WC4jRDKdnQvYkDvATUplwjgQFEDfGFdSAwqaIM+zoiQ8GAt
pfCRiOa+x1ZkMaKeK20jxDdWtK1YQz6b8c5dLaGRLYY6h/8MtQBMBK3ATlQ0
jlJDS6W+EHuX0QdIbaOmx/z5833B0mDXnuPhO6Z/7UunL5dIVU/nGIRmiM7B
bU7BBNpohjhnMxoebkfJaNHvmQHBIqNvDFk5HF6mou2yXW8Pc/pfydv2mhQ9
chOpug1C8JzpGB28JcAn6XZ7bT+AX3XVuw588rFl9uViQxsVU9WY2fYLaWZ6
x3DrL3XbfO2fg9GHI+oGzAAxZxT2VxgyEAsoGUKmZG7bB5lGLINdXusBSEag
csDAdXb4ggULPMRwZSjxtEzf+HNE7cEs4CtjXMaYyx4lykZAQX4FABMjp/vr
rrtO3UGr5OGmebpGJTT3HEQDOZcSKBlBcHiGQPjOKBvqZtCUNGQm2xCZDLl3
jd3lttg6WCAlTdauXRsjA1WHJnGQ6Jv+WMPNmzerzgH6I6jNlWozkNQPozTC
28UmWu2SK9uZP9ONWQRKkI21KIHbDVLgE2xfx/2GO4xr7jMh0EjXZrI6pAJv
CJ47dJ83O/2CUWrEQ+ze25tQM96WtjZfPGv0dqphTlF4VdSw1HP3jh3RV70+
fEWDUCX7+HbCqjGVdcfMD8zFyKINe5dU4By75aCDDnJjSo1FiIXNz3AejhAg
0r/ffvt590MIgw85KgAVmTulNrFtzO+G5562e7e1nbRLkL86Y94h836bg/Gr
8S3hULCnyFdVoTSZy9PzcvrPAa/etgPpPUaDMt/xqPNdvOxleMg3XBjIH0Ti
xGIAq7cOGg9pU49/7Oa+uiP6kvkpmZdCoBaPPujuoRcCn1CSUdUHA9CoCb4a
ETiJqECZ+3IoDoYkK/kqo/7e9773SsrKVAiM3xFykT7S0bTGuvBwD8XmXq+W
MjFuyLN66qmnmjQtV4bQqsC04UCK8U7+0zcaFgvHc8Xw3HT/0tEIw+NVujIU
NdgZYqiEUd9sdONio9shM3ybwxFq6WmBtuNbVZ8SjpBUojQk0aaraR7w+Dc0
3oi17wiNNEZaezgQwZbUXwTxsGZVsXicw1GC+0gNwGe4e2td3BsRxYc8JONM
IV3Ineriluurqiup/QwT/s++yZER3EkTHPx5bzH2jgoAjPHZntagGPhVg+0O
cvewOrX56mMNvnuyuwc+UKk6VFuwWGmH2/wb7p5OfzBqTtNN6bRtHd7sn1P/
/O+qkEl4RJuwHwcLxNoW6HpsbqZKX5vXrfPvNkfutZTea/FnkLlvtZZ+psW/
7v4PK+bqFDP1qtddr8MbHNQXIl3qXTggdFg28ZbIu82lQ9zOYWdwc/+Xwy19
Hd4HRxre4Ii+EOlP78IAqRWMT798EfLvNkfu1UOp+mPOIOb+L4XYMHvSULPG
Xfr92L2/fi1JpNGBv3pE8il3Dw2kzUmN6RWoUQ8cjS6DBG3wroiyAkWGh/fs
X12Kqf5EPZpP7zkBGj9hTyNDyOGpxEYjaI224Xc/jrfJzYhqHhP2VXE3ov9K
UCQASqhXBdEin0u7G+cfYSFiwZOLFh4pw04dRoFHBq9AMCLvN2ZIjJg2w4jH
cvLMSBt4DrtHNUJFciOQG5YvMCEGzgiIY/M/u1npGX8E10TUa+ARB2XVMx3L
GD1Tr9XG+Ak9E1rm1QcffNCHoCPdWfBSfM1cDyPcbpoBfaIVQq3Cl8J5cxsv
PFYr9jjzw4Ved95j/WAIo2jNAZ3O+1H3uCSofZb7ekNrxpvKwHSgaI4Dr+T2
5x1MIyjrQzeYf3gZgCmzPPvssx0rHF/szgJTRx8xOIbNtDlKQWQQ+ZYgpkec
MEdGG68CGZa87pzr4ynPSIThfuTrjawXgAANQEAHjOYKGA6reLb364zTjG2I
05QC4A3GZD6VCmnzNVlYtYriqBoZtKSjIzl+YCA59IUXkt+YXlesXOkt+cbk
4IickOIvlL0S8XO6upJTOjuTI4wqtb6tLSZ+5Xivp8HF7ikeGHzaDmWxmd7U
vr5Gu/5sXQ5RRRXpGegiMPCFdw2eVRFN+myXmmdY1Swt2A6m4BLXcuMOLQgM
jS7kX2RgZceyjbRYzuvibVGOmh8lTuq0vCtdjLITw2FbMZJKJC3h2gVVJXY6
qRgI2KLqPoRxKMt07bXX6qP4SFQnFTrNYs2jrcsFWg26tb9jn5OuUnwGQFwd
d39GJxgF0rnsAg2pSVxIY0LK4rlnN3Kby0hQ//xPehljcmPQEPQZyFnOfynW
rBXdgy1AhSmT5ZQfQhyiVc8+56BddQypeTXkJMSis6LqVZ/c1XYL68NlFHRb
9rkctN0z09fb3/52JUDUh0G2lHhgEAKqg0AmBwyAzvkf2UI6JUEnN4BBLSVA
EXo5oKSvjxnM/PynP1eB2S2uX/a4i+XB4+Bd2vpT1q+oAvIllhT0a3+XU9LY
mmcUbSYmE1JTKRgaw2i65380J4aUH0Jjq8l03fmg9rcDS1N9ZhF/tncFar+O
+VM1GN6Q/Clm+ivMHjOnigaQRCDqzxf/+Mfkzu7u5Ajz7K1GMWwxjGmsMZAC
RbG+AN81qrrKcoCloESiG9AG1TWmY0gNvqq3NznYIPY7jajdw2iYH/z+95Nn
3FnxxFTpB/0COy60CqMS/e01QwMv1RUIR/gZ60TDLg7tBHP94xdfTG7u7i7/
TBw6n3FkUcKhGqFErT8ZZ6jb2VnlVe/tHHtmf2O64cEPcerAAw9MX3ureJWX
a0X+SSK4zhTlGeYbM+IZNjWiI85r80MCSph85J9wPWHCBL+HOzekUTVDKqeW
UondnNewYudTj3Rf474rIWYxBbVRxWHJbPzlL3/pWRZHiZK7FfRjf8f612yK
zzDKxLLc6c2u7Vt0enPlmKBzFkTJDOqf/9lswJjcGMSywkOiwUzUWjalVUxZ
Q/BoWT7F+DOpVCUHVI9w0OGzrjJYHUiOtF3RVqJX0HKf0Gh0uxbAo+0mHlhB
4zN/b25IsAre0VHQmp3+17fDMTS6gCFSObB4JCqBYmSOzeEzz49K5qojs7Br
kFO13b23ZipwT7dn2oOsDJRlYGaKWsX6028MgeEE/A9t8e087Y5qZBm9QNKc
Q7gMdo7mmRSoNxr7qZr2G4T9VGlM5WZcrcnydvP72L6+ZI7RBcJnU83vUUZj
Ovjgg72jdbD6tSiM3HN3gJpXhMtMHDS3nxrdZN+gv72M1vcTUr+NQsvykGGM
vEShVX/VZtE7otrDKa4/1o5n9Kdn4fgeN+MbvfvuyT0uf776W3FYfMGhawMU
V7PuaEooYBlOvGUo1Gp/oy1hVBTwSepGUVxFRA+jYbXI3gmJC8LjoKkYC4+N
iNx5lGmSBSMYLvpuXICWyuKCsoSmRsY9LdDod9ppJ+f7HOlrg7H0ZEMpZsB9
I1dF8fDXoDCVTXLVIF2X9nfsU+LBxWdwDTGu0Fzk0ySGEiIqHdJoOySc2xQh
CD/N/yqKkR/CuNxn+OMAG/RhTiRy3ftP0T+5n24IHknLpxh/Jr2p+G2maMYp
XkO+lfarUF3ViIYGPjnSdgv7lvR13eaN3FZ/OwC2l0KQKO7ZAMh1oBBfTHf0
u5+p/te3wzE0uJhAhS5ZzDxURpUBNDLF5vCZV6HCqbY5HcLgeIvrHk8otV14
BE1C7nKMFCFYnBn2rVBbpOM+5xc1JKn8sxQcMFktan1wNIbb+l/fdv8PalUF
F+bMoQ4hXHKrWjXF5vBZ0yffeIyqYSi8cRhVFoBTPnkd4fhWM6kJUYW7ORlt
Brif22EkVWwIItwPGEErSScp2OLWC/41w6gYR2zdmjxtnhf7+R9Gi8UjRWUG
1knnzknjzk1rl7pyXENGOUYbVcUm90x73S4xSubH9923aIaJezXwFcepqllR
nq5G1RCAVhothi13GRaMKuOAkX7H5J6hU+FZDDEIP1xcfpVzavRPsPrAAw/0
bfHX0X+Mq5eNiTxa4InXtLExVVFHqaguqFX4Zt2Z6dZfvPPOO3tuhb6Icwwr
AF+xq9plcWX33XcXmVO2NKhvbgelBXFd2t+xT4lbFZ8RlxK3AtO1XZMhYWsS
jC0d0mg7JLgJaRnAXd3zPzUJ5B3PhjAu9xn+4ETcY21x7WpDKUNgnRiGG4Jf
j/Ipxp9JrYp929ena7WQQJLieAW1qOVe/5MjbbcMVRLYdavPqQvdDoDthTjO
UKlVDsh1oFC7mED717/+tbX+NFP9r2+HY2hwMYEKfl7lT2VQGVUG0MgUm8Nn
Xq0Kp8qfw3EtCACFLmHmNDvuuOMq8SicGdAUaot03Of8ooYklX+WggPoa1Hr
g6Mx3NaU9W33v/9uI6vq4GLegcO12m11+mbjc2wOn3m96nXBqWrBEONUjYPh
jcOqqlxX5WZfXmyuM3/vN2Lx8hID5wMf+UjylwccYK8GL97H16gNJKspJC29
OaaGXGvuXW50q4jO+33T3TFGJVvR3m6bAuqwu2KctFzSj68ZOiq59Gk90/Ce
7uhIjjC/IwZb/U/lDZNP12VapfyuiBDoX2xZzZBlVNmrEWQfk3uGfgTSh4hG
2aq4oKtm6VRb//CHP+zbotcdkCJSlAeXjYn9RIyBol/1x1RFRKUyvaB/idPS
gk3OZuQ+LR70hZwfe+yxJinkz7sAtHCCzVpHHHGEUBZOQjw66M7+jn1GACg+
g2uIo0k0i5pgsDNnznTDGVc2HBscZY91IEiS448/3o6n+P3wG/yBFGzmA7/Z
s6b++T41Ag455BDv3C6fV/yZFK6SbypRknPQ2b1HMN1Msbnu10baHuG/Esua
hfuSBqXbAXBzWAu98ywEbO3E3xMbimVnsHrqEId6lb4ZfrvRhQMS+HrJN/SQ
GFW6ZrXTag6fef2q5POCP/SHXsEevZUrV6ZffX/lV+kRjxXmYTihsomWAYF0
Cq1hJRDGNYS4yAn+p1gSn3WfLyW+2DoKGgzNmPuO+MYMemp8V8G/NwjfiU/9
jcd3qrSncusuL/QIsn3SaDNldgwK8MfM87ldXUMQzuNrtGNgDiwD4VajQxxj
NNujjHq02qhHEbON7mb19CTXGOUKZRtQorKou/wUWivk9NiaoYMuUpr1TMP7
yL77Jm9NVZxG1Icq88NW3rEOxeFVzKkOhWRYgQrF2xnGjB0KIaejMjqUQaMQ
2fB0BpLL84oq1kl7EuNIwucaP292kO6oRuSGF4MgMjHCkvHUl6SlsrmgOLEd
HG2EfE0yX9O97ukzMJPkMlWpo8qIsPzYY49NvvKVr9hAKGmtcnxio4HtACLo
0z6LfEummB6BXlj2EKGYGCYRWE8xHEQT7WqHNNYPibbkOxL9x+VPwFT90weZ
ghRMKgxBn8GlyxA4w5oN70CBJFx1D39mORhefghxaFY9Uz50OEWsvG9/+9t+
FZCaFAHWStx7771+FSJ9WpBR4IGK/EwVKnF91oDT3RfKhI/IDUBQB4np9SEw
1o8IgwzWBMenHZxO3eN7J4sUvHEjaB7EGhL/YIGo7OcAMqwCjlXPtMMugs1e
RsGnkHuC/5QpU1yfb4716WHMb+JlZKUVqST2vSIaU84T9SVMp6oLgsbRGI8k
1AQTLA6hkUXELKZ/UaMBS3MFNIdVPNu7gkJedV40tiFeVDr7NyQbyqJ9I51w
jlpueXvlhIGB5MMV9goD/nvDe87p7/e64lBU7fTd3S1QmHioGxd0CLsz78K+
vkqJv9b8PtroWt8zspP6XWCI+svP4S0NmXrhs8mTJ9v+9Izxfc+M72fz5iXP
SMep1iLKwLBXoPresabbrWY5i2qEGKnTQq48sTIYMrhQ/70xNc/YZIG4QdWl
NFyIX7RL2bAZmWGZinPGRBF+IK4vv/xy6x+D/ekZqU9F9t0cGQ+qP9/Hywfd
MC/kWHw8I3PjKWUKcenhdvq93a0MIWTiwBzNqCpPRDUhfP5gBBTsVaUKIIXn
/9FHH/UrQuWdGTNmWI6rvpoj/Us46R7uYqp/mZVokrjG/0kNVo6/Jtuvdgyt
dgyIY1gl/2McDiv0jcme/+5w3zcJ/1QX5qzoJUuWSJGgWxYMGgg+Wz6T/L0v
OC6kr1Ci1GjVQnfciwIqFRczAzvfTXOA5owE0nBduUnWfEKv6DZwIffMwMDb
8JWTG+lHQK1eQIrEcfUe6XYY/Zq+gJwG01J3NYbbbllJOHMw8eaqedTc/kIE
9QRV+CeFywTZzD9Z040whFg7WEe+r7qLYXc4P+4BUcATHn1dOb86CJf1TK/5
r46ptyBWesK0RSNMvKV0Fvl7n4qg3WtP+8PL5lUf0V5LsldJoJh3p9wKynjz
wQagnzdiI9P6R+ZsDsQAu5pQmSYaDWBZe3uVWlpUyEP1Ugo+Gc4oeaF66aRx
KmDemvzokkuSeZ2dXsjEusPb+iWjbB9shBZ6IcJU3cUkTwrRXUv7YguHfIks
iJ4xtD323DP5hoFU3paJS7gqZWAvrzQK4WMcpIqQ2N7KeS+oN62l7UaH9ywE
4eeOfYT4g1wwszFfNv049mF7kGpd4GLWqhJDgJWFzwpto2Mh/Z2dbo4KBjGW
GC3UcFmnXmTF5Y6uoI9ymZj2+09mnD8zjMDLhkw/gFoJdKLF3dDTk1zX01PB
xWO8a2cvCdC6BAKGGKLESWZYB952W7KlrS3tfqealcWheby59+XDD7fdua5K
hHU6oF2ivfA2awunCp8xoB+YZ781qqHD0RIhF5vuJyJK+L83skyqrPi8uZ5g
WM/y9nZf2sT8To4z97hShcjburuTab299krtTjQGF/FsrnZz95417x5r3jX9
Nu3rCfLQdEjvjAzkkgbvnR+5d67/gApALjB87XQzrHQ103uTzfWiwjDP7O9P
Hk95oJ/O9QbVQLew3Z3BtPcth7XVuH/AE5sb+E/+l733t/7XFytWYob59I3u
8xo6w5np7r3V3cNcxDW/JWj3pJneKW7aGvq5ZoqOzacj+Bc+OzZciRY7kF++
+JPk3u7Zia1EkhJvMD771+SfteSemd/N8ds7uqfX6rvxnr5un420z5a1P2eo
YJn9fVXvzcm/vHhMcnP3Pa/XoZf0tB2vbGnbUnzUQHd5IvjaUOe+a/G24TzP
Gw621v6e27U0ub/rmeSO7ift9V3di5L7up5OM6M71iSb0qEPHY5jaz7/dMfq
5OHOFB1mdz9lPz2na7G9fqRzebLEfHZ7FntkzRe3mAkv7liVngnQvu5LwdvP
tm+2f7ZT88O9/UzHRgOGtckZ/ct8D9uLhLWQWGOA+88vLvRffNr8Pdy53l4f
+NIC+3yIqD0uNj77P1Ph939tW2w/yu/HOjcYJv5csu8f59efRx4v/zZyTwz7
1ECuiBEvChixGPa9XV02377N6mvpvYmpyLVXb3H3yKI70tzfZK7CRXSyJhti
fHVKAFb1StVivxG6G/x7qZ6QE3/L25cmJ2498jXnwG848Te6huL5f2PbpuSg
F49yfGVLQ6sylJHl+eDS9mft9bW9t1kBMLQP1n+llvtubttsuNlvrdgf9FS+
PlSgvNXeXtW+IbmlO+Wwv9l2k+Eqd9jfF/Y9mEztfSiZ3msZXnJN77zk8t6H
7W/aHGba8vt2I5s2tG1u7JM7+dsOwMnv+uYmR2y9xf4+beDu5CLzWdvL1b3z
DKSm9j1kH53ff7/hiVa/NDzzbjuaequ7c5TBP975rJ0Xv3+17QbbG7+f6HzW
MkxrCqSWe7Hb3Ocu7Xt2uwlmRA0m3Nm9xkB+Rc3XrjSi57itzwyVmEdHQZEi
/SaHgs8Xxtya/L5rnX22pGNTQyRoBd2/8fPzGSSbw8+94aXF60r4CMBX912W
3NN9p31ykX/gnU9905ObeubYK8ms8/uvTh7qfMIg/6UGtW7a3X3wxp67jaV7
qSHEy4x1ewVE2mR3OFrlZbRrdXP3AssprjDcYJ7RRo0C7HSXVkvWUNjZ/fcm
X/3DhcmK9nX+vQUdzyUnDdyVnNd/n1WoV7dvcM9akqeM7nlV7yPJR/90mhnw
A3plmdHB6QrSR+82OnlqE0cdRs0WiycaMlncsdGrTicNLDHEvcH1mN6b0rc8
ubknrcUu1en6npWG2a3Mtbule7XhSHZDQCWfra9Tpc8I5U51odzBvHeHq+vV
+HuViLom1RoLr4wqZRKPdnYmZ/X3D2rIVc+m9vZaUOSf5Zf088G9gqfknYUZ
PtH5aHLOwCkXR3qRv2tl++rkmK3nJmvb1rtzLIYbvN1sRM9Z9v/1bRuSw7ed
YdT95e90Az29//JkfqctO5uc2z8tuafr4ZQYCp+Q2g76IhiNQPWuJHD28G03
Jws6n/MuovmGZD7932cnc7oX+3bPta9P9jSof2v3Qt9upbm3/x8uNurI/BT3
cqWDwV5hq85pXm54OdifTi+9ZyjBTPwZS8rC9JMHlhqC25jD9E2Gco417TDw
vh6Z5VgHTrD3vmzpZIs8YjDkPIMhYZfh62r3jLFtTna2TcyGFyFvaUsdVOuC
ezGgTzJ9LXM2UEukXT0sCmXUmQMnmPEtdvjRYhZyZXJD7/Tkmr6pBlwL36Wp
ds010J+RPNT1QNOBkU9q+pf1zTJ0+4C90lmfT3Q+ZfjZVZ4wbum+F/4rlDty
69lmxpZVGYNzUXLCwEUB/9XS32Y0rn9/YQZmqj9C8wHDT2GSIQzxIhy19Vbs
et/uGXPviG23WCRVuzVtG5NJBnFv7HnC2Yz5ss+x9dR5QGuNdn7EtqeNBrjF
o+EdRoe5qve53FgmG5Rb0JEyYY1lmUHXSQNLcu2uNu/d3J0y5r/zCyRreZLb
bMXVzu7e5rbU4t0QEMLthl1e7TyuY9w9Mmh+nyKuH8Eq52jm6i8iMxdGca0T
NYS1xFMobUoAVMRGuaNcPe96juthyS09M4Uca9vXJCdsPcII6+uNHnhz8tX/
/qvk3u67hByGwyXnDUxObu+5MfmXl76b3N19e9MP/Uc0hIUdIMLvAqwbkczu
/j1Y5rEOFIPxGbPD53lg/By3dUpuiqgBYCxX36lAAiPILVIZLuZ5DLr8Y50r
crzo9P45VvCHPOtKwzUxP8J2M3set9yUKxX8dscphPX5vZ4Uq2OdgV+s4vz+
5UbnWZdDgIuNbJ/btS6Hgrca9LvGoa/agdJXF1D6ScNBTxtYmqFqATpCvJVB
JGSsu4dffb7zq+sbFxgEnesQVO/eZRD5SofIagf3vcy5gt5fAQHpAVR9ZecQ
+VD+wOpWm3ZHRJRMTnLfN23a5GW0Tnqkniy1J1atWpXjrvU46bPty5PTtk70
gZ+VBrkOfun7BnVv8sjFvZO3Hg1n9e2w9S/pPyc5+oX/8O24N2nb4cmDXfc0
/VMEzEIakPfZ9lX2Sv1d3ntjcm/XIzmkntJ/jenr0Vy7B7rmG3tuZq7dbd33
myW3W/2a9glovng+TXBCZyrl7PBEGjf1PGGtTa7eEty7vuexXC9GQUiOH7gz
J6a5B8mE7da0b0x+axSKtW0b/cFLbJZ0ubSeJGIFSGtJYk7XWmtZcqWTSNHg
j9r6tGESW/wsMABPcJw6JJ3fF0iHd1E21rRvqSQJvJkXOxQWSdwYRM40li2O
t68N2uHxnOjISWNhf+7dqYrsSSIGAZEE8VLSTMlkNiQh1GZvFVuhDz/8cE8K
JC1QG5luqHp34YUXNrUUWfsuFUyq1WFpUSc+Y+D4ZFnHUkXarui7yGoV6VX6
7yNdv08u7E9Pp1M7o3UkUwZOz7Uz3SSnbp1gdLhNTd8WPw8OUogJcJHNNIPi
0lJEDucYDUV834f2ux4yut+sXLube+4xS3Z3rh1yZNLWC+zVF9zXY2WHNXYO
6WZXzuzZsz3MY2CMKXch2k3Yers1NmX1oehIIdL8cSYRRuFK7Y7ZeptVgFLE
aHPc/snkkr7fB3OIE1mscF0M1lLcIKOTncQQiqOHn+ruqd2krUtsxIWrXYI5
QpZrDFmq3WV9zxpSstUM0uCXxUkRCnJjjiMK3SNcfaZT0zUCwg2nOZVcihYH
jii0oHakRi91oYr3V0AgPLajeBSdzlEkBzYoLo2sUX47O/J+/vOfV8kbkX24
JhlzEyaiut/Rc3OO9S7peNr66aEUrdTZAycZGCzItUPonDEwyajQT/l2V/Zd
bATFnAzahoZISaKmBnsOgnN75KKLHSdlxyjMxQdzYd/0HFUdtfUcGQF+Lmva
1yVHG/MV8aB2l/Rdb7jB4zlOAOVBgVxpG0isdqXaw90YM6eLtkagahehORzx
kx0rjTJ/d46GiJeh/202uNkS3Dty6y3QluddOH6kE7YE93Ai1aO10sppzaFA
w0X6XIFy0N2udZayKGdq77PGnl+ba/dUoM+pXSggvxahbAk0sliWONoQrWGY
HOEME9HQrYYepzt9TrR2eUCnGgtbJo92Qu4DFRBI572zTXlkawI592TuKe8e
omK8PCcTiD5mzZqVLWs9iooIricNzhoJpMVHcN3fnddScEZO7708R1Jzu+43
ut25uXZ0hUmTgXeMtalUvZ3PkU+nbQNlZVpjwkECbk3bOktSXO3mwbvW2H3n
5RARY2dRx5Jcu5MGLjEsb0WOxNAJ7+pOhYMqBpSUN1PXGn74uRoqi8m2YUa8
Pi56P7P/Hkt94WBIBiA0Eg4a6wkXbdjOqIvWFQCF7hMZgaisvI5O3P1yiVEC
H3RKoHD30kAqhXR0ee+zdemSaPspjgZj9Cajf41zD4X94X56xNlUuodN9bC7
J3q7N7Cf1A7HwEXu3gcqYDHKISmHpLFfGfoiu5kxhjWA0Wg43ImiDyTsmXtD
EmjNoUA7Zesx1kfAld7gGitqY1vmhZAfIbQlzh84zdgTj+UoA5VxmcN4AZuq
Qmyefuihh5qUpV5Sg7dKIyOu8FRHuo5iFGiU56S+Lw+L6b23J7d3359rt8W6
lM7if98Og+0yp32K6EqK/4yOwLJWjEE0jzpRJMK52Kh8D3UuyxFOSExqhwtD
Np3aka0zpS9Vo6sIrLS0QlCWMk8aQtGJgWgLyUXKo9oh2uYUyO95K4xTm66K
rB4ypHJBgTSsyHJ2me4dvm2bJcGQrJ4N3Bxqx9b+251o+0AFBEa5JWVrE7sH
RUaoVEaUiQDYXaZT6Id7oB1ah4aaii639B7qHAZWSE143a7vvSqHysis+Z0P
5dphcJ2+dVKu3a09s3Dm2SvZvmyWcNVl/SaGqirJORQlDeG2Am0geOSUEG2g
A17gdEi1I5/whIGLcu2ea19trKTzczRUUgKilIZKZCz4RT7AeqNWS1xBOXLs
iUpCBVDUxLVEmNpd1/MooRB7paNZtfvb1WCRrVi+vTYusXBCn9m/rIC6m63m
GLZjSkcYktlkmKjQGWc1MZawHV7FRzttbYQ0MmlxcoyfSI8BQl63W2j0xNML
9taSICwiXXFSkN6ldmEa8gcqIDDKPdP6soWT3b3h9gey22HrbJmA7ZfJKDGH
21d3Jw+uS/2T73P35q/vTFZuTsf4Xndv0/Ntyd3u3d3q0OawLDJplITuO5KZ
vVfnKO2C/tOtlhhSGtqmtEu1wymO3zxsZ4y35JyBk+3V1x2+qiihED5X7TJf
7jEWlAzttov6rsvRHHQ52ymGguPatvVe+VQ7Yoo4IUMGBa1Cs1x91g21ZM9s
tXwb7ue+2ma2cCWKvLv7qRq5hdm2Mc3eCdLv1xlUvyPXDtlWNNOCHSvRnU8Z
i9aYjfyxTowQpfEh/i7NpfHtzjVE9bgL2cucWm2I9GhHpGo3o2eVjxbF0gKE
umcY1XBBQTXcEphnGgtm2BXOPBMZBrFqP5b17l3S5z8YzJxdStdcc41f1tq4
Uavfo8NOM/a0ZPZLi11q5AOb5Qy/y/yMO7sGD63rTL7x2MvJd594KblpVc97
3e3Ln+1NfrDgpeSzj/wxeXJjx3vcpzZsaUt+svDF5Ivz/5hMWd6XrNsiLHRQ
qOGqwyNAFG0807E4OXfg1BxwVrevMmrksVbVlLN4pcFj7oXkSewKcuRK7Wiz
2jns/87hvKpbqdpMrkBavlpYFXkSB5ATUmQ3pe9ag8ELc2RHmxXtqZ4lTRmR
e33Pnbl2F/ddn9zXNc9eqbpJbPfYqDhUq/yvZJKTAxcSKoopWS8h9Jcak/XE
gbty7ZBRZBeE4MDn4tLxmr7i7tUEcwOcwte3xIZiQwSfaQjrhp5VOWIj2+A2
R2xq94iRfGc7aap2DxiCvswR9Kc1+jrH+lalDGxyxLYpwKcwfqaxXB4QqvDz
nizfxrebF6Qq/IX7+g6On51//vm2dAHdUbnLdBEVrTs5VFhrCPXni15IntnY
YfhFW3Ly0oHk4fWd73aP5xkpe8TT25It5tEj5vexz2zllXe7r132bJ8lbwDH
76ue6xWZCw4hq87YsnAGPDpp61GGPa/NINd9ZzKjd5q9khkB9cMFQjZKqE+q
sNqRj/Zg1z32aj83SChZVRBc1ZXKTZoZnqpX/J/4QUNiPX7gQqMj5aMcEOvv
XYBP7Yh+E8EI2xH1QMfmSmki4ba40RHYZUa5g+KNPU8ogk562zlGwQ2p9sGu
JZ66FeZH5G5ySc38kYB73NbbJVUl9keOHNkUnmeu5hFUraIeKPEB56ERBUwx
4nWe01nVDm/oFc7TqXZEwq/rWZlrB6c43oUCP+bgGR56yZ8ZrqeeQZxEWRR3
6U48hStE+sQIZzl7VAMN3a9C4BVBnDBjaz3Jze5dkf52xgll1rFs8gjRFZVu
TjnllGxOKQBHWNVY1MrfYxs6k5OWDED3Te9ynZ21rD95IFW17d+1K3uT6St7
3+W6WGU07sMXb0Oe28do3BMNT3hqY4fD+Giyich9at8Ub9GKjENrWAQ3q/da
kkxy7dC9r+2dmmuHZ3daX5py8lUHuXAXst8sX1L7Ip5Ugrx26Xc+WYQ8+d9u
O9OqGxKgBCFnOHktcifFakHn4hy5kxhDSh9X3458V/2R9/6I03QlaElDPckJ
X5E2tu0MF8UXaZ8wcKfdNubX1gjyc/vv28cNRKeTSaO/4oorGgzYiyBQdmc4
uSykPjoNuOeolG1Sk51jSO0uDTiB+nOBfnu1Z91Rlp5dqkmUn4AdZ04cV3u9
o0fR92OG5s92NC8zOnT3ChfCXDC1OzvYkSv6HlyIcnQxRGnfY7qUrVLpeMIp
WcXPmExvtjJ8wYaOHM5csKLPtxOFPmeI+WhDvJufz9pB2Ec+vTVZtqm9aXfx
rlU9yXUre3L9zc54iYNLkIujwc3uvtWIqdSmzXZspxJ/bdsaP+DHO+fb5JuQ
3CFryDskd7mcIcLvVRDwzJ67fN65Fm1Jx4rk5IFLcgQHkZ/Xf3WOgPFTSdZ7
Y4p0XecXtgScM3iJSWL0hmS7rm2Tje+HIEMas6MzJFt07YUd2QmLZO1e3Tvv
b9wr8DEO2As1vEZD/8J09ixe4BLJha24kpRVI4JkYX677WkL3Ey6LbHbNMJ2
Zxmle4GzkD9WOs4xlaewlh3KU0WxYUBFFLvRKeibg7kRiJniqFiLf1mWOuzn
Ya3wbdvow1nSVYHO1lig07NQrGaCLvgfUNbnzp0beEaEvo8beXva0gF35VZi
U7ulNwxk0eV0Q2szVvXk2t28ujuZ+mxKb+/QDIzwnWDod8Xm9kyhNvdOMd8w
irvo0lNejXrXHKp3TTGzVvee6ljoc3/UH/o41nXIeja2bbQBILIcihS/vm2d
X0xCr4s7UhH7j55vZGL9Me/jenNwD/06pN/Qx/VmP4JNlla5CmNC7HHn6nMB
A66bUFciqEmD2+xklygZa/h5t5OJPxczVcY/Xqz5qWy3f9f2zk/u7F6kDbrk
IrkzFxrMO9D4VrRv9qnMIgFyTS8qkPyJga0tElhPvGtrSvJqx07j2d1pqO/j
paOrPiGw6tiHZj+DzN+ditg1ARc+HbeZU6s12plBhQmt9l1BgQu1C7OKRNjl
EdXhZRFVLQNFl7B28KqQlZrVMs1LXyHv7wyVznb3fLDRaNFXP9cbIEzqrD7G
UO9KQ71qt9Hcm7QE6d3pqRzH95Tl/bn+0NxPNO0MB3C80CcCxnSoTJvzaeVG
okGnG9s2eDpF4Z7ee0UO+8kBfLIzDUJKKBC4lXNb7Qg/4Qj39FwimUP3mNaQ
ahNSo0WxWNfySmcbCJZbSg7bkWYr61r52o3m/Ak76/HF2GYRcQwsaPL/MrY8
PDmWvL72jZ4y0AOMPqDHqAEPpWqA/WPb6UOdy8QJ4Euufnj93IhcxAdKXu+4
kmjhJqOxz3Jau9rBGR4qaOMI9LOcNy3LAM8yzz9eOrqhlzCPyRvxBDbrnORo
WDyBiNbN3fnI0DmGTzzqlALh02Lz7qnuXbVjF9s1jk+IJ5SHg8eUhYPtNfhC
doVOzUT4H3vssYETQaxgtVOwN2zJMGa9UbCPdRazr3S5tiu5cEVfDrPwvJ3k
SFztTl9mnXO5dryHcsBV6oDwfohQK4u518UMUL3ZyBYS+VV9l9iE35DIiXIp
rVHtSEtUREztHut8JLmsP93QcYC7Vy8pOHS1IdZDwp/ae4PPpRfhkzN/v/OL
ZzuR5vtUDbW7s/tBH7YWg2g0LVEad4ylZtpdZuWvTM7ovydgBa3G4JhtLXje
2mj3/N3itLzhqPlsxPNkw7aVZzpWf9GBQ0dG6HHVyRjxwNMyu08kvEewSzlT
onK4g/ajZtSSJYGoHftY5W/fy02hOMZczKSxAv0xjV9MYHawBUVMAAtgSqEa
ieJp69vCNNrsXjb9PoMjXTkmMNQQNvEXnMbTpk1LPvnJT5LamJvLTxe+mCwy
JC7Bhz4/3dnQokX8bKcuTUlchiMkj50QtrvEkLjeVaR08cYOqynwrtqtcuzm
afNdxwpEGqEGl+mQGjAJJLf13JAj7Mlbj7PbEIuEfWn/+bl2uOTkcc+CrWtt
rjNXcssdfvjhtnwi3ljDCOrmKQsJznP7xUNCx5n2ZMczOUIneEZOV9huVs9s
7wdQO5xxZzhnnI79GUQSpfhEyFtjZKh7uOFJ/g+5wmmZw8D+P3ngbs8Vgqwv
+0eBCsM55MdTMUpiGa4IelYzoSwfJaclXB7kH4sw2Ke+NK204Ns9GATH1Y4E
L+VXqh3bMI9xwfE9GxjlYMtiFt3YzTaqdq8jY5F76KZTO/SAyYViRucG+kJY
zOhZ5877kLsXJhPEQuryKsMimAleZfNct1GTOEQb1WDevHnZKjiqL2LJGqMU
/PbpbXjksq0lxhZwwt1Tfep1688hNO8eZ6h+ztqs3ZnL+pP713bl2qFQTFpi
zKwt7SrlIDoJtboYMosQUj/dubn1X9G+zG4oCvFkgxHgWPyhK4k9Dc+1r8i1
Y/+D0kC/7ABC1V6gyh+7nozMq+cDjskQ6RO4AvHTh2wh2OvsoYPPnroTYbtL
gnBeVuZhc/LrbadZV2Cdw+6FXyHvrVUbKGIzvefRHINAjVjkvIJ4DI3J0KS9
uOwQui5tb3Orj956a9PfuL7BUGQytd4NBoeZMcoPiemBWg5KTlxfCLpttBss
8l7BcDOR3iV1+hmnbqjdMUF44KPBEFVL1A+xoVqhVal1k4JNQyL1E4NNQzt5
YGdmgNrNjBSufM70NcGxkw85wMe2hpUE6ocagXSz+9Dv/5Tctabb4xycQR4F
6RObDXc43VD5ecv7PRM0JkVy1NNbkyWbOjz+G10g+ebjLxPH8+3I2TnDvIvu
oHa3GBNi8tIwNdDbU4GWF3BjLQe0jicBghBPwG9/ed+FOT4RRvCFNGvb1lg+
EbbDmNCmji+7e1hiBEMNvRtewBG2LaSJWzTIHf3eHHqZm2IGpuZLWvclzp2Y
pRRlezNG+ulttBvWmZ74ApvccUaE7QgtLHH7NT7t+EKdFNeQ68ZYmCBMqI/C
CyGHCJLILUeY3jvfc4g7uxeJo9jcnVMGZjsO0Wo1GyDJKSiorWHZ7+q97KFv
8ULnW9RMFgX7l7I9SCnjMP/7drqXIVmztSlUI+crEShkNUmyggkSc2HejUj3
wmAvu0ickMD5LiSgdg8GG4H/0t0LExtLAvHbG45MtYBRpNB5vGiz9lEbfvzk
USOlD37yxeTiFX2+QhGeQuj6P57aBt2Pc9/Y7F6BdD/1yH/jGfCQxhQgNGCU
De8Z5B5mAybGgQteQnHw7Vdv9mV5VGNXr8WUuSqNl/0ecu374HHPDO85ECKR
7U7d3rAdCsbv+s/LtQtzbr/sUEKpPHyb8XEkpU56Lp7eHDimmzLns9AKJyPO
xpAPoAuc1X9lDv2geYUQwo2x5ARQzMInIAWpuOIDJbav14IC/poNUOC8tG+u
NSJC6meHMNl7dIYuYLiDp/57zH1XwcKmzV7Q94Cn/ttuu82f1ECi2He/+936
WQAlygJhwRNd3EFYNCfI5BF9oyi4Km5BmdGMX6gdZVvudnGHKj4Q0q34QJg8
m208SY8lWtPe7tup9vTzwViuNe/d5ryKMT4QC9gPcwi6vSHOvR767+SQRS+Y
/ozZbqD9H0+9kPx68TabUYMKP2dtlyODFhvsI7SA4DYq/JiAqH9m+MURhj+Q
gbd8U7t/ZemmDhthwPdgXtcrvzcGCKxkonuEd/LdIc3XaGlZ3p7UR3Y4K0HH
u1cM4ULAIfHiGVDSjlcze2bWMAOsAKyBbPVb7FEGc+fOleoqzlvibq5yJOFU
lMIv4p3T/ZAq03icuSLI1VM7cvzEINQOAp/mnIqfcVAtT8qNs9AqiY+DwGUF
eJqHpu9xNO94gqd5ZyPYZ0j/ab3zXLn3UbZQPydnClyl6QM5Kb/FJQOE0huP
4B2OQkW1oUcxLO2hHZdqF3oUv+K/FtKgNmuJVpcEEYBs01m2V0UOs+ODKv5q
h9X/lLsXo+lR7t/tj2E2pRkz69N0OK8yI5Ihryc2ZCIZAsbxP2tVj5M0LdZ2
x8Yn686IYO8/M7c/YyQ6ocF0v0s0q07okmbBXZojMpdUWyCypclZAyfm2uHO
m+dQXu3CpFwRI0FSCLJAjJUHlseJEYeesutEZNf13OE3Y3qLpPteT2Rq93Dn
E37Dmdrh0JPl/ll3L7Qbd4rztMwLKjBSBGeFy/wR1SFd70h1b+XqeKqj2KTb
PpbMwm3Xs8CfkPDggw8m++23Hx9rMJ4v4MfkJTqyNqWIovDZ3+giexkdrTRg
XJ1rN79zvd0plnHWuFw9LXLMhCLza3O8r9vwot4cDV4VFMGRQbQmkLUfqaDB
HRE9/KcnXsyNh/A4STWGDD1stjgl2pBqFnle3WPJFEe92pHljmHNlaM96YW4
phYtWuRQv60gEkNHmAgZhxeOL67GeqA+b53jUJeokA0pa9rzGxyIoD3WOS+3
cAgZlAw8OY2lsGskYUqcqImtYNqXElKT3OPZPtz7LIWG7Ta5lDh0329V8KZw
U4iICoPW7c+0G0uWta/1REXlKZfKLpHnqti3WD2a+Bz7G1atWjXYygGisLDy
mladbNS1LnYuysFLPtV5wNXuHENJjxUoka3Rqn0ZozBRhArks3VLEd0pQeUA
tQuT1bIyYV02fBW2ezCoHFBOYUM7HTOzVZWGgoUI/Vy3sieTx8aaPHlpPkrP
vkyCUFijakf6C7QW0JSsy5hDomrTUijXtCjEqZUFrkVBrol61I5wFpUHfLth
RL32E0Zv2mSPeAs34DSQNO4HEYimbNfuhX6TV45w0tKvvl2od6q/sCjIZ9y9
ejlr4okho6qN9m2yVQ5SwSqyu7HnCeSX7YlqHYZk/TPqWZ2Wbug0+Ho/aWxe
u2R3Ssi9q4sMhHu8FHMWXEIqElwWB0UGQkpd4yhV7ch82eDufdl/TT0/HCSE
iu5uDE4mEj0dY2hzlXMiZ+UDM6+T2pFvdpeTdh92iFLYdqec0SEFuxyC/fCJ
lwKu2eI8vgPJpcbKe/75NjmH71nbZR26XMnfhSN4n3l/RA76UaNmKnekQIMx
t0BtwajQvNvJgzEzAzOKksx5tPNhu+MjpMswhBwr7JnR6hpfMkDvKrXz+cAo
QVYtdKFgtUMbXNDxdK6/aUHtnE+7eQ+2OFyMV8U0Xd1DmWRfRkZoLVaZ5ASB
9WYuhtBU/pzTfNymafvKUiMS5bWBf+Ps4vxohmqslvox3xLZd7+RadohKfp4
JEgQz7YoZ2GfzAOb1SqQSnT6wDLrzfGUVyL7pgfVCESDjwW7IYVki4KYrSTP
CUFwR+0mpcdN2itZeDW75ZriMVuYOrFdojNVsSaL/doDscXFW2401psGcdVz
vT4u42tKGNWTaOyjRvyp3VFpfndIetJAA+u8ssxFml95Uw6licQu7Hy8QF7z
PHn5oJd5jwyPsF0YefmOn2wWzMsCHOLZi43xONllX2b7cm/3FRzVc+hr0QjY
wKwipyK+wSZhxZhUFk0V7J4wNpl2QorkSLKaZkiOWIihLZEchc+pPd3mRN66
tk2e5EAZnDXYimZgOc4QrzMgMMVKuZGEOdOZaiKccGeFiISNkVOcqeZrABhi
vc+lXOzt7rE3iPMvGZVPK6yzpVnfCF0jIsQNTjF9PiAw9jrOcAJShIiy+ZBT
TIWYRFhPcAT7l+7r2x8plXvhhhtusLPQ9s4RI0bA/kJKOWhBavuJUBUYJW3C
79AxOiqBUK4k2YmE4BxduqndAwyHKWnVXO2REqpifqFBX9iKi9LbSYnSC3JI
f8K2I2xwtIzs1I4qdvMKTkfqwXOwE1f/EExWqykCJP35nq6Hc4QaZkGqHQSo
e2oXSli1Y+OTIqB/7dZgEMlRgmPI1WJB2Kx+0FJf7VTUqoQpNjCe13/f7u72
ulReWuX1t9tu/jvXQ7y+gKa4we1vCInxkqB4sIjMZkS7+twilDAZQu3CPZAf
cd+M7UCWdMZnSEkzYgQf/OAHibE01U0CsDPQKNBHj3GkKRcguc2LHQkLAanq
ozIjItcw2cHLkaCk1kfdvYajnmPKop52YTFEmCgnxHLN0phJBpN6t/sEZXuQ
kexyECpscPsO2YusCZDBRLBy4/MZypA9danbB+VIVM7UgnugyopU8ZAQMZYa
LVLbGrTgIR2qHSUHlMjkq431TTVIlWYdSA1CzSgWnqiXBS06DAMMQuYwmVHt
OFtE9Kp2jwabGiXQw2ojn3KQqJO1FDK8WjlLLWPVyRflPpJGG9MidX0P6dCK
X2+70WrCxw/c6c+gJQjS0tJCWlT99IMCjDRPVFEq84REe0KwyUlrGBqbmYvl
WasKh+0IY1zi1GARd9WGZINiUi3tukLoQWHhRjckS+ASw5zqqNVvBDTXtzqt
OSvDntZnDTnC4iAuIhQ/I9iQHKP08rhmadlFuWGZ+Sc+8QlOtM/lk/3YiWLR
OXuQca+yt9GXDTUm6NnOvarhX2n06Kvc7ihfKcDQ+ByXwejo3G+/znwOEY4J
Wa90dYh17/dd91kSDZc7JNnsSJFMPMeqkXzJfRMvGcuNEnP44YeXKDG1e+hJ
NpjkYolC4zDJUO3Cmlyy3G4P8pt3Dt5F3IdkXZJ0pChIgUlWma+4aIlrhDSu
SiO3pVmIonEkM57bM/vvcd7aVqsvKJGTAa1evbrBkgPSljgqS8VCRCbhlkXp
ZqFRm+VjLfUpzVpKrlXiVSQR5nGn3xhlz50IS6o2ulNZY7wg0JOF4w8HKUgi
ZZxIlzuSl/p6ZJqykFuINS6VAcfxnhFS1kbGknCmSIqqe1CyUaoDFfY9ARFS
7CPjA832+rbV+aIBJCOhIxtC9sSKgbvK1eJzxCrfUsx5EePqgl0a9Xgkt5Yk
G8zuvq2ULNWOPUxKT1a7pzsW2YwkrvZ1BIUZCfniJuU3WgwBOcYymDrPIsOJ
W6fYEpchuYYbGNUON+/d3XNz7ULXr9qF5rLIuk4OUcgTs+h0VuvWbjbOU7Ih
13MNJZMpeHv3k6Lkow0lc+6zUcs9JVN/AjjwN2zYMHxfgz6IQOwOlfpWF6L0
uddBYUzR9NOB61ftlIscnj4VphSKNmLblVlnNDLGAy1jgwqWjYX6JenWO2t5
Y0C164Ngp2Z/TnCAvdqRuPSg4wxelULwuzBOFXXXyXu5//777a5Eo0blkFVC
WXSOos02ABKMNWE2Ei129vHu7nNsQiJdYc2WNDOQ+n9GcH8gT94xR0nGyEWY
FLfVCSO6x6ZDea9ixKp21BBRec3woJiJ2w6zu5cVibj11lut+ijwoGJSW7Qt
yxH2862XJCyqwmTWxkPdI35z2LYzckRMMrHqFegee5QUv9G7K4M6uH/tIFiV
NxRjnlUSG1taFUZE5xytzlE+2NTGthadk+yAgCdxWHSOXgAY25zKx/lijSUv
iLrDQwtEteE24vEeiJl7OTzU6nTHBaTqhRuTJLFjG6ShFbz1KK3oGscdd5xX
ZksUoipvaxhZFcDIj3jSWd3CmZWBda524XHp2UkT/bbAdT0SL4nUiqMgz6dO
nZoNwRLZ+9zLyza1J1959A9WayYghBPMWNMq1UcN3YMWvmjp/BeLXiBu5Or4
RnOLtCqhTBVJumIeOZK0BQW2HWGrwftAWd/vkoe7HsytfJjVoK2u6C24UEjp
x4kfehUay+bd2QP/Ee/nyra2Z9m8WVWn7GSGrB5MWvydwKzwGUVcpzD8tbtX
m1sUZ4O1RjPilqShkDzxQlMggESixzpXCIugWJobyezTHxYvXmxLOqKSGvKU
I6nR9AfNCWmrjbxa5SuD5Ns3+7lntrQIY3ZwvqLahSmAezo8KW4MvuWWW6y+
f9999+H/UHn/EqWmijQJ5EqCClgzg7p8Is3bgjQltQuDuWq3wtWO39KW7VEa
RDBXTAamhEkFulI7AIbz5JNPhjP554WpIH6f+8pSQ6+UyP3RgpcoqSlv6Zy1
3XYDwLTnel0hsaCwVpZKstYbqlnl2eU+10hrQ/kOHTCkdvi0yFXyVGljtvu6
SapuPH8f+chHOIDMT3IQmbcxieereRtLVtUv/W7jgUv9jt6sktwyH3HK1Mc7
/Xa+b0S+2+L7y2pyidRUk8s9E1ZgzrJPf07XYp++h98HrdaQWZPorDq1IYtR
Z/qoII5UU5BUK3NuUAhTuA1lzelem2sXFsJUfKVqey2UBiJSWp2/KVOm+BnU
yzgQELPiJqmriepa8umEJeSbPbAHvKtJ7U4J0nKHpVCa0dOjemFDDNXqNobZ
hAkTkokTJ6K8Z6vwfvf2hi1+Z40r8OwFUOh6rAqU4eaVH0kLRJiGwhjhApEC
oco3mYmwzu9/VztSJ1QUIzNoNvjvSrygrqDHL1u2zC3OoLJsJeFIH1IORLZx
OlNnRVAQ0/Se23PtaENkKWyHV9kdH1xJeERUkWlcyeqhNBaEx8mRojpU1f94
YRYyz1MdDBaXs5m+x9nqTe3h8Qg6ti4r2pdS4qbgLBqCN7c461OLhZW5uECd
cwNf8F+6+RXyhzVA3PmcDAK74G/mzJkeGPGUAn34tqC8hciGjFs0ytXt7V7l
odq0SO49Dn+CTav2j3IXE9OcCL8Lf/vDsNqdi0CkBwpTTps2rVjngit3nJDs
wpjzr7aucuiD9VDpucHTk5YDuqNMbNiOoxlUM1LtoFeJRbVDVFIzkqvPuPmo
IjTrNm/evMYyaUUJ5KVf03trjmJOCnZ/ZrukV3hnr9qx4UQJE2E+MDEcIyo9
E2j8tFetxRFBnq3ojjJ1v9qWlvUQ3VF15rsvT7UHVioawyYbVj7k6TVZDgV6
l7y7MAidaqRPBSVgRXn4aKe6TSFqt9EddBKeFhVuK/tS5Lt698TAHHuPW3DC
J7PTcIn9uzAtFPFe95hUhUmptWYfY6md09+/l+ux4TDoyMowqBFhw6xkNat9
5ZXgkLWjs0BF4eDWmHOtSi6Fjk8tDAaanKYZLTznk10z9T2rxyqAsyFkmTsv
S98Ns4g+60DBBhDSYH/xi18wb9VvaSBDViKJ7dVkB5EyruQHtldTjoErMXN0
PqX0qR1pfhJnQj2ICWLk6q/c+BtN6dM4Q20gJk71LtUedd6BSAnxRXp7eA8v
y/deusLmz0qswWtzR7M3leUtCAI3Bmcg6A3MM7lWPLF0ZMSiduylPq1AfOEh
XDGi0szJRD/dBSlENQuyfVg24+6o9DyE97mPovu5giqWJk3zphhFDXUbJQUZ
EWCQB5TIAlL8PC+DXrBXBRkUc2dlLivRU+hzjCWZC4Zh/RLBOnRwqB0VFIuH
UiLPlIH3d8HABf+sOn52QLhk5GOdi/zZdcIPLCgpaGqH+wJKCvPKoSJVTBSF
DDbvLibJM9dG5glbb/SPO3K08JMXr/F55j92vRkdxOocBNVxXDz44IODTgAQ
/aOkKW9V7a4ITChlQx8Z1EUU2kBN0xw1qR17O1SJYF9Pk+r5LEMX9zvHw3vd
N5EkGDrs1vjPbdvIuHHxr1Zbl4ACZAgh/H/4CGOEoV0aVXsR4SB77723JR7c
SwQnvFCxwMmhfo2rKCbAhTchrgs66FFyJQg6YZ0vwSTctiT8R5/Tdn21Iwmc
ZHCP/zmTGYw/3yWsaFSYJSS8hFi/3lhLeN7XtW3ISip3PuWde3JFkr2qDYaf
dHQ9iCQ2oWNMMFeJCBztbpuEJwG8fdpSKBJw+T/2j9qyP/jBDxqMiwsQYclf
vxRB/Z23BvcWdmzILe1lQT6p2hGTU4bMvhUzRBTA40HlPQQ5IxI+8qc/kQPq
3MlpLfwDXn7Z1t77RCnKl/qTpFoAnCOOOEIYH7KCAsf3Kx+4bbLUXOkQaDTa
wOAlXtfvvUUvcIQlLdWOrUOnbZ2Ya4fWpD3rGlx4UGoVp4dbEzZe2rHC4zLH
TjzsKt1pRqGOI4kV1stVOxLGVB1bOF+S4KXgUkw81jL2+S6pi6vj3OpBRMhi
dVwaA24OsZbt5Nq4o97DbA5l0BMrutP5ogV+NgaB9SH48Tlf6rI+qrCWrAtt
Tt3f3dvclvmHyplyqeOlOXgFG99ANSDTQ/NIGXo1qhgxQdKbeq7LzRtlHaU9
nDe+Wx171OJhcY89+ogrwTFkzhowZRa0A1yF0FlNx/8azlMU60YRUaZCWCGN
2IpR7b3Tjc0D5CBSRck72IxKz8G8IRqjqGIzm/YejUvidzrwrCDqYqNt9lBa
YksncHWMm9uyZct85ZiLLrooOeCAA+rHPAv9Z8dAL7fbrcNvPhzk9O/mx7HO
bkIN24U8Xe3YcHOkS1/OFBK9wVaZic47e6QDxiAiF1pqDj3HvPU4HGexWsnQ
V1BbrJOD9nSquj4QHsCnmYU5tJpPqGCoHQ4i3VM7lOvrelORL+MU0w5TjqxE
I9brJuRpxdhRhu9lRftKj7+hSpGdHzHL7oJOMTK9RwwRczZsB2sWG/6Ea10S
5BLIQpmVMU3vhunO8mwFdDICUErAerLK77jjjgYrhe+a/jKmpRbnuiAdR0Bf
ZdBugtvnpXHcG+yF1g6KY02bVY4py9YNycKn0xgGfI/TnI9y97ZzrxY7YNCP
fHnOkPHGwtke2oF81vjI+pSH0B8h3HuNTzkTDEBagmwhrNB2xXjVDn1CJ9ek
Hscxdk1CExeKg3O1DTLlLDvB/gGrL4QIeVXvzbbcdYiQ7OIi/mZ0Z9+OyjcK
kqsdWS2krBmG7BhvPFzkqykEQq2K5bKnmL3FGf62JD/72c9sRgu+GrPedeNr
JSAIC1Lrc6cFGq+WclIQx9aSowWrCK7aTQ0K437RATb4rv3DZXhGf//Rbsg7
riQkjPttb3ubPWCC9NNVq1bl1v8ncYU3dC1lCq+8zSAmymw4c/bKs+MonDnu
PlVdUzsOfJFbRO0gHAgIB57aocgS6uI4p5Qbj0ouvPDCXPSfvbJ33mkV1kGn
Yu0SfmfgYuJQHpFB7OWFM1RJkVa9d2EPhMJR5WE7FG1qNjKXT7p7YbhGwepQ
3tVqxyRWuvIwnj2D3nh9FYENSyxWR7O0qpuCA8AFJ+qoctwamnK6b29EeFSL
/eO9o1JnR3a0QHdWjOnD7l5NeYCmRo9JzVMEBS2okvp0R8ex7pUdV0ERNebq
q61XwNYBNkhV7kSPuZWqijXAnuXgFoRxomsfnjAerMOJbnQVRbFv6Zmpkzwu
6j/LGJBzPTz4be59zpEBxAk9U40Xjw2et8GlNYUFCY8z1iJc3OttBoFVqEWm
AR4S1GzT3rcjMVn1JiS12EakwxO+VsG9ObLb1Rn06E2eKfoKh0iDxo899lim
rdQpNLyrA9w5WfKD/QOJDUsWXHl0Tn92VhKH3J/ev0zbwlYGqvKH3KhiW/OH
WoVXhbr5NFmA1/X0NE2I4PeQd9C0Wlav4zqPP/745Oc//3kVuxeax1xHxVI/
I6wRdfy230pXsfoNLJpsWYEY/YY95W02drzFVvs3hqUeE0y6oP8M/zGK+RpV
RwdQk0z9jW98w55ECviMRjqUJCHZFNQWkotbqEQNB6Go0BanHuhtNO8ml/9o
Xv1JDVfGX6FzNIW2cBmGutdee1lOYey6BgvfjncTI4/VRTDtHxHOxzs3CGSq
mODcFLbmljH0vuK+UV56czuOtmz14CSFjS3bGIMxXG3EywxC0h8H3aF3Ay5/
rEXoZZbSGPiBosrqaDdIwpXCJtLAZ/Ve64vLEKY8+KX/aXdZkuZtuLI/C4HD
5NA34Mo47lDSzT3x15kzZ9qtO21p1NUeh02UkmvnuPH8td7x7ULFLTbOdwaJ
oP5dtmcQ4A9F7409dyc/fukIu4nasv7OBZZDr2lf1/STCo56Vnbeo0dNwsTf
+549zzK57rrrgnHXcwgLNdfZ1NXUvUaiGUqAwUfBmLJwP39hkQ16sGtyo5nI
19yrxfKQuXLaowZR0bTFzve/tm2zMXaDh8dVoGFV0Tc+Q5SP8xRJhCLfxtxr
hD/GnDmZTS10JOvq3146MJmw7b/sH8Jd28xRhb/3h68mP335O/h8dRv37xf/
9LHka//9KWobp2d272xVb7QaFF5kIoxFG4kiPpds4d7ioI+vjKwquB/C/Nsv
/xLfV1bL92Eru1F8v/aH/0U8r+mnNeyO5MWl6SFDHqfQOfAsMBLszLRyevqs
0S07Imwi0T9+cWHynZcfx52l2AaY9MU/zucsUa9E1JY93BFFNieWYlKph1Yd
8ogsn7RxW1x7jDlUqkofI1jxam1oW+8Tt/Csbnb5N4IQ15vaUsvzCw6YbMIj
VwLCNgriIAqNvcU1hUWRoUd4zCh8+hiWPpY90bF/ibx+vJssEgSuiXZKdOXH
P/5xg5s8xPanG3ai1FVNf2N28mXTfm6g0XJ9O/a4uAnuU0Mov8VCIPAx0dgn
VGQx+kQhslpwXsS03EsavKcVQflkVRClhmMhw+r78wp9HeMwvFiPbQgncp3s
ug9ddKpEHz2mIz3uhtRIjrsxS1FqpsVM44Rnc903YaSoO21eo4j7hSa5Z1Wl
sQZbe80OZNf8gGXs8HfGGWdYY8e2e8gN0Sjuybe+9S3L0Axwqux8jbm8tlBD
x6DYz7szP+3vZ10jCPewww6z2eCxLD7bOA0vORIdbokAExWtmD/QMHDJcYSR
HvFH4s1Z1a+e71790Y9+lHv11ltvbTqnotuWivfsyH8ZjjyFItiCgnL33Xez
d8j3AUbDDTg2hGdGp3bDjr83xT1DnEOEv/vd7yzkzAr4Mcf6bKl4LxzzV91q
YAOAFV4YmXtgL1UnuTon0u5Cd+/tb3+79UVxdV7k3eGRdimDebOlYpjFm970
JiuNoSTa4LbkPprWHnvsYX+jeUkEgKG8w30Q/Sc/+UmTjGPuQ118QdwFO4YS
OLRvbW31Up4qTiTZGc7fdIrDdJRK7CEo2owlDeC6JKWdLDPRl9EB8ffTE84F
RmgsNKpRp4MZ40/qxJDDD7vPPva8NAtI9DNYG9YBr/KM47nTQY+wQPznf/5n
S8WcTwdL5DNmwZtOsG12sYWvGYrdTzv4b53qumlkVlyzhkhJ8J+KVxxObN5V
9ilBLrpQUBRPDNeA2Cxd6pzetZHVsNdVAJCFWjIiKWZIMPwRGTIMt2KG7vgE
DkeOTDeEoq1fbN1AE5SgwggyvY9wj9mej1CXoMKvM3ny5FPdon3mM5+xEOQD
/AbwzIEqDmkNN7dxfoR1PIfhYzYZAhaMfI31kEMOyUlN1tCs3TC3biwtUMTd
QXfQP1oLUEGNEhRpg0qFEQovwLtkjLcTG/nKyHpfObXh+Yywr4CD2EBkmiJS
QLxsy2zqyJUlxx/+HCPiJlQvQEg1JdNtaBTHuTYIdwQrwhqUQAFE8SCu5Byu
huCsImgGhaGK6GwAaZC88FCjNAlyBx10kB2TygCQUA81G00kjzTDc0Bm9iiK
Ro42R1aS2bMvIqiPw0piKKM5CdyYplCh279rAWiUO+8XMDYKmZcg8AlD/Upz
+JWmUxuZSyownKXoB4sKhpUoODtc0VccqtirY6thr1fcdHNfCebs2Z4ZiQYW
DMLp+SPsrjcGi96HDxXph8Q1jNijHfMFBiwtfxg7tAW0+jSIQxvQk12OzMjo
YtJ7mAwCD7VzzJgxdNk02Q0LlS0Pr2brtAOzDctt2qcWk5gkX0QLxb407FBf
Yo2xj+gV5nrooYd65Y0FRq0gFqyBs4CYqo7bWrhaAsleYbEy4TXYTzSHn8jh
UOksUhzCGxeuLh4IXAEN41Ac7M0BAjnR6z8RzNYjkBmGXglG4BGI7nG442/D
1YUsxaVgBIg3DhAmIBVdklhiiMU9G2EBgBGFJ57MGQwJEMnwrCblLTINBCRc
2TDxM9xoMd/olu3B0CA73g2sc/jSaiHN3Akdo1IbZuX1TFZSehqMN9zcIFgY
ZusGMtryGjjEvHnzPLLARBR5YETotAYrmk4c0jeaw284bKmaQyoUvvnNb/pA
GMwYDDzmmGNyogmLTqiDVW8ofkIcvuq5anbDGvi6RBKGKYcVYyHAmugDlNlz
zz09ihBS4nvoWGhuRrx5KDmhFGDqKOsYRAvXjJgCO3WJW8LTgLK2IKAVQl/k
HIOeGM3G8PubWjyBqyP+GWl2iGCrFxxySRpTzY1kV0sraEqoY2hQmHBETfka
ApjRoZtzH7gzO9RfIIdmSEXHE+t+Z2S970yumEaz6wKrlzUGGDBwhoHyiZvO
F9pLsQU+znogL9AJjWUxIWAqRVALGHUmaoFRZxQebSh7iZKElsF7HAwOpzD9
e/MeTyx9gD5G+RXmBhhj/4jNw23Do28lXxV6IyRulCZJJXQmlPonn3zSI6I8
4Vx9vly/wQJzilX65tic5oGkgSO6hAHrF0STw1WLusFz3BX333+/qAywAg7G
y8Dwspx33nl2S/NJ2/eJ06onoBGwaHAvFFySCAhp8T9OPtEweAPaQe/oEdDw
cW50JdD21FEyu0Y+n35inMUF9nQwDPCTrvkc2w5gnE6e2qMNMQPAQUQGJSib
Hf5CeOAvbG///fe3/YEFkAEsDilFIg7voQbhSWQs6CqYTQZyjmk3W1f8zjvv
DEdtClVMsbLUge0s9F0JDFoSoOvvf//7Pr6KLBAJAAKMAuTJSSed5JOcgK4B
kfO7jKzX7hzXrM4nlfUUGDY+Y70RQJzt3sewR6rNmDHDAXqU9eehLmDGMDOy
YjBEuIddnUnJ4TYGwn39XX/99ajvEgWsCwTPIz4DgoNSumZ/1WSHR1wDGMxx
NA2wXOpdbj12sj4ofVHedFCOawDHtYHrMJdyBOIiKPkCTYy17pcD8KurSDst
R50vKtUG3GXMxoR1gZzGYGAdaPsEMpHQKLQKN0BzNEBwMLBNJ7nvYSmxXFzZ
B/aflqBl9s+pf/53P+TAEtuEGsv5imX+h5tVY+1UpiK4F9aoj5Wo1yvBPfvn
roeXfrk1vKdZZdXo68zo8+5evQr65RlwjUKjNQeN+uPMQ48/953yxRrsJ/L3
PhaZ4vAK8NRLEGweAhhRn6vH3OLfrYcZ2nTvxl36/di9fSpgMRTCaS4bZOzd
wQ28cYA0DOP8Zz5bAYuhkE0ML8pJqcXeQwTXZR6tOebhuqrsWlPHz25ETNXR
GeHr2sdXbx9/FSY0ll475Nm77isQNMMbN41G+US6Xavpg+6rsUzbOomWKFiY
M2gBOJZOOeWUytS79L1xue4OPfTQXKY91pieYWY2csoCih/xomHo0kYLwW+D
8a8EUJcLk0sIlfkVjpNvoKUbZTLtaqRVwDUF0vcLEKoEUM1tZVkO9vQIwZRr
5ga8ccOEQfFG4U1wHJMM3ZpvY/XqmVIoq1CAcQegxmAOuyADMj6MhrtoZBTV
cN6zApYtdddgfLE7S4iYrjhtwCtcHeAraUs6KCDyrXRpxvpH5COwbMGmEr9s
dAspMfkcbo21o+F1Vh1YBcfl+K7xR3A/8nV9AQKlC75OU76Ge5vuAQQIAdgd
MBrBx9izzzcA+3JWMyIKe7cbx3zXYL8hSqagZxG8T7saY7viMwAL3xEeK/zl
+AZKZt3UHKwZlqrCr0MAOg5SqBVTVEDnXt0lH1Rie9WRd43geuQ9C1ecbjjf
lDoA7jeA65oco2dyvFrEdZYJmCI+ctjWGNjZDoofJVjxYY7RNYLrfJGuYYL8
Jgk3i5JUI3yMyX6tAqnT93aOvZdjKrhnwETGOWnSpGFVaNAYPymFcYt9HX8D
j4fBymDDLRY1g7kPc27xgA6bwnFBSAzZYLhkZdgDtIbsHLKsLGgn5bU1qs8u
0jP+32233fwWzKo0bDmRy/qF7eMXCZ+5OKTX2dyZMU3KNAhT/bVbQecpATe8
Y/qNs6+wLUCIVBwuj3WMDc+UNc+zAw88UDNxEPMQbARixU2rn3UK0xBOxwmf
UYYWT3zxWflC7BIdEqRDP8VnLISm4qYd6wZ9GWojr46m1C/WyQF0g7xw+coa
zlC6KR1NY1hbXIOPVgC5xfVbsj6V/SquCP/C3Rz0a3+XL+rYmmdkRbpcbr+o
UK+yxXNgGOeHhPECYcAKAYM7ZMx3z/8wPIaUH8I4/xnitjAeAoF8HgctK0T/
TNfly9vfeQKtj7fFZ5+vuxRVTGt83eVH6uHeDZ9FaKQIxhB/CZOHq14NgnQl
CW4hpZAngLqBZdDrGh05FET8SPjk81B8XUQY0l6pqhNH5XwbMrsabeGAOdg4
NYyrWSLgWKQGhgS/Bwi1sqKxdaAvoq88K6BCI9TAOuCJ4DexKVLTwmMXqqgh
xqmlBA22BJbkGosPyhIPCTG+EinGNcR7qqH9Xt8HaAvzIRohtNUzhgGbB4RV
vJqETVR+gSHsg3vCoqFoMEWenebGuSLGw2tKN1Vs99IWVpI3EaHuWeU2IvVT
VtERnYi0x6wCwNtz3+Sv3ulbRI7RhokIh89wEWFEFbanCXciw/WHf4H7hWfD
GgFYawxg0dIGX3BaQQNHi+WesZQAPzeZwcOecDnd5IeYH76baWk/8BjsBaik
2A+2BcBsZDxV/QxmPI2CXqhfAu6R7tPhyuS7e2/NLkjQjFyScNUaWc3wGfgn
JhTDzfz0x+WmD7OC0YDyYf8wAf7HKufb2qEpEIbfwdqnLW6O2jmP93MeLMYW
nn2uGvpK3a0ks7E1a01TAU/PIkAsQx1eJ62rdt5vqTtvYI+JyPMGYK8ZhKMz
JpfNRJAlWLH8Yv1VyF+2L7fOAc4p4u82qAXGD8DkG0B80U5xcrh6qvC+SgSU
wZ5n9MWGAoZUZEGN4/1oD1naE1mognAVO97ffbuRYolKmmMssEZwKFzlHDV8
uO7i12Mt9aQsrgK4NPgZPmMY3BdGlHPg0darQyGOYh8h5uwoDp+GsrwTqLyk
X3X9Az2TwuOeVe6O1dDL+kXhQWHJtNh0Yzv7JSTkyo8ibPUbotlt505g8DEp
Es+w//RN11YOiMhw7W9SmnE4hM8gygLI6s0sgFi0is1n3PuNH7w4Ktz+7auX
ajXcsyGvhjxK+TG3Wv1PdYby2BLvR5sHScsN+8EucYWiGhpPWT+DHU8jayEV
qKQibEsDS5XvfnTNLn7852JbWsYyZK5d+tH2GTaL+JaWF2LGJgJ78+AYVwMO
ttth7bLDTVPV//p2Ho3G16ARahU+/9AFIbgwZwg3gsL1p5gvbvDZRlakipWN
r4sMoU9BzyJEU9Yd22Lk5Bs0IEZb5gRONL4WY2tGh8xw57hW4UMj1FG1Fp9q
ZC0Gw8hG16ABCgDMp5w6dsu9E85Y0ED3KlIHY8JZAzRKxlS1IOoKO4JP5/lW
Y8ShTwFtIrDkeyrqmhvCqLoz5NNyEQ22Lq9UKIYFCxUvEhLkvF+tFbgxrpQV
NQDsXB9Ez0DfENoansBQzsFTFgtLK/YBaNg7Rx87SkIUVKjyErPVtXv0TELb
PfMrFytnkT4bUdqvUaFMG/NEneAeQ++pPex1TFmxaPsbdRciIvjJNUnEGeq8
JdeWv8hg7W8SqcABNgXpGe68AsC0JA3Ayy9J8MwpUFVn21ZPV8+0Fu5ZA2sR
HzMJ29oHno251VoU8LdaXCmfO3U1AOfBBx/s+6EPmFSj4ynrZyjjqbcWUqAq
zxKuWqpxdcveEEIQ09Iy5svhtMaW13MLnuG0FtfS8tIny6ZMrgwc8TFxDyWK
5APmoCnr23k0Gh2lEmqV4FRX/w4u5h14ZKvdeqFvNj7HfDmgzza2JOWcbHxd
bEA9Fzj1LDJdQaLYHcF7laYaPCTSFUUDa3w1xtYMD4nvDsuuwohG6KNqMT7V
2GJU0Uc9VgZuS4WK08f4uhycGRfpQ2PimRtT1ZCKC6Ku2MPEp/Oca3xD5MEz
pofPhD4Js0lIuTFogRqQUV6FGmydeKlQDAvdQNxISOCGqy7KcaOcGUWA7d55
cxTabPMCfVFz9Ixh4FYRGMp5+Gj7jA10xT6YGkFPnIk7SkY4FUr12MLqXOmj
ksrnY8pq2NnfeiYp7p75hYxVx9JMyvoFeuxGzgpNtti9d+x0zJ3QvWtZkTD7
m2foPQCWa+6jFxULitUf6kibgIbbUc8Q4DWQKp9RACm/NmHJTx38GT2HfEzd
WfIM/z4L0Pis4sNFZaGf/HBbvPoziBkTBd177739UMBo7TJvFBdq+xnSUKqA
L+Wp8rT3krV5f+VX6REJRz5AuG6NrGf4zJUNtNdaT2iVECWE4YEwrnQ4MEy2
LtI1Nin/s6uYz+ZRZkwMZaxBCf/Xdl9Bg6HNmTOnaTCoWiTAzzW2AFHuNL7u
siMNBTw9i8xQky92B0uWNaxn8cmPK5389gKfJBC2B5esfVMjjLoM+H/dGPCj
2P/mussNqeLMbwD7SyGASlLEfoaDOKDOBhuLBrMCPKMfKj3yLM+KGkN/nvFt
omGcqN1cDcUqZvy1KvSulkqsN1q8NCGtd66q5q510SDGXuIALl9wUBSA6hlD
ADhChnJmvJN/VuwDiID2OIx2AJ+vqwDtnCsA+qtDDk7m/+Yfk5eP+VbSvnZl
rF6nltWd7WUFFRpGWMozVmpTmFbskqCnysRS24Bnh/30h8n/+sJHk7/99F+5
tace2FtssT5BgL+wZCgqI9/Eo0Y5HzAXLVvlRFHwC+VFNaTicCEcUkmuuOiC
5OPv2z15+7idk9OMlskzumCq6ZBG5rKk6kCrWPj0k5FFaXX/gorQoKqympl7
6MYKpeo7qJFwbzYXFJ8NZlVI5+d/tKLiM8gjA8GbS0FAyQlWQSuC8UH4Wf0A
5kbGU6+f/Hi2a0n2rABxS8XSyF6K9OmHwW8c9WzNCfqtQeT8so31zyiTBRjC
TAItKS5pnFVwL1fEVwazhkRwnybUwwGKYAmec3XPFhT0NphXcQj6DF5vJBM1
heG/+AzUP/oC/dPOgaURhI09+3wDq1B+os/40lVQRWryfJDr4bMIcWj26o5k
OrQPZLukT93Zp+tHJimvYdviom4A+EXYw8tQ64A9+6hIIKm7/IOvuPzpIVKA
NNPIexZQONUwJglXNYD9xdkTDZNeVUR+HAM4MDT7QcKezBdGNWHChPzKj2sI
7wEsS6eVR8fNyrRWI3+MI3+tAQSPvOexkeQijE5qEBVZUAERmgfBYeoAmdfp
nS+TIi0M1TNMYF6nmxwfHpcbGLtY+Dp1fIpdEGJCrLEAxTO8Ylhe9WxkfbVI
ZcbPPO6o5KL990wW3HxN0v3Incm2S36btK95rlgWPCwnRmUqisYH1cLDot8t
7guFHsLi7snqO6cnJ3x97+Tk3/zvZP2EHyTnHnPYMFdFXEWo6ERkEhQjt+nJ
4DKV4whRhs94L7hORzI6HJ31PE4579zkyH0/mjxw8eRk7vG/SA77h/2S6ddc
A0yaNAxXej0YRk2p9Ob4bav3+AOdns8KookvEcommKoq7xgbsbLr6h8/HFSM
QuFnFYP56NxQ2Lc0Y8YMv4EvfDZ79uyKmY7NtWWDRwjw4roG44gNo+r16mE0
CvCPRWDXWgHrkm5EUOS9oYnDk/NLkf+ExIXukYmgwwuGOVoDNqTewu2Cgv4y
LTUC9luyQ8PBaFihZ3rNf3WMhzrPkNzwSB32RLfwaQwtnfVahmSxe/tUADR2
PEEdgEL4SH64mnvkjblaJG713fAOSQ3XXXedB2jJ1MK1IPeRtXPAbKoPzVY7
DDTIX/ziFxaaeIAaWsOGzk/47CARNNaHZgEzgKoJUzSCnQIwYYQ8dqbAR2Kl
Z6mVsd/GoEqoPr+QY+viKGADslpIJKt5Xj6dPL78XV2UzLcX/4XAUS3wi+Tx
sWQ1q2h8cFAECqiKRRxT//RVw/AyPoF+h0fFvR6+jRUJwdTH0JLboc5gVYaR
rveBq05Iup54QPNJeudcm/TOvjpVLkYkHc8tTbZeeqT1p/C4fdXyZOvUY5P2
9WucAjI86bv1kqT/+uxsv/4bzku659+9n4MM+sn/f2ZL0r10tnltRdK2eV1Q
Wu7JcmVG52d3PXF/0j/jrADczUn7utXJ1suOTto2bXBHbTXbcaDkhO1677wi
6XnAZqX7Y5w7n3nCTPv4pG1LVqPazuuyY+y9r2QifmSy9d4jkq0PTEy23ne0
/et/+Iyk94nLzWzuZjbvdpPsWXxj0jf/gqR34bVJ1/IH7CT9s0Uzkr5HL7b/
dz73sHm2PgDAifW0OdSM55OtV0xMOpcs8KTSd+vvku5H06N4dY6lee4mscWT
SMeyJ5OBa07JAaD/xilJ12P5Q9DtvRQPmr7sAaDqKG2b1iYdaxYlXcvuNbOf
mrw86x/sdIwC5HodkXQ/c3vy0o3/mHQ9OzfpfvrmpH/+lOSFu/7d/L7VLdGI
pHfBlclLN/8w6Xz2oaTnqRuS/kfOTl687V8BSwCSd/jvD3fvrepYmizvXJAs
7nooWdg1J1nUdb+93tK2xc1+RLK5bVOysuMZe/+ZzoeTZZ2PJ2val9tT9nSm
4sa2dclzHYvNsydsm+UdC5JNbet3r78GXQvnJv2zznXU5eD99KMG8c/MrYFF
wvl359oB/47l6fG4Oka3Y/lTycCVk1hb367r8fuSvpsvytbAjWXgodOCsbSA
pMnW+ydYPDS/9emtD0xKOlc+mqeTTWuSl274btL75HQ/xLbNG5Jt9/yWZxma
rF2cvHzDdwzu3u9PlwnBYNdl78iDqZF7CpazUrf3n5Ncs+2I5MaBk5Nb+89M
7uqbkszpuzSZ3XdRctPAqcnV2w5PHuy91h3JuVPyZNe9yS39pyfXbk3fua3/
bNP2Qvv/jK3HJTMHDH/umvtW9wkW9JGeG+xtXrl5YHLwylnJ9K1HJXf2n8+i
u/mn+PovDNiGsX7CLxvO/QG/rAX7P/n1ZX/v6/z6YXY+okOU1nDS9s8f89qU
Hl5oFzi931x4pe+2Sw0N3uvqhzXWXXBfJa0jr9j/e+6fFfuqZeErl27fV+Ov
hN1ZzrxxfbQ7ELxrwYPheYMh7nzB0/6wqjGkt7fdczjcdDBDiz8bFQUkHK5n
8c2l/XSteNDIgzO3D5o1t0W6fY9eqEfR3i0wH7+sGk554H426KZv3cURQAxu
kFUgfQV7ek0/bjcwWLCmh9ilzzuNadt7Zfq774KkrftO+7v95QPM9dQqLBjK
gB3dG/7WtnVC9uHuu8wHvzXUTktap+c9tfVeZb51jPs9PWkzgthP0AjdOkD7
agDnedt+a+T2pjci4r2mPX2DX6la2mqP5KbRZS/8wp7fWRfBWpN7+i4rPtoe
4kOQF7uTulhkU7cMnJ481n1HI6MsH0mrm/C/mU9fUHg2suaT/L+iY6FRCo4M
mWrIDXPCPBbJbLZSuvvh9IDY/9vbtwbZVV3ptWkJAbaIwR57cFLJJFWZOIk9
xmPG8fhFYsaETEwlP+xyuRynplI4VMplp4gfIGTEQ0ISMAPmpUGMJBCSEBJG
SCAhIQk90Kulllqiu6WW+t19b9/b74fAmKn5cbO/tde3zt63z7n3tiTmRyPu
ufues8/e672+tXZoCY6/8pQ8/ZqU3/JRYqXBVWo/ra7MLG8JnjnJWV6b8tIj
+7eUxrY9l3g/zkjANPSm6QpTr00c8F7SlZz+4WVismf99p8E1yb3LYWJb8+d
3HOfWIXhcoS/nWuv2e8cIzkwLnFYnIUJZ6ngLMwrUn4rekguXZ3ybdq1uRcx
7uaQRIb3iHAujDvtN+WsM2eSFkawwZ1coAJOnp10Fvfw7tRFm6vUYNdGf1sq
vnu70wFALQzYbYpn3RPmuX9bzcDPnP2kc9AGT9k4SPLCJM5VzNuahr/91oe2
fmnXbimj0vbB5tKqd38Gx8lOMMZ34PDkWcn45qGDztRfLI4Ym/h3FdtK66d+
LVTz8eAeEFL4xAN38duNk/c7567PWP6TAd/Kr2zZertLU8/Ow79GxoX+Xn8t
168+Bjh4r/i7Xlj5a6M711uggOMmVy8U/znk/kJvl7+f87G/otem9V0WKc1X
ha87cdAfsfkHeq3Y1+EZxHl/nMHIqVfFPw7HDXY0SsQhnOl4w4rSSIv3/EMv
caLbv9FyWxdMd9i5+c4Jjl7BicXCFI5OGLAjmAtuT4vn0W+lOxk38qrnk0Ih
GQcb492fxvdz/pXwlfv0l8GEjjmp3+Oomoc6prW2ZscKfPpoxeV0X7w1tlqc
PXxBwusotjhCugcEYuJs4+QD4t2HN20a3itqCERIIu8rdDn/8xf41+4HAjww
+ttgF1IVBOePEAxCMV7C+GsTLz9RGjq+P9pICa8c2xNt5GDLsdLkuofiDW9p
LE2+8GB8vw2PSqgBn67Xp+M8KRSIA3h07tw50/FZ3VgjihTNJOK5yx4MNeG8
iWiCxb5zbtx8ifL8gb/LaNNGTguhrImDTyR0KCv0uE4QcAXtL4CmYrNsgE0C
InbIA72uNUp61EvnkLoKvV6Ouk2ycRDRzhotDB5PGH2owcvRFCrsHmys4/FN
2Q2r/dljAKDfcccddYzOslcqsvBBJ9/aVtzdZYPTMp3FM5EU3u2s6f2jL0XX
zgweL700dW90bZNbo+ahQ9G1t0c3yu9DJugptpdedOsBiVwD0SKYOtR0ICIy
WDljb7wgnz4ZydO7JChKkwLxxWJXezRubNvzZiXZ/fZtllgyPv2JrhWyG4BN
4A9pZhxHRb89u5ceTRt/TAzJJ5SCNo+jKxwd74iZx/nnQ+3HonH+2tGI1sWM
2XmXBG5jqeqf+5iSA+CUfAdkRYBQ6OvrizT8FE7M7UkoHTJ43LeypcFYKHZ4
Ci7kbKoyZmR7PG74Le/nBa8ksltl+n8xviJ9p7W7C+kbBauAmtGmw0lTCgiq
eTO6i+dAbyZwe9zbvOjeGvRHOt03ut4EKa+dHN4nUbnwGoKAMNTL+ePg6KZg
01Lpma9V7DhTmlp5j+hk0ung2WbJbYT7LsJaTWkzkbf8ncXCTcnl+iWEVezu
SO535pQTzIsCeq6X4yOB67nuuuuc1Y8qvCusC1BGi5pENFAxIYiE7EA4UURy
i71t0a77YNQrZRPt9UQ7kLw4shCSZXCf/mMFQkaaEdBXFHThJQBwcVolRVAX
O5WkBxKyhBZ22jgiSwjzicdi8oV5Pbw/Hje6zpH5poR8dYJNztToGHq77tMU
1E6gn3TauGFyYenU2ErR3J/R73KF7tKZkS3uN0+XmsfWOhe4zxvFdem9k0i8
BEGH0jBkAObcqu6e+x3CyoUys3m7Y+FjysIUzhDqncquJHC47zBr2wZP2Dgo
CSqAq+3aaYmeI88xzewl+cNsHX1zXSQexfHsPBtRi9gRKvZJLaF3yXGwXWge
p93v83oH4JwIJUTBDKD27LBQqT1G/TQS8+bw/GgWYnzsviea7VB7gwjvaLZn
D5h5zXEjzVudKf18wgPyNFI+oDPodQ07E10xMS+K8PqQNYWanQOCT3RSxC0b
bIopupBTE6U3GedEZGEKB9EmrCmG9+RD0ygf1H1ueKf6HXNK7U5MHjj//0pt
ztjuHjxWets5Ww3Ops078fqHOqbfqfyD538uHOK4Rr7f895fuevnVH+lt7Xg
u6VRfaV+JTJTvtxZtwAwsvGJN0SK7uVJn82kXmhwL0CPjuOOOG97z9jaaNx2
x/pIFiX7WlHeQ65DHocEOv6a0/2aD6WZCDsFhAsv66rwGnKkA4nzM7Z9jdgr
Wff7E5UXOC1k3759Quxr1qzhslWsUVbhqwTKRZjc6zzL7pZotsibUhEYxcBS
F6uk12Y7euJFya+G43CvyT1+Qxjkx+6GJ67glJxoTt0+m8mcJvAZwBgoS4Qx
n6IjtHD64hk6/R7uoUSBJ++PFlFC4UP743Gw79V+tXHevpdPSXydrskZ97St
H3yz1FtsMRIAyzSPeZlHd73HUeWu332v1DK63sZBOTRO/HUiCerSS5UrsUUN
+7tnbE3p6MgbpvdguLcMHYleMo3wkb5EihIeKKcAZoC3Go7DvTap5KjAIJS2
4kVq0t/sjKNvWXKZJDdycJsgJCLSXLvEktWmxp1Up0GU3G+3eb5kEByVCCYp
Y5BKlWqiTakCx46uEmBFOEcBWzRvjZYSzgB0QThucv/DEi4Jx03tdlqrrz1g
i3qre/a0UIjc1nopQQHgBl2kkm+N7gdPmAA3eh5LzBmj5xEnOByFRuNAhapM
Ev542plHfqvpdKRFSbDHrc7vOz2yyWxEmEeH4fM5gc9xTkE4pfBLKAfjnrzz
n484s6J9+C2z+Y9OLhLFgk836kqkla1V4oqqm1pXTzKO1gFyfsf48mgd8Jkk
Tx2zc2yFRRQp5mA2gV16C51Gm8j8nxs8FdCCWVm1HraYxkJeJ7wai73AHybZ
TWxwpHjyUDRudOeLpdG9myIWAksx2MNxxZ5OiyV+Qa8BMI7KNMc+dXTHMssZ
IuYZbn1TvOKIKQI9w8WGEzHatCFm8Fy3ORKcnSQPzuytzDzUJV0PB7JpVmkw
31wa7t/l/vaUigOd/5TLPdBXGsoddZf3l4r5dgK3CtonH5++odfQRR7aK4MR
JQCE4HpnwmAwPnwqMvBdWk0pXW3X2swySxTaVvNneFpamv5k1CctiJSYSdTU
yHI2uKd3Dh2xcBYU1+nIta0XRfbO2HPRqjp7ULybkEXTKi6u1KVlkRYEmJs5
oY2VSQfK1bveEYtSK/UHQQwE6xFmClkUSKtXNORGFgUr/nbywYi64MUgThuw
KI9JQPM4EBCKUIJDlypF12rbA/IxcHMA9+ETOSUMqJq9DhUHXuzvtXGC79rw
aPIulwFXQ+ky8eLDgrjDp8/rLuDAE1SvAu3p5kMBA0Ma5JRAgz3bgMVigXBa
fP9w8SwIG4wTP0hzfRwXhmM5buSdLYJIrMjC9Ukm8vLSWM/a0lTHnYIOQULh
fMfPS6O9LxM/N5Q77C7dWZrsWiL24/mOX7ifPEdkWTF/rjSY87bDNynvGxsF
Ag2MbpRHlJBCsimSaRj2AETLLQY2pY0TNm+OxwXsaywNgpv0a/nnKe9O4ZoW
LwsVA5wwZ0UaU7eNvOEY8yldEH8NludRJXqO63Pu/GHHNLkgowJdrPAHi80g
RKH2kq1PmBWhJcvCBeDlOQ7gXoQmyukKOrGr2GZqAGEJ+ld0WsGUG3R9OA4+
XdvgiWicM2tLu9SW+eOYeTFNcB8PlNLDQsigMz3Mg7cthwCI6lyzmPIbWpmR
ZXLv0KkjBhE2QoHvBG3tOJpMArTm0DsN0TgJn+zywfjP6fRmelJmIlJJktCm
xd6z0SyHT+8qjR9ZHpMp485O83KWo8fXSTYwHDfYedxwoNW0MbgzFA3jPcsd
p94hzzBgaL699Pu2bzvmXq8RN/eM/Cl37VvgckN/QGW/d+5/uXs4N36g/1P2
87bSP7T8UWmkb7Oq7MvF+keLSixMcMJdIpNtZxAhU5IyFkaoePTFeAfHXtDk
fDBu4jdmRtu4ICD+lZS14c5Vigxi3c4N73L6eZWxw0AhJyZ2X/G0sYM3udsj
tjk1vkKikfjEfAKime0qzr6pz59Z6mluVupJ5p+x2LFydwrc5AiJEInR1zRM
y5eC7b1dM718qcPuhd4aeyEaBznQOPxmKAtId+ikj7kuWrSojqmzio38K23H
dBkw+tbL0L2UAWF0ny8GyOvonlciahnf9LSlXc1OFETAXWJ1c5yg5NcuCWTA
BZ3gNF0MgN2lHiCYKJL8TF2ZSXLgUfNoOQ7sDtB9JC7chM6/+QsJCFUXAw/G
4qd/X2mq814RAwaZGOiVcSN9O8xjLAx0uXHzYLzb/WALjPWskLDZJ4O5THQ/
6q6vVBK/XFwreoTYfj3gKUUGiBUepzs9DOZ4zNvIHow/GV+TjARCRrnktwgp
jbxRVQakxUST2ZH4IQlofZP4Tzon9dzw7kiy5txMDjtDBpFZjoOB0KyMQ86/
mKTcZTUsLRk+X8hNY3jAA5Ec7iqetTkiOXdIgxZ8Z0JykGfhOMDp6Vwrw9OW
gT0CR9VZ8NUCyJfVtPZ+QcRJHmw5ZuwKDH2xvTVi4cm1S02NkwAkuffaimjc
0Im3S+OayTBCQTGNT2IrmuLKWk4sqZtOwpJlaIwNEZQKwYoPyVXU+Ttbopmh
LgOoOfCTORSIamn9xp/pNZSTaSsTv/IyAxNlA8546FzgFPc7ti/FfKu7drdz
uzuSxHjPGqfo10USojCQc5y/0Cn7QzYOLvtEl4cbfUuvBceWGMl6+31evK5A
0ynOIbHB3b5NLYjHOeeyMHWXMG9kEIyviMcN7zP0USWGTovmRrnqwWOl4xOP
GZkfn3hUEiYha4vi1+eTtdtGXjennON6HCscm4yNqx7nozDCzHMyLyYFyX3M
Wvd1uu70M6CjD5cZH69PPG7hZ44D+AllT+EzIBqYXvw3nr15fhLKLtGx4yLa
hqbpctQRavqFRBxmXyxGgwy86mhes5I/d42/RZSNtjvHhZmbf6/Trb3Vfkqq
UheeljuJdrCzSUCzEVtLHua+iJCH2/ZLUj4cB5OAuR6OQz3caNPGiP1ZDwyr
KgSCTnY+EN1vpG+rc9mXRUQw2vuSY3zvFFtGzDno8NkLA502bqj/gHkMJJbJ
rofE18cnRp+wTlgv2ETakz8Qiokefs5ALEl0bZPP+oc7POHEjJJjkm993NJF
ibigrs9XFANp4etkdqavC12ir51lbxGr3sFmCYiHTH3UWSJdQ8ci5kfw+ZAT
XHDoOa7F6dFWBbmQ+WvNutbXtK7cEVQzoi4u3GFodUBvwp07PLLZzHZSDKBl
zB4pm1+hjME2e5xAdpu/CktcjmA/+EZp7PWVgXN+2JxzM+BbGiWAFhKxBNTe
ORqNEyylYhZ4TQD4qtXZ8yq7EXTl/F1krItpoLhI46xTm0WBRzTZ31U6v+Pn
0eRZExyO82E6Hz/8pu2ova4znYf63452tDDQLcob/GlJur5XRYGHtDjZeb/w
bUiz4NfJLk/HTHXCZ0G/QXib2gQ6jWeHd5r6NV4MbHHjWaB+lNotwm782R+k
uh72WIcCG+XGhgyJJi2eHaru3mILONHe8KyTK6c0bsDnH3bPzns3N4lfOzPk
iPoWHHdi4olSZxmW44gzTfo0bkDurTU5XF9thYWyaFhBdsC2hg1OrkREHOBQ
fLKkXmCDc1zDyFbjaOVealYkuBAUYHM57Q51od2b0phZyjUb9wVx8pyPk/d0
Gl2MvP26ReRMMztPHHmwiG/AX8vvFHx+4o33eU3f16PMnNG6tIaMo1kAAQTO
BAmM67OxIPElL8enz3HXfITdE7ofyBsKg2Ftr4Xvi+5XzLc47p2volXlQs9K
p4l/G3EqtO1grjHi6OH+vYbg57gxZ7KP9m4KOLpe+gUipI42GIlDkGjLLtOW
xqGDSSDcVh26TbVJkrROjHAbN7rB/W2MODm0SehMhI04whBEv9NOjsvsjcKo
GJ973Gl9JLPD554d3uE4fUU0rtXNpVXR/xzXO9hiupuqoNZEdn3WiurcX1FD
n7wJUOoRjUbyHQFoZeCM4RNoaRraHLdrbJUF4JWHZyuxl3W8qtTFZ9oq028W
BurtjoQbsBlA94XEnRYOG2x7x4CtFg5DcwINh3085bcUluylh95raCFT3ugT
MTL084l78PnlleYFwTOhaOlN85rhAgcCkz8pyk4UrfOaiQs09RpE1L5hi2Ui
q+81U6oGoso1TYuZFfNnxMMOx3mvGx52gkKAKBjMtwSsOlukMZrqoAEfG+tF
kIPJWHwIzlsZwZ4FlJUyoDElk9+FzoR5wcxDh+NxgClqVupmWwG+GVQSlGfO
3YXs0Ty2RvJd4V1Ojj/jWHZvxIrtw3vc9WejcQiAE5FFVqSSgaRGS79QwYc5
LiYbMpLYWEh0L0SaLFrIy0KYGBzezROPRHx3cPSVsmqe+tKhkVcFrxWOg3V8
VlGdyp//TOdEZYhqnYn1jxhaD/CnV2MPTkCyXXGOXGrI2jwqwQJHqLUoy2AB
g044FdkL3aPQshCFPvB3gIUIs1DwYnm8R5yFMjNbfNTFMaM1bzPms0BZ+1FL
KHPcmLN6yWjGfO4z8IfGVBmaEJqMti2JBjYrMkzh/Twbro3GjfU8566/Hgup
/DsSrMInolshYFBdhCAkiOz06dOBbWtMJVBFT5YJXnfAF84PNicIGBRfaGrD
xiGFrIVyNg6/0zAXG4GTRA5JKKWfk+4ePFE6NhlDfs66R1CxcRyyxP3qxnER
QsXGcQhIAxocchjCMzA/0ZcXpFCtmgmdoRHdBM4CnWTRO9RpIFqFUEIwsdAp
Fgzb29ubwmm0ZnuK7cZBWyeelGLNkNOQYn5Jw38JRM2HnHLOX/hsOqdJImfn
i1bsxarOfBIwRA8TaeFUSJAZuzYkam6Z1HiG/FUwrFVO+etyiQrBfodFg/9H
KYTz2GvL8HBXfMT3TMTgUmB0rkwa5/u8EZnvj1PUHqNoEx3sOlWa3OulNk9B
ykDJhMqEHJjYsVBSyCv3J7g0Z4eO9sawXUSNkBgKiQ+eJMtFEk7dYiFkciDa
EfNkWdRzPf3002kcGNifSa3I/um1IlAymumxccDLjsbWs88Kb044kFZQX9FH
7MNlOOMGtmhamcvgAz4PRgILv23QSXKcBHyEpZPS0kNTd0oQKeTBWpM75EFA
21AauX27hAtK69evh0qrSna600zeksuQlD02siPiMviVXX45DB4dFlpxeuiF
hRwPPmVwo4/AHLQiEvdxWItbDWZ0eAcCPtEuSb2UZmhJ7hK97emMxsGsBHoD
n/6tbt3mzZvFD9fNlGa6r78uGqFyesZMy1XR5o4dW+203uvRnAVqJQmYBHcB
vxEo/HCcRGoPxX6ZtEZQVOWf6qZmYGGmB1vg+DHHYuCO3HGn3uJoGDKwCAeF
jCmOqFqeaQxMxgRggP2p0VXQ2eeplmcCnVziW9gUglDU+DIfGApZTwpd7hbY
pY1D8EWvmch2ZFXQ+pByJdnorNzuwUY+GsrwnD4mYbycwKQGCkn0Hymak1pK
QnrSW0UM72M//vWI5qk1HUOuAK1BL+zfv9+YtmpFGNkMWAptUGI3RL0kitTx
iWAbmKZ71TDhONTLsLY3ZEfLj3ofL9qT0BA16C5SIFrUaFBg5+MR1096QisS
7VGmgQ1/4CssAwBN0NsVSlEB0zVWdXHLJPy5/+FoZmJUNr0cvwFKz488E42T
cE3b/mjc6In19tsv6bUQdhInSGJ1ONK7yVRfiKVAuAbcZAazGJoPRmQGLCSA
zOH95LcddwI/oVzn48x4NkKdSDYhEbBx48ZEBCQlMM7FUlpOmjI0+RSqo3kr
7wQpaJlN0pRhi0VpbBwgkgrnp1U+HeeesCAMyY6ht61Ky/28t9gavTOKLnsV
sst3BqihTSEWHAcvsH04XhvYqE0aFCELVkqKrFq1iodA116KRu3XX+iVHj/o
/0A2OuWsC7Ig2Q3laRsVSspxIZwp0n6ehqT36coFCd4FoUqosN6kWEfgxR1n
Ik5D6HNsR1yPKa0dt/xdwGmz7b3xh8PRnSlVe84iBhycUebVieZ6NIbZnohk
ackzT3Ibxv6dJ5z5uUB04LV2rUmqBvDpBr0WQj2SuJNZ26KA9kZkAajQcN+b
EVng81jPqmgc8pZjPS9E44p5p5mVfclakL5I79x4442SlUaLXHcthbWkW8R8
lF8mLANNppUkxjJw4aQIIJcgIkST/RrfJXuOoJ0apVWs8dpw6XX1VHfRQqCg
+bAiorkQQBkTqcBrQB/0aKCCv0V9XEtZNwnw6hkNVpIH01IbH9N34gmipLco
3R8fzRrmxBn7pPJDIc9x1eb8LRpdEGvEnC0KRRlv4ThwZ4eKoRRu9FnFFcb4
0HGoXwsJHzihKdVnVkcsnX3vjopA0aQVHJlwY728MUirtbXV8isVj1hTW1Nz
g5YHbFxrWXxOCyHLscY10bSAJmBZW1i6T2CgZeL3Lbb+FeTHAJsRmXVTnfdE
RAAuAlA35rgdxoUW6elZLf5dOA65DERsIg7u3+1BgIUEHoSMNeD9fsGSuRQm
4/BxAQSqUTcDH6JjgAQ58gn4UJh1SzwOARM1lYwxpUvXQgRMjTGr4NGzMeeJ
aoSv6HxGq78fOmTgHq6CDomuARcAcH+4gh1OCxFDyHGwWIkrIFum5Sv8Pa6y
U+yQ6Ctkp+gTtUB11+R0MlrshgyG9run1Uz4Q12yfe5lNEAqf7BUX5pa8O8C
/ovUrW95/EhEtqH7x+1Bgzy2k45ax3T7ONeNuu44tAOBJpDQwYMHqyYPIt0H
fD36cxfyfRYx8MC6uyV/x8kgx+fTCAmyEeEZ0XMD+QT+1rrDkDpE4AQAicDE
tQDOQKdl/NL0l0H7nHPHwpiEO2F6dkQ0M9r7svt7JeAw39AeohupBHgmTu8F
+sT4S5TXfVBYJqEFE4/429BRk9C+L8F8uWbjED0Qd60nGYcIjZTz51ONbcbm
s32rhKkApWseW0emCgGyXAyf8IuNA9ifDepFzo2uLYyu+SxGV8RU2aVys4Xm
YI+yf4UTGXUh4WXXy3nummMFcuxKB5y9/9xvrcbRJU/ra7wwcou8c2xFyFkq
KiXCcupI0nbu+futvQHJVTSWhjSNXI/tsT4dHBdm7v6TbgNiTUgb4viLIM5U
OYNgMRHnmFFP0eVHao3xFFPHoru2R3oAIU/ESobajwbg8ryPn3Q01n1RR2fA
GGLVFleLDeWOOabygpl0BfUHgBs+RXh59dMMHhAkJyxi2+32oN+Hr2/SdcN6
fec735HU07Zt28rRZHN807wPvsESbilXK/79DeAn69MBjFvxg/+AbpKeR50G
KP7u+4iKmjUkZW+KeyOvhTY3ibMqflpzctGbATBzVlPP5BgETajWOA45vpNa
l520qclbIIbjUPxyRGMZbIRUWw3bLEFpBUeFcIOzythYdsaOQFBoR70D6qzM
XfDx9GSB2dL0HdfwHcadGN5dl8Jr0t3gbLPxmtSVaO+cpBVY3uuqns6EbBGp
X3mPNHO1jkzIU+zaEPBavSgsKOXkrasHdGlCmlrrOV0679RasafVWAmtzdDh
AOqKc0emQFRdz+kA1Z2XKlBncpotAADq5N5Fkvr4ou5EGeogXHUJPBZCi/F1
S5UnLPS0FHGHrAa9R1xqnGZfG91PQy4Bq9VLVxWc2ukXLJlLQWPTbJQrUQ5o
uSnH0ufvhAVpPaEE0wKrE9fRSLDQV/ff9V6hxUz5lw1ZTjQXbLXjE4/xdY65
6fRoOQR5JFfoNH7gK7Y4Y5UFYfytj6i0RkuGSMlJ7Qz3eZ3WTIvEmNGjN6oZ
PZl+9SIxVg0hMbD8vR9Leg4JhpPD+4y1AHJBm0yAWhDFRFl4GmutXohQiJEn
oN44by7sxjrUdNBO0QhZEBjwkAVR4AGIaMhaOD4M53/iU819uixdf2ZP6YM1
35AzL8h7UEM4oAQt/yiKUaL5weqviPlo5lGut/T+hluRRkiO+Wh41rlmSySb
9+cmgpPwx3Ol4b4d0f6PSgTypWj/oYXGu5+Kxg2KZvubaJw3M70G/LZeQ9ZX
T8VLgQtLpB5lUo4J7pBrMdYXf5Uh03UeBV2uTpAAy3uzx6bsr/VEU25yMrhD
ddrVdg0BjQPRuDBBRxaYWUJtblZCzTg7pWoqYIHrdAnRz23x72+W2ERfoYuk
jT4k//cf/gU8J834Jd5cY6Po4VBqTYu71oduGVQNOg176lVi2facIChDnpBa
Bw/qsnFS86jBjZv0DmBsHo1YSAL0lePznieukJokuE+IqSPWPnx6t2SepdVm
Pmfn+px6VSKHQEEjVI8w/PntdyCiYUcvIcP27hs/Ew+LKP00XQLMMwg8pAqf
bY77Y430bTZmSVCYPT7kXggTZwmzkDFgTeC4vXgHFuqKVYHMZsNiE6XgY3Xz
rMuMUwgNZY3PGicecUbW8WiuyEr1F89G7+QVxWvROBhhDKmTIy4mg0WZmlVQ
xIQTRSBCAGjali/k6v65XustJM9Q0T9LmS8jGirDs/RP1VApyQeVQo4FyD5S
PSQNvrsSiydo+s1XQEkQmtKGjCkNvndvjNgHR6nhkDSyT41RTxpsn9AHDHYc
k3aD6PKGU1uGzh2yw78QowBqCp15EBcs9rbpd/WM68mnpCV+aCcV1E6KeKDz
roheUJk/3P9WRH+ww2CP4RODniN9251iej7iFbwwwi/GK2V21yL9JgOkOh32
G4PHvWfeba+E8lkmcdMSwJwqlMmhqbuicQD/v6OkylcHiqNXe4GQVWrNNNE6
r1x+879jYs+IMHqxkKFpqocfSexyaFJCxI5gScQcB+Qgi1zNewQDwDU5lwBs
fapqPlp26tkrV0nbyy9/+cu2OVVjiQ8HRAIoYshNmLAUkhXSrRRLT3UucIR4
Ntrdya7FkmcNd3e8+xlLIiVAwBcc0foI/816Dd3lGhoaEpaUqTxl/6dWC4mC
U0N65PRIjGVEFyZgysNHho4xxwGbfnwi7j4NhAKgQXCM2d06O71SH6ZXjB4q
V47c7gkvrb2CF+hXhgJd/qq1t/C5y+6AcLqQ30TMKLB1+4VwBk+fsOMCkWVh
T3qOQ2kHCZFJumXLlsl8cBIszqtG+MJJ9LAaJTumu1Rvwuas+DFYFQGYqImI
2c65o2JOhNTmM/X7dX1IlXmNAOVt3Ehgi1tPwe7fuHt6yvqWTgZZ/JtuuknY
HX/YJicCk8k8lSL0fKXREdv7MI1HmvK5gb+NJtA2slXaVYbjfLBlQTQOBcdq
mRvtZecQ6sMcgqUCsmoe9iqAW8VeWq1/JblZW6E/fSjAyN576K8kHsOJIW+A
E3DwiYdGomnPu4//1NrEQQief+ZOWAO2U2jzB0UGawOuAHwd9+JVY5363rBp
8WmJ3g6TBgvxBW+++WYoj/An6IwVihivXl+I6NEDLl+O6FESawpltgrJ/oMS
gQy32Ucz2yN6xFRQwrJ06VJRx+B2gsxMc3vAcSQSoTcZA+R8gXbsUyCz9XEf
PCnnJYTzCE1Uzjc4wsveC2U9rAkgWc4M/+8j81BRsL5vu+22KDJfuQhAxSVt
3bR4T5q8rR4L0s1e5lXdZ3Qj0FjivcX/Q2Ae79/9Xz1yP5/jibigVEhHoEOg
mt+/+y9LxY42mp14EqwISgzIuZMnT9aGO/5rnRbWFOGOUCqnaWWAdhGGi+lt
v5WLW2/twA2zSKRo9F+XydM+c8P+Qmf8xBNPiFOFl/rqV78KIV5XWUh6t/8l
myWSpwgjoPDx4ynXkmKxx6xYjOMaJx42GCBnGSp8UuPMsPKzRYJBcH7qU5+S
P+dY2neVgfJKjVeoACsPvITSl3m07OJqUuDPA6HoYQ0IPg8f2Vn3R9zC5mO+
RMtZkX5r5gKTLcep89nXX399aetWyedUxtIGJqAvzMEb4LgZ9+vp2jjMnyTU
02H2oOWKEUxWGDlTTKAw2oiWx5JaLC/KyDaQflg6IltxpPvixYuTydBESTNY
p+PhYoLUkiZ7IXjvjVohyYkiGUmRyRcCaCfnvWN7cSQyKW457sT4k2YFkCBn
ChwHJBOqGONbW1ulJmgGwHEWQkU+TdWICD7CosMf5W7VaEmwHVeKSQcegURH
NArznBmi9CHqnYMHS5/97GdxIHuZJxLrYujXolbjJVQ2T9znkMp8qdGOaBzi
scwOJsW5Ow34QmqE23TNNddYgxSgPm+//fZIF+tRJ4w9Zdi2NQPHPE16BUCB
GCbOkyrbp6a1uOkvnrM0BceFwDHSKcwCRqlIp7VGny7XO33uc58z66m6jIk8
nWmhBgpcuO6YA/7Qqb6vL8F7ZlUfSwTVfXpQ74EaH9TTQfvDRP3xj388kybv
OOMdn+gXQx7dcMMNyA0H+5Rg9XOOLn8VgSuRsWb484qUa4Z07l0vPko4Tq71
+aaQ1LuwhwCJxMuDL/bt25cS8swwZqvHJWIJ6XunzAuKRdcJsiOcOKiJ2Chr
NDp0UHyicFyY+OI4GJRQ9/j0BX1+djBnjuwY4rzwJWd27IgKwDB5JRFEI5W5
pQ0bNpS+/vWv25rBZkA0k5/T+qQkJP2QTh+5btAx0E0gLneH2CMXv7QvAeTm
mw19bv3vBZy3LVoq3yKkK1pShADHe56Nxnmkw4GIZsA8kC4o3oJUNjdcprRE
WTiwLuVvJr0atZ7ROm84zcfOG0lzrW3OKYnPDwozQRyHhGmDorY5DuYfNTPp
pFLXDtA3fIHNmzfPhNvLtGU2sVxeampqEnkOWwuLBFYM6ggrY4oeUrkHhY4f
g6QdnSQ4a4OQ9+/jod1Bb5g3pMOE5wgKni4zuwzVHTidSQ+ZBB0amlhYKzr3
EDBu+uU6fZpBOKMOfwBBIkDCF8OJBcRvceND8ytpwPisNY/gODZlChswwltl
IIUEUglkCdMQ/E1iqBoYvT0giWBVZosptWXLltJ9990nZGd+UF12D3CWWD8e
XPP83Z207O99xf1tLNvSU25Ll0ZbjzoyoqKYCQ7ryAyY5Xw40U0FpgJmi8UI
xNPq1avFSdi4cWOcEtAQKI3s0Bajkq61C1xBkLbiodHugF3dUNaOGnlmRlm5
ubDBe6Ne8jGqlkvhbfA3IyKoBAqEbfbd735X+m64V8Kr2GtVZuCQGnStWPhI
ukB0Cs2PQGW4eX9/v928cjvpJyKqwFFGSflGmPixMg+U/Wq00w6WFcj3cxFV
eKujMaIKT1FLIm0BXsBZo+BzxNUccwclIIvJhYElVLVbWCgKwM5N48vM+gzj
opwqSugRmAqnqinYaFzYvIKvDooi6OZ6vVYrWG3nzp2yWVCYThRUA6s16Lml
KfoCyBh8WqLXYAvDBnULa2RQOejzxDRtECZRkq59S82UNHRBz1rrpvCJ6FrZ
qeb9e818+M96bdGiRVKYZCQpM1ikM04zbqqn0acLArQ6aJhcSBKQc25G43MO
hZm1xJkThsNOs5LjfH5xeRmpdErT7oQEZoqx8pEgnJGI6BEiPslRIJW7nmfK
Bz2byRPER0VWotYS0SYcIVGo5jjpfQjCpQ2RduguH9n5AKyA1LRI0iZ2tVgU
4fIBXYFUS7jMqAORfvDBOI9c3xTRD14LdhEK22JV4reN2eUy0yc7u1wfEo8Z
+UiQ0GUl44cxQU7bZ5Cfi6aNhlKt2l+H47zR+UA0zgumpyIqmilMKSN8I5+r
w5SmGR2ehK6QwAP4D143usTj/JFCrVggJjwqHWtLgS3bO5CPdUbuhFkhSRfh
/QIQDced7/il6KZwnS1fPJA0u0MEeijnK9FpmaDLFDgPhin+NV+rLPfLN/UA
mr3R88WUcHbiQCEhd9DM4alfR+P8adHHo/cJlQjpEFkRxpdJDzMLk9SHYRIb
Nw2kk+WwAiGJTwyyQQwxOIrubBjDltbq7dgCTcO1RBnYSgfDqvh+/+x/kwYh
yJnK0U8DOb6URwuvjRawaBudtwX0aGFv7xFkDdd3MHcyWuiwSoYEgUQ4Zgkm
gunkFmxauiFdVECJnCyrvO4Y3i896MKZIL9KoC+3RuMf0juW47xi2h7NGJ0n
2VWSpJEdx5hVHsegCs3EpVS3N1igxWAGoro4q5jCBTAtSomKwQxTM96qorCo
eoCq/7WkMN9t/wmMVi6OLwzeES02KIgRVz52OChT5DhExAhg4riwXv/bwfQg
CHXzZXplVZtsLD5deGCXfdIpH53ZxV3mZKA4GK3gnZHBZ3MnjusaOmrZeo7z
RUye9r+o211rBIMmSU3oEb5AmBDhJGo6HC/ybhk0gVmI0LXTEZGLlA3uoH1S
4YjRck5FVEMUy0BvAtgWVFtLtL5IZUrdazAOvx0pIzJp5OfsHefkJGgqSdl7
IrtZXwRwD7hqALDA6XFsGCzF32QtVNlb0AxAtJ4tuzgOcU4k0PuLHYb3hQ3s
qS5n46CKOrWlX9J5Ky/GrPOHbBxUEftikpoq4UGCcEc2HiSkIkr+KumLCzqr
jRJrgw8uLNBHZZx8w9tt3LhRci+wxZHcDB9VuayNsftp53xmbCBUmaCMBvqT
01WD0mgDdjvZJO1bnX/O3+opDPKJG40c6XklQ47zzfI8aonN1isdPggxAXEA
S/+WW24pc88YoSvzBWrdifIFAAWWyy9o0SYtLraCYydR6XpdFvwWqGck8D8d
/Pbt8z+LxqH5HTQrOOJPdZ4zhY5Uit9kQkf0nXnMaFlitEre5MKON4vp/T69
ltZZutL9q6V6gdPHJyZO00/T5IsiqqxwEPlDqNFO9bvcfXxRQgNKy5JRmOh6
xH89R1Q3zHslYbH2fOKrz2p30jr2V3sH6mimsTJclKpLLncjOSNejICSU912
DalRkF/34InoePXtv7+FNr6EF3EMe+fQIavwPXj+FwL8xz0RZcD3bvyXAk6r
BW7CXBu6XSPlBHsbgi1phzMjuEmcu8mKIlQ/g8tvAjtLpRGqv8fcrGdUfH4y
+Uf0zkieAP8VCppQIJFY/alTvxHDEiQHvJOzAlkFiLjWu+3/R6jyd2e/D2K1
CkGk1z4483WpLoEt4QxK62MRUmgt1WVRhjXDZap1keNXnCOnSu363fcF7AQk
M6KkW/7+S5Cd9i5oWIjAB5zarR/cCFlr38HCQGgMRL3j/VsRTtPeITMNWsyW
dSHXocejsyqqc/B0G3ROecZIfhSna68MYxTyVzmdlE2TV2b1j0p5alZk5HH7
P1rRwKjjyMTB3Alzt2BmoiBjpG+LdU6EC/veuf+pRyYOVKKwqm2uyqEjZS5X
bXk3lmYgag49DZ0My7R78Ji9CBDt8FpxNGlybUAEIRpg/lkNtBwGObi48DvB
Eo413DXHGHVX2BmGlfhLWQPFSIXCNEBymHyqktOtFeLJiVeiqoxHyP9XDbKU
PefxlGu0TtNIpYaUNW/DuGqZu1U9Sxff5p4KxHWlrgh7aOA7mFfPP//8hYEx
fOD2qjCVJDfJiE9UyjIxzZKmqzJuV+lRdSV8+uMKW5PxQyJ1Q1+jvsK8mVhJ
25+rdEtR/4JieU1gVSGOn/q1Jf9XytjM9KyQEAhQ47njlR4la/yvdcHSzopJ
+xEXOLRu6yvMeVGFxecCI46KRS5b4IwtjhY4M5FR7SwHEmzaEc9pvw2vTSPO
8qM5wsGP6rXQ1koD0T1YYREZlMKGIBKANGqlRLkukcyTEuWHP/yhmMb8Q2Dr
cV1pLAJMXH4Hw8Kt/pMVfnpryitYuxLnK8LnC/3ccEmIDXjmmWei+yI3+9WU
qQPrA322fPlyeR6qah7X70AkWFosC2rRUX37VIXfPa3fgagAx4KuxO9OnToV
PXuBzhtyB8yPT0/qNcBNsEX4tCxl3N/qNQhCrAM+fc3f2ztn16JxvoSEIfvh
lNCkQ2XvrFmzSkuWLBGy/MhHPiJjEHtglhJsAmvXLa9PmH3iUt0OXFjnzzWd
bdFr+FQIanzta1+r8+/yL4VbcR/8pYy7ZPPBZ6wsxoNCUOiMuBkOPfmVLmW1
udT43v61P516C3zGpkPgQQrBvcRP8Z1uuhhY6OGLx+BsFlzDlPEZPgoiRr+U
KV/3j7I8njT+1SXZKnwGMSNLduutt8rhGJDMmAul8/z58+Ue+A2MH6wL5oNr
t912m8c1G+gNofTQ3ECTkaVLl3rRP0eclVC3YnExSUiUBy/+FtQwOD8HgSuO
wd66Nfll5a/rL9UE5sjmgZhQxokYMQrjselIQ/+q8iwuwXv6rz8qpI1tQugW
t4M8RPoLs4MThJ88++yzOLLXDEu8MH4DuN1d/zgL8sAl2RbQMSYOCxSGB5QD
QujOQbf1Ao3T4cIfFJV7+S9k0zC0NVSCxeYvj14X80D012nKxRf16/qUNcBb
IOK8c+fONMoNvk5bopk+26u6xYv9e5AcEJaAm4pPVSZxcW/IB4Jm4ceePHnS
tg2mIEQY676UZmsl2Uu/Evdfgu3wZoQezWCvCncCXacYlleK5U+UYOVTJHl9
EhP6Ccb43Llz8Yp19cHr4q4I9cIZQBbE2beLL/yntFKxAkgoQTNAU/3kJz9R
AZf+3ayLfaTfHJQUhJuDcihkGxMyTX/8RbwVHw8ChfGZ9F7xHg1sAQQJSKCO
pLIJ9ENdgPsvav09XapFYW9IVUKroIwucZtUupwlT4LtAo3gFBAngHfEg5Fe
hFty5swZ9d1m9JNZwbsioE8NAKvsVxW+m3Whj/KqTNO1shRobACCcIZSxUfW
X+BrhISH606F1lHDQyJCWiKGR8L72Mc+RoCC1G7DqANI+q4P55UfuNBV9iob
IpNFqLg9fDdHrJHKxqOpsuGT/uAHP4hUtidnQNuQVkQTv/L1hqyHWQJvEibH
kgv8XbhPEPysUHGOdrT35d/NusDn+e+uEC8biwdJgDw+jH8Y4SgQdw5EpUdf
6Otcpo8Gx8M/AHQA/griCQgqIrlx7733cp9AeUjboPMk8B7AOjvTa96H++IP
XOCa8+WAS8cLIZEC5wu3B7HDCbJu554IQagwnlHXAZZat25dht3I0kikeAyE
FtsciJQB6Lxy5cpyu3Fmv06zqqCF4NGeOHEizWQLvi43VGb2bFre2CNwPFIP
OMIMIUf8i+bad1aeQE1vd3XWr+UzoujwJhARh6GI71FX4ERffUCb0E4IvMO1
xRDnKs/70N9+YS3Lf3XWBGQ4KBTtcvA9YO0IByIY716V/APqhDcPExPnoyJ1
6MGSGpa6RvQBwD0IZCAvjpA4JgoXDE1C8F4AAoGtMOZ73/ueMD7SFdAvP/rR
j/RlPnMp7iVvhkWDgwalARgc3hAsjtVwi+pDUtdVG3ZJXm1Bjc+6BK9lRSck
Sny6+xJuE9ssXIJ1s7kGfrOCipSyrhKdDTsVbahhjYAFQbP8DPZsamq6TOLd
sxkpFw7BEFTGLbyQW81Ju5V89oVT/nHgGFgX+DnGHDhwQGOd18qC4Br+UsZd
ijfjWcfVHuVuU3exr8ViFGhR7DuCOvMv3SaRrC7BqtlUIbSgVh955BHt1e5j
9PIfNnZkPY+Tl/7bL+oXELi4MxBo034t/1lS6WrdR/4/YqewlQ==\
\>"]]
}, Open  ]]
},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{1144, 801},
WindowMargins->{{46, Automatic}, {Automatic, 91}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
ShowSelection->True,
FrontEndVersion->"6.0 for Mac OS X x86 (32-bit) (June 19, 2007)",
StyleDefinitions->FrontEnd`FileName[{"Creative"}, "NaturalColor.nb", 
  CharacterEncoding -> "UTF-8"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 111, 3, 56, "Subtitle"],
Cell[CellGroupData[{
Cell[704, 28, 51, 1, 37, "Input"],
Cell[758, 31, 209, 3, 20, "Print"]
}, Open  ]],
Cell[982, 37, 253, 7, 71, "Text"],
Cell[1238, 46, 730, 16, 170, "Text"],
Cell[1971, 64, 27, 0, 31, "Subtitle"],
Cell[2001, 66, 54, 0, 72, "Section"],
Cell[2058, 68, 1898, 41, 65, "Input"],
Cell[3959, 111, 4661, 122, 546, "Input"],
Cell[CellGroupData[{
Cell[8645, 237, 772, 16, 83, "Input"],
Cell[9420, 255, 2281, 55, 36, "Print"],
Cell[11704, 312, 514137, 8598, 375, 419336, 7042, "CachedBoxData", "BoxData", \
"Print"]
}, Open  ]],
Cell[525856, 8913, 27, 0, 31, "Subtitle"],
Cell[525886, 8915, 926, 24, 53, "Input"],
Cell[526815, 8941, 3650, 98, 441, "Input"],
Cell[CellGroupData[{
Cell[530490, 9043, 728, 15, 37, "Input"],
Cell[531221, 9060, 608, 15, 37, "Output"]
}, Open  ]],
Cell[531844, 9078, 41, 0, 31, "Subtitle"],
Cell[CellGroupData[{
Cell[531910, 9082, 754, 16, 68, "Input"],
Cell[532667, 9100, 2240, 55, 36, "Print"],
Cell[534910, 9157, 554572, 9255, 375, 453708, 7600, "CachedBoxData", \
"BoxData", "Print"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
